@@ -64,7 +64,7 @@ int main(int, char *[])
 
   //  Software Guide : BeginLatex
   //
-  //  The following code is generating a sphere and assigning RGB values to
+  //  The following code generates a circle and assigns RGB values to
   //  the points. The components of the RGB values in this example are
   //  computed to represent the position of the points.
   //
@@ -81,7 +81,7 @@ int main(int, char *[])
 
   for(unsigned int i=0; i<360; i++)
     {
-    const double angle = i * vnl_math::pi / 180.0;
+    const double angle = i * itk::Math::pi / 180.0;
     point[0] = radius * std::sin( angle );
     point[1] = radius * std::cos( angle );
     point[2] = 1.0;
@@ -160,6 +160,6 @@ int main(int, char *[])
   //
   //  Software Guide : EndLatex
 
-  return 0;
+  return EXIT_SUCCESS;
 
 }
