@@ -128,9 +128,7 @@ protected:
   void PrintSelf( std::ostream& os, Indent indent ) const ITK_OVERRIDE;
 
 private:
-
-  CompositeExampleImageFilter(Self&);   // purposely not implemented
-  void operator=(const Self&);          // purposely not implemented
+  ITK_DISALLOW_COPY_AND_ASSIGN(CompositeExampleImageFilter);
 
 //  Software Guide : BeginLatex
 //
