@@ -53,31 +53,30 @@ void usage()
 {
   std::cerr << "\n";
   std::cerr << "Usage: DRR <options> [input]\n";
-  std::cerr << "       calculates the Digitally Reconstructed Radiograph from  \n";
-  std::cerr << "       a volume. \n\n";
-  std::cerr << "   where <options> is one or more of the following:\n\n";
-  std::cerr << "       <-h>                    Display (this) usage information\n";
-  std::cerr << "       <-v>                    Verbose output [default: no]\n";
-  std::cerr << "       <-res float float>      Pixel spacing of the output image [default: 1x1mm]  \n";
-  std::cerr << "       <-size int int>         Dimension of the output image [default: 501x501]  \n";
-  std::cerr << "       <-sid float>            Distance of ray source (focal point) [default: 400mm]\n";
-  std::cerr << "       <-t float float float>  Translation parameter of the camera \n";
-  std::cerr << "       <-rx float>             Rotation around x,y,z axis in degrees \n";
-  std::cerr << "       <-ry float>\n";
-  std::cerr << "       <-rz float>\n";
-  std::cerr << "       <-normal float float>   The 2D projection normal position [default: 0x0mm]\n";
-  std::cerr << "       <-cor float float float> The centre of rotation relative to centre of volume\n";
-  std::cerr << "       <-threshold float>      Threshold [default: 0]\n";
-  std::cerr << "       <-o file>               Output image filename\n\n";
-  std::cerr << "                               by  thomas@hartkens.de\n";
-  std::cerr << "                               and john.hipwell@kcl.ac.uk (CISG London)\n\n";
+  std::cerr << "  calculates the Digitally Reconstructed Radiograph from a volume. \n\n";
+  std::cerr << " where <options> is one or more of the following:\n\n";
+  std::cerr << "  <-h>                    Display (this) usage information\n";
+  std::cerr << "  <-v>                    Verbose output [default: no]\n";
+  std::cerr << "  <-res float float>      Pixel spacing of the output image [default: 1x1mm]  \n";
+  std::cerr << "  <-size int int>         Dimension of the output image [default: 501x501]  \n";
+  std::cerr << "  <-sid float>            Distance of ray source (focal point) [default: 400mm]\n";
+  std::cerr << "  <-t float float float>  Translation parameter of the camera \n";
+  std::cerr << "  <-rx float>             Rotation around x,y,z axis in degrees \n";
+  std::cerr << "  <-ry float>\n";
+  std::cerr << "  <-rz float>\n";
+  std::cerr << "  <-normal float float>   The 2D projection normal position [default: 0x0mm]\n";
+  std::cerr << "  <-cor float float float> The centre of rotation relative to centre of volume\n";
+  std::cerr << "  <-threshold float>      Threshold [default: 0]\n";
+  std::cerr << "  <-o file>               Output image filename\n\n";
+  std::cerr << "                          by  thomas@hartkens.de\n";
+  std::cerr << "                          and john.hipwell@kcl.ac.uk (CISG London)\n\n";
   exit(1);
 }
 
 int main( int argc, char *argv[] )
 {
-  char *input_name = NULL;
-  char *output_name = NULL;
+  char *input_name = ITK_NULLPTR;
+  char *output_name = ITK_NULLPTR;
 
   bool ok;
   bool verbose = false;
@@ -233,7 +232,7 @@ int main( int argc, char *argv[] )
     if (ok == false)
       {
 
-      if (input_name == NULL)
+      if (input_name == ITK_NULLPTR)
         {
         input_name = argv[1];
         argc--;
