@@ -60,8 +60,7 @@ protected:
   virtual void GenerateData( DOMNodeType* outputdom, const void* ) const ITK_OVERRIDE;
 
 private:
-  ParticleSwarmOptimizerDOMWriter(const Self &); //purposely not implemented
-  void operator=(const Self &); //purposely not implemented
+  ITK_DISALLOW_COPY_AND_ASSIGN(ParticleSwarmOptimizerDOMWriter);
 };
 
 } // namespace itk
