@@ -62,7 +62,7 @@ int main( int argc, char *argv[] )
     std::cerr << argv[0]
               << " inputImageFile outputImageFile"
               << std::endl;
-    return -1;
+    return EXIT_FAILURE;
     }
 
   // Software Guide : BeginLatex
@@ -96,9 +96,9 @@ int main( int argc, char *argv[] )
     }
   catch ( itk::ExceptionObject &err)
     {
-    std::cout << "ExceptionObject caught !" << std::endl;
-    std::cout << err << std::endl;
-    return -1;
+    std::cerr << "ExceptionObject caught !" << std::endl;
+    std::cerr << err << std::endl;
+    return EXIT_FAILURE;
     }
 
   // Software Guide : BeginLatex
@@ -159,9 +159,9 @@ int main( int argc, char *argv[] )
     }
   catch ( itk::ExceptionObject &err)
     {
-    std::cout << "ExceptionObject caught !" << std::endl;
-    std::cout << err << std::endl;
-    return -1;
+    std::cerr << "ExceptionObject caught !" << std::endl;
+    std::cerr << err << std::endl;
+    return EXIT_FAILURE;
 }
 
   // Software Guide : BeginLatex
@@ -184,5 +184,5 @@ int main( int argc, char *argv[] )
   //
   // Software Guide : EndLatex
 
-  return 0;
+  return EXIT_SUCCESS;
 }
