@@ -58,12 +58,14 @@ public:
   typedef itk::OnePlusOneEvolutionaryOptimizer OptimizerType;
   typedef   const OptimizerType *              OptimizerPointer;
 
-  void Execute(itk::Object *caller, const itk::EventObject & event)
+  void Execute(itk::Object *caller,
+               const itk::EventObject & event) ITK_OVERRIDE
     {
     Execute( (const itk::Object *)caller, event);
     }
 
-  void Execute(const itk::Object * object, const itk::EventObject & event)
+  void Execute(const itk::Object * object,
+               const itk::EventObject & event) ITK_OVERRIDE
     {
       OptimizerPointer optimizer =
         static_cast< OptimizerPointer >( object );
