@@ -30,6 +30,7 @@
 #include "itkTranslationTransform.h"
 #include "itkMattesMutualInformationImageToImageMetric.h"
 #include "itkAmoebaOptimizer.h"
+#include "itkMersenneTwisterRandomVariateGenerator.h"
 
 #include "itkImageFileReader.h"
 #include "itkImageFileWriter.h"
@@ -155,6 +156,9 @@ int main( int argc, char *argv[] )
   metric->SetNumberOfSpatialSamples( 10000 );
   // Software Guide : EndCodeSnippet
 
+  // For consistent results when regression testing.
+  metric->ReinitializeSeed(121212);
+
   if( argc > 6 )
     {
     // Define whether to calculate the metric derivative by explicitly
