@@ -47,6 +47,8 @@
 #include "itkGradientDescentOptimizer.h"
 // Software Guide : EndCodeSnippet
 
+#include "itkMersenneTwisterRandomVariateGenerator.h"
+
 
 //  Software Guide : BeginLatex
 //
@@ -380,6 +382,9 @@ int main( int argc, char *argv[] )
   // Software Guide : EndCodeSnippet
 
 
+  // For consistent results when regression testing.
+  metric->ReinitializeSeed(121212);
+
   //  Software Guide : BeginLatex
   //
   //  Since larger values of mutual information indicate better matches than
