@@ -34,7 +34,7 @@
 // class for performing registration of two $3D$ images.
 // The class \doxygen{CenteredTransformInitializer} is used to initialize the
 // center and translation of the transform.  The case of rigid registration of
-// 3D images is probably one of the most commonly found cases of image registration.
+// 3D images is probably one of the most common uses of image registration.
 //
 // \index{itk::Versor\-Rigid3D\-Transform}
 // \index{itk::Centered\-Transform\-Initializer!In 3D}
@@ -61,22 +61,22 @@
 //  Software Guide : BeginLatex
 //
 //  The parameter space of the \code{VersorRigid3DTransform} is not a vector
-//  space, due to the fact that addition is not a closed operation in the space
+//  space, because addition is not a closed operation in the space
 //  of versor components. Hence, we need to use Versor composition operation to
 //  update the first three components of the parameter array (rotation parameters),
 //  and Vector addition for updating the last three components of the parameters
 //  array (translation parameters)~\cite{Hamilton1866,Joly1905}.
 //
-//  In previous version of ITK, a special optimizer \doxygen{VersorRigid3DTransformOptimizer}
-//  was needed to be used in registration configuration to deal with the versor computations.
-//  However, in ITKv4, fortunately the \doxygen{RegularStepGradientDescentOptimizerv4}
-//  can be used for both vector and versor transforms optimization since in the new
-//  registration framework the task of updating parameters is delegated to the
-//  transforms themselves. The "UpdateTransformParameters" function is implemented
-//  in \doxygen{Transform} class as a virtual function, and all the derived transform
-//  classes can have their own specific implementations of this function. Due to this
-//  fact, the updating function can be re-implemented for the versor transforms in such
-//  a way that cab be able to handle the versor composition of the ratation parameters.
+//  In the previous version of ITK, a special optimizer, \doxygen{VersorRigid3DTransformOptimizer}
+//  was needed for registration to deal with versor computations.
+//  Fortunately in ITKv4, the \doxygen{RegularStepGradientDescentOptimizerv4}
+//  can be used for both vector and versor transform optimizations because, in the new
+//  registration framework, the task of updating parameters is delegated to the
+//  moving transform itself. The \code{UpdateTransformParameters} method is implemented
+//  in the \doxygen{Transform} class as a virtual function, and all the derived transform
+//  classes can have their own implementations of this function. Due to this
+//  fact, the updating function is re-implemented for versor transforms
+//  so it can handle versor composition of the rotation parameters.
 //
 //  Software Guide : EndLatex
 
@@ -110,14 +110,13 @@ protected:
 public:
   typedef itk::RegularStepGradientDescentOptimizerv4<double>  OptimizerType;
   typedef   const OptimizerType *                             OptimizerPointer;
-  void Execute(itk::Object *caller, const itk::EventObject & event)
+  void Execute(itk::Object *caller, const itk::EventObject & event) ITK_OVERRIDE
     {
     Execute( (const itk::Object *)caller, event);
     }
-  void Execute(const itk::Object * object, const itk::EventObject & event)
+  void Execute(const itk::Object * object, const itk::EventObject & event) ITK_OVERRIDE
     {
-    OptimizerPointer optimizer =
-      dynamic_cast< OptimizerPointer >( object );
+    OptimizerPointer optimizer = static_cast< OptimizerPointer >( object );
     if( ! itk::IterationEvent().CheckEvent( &event ) )
       {
       return;
@@ -181,7 +180,7 @@ int main( int argc, char *argv[] )
   //  Software Guide : BeginLatex
   //
   //  The initial transform object is constructed below. This transform will be initialized,
-  //  and its initial parameters will be considered as the parameters to be used when
+  //  and its initial parameters will be used when
   //  the registration process starts.
   //
   //  \index{itk::Versor\-Rigid3D\-Transform!Pointer}
@@ -223,11 +222,12 @@ int main( int argc, char *argv[] )
 
 
   // Software Guide : BeginCodeSnippet
-  typedef itk::CenteredTransformInitializer< TransformType,
-                                             FixedImageType,
-                                             MovingImageType >  TransformInitializerType;
+  typedef itk::CenteredTransformInitializer<
+    TransformType,
+    FixedImageType,
+    MovingImageType >  TransformInitializerType;
   TransformInitializerType::Pointer initializer =
-                                          TransformInitializerType::New();
+    TransformInitializerType::New();
   // Software Guide : EndCodeSnippet
 
 
@@ -300,9 +300,9 @@ int main( int argc, char *argv[] )
 
   //  Software Guide : BeginLatex
   //
-  //  Now the current parameters of the initial transform will be set
-  //  to the registration method, so they can be assigned to the optimizable
-  //  tranaform directly.
+  //  Now the current initialized transform will be set
+  //  to the registration method, so its initial parameters can be used to initialize
+  //  the registration process.
   //
   //  Software Guide : EndLatex
 
@@ -390,10 +390,10 @@ int main( int argc, char *argv[] )
   //  Let's execute this example over some of the images available in the
   //  following website
   //
-  //  \url{http://public.kitware.com/pub/itk/Data/BrainWeb}
+  //  \url{http://public.kitware.com/pub/itk/Data/BrainWeb}.
   //
   //  Note that the images in this website are compressed in \code{.tgz} files.
-  //  You should download these files an uncompress them in your local system.
+  //  You should download these files and decompress them in your local system.
   //  After decompressing and extracting the files you could take a pair of
   //  volumes, for example the pair:
   //
@@ -406,8 +406,11 @@ int main( int argc, char *argv[] )
   //  by $10$ degrees around the origin and shifting it $15mm$ in $X$.
   //
   //  Also, instead of doing the above steps manually, you can turn on the
-  //  "ITK\_USE\_BRAINWEB\_DATA" flag in your build environment. Then, the above
-  //  data will be loaded to your local build directory.
+  //  following flag in your build environment:
+  //
+  //  \code{ITK\_USE\_BRAINWEB\_DATA}
+  //
+  //  Then, the above data will be loaded to your local ITK build directory.
   //
   //  The registration takes $21$ iterations and produces:
   //
@@ -434,7 +437,7 @@ int main( int argc, char *argv[] )
   //  translation vector shown above.
   //
   //  It is more illustrative in this case to take a look at the actual
-  //  rotation matrix and offset resulting form the $6$ parameters.
+  //  rotation matrix and offset resulting from the $6$ parameters.
   //
   //  Software Guide : EndLatex
 
@@ -523,23 +526,23 @@ int main( int argc, char *argv[] )
   // \end{figure}
   //
   //  Figure \ref{fig:ImageRegistration8Plots} shows the plots of the main
-  //  output parameters of the registration process. The metric values at every
-  //  iteration. The Z component of the versor is plotted as an indication of
-  //  how the rotation progress. The X,Y translation components of the
+  //  output parameters of the registration process.
+  //  The Z component of the versor is plotted as an indication of
+  //  how the rotation progresses. The X,Y translation components of the
   //  registration are plotted at every iteration too.
   //
   //  Shell and Gnuplot scripts for generating the diagrams in
   //  Figure~\ref{fig:ImageRegistration8Plots} are available in the \code{ITKSoftwareGuide}
-  //  module under the directory
+  //  Git repository under the directory
   //
-  //  \code{SoftwareGuide/Art}
+  //  \code{ITKSoftwareGuide/SoftwareGuide/Art}.
   //
   //  You are strongly encouraged to run the example code, since only in this
-  //  way you can gain a first hand experience with the behavior of the
+  //  way can you gain first-hand experience with the behavior of the
   //  registration process. Once again, this is a simple reflection of the
   //  philosophy that we put forward in this book:
   //
-  //  \emph{If you can not replicate it, then it does not exist!}.
+  //  \emph{If you can not replicate it, then it does not exist!}
   //
   //  We have seen enough published papers with pretty pictures, presenting
   //  results that in practice are impossible to replicate. That is vanity, not
