@@ -404,15 +404,15 @@ public:
   typedef   itk::RegularStepGradientDescentOptimizer     OptimizerType;
   typedef   const OptimizerType *                        OptimizerPointer;
 
-  void Execute(itk::Object *caller, const itk::EventObject & event)
+  void Execute(itk::Object *caller, const itk::EventObject & event) ITK_OVERRIDE
     {
     Execute( (const itk::Object *)caller, event);
     }
 
-  void Execute(const itk::Object * object, const itk::EventObject & event)
+  void Execute(const itk::Object * object, const itk::EventObject & event) ITK_OVERRIDE
     {
     OptimizerPointer optimizer = static_cast< OptimizerPointer >( object );
-    if( ! itk::IterationEvent().CheckEvent( &event ) || optimizer == NULL )
+    if( ! itk::IterationEvent().CheckEvent( &event ) || optimizer == ITK_NULLPTR )
       {
       return;
       }
