@@ -91,12 +91,12 @@ public:
 
   // The Execute function simply calls another version of the \code{Execute()}
   // method accepting a \code{const} input object
-  void Execute( itk::Object * object, const itk::EventObject & event)
+  void Execute( itk::Object * object, const itk::EventObject & event) ITK_OVERRIDE
     {
     Execute( (const itk::Object *) object , event );
     }
 
-  void Execute(const itk::Object * object, const itk::EventObject & event)
+  void Execute(const itk::Object * object, const itk::EventObject & event) ITK_OVERRIDE
     {
     if( !(itk::MultiResolutionIterationEvent().CheckEvent( &event ) ) )
       {
@@ -143,12 +143,12 @@ public:
   typedef   itk::GradientDescentOptimizerv4Template<double>  OptimizerType;
   typedef   const OptimizerType *                            OptimizerPointer;
 
-  void Execute(itk::Object *caller, const itk::EventObject & event)
+  void Execute(itk::Object *caller, const itk::EventObject & event) ITK_OVERRIDE
     {
     Execute( (const itk::Object *)caller, event);
     }
 
-  void Execute(const itk::Object * object, const itk::EventObject & event)
+  void Execute(const itk::Object * object, const itk::EventObject & event) ITK_OVERRIDE
     {
     OptimizerPointer optimizer = static_cast< OptimizerPointer >( object );
     if( !(itk::IterationEvent().CheckEvent( &event )) )
