@@ -79,7 +79,7 @@
 // ShapeDetectionLevelSetImageFilter in
 // section~\ref{sec:ShapeDetectionLevelSetFilter}.
 //
-// The pipeline involves a first stage of smoothing using the
+// The pipeline involves a first stage of smoothing using the\newline
 // \doxygen{CurvatureAnisotropicDiffusionImageFilter}. The smoothed image is
 // passed as the input to the
 // \doxygen{GradientMagnitudeRecursiveGaussianImageFilter} and then to the
@@ -119,7 +119,7 @@
 
 int main( int argc, char *argv[] )
 {
-  if( argc < 10 )
+  if ( argc < 10 )
     {
     std::cerr << "Missing Parameters " << std::endl;
     std::cerr << "Usage: " << argv[0];
@@ -127,7 +127,7 @@ int main( int argc, char *argv[] )
     std::cerr << " seedX seedY InitialDistance";
     std::cerr << " Sigma SigmoidAlpha SigmoidBeta";
     std::cerr << " PropagationScaling"  << std::endl;
-    return 1;
+    return EXIT_SUCCESS;
     }
 
 
@@ -332,7 +332,7 @@ int main( int argc, char *argv[] )
   //  equivalent of a convolution with a Gaussian kernel, followed by a
   //  derivative operator. The sigma of this Gaussian can be used to control
   //  the range of influence of the image edges. This filter has been discussed
-  //  in Section~\ref{sec:GradientMagnitudeRecursiveGaussianImageFilter}
+  //  in Section~\ref{sec:GradientMagnitudeRecursiveGaussianImageFilter}.
 
   const double sigma = atof( argv[6] );
   gradientMagnitude->SetSigma(  sigma  );
@@ -487,6 +487,7 @@ int main( int argc, char *argv[] )
     {
     std::cerr << "Exception caught !" << std::endl;
     std::cerr << excep << std::endl;
+    return EXIT_FAILURE;
     }
   // Software Guide : EndCodeSnippet
 
@@ -604,5 +605,5 @@ int main( int argc, char *argv[] )
   //
   //  Software Guide : EndLatex
 
-  return 0;
+  return EXIT_SUCCESS;
 }
