@@ -82,7 +82,7 @@ int main( int , char *[] )
 // \code{GetNumberOfObjects()} function. This function takes two optional
 // arguments: the depth at which we should count the number of objects
 // (default is set to infinity) and the name of the object to count (default
-// is set to NULL).  This allows the user to count, for example, only
+// is set to ITK\_NULLPTR).  This allows the user to count, for example, only
 // ellipses.
 //
 // Software Guide : EndLatex
@@ -157,5 +157,5 @@ int main( int , char *[] )
 // Software Guide : EndCodeSnippet
 
 
-  return 0;
+  return EXIT_SUCCESS;
 }
