@@ -151,8 +151,7 @@ protected:
   virtual void * BufferPointerCallback() = 0;
 
 private:
-  VTKImageExportBase(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(VTKImageExportBase);
 
   /** Actual function sent to VTK as a callback.  Casts the user data
    * to a VTKImageExportBase pointer and invokes the corresponding
