@@ -55,7 +55,7 @@ namespace itk
  * \ingroup MeshSegmentation
  */
 template< typename TInputMesh, typename TOutputMesh >
-class BalloonForceFilter:public MeshToMeshFilter< TInputMesh, TOutputMesh >
+class ITK_TEMPLATE_EXPORT BalloonForceFilter:public MeshToMeshFilter< TInputMesh, TOutputMesh >
 {
 public:
   /** Standard class typedefs. */
@@ -192,8 +192,7 @@ protected:
   virtual void GenerateData();
 
 private:
-  BalloonForceFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BalloonForceFilter);
 
   /** These meshes are defined to hold the vectors as force, etc. */
   InputMeshPointer  m_Forces;
