@@ -63,8 +63,7 @@ protected:
   ~DicomImageIOFactory();
 
 private:
-  DicomImageIOFactory(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(DicomImageIOFactory);
 };
 } // end namespace itk
 
