@@ -58,7 +58,7 @@ namespace itk
  */
 
 template< unsigned int VImageDimension >
-class ImageRegionMultidimensionalSplitter:public ImageRegionSplitter< VImageDimension >
+class ITK_TEMPLATE_EXPORT ImageRegionMultidimensionalSplitter:public ImageRegionSplitter< VImageDimension >
 {
 public:
   /** Standard class typedefs. */
@@ -106,8 +106,7 @@ protected:
   void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  ImageRegionMultidimensionalSplitter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ImageRegionMultidimensionalSplitter);
 
   static unsigned int ComputeSplits(unsigned int numberOfPieces,
                                     const RegionType &region,
