@@ -35,7 +35,7 @@ namespace itk
  * \ingroup SingleThreaded
  */
 template< typename TInputImage, typename TOutputImage >
-class ReflectImageFilter:public ImageToImageFilter< TInputImage, TOutputImage >
+class ITK_TEMPLATE_EXPORT ReflectImageFilter:public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
   /** Standard class typedefs. */
@@ -92,8 +92,7 @@ protected:
   void GenerateData();
 
 private:
-  ReflectImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ReflectImageFilter);
 
   unsigned int m_Direction;
 };
