@@ -79,7 +79,7 @@ template< typename TInputImage,
           typename TOutputImage = Image< TRealType,
                                          TInputImage::ImageDimension >
           >
-class DeformationFieldJacobianDeterminantFilter:
+class ITK_TEMPLATE_EXPORT DeformationFieldJacobianDeterminantFilter:
   public DisplacementFieldJacobianDeterminantFilter< TInputImage, TRealType, TOutputImage >
 {
 public:
@@ -141,8 +141,7 @@ protected:
   virtual ~DeformationFieldJacobianDeterminantFilter() {}
 
 private:
-  DeformationFieldJacobianDeterminantFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(DeformationFieldJacobianDeterminantFilter);
 };
 } // end namespace itk
 
