@@ -51,7 +51,7 @@ namespace itk
  * \ingroup ITKV3Compatibility
  */
 template< typename TOutputImage >
-class DeformationFieldSource:
+class ITK_TEMPLATE_EXPORT DeformationFieldSource:
   public ImageSource< TOutputImage >
 {
 public:
@@ -143,7 +143,7 @@ public:
   virtual void GenerateOutputInformation();
 
   /** Method Compute the Modified Time based on changed to the components. */
-  unsigned long GetMTime() const;
+  ModifiedTimeType GetMTime() const;
 
 protected:
   DeformationFieldSource();
@@ -162,8 +162,7 @@ protected:
   void PrepareKernelBaseSpline();
 
 private:
-  DeformationFieldSource(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(DeformationFieldSource);
 
   KernelTransformPointerType m_KernelTransform;      // Coordinate transform to
                                                      // use
