@@ -65,7 +65,7 @@ namespace itk
  * \ingroup ITKV3Compatibility
  */
 template< typename TInputImage, typename TOutputImage >
-class ExponentialDeformationFieldImageFilter:
+class ITK_TEMPLATE_EXPORT ExponentialDeformationFieldImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -175,8 +175,7 @@ protected:
   typedef typename AdderType::Pointer                AdderPointer;
 
 private:
-  ExponentialDeformationFieldImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ExponentialDeformationFieldImageFilter);
 
   bool         m_AutomaticNumberOfIterations;
   unsigned int m_MaximumNumberOfIterations;
