@@ -53,7 +53,7 @@ namespace itk
  */
 
 template< typename TInputImage, typename TOutputImage >
-class IterativeInverseDeformationFieldImageFilter:
+class ITK_TEMPLATE_EXPORT IterativeInverseDeformationFieldImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -128,8 +128,7 @@ protected:
   double m_Time;
 
 private:
-  IterativeInverseDeformationFieldImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(IterativeInverseDeformationFieldImageFilter);
 };
 } // end namespace itk
 
