@@ -43,7 +43,7 @@ class foo
 // This structure will generate a compiler error if the template
 // argument is false
 template<bool t> struct OnlyTrue;
-template<> struct OnlyTrue<true> { static ITK_CONSTEXPR bool Result = true; };
+template<> struct OnlyTrue<true> { static bool Result = true; };
 
 
 int main()
