@@ -40,7 +40,7 @@ namespace itk
  * \ingroup ITKCommon
  */
 template< unsigned int VSplineOrder = 3, typename TRealValueType = double >
-class BSplineKernelFunction:public KernelFunctionBase<TRealValueType>
+class ITK_TEMPLATE_EXPORT BSplineKernelFunction:public KernelFunctionBase<TRealValueType>
 {
 public:
   /** Standard class typedefs. */
@@ -59,7 +59,7 @@ public:
   itkStaticConstMacro(SplineOrder, unsigned int, VSplineOrder);
 
   /** Evaluate the function. */
-  inline TRealValueType Evaluate(const TRealValueType & u) const ITK_OVERRIDE
+  TRealValueType Evaluate(const TRealValueType & u) const ITK_OVERRIDE
   {
     return this->Evaluate(Dispatch< VSplineOrder >(), u);
   }
@@ -74,8 +74,7 @@ protected:
   }
 
 private:
-  BSplineKernelFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BSplineKernelFunction);
 
   /** Structures to control overloaded versions of Evaluate */
   struct DispatchBase {};
