@@ -101,7 +101,7 @@ template<
   typename TPixelType,
   typename TCellTraits
   >
-class CellInterface
+class ITK_TEMPLATE_EXPORT CellInterface
 {
 public:
 
@@ -444,8 +444,7 @@ protected:
   UsingCellsContainer m_UsingCells;
 
 private:
-  CellInterface(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(CellInterface);
 };
 
 /** \class CellTraitsInfo
@@ -471,7 +470,7 @@ template< int VPointDimension, typename TCoordRep,
           typename TCellIdentifier, typename TCellFeatureIdentifier,
           typename TPoint, typename TPointsContainer,
           typename TUsingCellsContainer >
-class CellTraitsInfo
+class ITK_TEMPLATE_EXPORT CellTraitsInfo
 {
 public:
   itkStaticConstMacro(PointDimension, unsigned int, VPointDimension);
