@@ -25,8 +25,8 @@
  *  please refer to the NOTICE file at the top of the ITK source tree.
  *
  *=========================================================================*/
-#ifndef __itkConceptChecking_h
-#define __itkConceptChecking_h
+#ifndef itkConceptChecking_h
+#define itkConceptChecking_h
 
 #include "itkPixelTraits.h"
 #include "itkNumericTraits.h"
@@ -256,8 +256,11 @@ struct EqualityComparable {
   struct Constraints {
     void constraints()
     {
+CLANG_PRAGMA_PUSH
+CLANG_SUPPRESS_Wfloat_equal
       Detail::RequireBooleanExpression(a == b);
       Detail::RequireBooleanExpression(a != b);
+CLANG_PRAGMA_POP
     }
 
     T1 a;
@@ -278,8 +281,11 @@ struct Comparable {
       Detail::RequireBooleanExpression(a > b);
       Detail::RequireBooleanExpression(a <= b);
       Detail::RequireBooleanExpression(a >= b);
+CLANG_PRAGMA_PUSH
+CLANG_SUPPRESS_Wfloat_equal
       Detail::RequireBooleanExpression(a == b);
       Detail::RequireBooleanExpression(a != b);
+CLANG_PRAGMA_POP
     }
 
     T1 a;
@@ -655,7 +661,7 @@ struct HasZero {
     {
       T a;
 
-      a = NumericTraits< T >::Zero;
+      a = NumericTraits< T >::ZeroValue();
       Detail::IgnoreUnusedVariable(a);
     }
   };
