@@ -35,8 +35,9 @@
 
 namespace itk
 {
-class ProcessObject;
-class DataObject;
+// Forward reference because of circular dependencies
+class ITK_FORWARD_EXPORT ProcessObject;
+class ITK_FORWARD_EXPORT DataObject;
 
 /*--------------------Data Object Exceptions---------------------------*/
 
@@ -53,7 +54,7 @@ public:
 
   /** Destructor. Need to specify empty throw() to avoid warnings. */
   virtual ~DataObjectError()
-  ITK_NOEXCEPT {}
+  ITK_NOEXCEPT_OR_THROW {}
 
   /** Constructor. Needed to ensure the exception object can be copied. */
   DataObjectError(const char *file, unsigned int lineNumber);
@@ -80,7 +81,7 @@ protected:
   /** Print exception information.  This method can be overridden by
    * specific exception subtypes.  The default is to print out the
    * location where the exception was first thrown and any description
-   * provided by the ``thrower''.   */
+   * provided by the "thrower".   */
   virtual void PrintSelf(std::ostream & os, Indent indent) const;
 
 private:
@@ -102,7 +103,7 @@ public:
 
   /** Destructor. Need to specify empty throw() to avoid warnings. */
   virtual ~InvalidRequestedRegionError()
-  ITK_NOEXCEPT {}
+  ITK_NOEXCEPT_OR_THROW {}
 
   /** Constructor. Needed to ensure the exception object can be copied. */
   InvalidRequestedRegionError(const char *file, unsigned int lineNumber);
@@ -123,7 +124,7 @@ protected:
   /** Print exception information.  This method can be overridden by
    * specific exception subtypes.  The default is to print out the
    * location where the exception was first thrown and any description
-   * provided by the ``thrower''.   */
+   * provided by the "thrower".   */
   virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 };
 
@@ -272,7 +273,7 @@ protected:
  * \ingroup ITKSystemObjects
  * \ingroup ITKCommon
  */
-class ITKCommon_EXPORT DataObject:public Object
+class ITK_FORCE_EXPORT_MACRO(ITKCommon) DataObject:public Object
 {
 public:
   /** Standard class typedefs. */
@@ -480,15 +481,14 @@ public:
 
 protected:
   DataObject();
-  ~DataObject();
+  virtual ~DataObject();
   virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
   /** Propagate a call to ResetPipeline(). Called only from ProcessObject. */
   virtual void PropagateResetPipeline();
 
 private:
-  DataObject(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(DataObject);
 
   /** Who generated this data? */
   WeakPointer< ProcessObject > m_Source;
