@@ -63,7 +63,7 @@ namespace itk
  *  \ingroup ITKCommon
  */
 template< typename TDomainPartitioner, typename TAssociate >
-class DomainThreader: public Object
+class ITK_TEMPLATE_EXPORT DomainThreader: public Object
 {
 public:
   /** Standard class typedefs. */
@@ -144,8 +144,7 @@ protected:
   AssociateType * m_Associate;
 
 private:
-  DomainThreader( const Self & ) ITK_DELETE_FUNCTION;
-  void operator=( const Self & ) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(DomainThreader);
 
   void StartThreadingSequence();
 
