@@ -87,8 +87,7 @@ protected:
   bool m_Append;
 
 private:
-  FileOutputWindow(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(FileOutputWindow);
 };
 } // end namespace itk
 
