@@ -37,7 +37,7 @@ namespace itk
 
 template< unsigned int VDimension = 3,
           typename TInput = Point< double, VDimension > >
-class FiniteCylinderSpatialFunction:
+class ITK_TEMPLATE_EXPORT FiniteCylinderSpatialFunction:
   public InteriorExteriorSpatialFunction< VDimension, TInput >
 {
 public:
@@ -98,8 +98,7 @@ protected:
 
 private:
 
-  FiniteCylinderSpatialFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(FiniteCylinderSpatialFunction);
 
   /** The center of the cylinder. */
   InputType m_Center;
