@@ -41,7 +41,7 @@ namespace itk
  * \ingroup ITKCommon
  */
 template< typename TInput, typename TOutput >
-class FunctionBase:public Object
+class ITK_TEMPLATE_EXPORT FunctionBase:public Object
 {
 public:
   /** Standard class typedefs. */
@@ -67,8 +67,7 @@ protected:
   ~FunctionBase(){}
 
 private:
-  FunctionBase(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(FunctionBase);
 };
 } // end namespace itk
 
