@@ -72,7 +72,7 @@ namespace itk
  * \endwiki
  */
 template< typename TPixel, unsigned int VImageDimension = 2 >
-class Image:public ImageBase< VImageDimension >
+class ITK_TEMPLATE_EXPORT Image:public ImageBase< VImageDimension >
 {
 public:
   /** Standard class typedefs */
@@ -249,7 +249,7 @@ public:
    * simply calls CopyInformation() and copies the region ivars.
    * The implementation here refers to the superclass' implementation
    * and then copies over the pixel container. */
-  virtual void Graft(const DataObject *data) ITK_OVERRIDE;
+  virtual void Graft(const Self *data);
 
   /** Return the Pixel Accessor object */
   AccessorType GetPixelAccessor(void)
@@ -272,6 +272,7 @@ public:
 protected:
   Image();
   void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
+  virtual void Graft(const DataObject *data) ITK_OVERRIDE;
 
   virtual ~Image() {}
 
@@ -281,10 +282,9 @@ protected:
    * behavior in classes that did not used to take image orientation into
    * account.  */
   virtual void ComputeIndexToPhysicalPointMatrices() ITK_OVERRIDE;
-
+  using Superclass::Graft;
 private:
-  Image(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(Image);
 
   /** Memory for the current buffer. */
   PixelContainerPointer m_Buffer;
