@@ -49,10 +49,9 @@
 
 namespace itk
 {
-
 /* Forward declaration (ImageTransformHelper include's ImageBase) */
 template< unsigned int NImageDimension, unsigned int R, unsigned int C, typename TPointValue, typename TMatrixValue >
-class ImageTransformHelper;
+class ITK_FORWARD_EXPORT ImageTransformHelper;
 
 /** \class ImageBase
  * \brief Base class for templated image classes.
@@ -112,7 +111,7 @@ class ImageTransformHelper;
  * \ingroup ITKCommon
  */
 template< unsigned int VImageDimension = 2 >
-class ImageBase:public DataObject
+class ITK_TEMPLATE_EXPORT ImageBase:public DataObject
 {
 public:
   /** Standard typedefs. */
@@ -608,7 +607,7 @@ public:
    * simply calls CopyInformation() and copies the region ivars.
    * Subclasses of ImageBase are responsible for copying the pixel
    * container. */
-  virtual void Graft(const DataObject *data) ITK_OVERRIDE;
+  virtual void Graft(const Self *data);
 
   /** Update the information for this DataObject so that it can be used
    * as an output of a ProcessObject.  This method is used the pipeline
@@ -755,9 +754,10 @@ protected:
     return index;
     }
 
+  virtual void Graft(const DataObject *data) ITK_OVERRIDE;
+
 private:
-  ImageBase(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ImageBase);
 
   void InternalSetSpacing(const SpacingValueType spacing[VImageDimension])
     {
