@@ -51,7 +51,7 @@ namespace itk
  * \endwiki
  */
 template< typename TInputImage >
-class ImageDuplicator:public Object
+class ITK_TEMPLATE_EXPORT ImageDuplicator:public Object
 {
 public:
   /** Standard class typedefs. */
@@ -89,8 +89,7 @@ protected:
   virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  ImageDuplicator(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ImageDuplicator);
 
   ImageConstPointer m_InputImage;
   ImagePointer      m_Output;
