@@ -124,7 +124,7 @@ namespace itk
  * \endwiki
  */
 template< typename TImage >
-class ImageRegionConstIteratorWithIndex:public ImageConstIteratorWithIndex< TImage >
+class ITK_TEMPLATE_EXPORT ImageRegionConstIteratorWithIndex:public ImageConstIteratorWithIndex< TImage >
 {
 public:
   /** Standard class typedefs. */
