@@ -69,7 +69,7 @@ namespace itk
  * \ingroup ITKCommon
  */
 template< typename TInputImage, typename TOutputImage = TInputImage >
-class InPlaceImageFilter:public ImageToImageFilter< TInputImage, TOutputImage >
+class ITK_TEMPLATE_EXPORT InPlaceImageFilter:public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
   /** Standard class typedefs. */
@@ -160,8 +160,7 @@ protected:
   itkGetConstMacro(RunningInPlace,bool);
 
 private:
-  InPlaceImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(InPlaceImageFilter);
 
   // the type are different we can't run in place
   void InternalAllocateOutputs( const FalseType& )
