@@ -46,7 +46,7 @@ namespace itk
  */
 
 template< unsigned int VDimension = 3, typename TInput = Point< double, VDimension > >
-class InteriorExteriorSpatialFunction:public
+class ITK_TEMPLATE_EXPORT InteriorExteriorSpatialFunction:public
   SpatialFunction< bool, VDimension, TInput >
 {
 public:
@@ -77,8 +77,7 @@ protected:
   void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  InteriorExteriorSpatialFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(InteriorExteriorSpatialFunction);
 };
 } // end namespace itk
 
