@@ -39,7 +39,7 @@ namespace itk
  */
 
 template< typename TCellInterface >
-class LineCell:public TCellInterface
+class ITK_TEMPLATE_EXPORT LineCell:public TCellInterface
 {
 public:
   /** Standard class typedefs. */
@@ -107,8 +107,7 @@ protected:
   PointIdentifier m_PointIds[NumberOfPoints];
 
 private:
-  LineCell(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(LineCell);
 };
 } // end namespace itk
 
