@@ -70,7 +70,7 @@ namespace itk
  * \ingroup ITKCommon
  */
 template< typename MetaDataObjectType >
-class ITKCommon_TEMPLATE_EXPORT MetaDataObject:public MetaDataObjectBase
+class ITK_TEMPLATE_EXPORT MetaDataObject:public MetaDataObjectBase
 {
 public:
   /** Smart pointer typedef support. */
@@ -126,8 +126,7 @@ protected:
   virtual ~MetaDataObject();
 
 private:
-  MetaDataObject(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(MetaDataObject);
 
   /**
    * A variable to store this derived type.
@@ -258,7 +257,7 @@ inline bool ExposeMetaData(const MetaDataDictionary & Dictionary, const std::str
 //
 #  if defined( ITKCommon_EXPORTS )
 //   We are building this library
-#    define ITKCommon_EXPORT_EXPLICIT
+#    define ITKCommon_EXPORT_EXPLICIT ITK_TEMPLATE_EXPORT
 #  else
 //   We are using this library
 #    define ITKCommon_EXPORT_EXPLICIT ITKCommon_EXPORT
