@@ -34,8 +34,10 @@
 
 namespace itk
 {
+// Forward reference because of private implementation
 class SubjectImplementation;
-class Command;
+// Forward reference because of circular dependencies
+class ITK_FORWARD_EXPORT Command;
 
 /** \class Object
  * \brief Base class for most ITK classes.
@@ -88,7 +90,7 @@ public:
   /** Set the value of the debug flag. A non-zero value turns debugging on. */
   void SetDebug(bool debugFlag) const;
 
-  /** Return this objects modified time.  */
+  /** Return this object's modified time.  */
   virtual ModifiedTimeType GetMTime() const;
 
   /** Return this object's time stamp.  */
@@ -197,8 +199,7 @@ protected:
   virtual void SetTimeStamp( const TimeStamp & time );
 
 private:
-  Object(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(Object);
 
   /** Enable/Disable debug messages. */
   mutable bool m_Debug;
