@@ -53,6 +53,7 @@ namespace itk
  * \ingroup ITKCommon
  */
 
+// Forward reference because of private implementation
 class OverRideMap;
 
 class ITKCommon_EXPORT ObjectFactoryBase:public Object
@@ -221,8 +222,7 @@ protected:
 private:
   OverRideMap *m_OverrideMap;
 
-  ObjectFactoryBase(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ObjectFactoryBase);
 
   /** Initialize the static list of Factories. */
   static void InitializeFactoryList();
