@@ -60,7 +60,7 @@ namespace itk
  * \ingroup ITKCommon
  */
 template< typename TObjectType >
-class ObjectStore:public Object
+class ITK_TEMPLATE_EXPORT ObjectStore:public Object
 {
 public:
   /** Standard typedefs. */
@@ -150,8 +150,7 @@ protected:
   };
 
 private:
-  ObjectStore(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ObjectStore);
 
   GrowthStrategyType m_GrowthStrategy;
 
