@@ -46,7 +46,7 @@ enum OctreePlaneType {
  *
  * \ingroup ITKCommon
  */
-class OctreeBase:public Object
+class ITKCommon_EXPORT OctreeBase:public Object
 {
 public:
   /** Standard class typedefs. */
@@ -111,7 +111,7 @@ public:
  * \ingroup ITKCommon
  */
 template< typename TPixel, unsigned int ColorTableSize, typename MappingFunctionType >
-class Octree:public OctreeBase
+class ITK_TEMPLATE_EXPORT Octree:public OctreeBase
 {
 public:
   /** Standard class typedefs. */
@@ -157,8 +157,7 @@ public:
   virtual int GetColorTableSize() const ITK_OVERRIDE;
 
 private:
-  Octree(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(Octree);
 
   OctreeNodeBranch * maskToOctree(const TPixel *Mask, unsigned width, unsigned x,
                                   unsigned y, unsigned z, unsigned xsize,
