@@ -81,7 +81,7 @@ template<
   unsigned int VDimension = 3,
   typename TMeshTraits = DefaultStaticMeshTraits< TPixelType, VDimension, VDimension >
   >
-class PointSet:public DataObject
+class ITK_TEMPLATE_EXPORT PointSet:public DataObject
 {
 public:
   /** Standard class typedefs. */
@@ -226,8 +226,7 @@ protected:
   RegionType m_RequestedRegion;
 
 private:
-  PointSet(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(PointSet);
 };                              // End Class: PointSet
 } // end namespace itk
 
