@@ -50,7 +50,7 @@ namespace itk
  * \ingroup ITKCommon
  */
 template< typename TCellInterface >
-class PolygonCell:public TCellInterface
+class ITK_TEMPLATE_EXPORT PolygonCell:public TCellInterface
 {
 public:
   /** Standard class typedefs. */
@@ -138,8 +138,7 @@ protected:
   std::vector< PointIdentifier > m_PointIds;
 
 private:
-  PolygonCell(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(PolygonCell);
 };
 } //end namespace
 
