@@ -34,7 +34,7 @@ namespace itk
  * \ingroup ITKCommon
  */
 template< typename TCellInterface >
-class QuadraticEdgeCell:public TCellInterface
+class ITK_TEMPLATE_EXPORT QuadraticEdgeCell:public TCellInterface
 {
 public:
   /** Standard class typedefs. */
@@ -108,8 +108,7 @@ protected:
   PointIdentifier m_PointIds[NumberOfPoints];
 
 private:
-  QuadraticEdgeCell(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(QuadraticEdgeCell);
 };
 } // end namespace itk
 
