@@ -36,7 +36,7 @@ namespace itk
  */
 
 template< typename TCellInterface >
-class QuadrilateralCell:public TCellInterface, private QuadrilateralCellTopology
+class ITK_TEMPLATE_EXPORT QuadrilateralCell:public TCellInterface, private QuadrilateralCellTopology
 {
 public:
   /** Standard class typedefs. */
@@ -127,8 +127,7 @@ protected:
                         CoordRepType x[PointDimension], InterpolationWeightType * weights);
 
 private:
-  QuadrilateralCell(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(QuadrilateralCell);
 };
 } // end namespace itk
 
