@@ -44,7 +44,7 @@ namespace itk
 template< typename TOutput,
           unsigned int VImageDimension = 3,
           typename TInput = Point< double, VImageDimension > >
-class SpatialFunction:public FunctionBase< TInput, TOutput >
+class ITK_TEMPLATE_EXPORT SpatialFunction:public FunctionBase< TInput, TOutput >
 {
 public:
   /** Standard class typedefs. */
@@ -75,8 +75,7 @@ protected:
   void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  SpatialFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(SpatialFunction);
 };
 } // end namespace itk
 
