@@ -15,8 +15,8 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __itkSymmetricEllipsoidInteriorExteriorSpatialFunction_h
-#define __itkSymmetricEllipsoidInteriorExteriorSpatialFunction_h
+#ifndef itkSymmetricEllipsoidInteriorExteriorSpatialFunction_h
+#define itkSymmetricEllipsoidInteriorExteriorSpatialFunction_h
 
 #include "itkInteriorExteriorSpatialFunction.h"
 
@@ -37,7 +37,7 @@ namespace itk
  */
 template< unsigned int VDimension = 3,
           typename TInput = Point< double, VDimension > >
-class SymmetricEllipsoidInteriorExteriorSpatialFunction:
+class ITK_TEMPLATE_EXPORT SymmetricEllipsoidInteriorExteriorSpatialFunction:
   public InteriorExteriorSpatialFunction< VDimension, TInput >
 {
 public:
@@ -61,7 +61,7 @@ public:
   typedef typename Superclass::OutputType OutputType;
 
   /** Evaluates the function at a given position. */
-  OutputType Evaluate(const InputType & position) const;
+  OutputType Evaluate(const InputType & position) const ITK_OVERRIDE;
 
   /** Get and set the center of the ellipsoid. */
   itkGetConstMacro(Center, InputType);
@@ -75,7 +75,7 @@ protected:
   SymmetricEllipsoidInteriorExteriorSpatialFunction();
   virtual ~SymmetricEllipsoidInteriorExteriorSpatialFunction();
 
-  void PrintSelf(std::ostream & os, Indent indent) const;
+  void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
   SymmetricEllipsoidInteriorExteriorSpatialFunction(const Self &); //purposely
