@@ -34,7 +34,7 @@ namespace itk
  * \ingroup ITKCommon
  */
 template< typename TCellInterface >
-class TetrahedronCell:public TCellInterface, private TetrahedronCellTopology
+class ITK_TEMPLATE_EXPORT TetrahedronCell:public TCellInterface, private TetrahedronCellTopology
 {
 public:
   /** Standard class typedefa. */
@@ -127,8 +127,7 @@ protected:
   PointIdentifier m_PointIds[NumberOfPoints];
 
 private:
-  TetrahedronCell(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(TetrahedronCell);
 };
 } // end namespace itk
 
