@@ -23,8 +23,9 @@
 namespace itk
 {
 
+// Forward reference because of circular dependencies
 template< typename TIterator >
-class ThreadedIteratorRangePartitioner;
+class ITK_TEMPLATE_EXPORT ThreadedIteratorRangePartitioner;
 
 /** \class ThreadedIteratorRangePartitionerDomain
  * \brief Domain type for the ThreadedIteratorRangePartitioner.
@@ -34,7 +35,7 @@ class ThreadedIteratorRangePartitioner;
  * \ingroup ITKCommon
  */
 template< typename TIterator >
-class ThreadedIteratorRangePartitionerDomain
+class ITK_TEMPLATE_EXPORT ThreadedIteratorRangePartitionerDomain
 {
 public:
   typedef TIterator                              IteratorType;
@@ -104,7 +105,7 @@ private:
  * \ingroup ITKCommon
  */
 template< typename TIterator >
-class ThreadedIteratorRangePartitioner
+class ITK_TEMPLATE_EXPORT ThreadedIteratorRangePartitioner
   : public ThreadedDomainPartitioner< ThreadedIteratorRangePartitionerDomain< TIterator > >
 {
 public:
@@ -147,8 +148,7 @@ protected:
   virtual ~ThreadedIteratorRangePartitioner();
 
 private:
-  ThreadedIteratorRangePartitioner(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ThreadedIteratorRangePartitioner);
 
 };
 
