@@ -30,6 +30,7 @@
 
 #include "itkMacro.h"
 #include "itkIntTypes.h"
+#include "itkAtomicInt.h"
 
 namespace itk
 {
@@ -61,6 +62,8 @@ public:
   /** Standard class typedefs. */
   typedef TimeStamp Self;
 
+  typedef AtomicInt< ModifiedTimeType > GlobalTimeStampType;
+
   /** Create an instance of this class. We don't want to use reference
    * counting. */
   static Self * New();
@@ -105,8 +108,19 @@ public:
    * another. */
   const Self & operator=( const Self & other );
 
+  /** Set/Get the pointer to GlobalTimeStamp.
+   * Note that SetGlobalTimeStamp is not concurrent thread safe. */
+  static GlobalTimeStampType * GetGlobalTimeStamp();
+  static void SetGlobalTimeStamp( GlobalTimeStampType * timeStamp );
+
 private:
   ModifiedTimeType m_ModifiedTime;
+
+  /** The static GlobalTimeStamp. This is initialized to NULL as the first
+   * stage of static initialization. It is then populated on the first call to
+   * itk::TimeStamp::Modified() but it can be overridden with SetGlobalTimeStamp().
+   * */
+  static GlobalTimeStampType * m_GlobalTimeStamp;
 };
 } // end namespace itk
 
