@@ -40,7 +40,7 @@ namespace itk
  * \ingroup ITKCommon
  */
 template< typename TValue >
-class TreeNode:public Object
+class ITK_TEMPLATE_EXPORT TreeNode:public Object
 {
 public:
 
@@ -128,8 +128,7 @@ protected:
   ChildrenListType m_Children;
 
 private:
-  TreeNode(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(TreeNode);
 };
 } // end namespace itk
 
