@@ -46,7 +46,7 @@ namespace itk
  * \endwiki
  */
 template< typename TInputImage, typename TOutputImage, typename TFunction >
-class UnaryFunctorImageFilter:public InPlaceImageFilter< TInputImage, TOutputImage >
+class ITK_TEMPLATE_EXPORT UnaryFunctorImageFilter:public InPlaceImageFilter< TInputImage, TOutputImage >
 {
 public:
   /** Standard class typedefs. */
@@ -124,8 +124,7 @@ protected:
                             ThreadIdType threadId) ITK_OVERRIDE;
 
 private:
-  UnaryFunctorImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(UnaryFunctorImageFilter);
 
   FunctorType m_Functor;
 };
