@@ -89,8 +89,7 @@ protected:
   ~Version();
 
 private:
-  Version(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(Version);
 };
 } // end namespace itk
 
