@@ -89,8 +89,7 @@ protected:
   virtual void DisplayXML(const char *, const char *);
 
 private:
-  XMLFileOutputWindow(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(XMLFileOutputWindow);
 };
 } // end namespace itk
 
