@@ -27,7 +27,7 @@
 // this is based on work by David N. Williams
 // www-personal.umich.edu/~williams
 // http://www-personal.umich.edu/~williams/archive/computation/fe-handling-example.c
-#if !defined(_WIN32) && defined(ITK_HAVE_FENV_H)
+#if !defined(_WIN32) && defined(ITK_HAVE_FENV_H) && defined(ITK_HAS_FEENABLEEXCEPT)
 
 #include <iostream>
 #include <string.h> // memcpy
@@ -429,7 +429,7 @@ SetEnabled(bool val)
     }
 }
 
-#if defined(_WIN32) || !defined(ITK_HAVE_FENV_H)
+#if defined(_WIN32) || !defined(ITK_HAVE_FENV_H) || !defined(ITK_HAS_FEENABLEEXCEPT)
 
 #if defined(_MSC_VER)
 #include <float.h>
@@ -451,13 +451,13 @@ void FloatingPointExceptions
   FloatingPointExceptions::m_Enabled = false;
 }
 
-#else // defined(_MSC_VER) || !defined(ITK_HAVE_FENV_H)
+#else // defined(_MSC_VER)
 
 // MinGW has troubles include'ing float.h.
 void FloatingPointExceptions
 ::Enable()
 {
-  std::cerr << "FloatingPointExceptions are not supported with MinGW." << std::endl;
+  std::cerr << "FloatingPointExceptions are not supported on this platform." << std::endl;
   if(itk::FloatingPointExceptions::GetExceptionAction() ==
      itk::FloatingPointExceptions::ABORT)
     {
@@ -472,7 +472,7 @@ void FloatingPointExceptions
 void FloatingPointExceptions
 ::Disable()
 {
-  std::cerr << "FloatingPointExceptions are not supported with MinGW." << std::endl;
+  std::cerr << "FloatingPointExceptions are not supported on this platform." << std::endl;
   if(itk::FloatingPointExceptions::GetExceptionAction() ==
      itk::FloatingPointExceptions::ABORT)
     {
@@ -484,9 +484,9 @@ void FloatingPointExceptions
     }
 }
 
-#endif // defined(_MSC_VER) || !defined(ITK_HAVE_FENV_H)
+#endif // defined(_MSC_VER)
 
-#else // defined(_WIN32)
+#else // defined(_WIN32) || !defined(ITK_HAVE_FENV_H) || !defined(ITK_HAVE_FEENABLEEXCEPT)
 
 void
 FloatingPointExceptions
@@ -524,6 +524,6 @@ FloatingPointExceptions
   FloatingPointExceptions::m_Enabled = false;
 }
 
-#endif // not defined ( _WIN32 )
+#endif // defined(_WIN32) || !defined(ITK_HAVE_FENV_H) || !defined(ITK_HAVE_FEENABLEEXCEPT)
 
 } // end of itk namespace
