@@ -45,8 +45,7 @@ protected:
     }
 
 private:
-  DataObjectTestHelper(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(DataObjectTestHelper);
 
 };
 
