@@ -18,8 +18,10 @@
 
 #include <iostream>
 
+#include "itkMath.h"
 #include "itkImageRegionIteratorWithIndex.h"
 #include "itkNumericTraits.h"
+#include "itkMath.h"
 
 
 template <typename TPixelType>
@@ -58,18 +60,25 @@ class itkImageIteratorWithIndexTestIteratorTester
     bool TestIterator()
     {
      IteratorType it( m_Image, m_Image->GetBufferedRegion() );
+     itk::SizeValueType i = 0;
      it.GoToBegin();
      while( !it.IsAtEnd() )
        {
        PixelType value = it.Get();
        PixelType testValue = value * static_cast<typename itk::NumericTraits<PixelType>::ValueType>( 2 );
        it.Set( testValue);
-       if( it.Get() != testValue )
+       if( itk::Math::NotExactlyEquals(it.Get(), testValue) )
         {
         std::cerr << "TestIterator failed!" << std::endl;
         return false;
         }
        ++it;
+       i++;
+       }
+     if (i != m_Image->GetBufferedRegion().GetNumberOfPixels())
+       {
+       std::cerr << "TestConstIterator failed (NumberOfPixels)!" << std::endl;
+       return false;
        }
      return true;
     }
@@ -77,16 +86,47 @@ class itkImageIteratorWithIndexTestIteratorTester
     bool TestConstIterator()
     {
      ConstIteratorType it( m_Image, m_Image->GetBufferedRegion() );
+     itk::SizeValueType i = 0;
      it.GoToBegin();
      while( !it.IsAtEnd() )
        {
        PixelType value = it.Get();
-       if( value != it.Get() ) // check repeatibility
+       if( itk::Math::NotExactlyEquals(value, it.Get()) ) // check repeatibility
          {
          std::cerr << "TestConstIterator failed!" << std::endl;
          return false;
          }
        ++it;
+       i++;
+       }
+     if (i != m_Image->GetBufferedRegion().GetNumberOfPixels())
+       {
+       std::cerr << "TestConstIterator failed (NumberOfPixels)!" << std::endl;
+       return false;
+       }
+     return true;
+    }
+
+    bool TestReverseIteration()
+    {
+     ConstIteratorType it( m_Image, m_Image->GetBufferedRegion() );
+     itk::SizeValueType i = 0;
+     it.GoToReverseBegin();
+     while( !it.IsAtReverseEnd() )
+       {
+       PixelType value = it.Get();
+       if( itk::Math::NotExactlyEquals(value, it.Get()) ) // check repeatibility
+         {
+         std::cerr << "TestReverseIteration failed!" << std::endl;
+         return false;
+         }
+       --it;
+       i++;
+       }
+     if (i != m_Image->GetBufferedRegion().GetNumberOfPixels())
+       {
+       std::cerr << "TestConstIterator failed (NumberOfPixels)!" << std::endl;
+       return false;
        }
      return true;
     }
@@ -115,6 +155,10 @@ int itkImageIteratorWithIndexTest(int, char* [] )
     {
     testPassed = false;
     }
+  if( TesterC.TestReverseIteration() == false )
+    {
+    testPassed = false;
+    }
 
   std::cout << "Testing with Image< unsigned char, 3 > " << std::endl;
   itkImageIteratorWithIndexTestIteratorTester< unsigned char > TesterUC( 10 );
@@ -126,6 +170,10 @@ int itkImageIteratorWithIndexTest(int, char* [] )
     {
     testPassed = false;
     }
+  if( TesterUC.TestReverseIteration() == false )
+    {
+    testPassed = false;
+    }
 
   std::cout << "Testing with Image< short, 3 > " << std::endl;
   itkImageIteratorWithIndexTestIteratorTester< short > TesterS( 10 );
@@ -137,6 +185,10 @@ int itkImageIteratorWithIndexTest(int, char* [] )
     {
     testPassed = false;
     }
+  if( TesterS.TestReverseIteration() == false )
+    {
+    testPassed = false;
+    }
 
   std::cout << "Testing with Image< unsigned short, 3 > " << std::endl;
   itkImageIteratorWithIndexTestIteratorTester< unsigned short > TesterUS( 10 );
@@ -148,6 +200,10 @@ int itkImageIteratorWithIndexTest(int, char* [] )
     {
     testPassed = false;
     }
+  if( TesterUS.TestReverseIteration() == false )
+    {
+    testPassed = false;
+    }
 
   std::cout << "Testing with Image< int, 3 > " << std::endl;
   itkImageIteratorWithIndexTestIteratorTester< int > TesterI( 10 );
@@ -159,6 +215,10 @@ int itkImageIteratorWithIndexTest(int, char* [] )
     {
     testPassed = false;
     }
+  if( TesterI.TestReverseIteration() == false )
+    {
+    testPassed = false;
+    }
 
   std::cout << "Testing with Image< unsigned int, 3 > " << std::endl;
   itkImageIteratorWithIndexTestIteratorTester< unsigned int > TesterUI( 10 );
@@ -170,6 +230,10 @@ int itkImageIteratorWithIndexTest(int, char* [] )
     {
     testPassed = false;
     }
+  if( TesterUI.TestReverseIteration() == false )
+    {
+    testPassed = false;
+    }
 
   std::cout << "Testing with Image< float, 3 > " << std::endl;
   itkImageIteratorWithIndexTestIteratorTester< float > TesterF( 10.0 );
@@ -181,6 +245,10 @@ int itkImageIteratorWithIndexTest(int, char* [] )
     {
     testPassed = false;
     }
+  if( TesterF.TestReverseIteration() == false )
+    {
+    testPassed = false;
+    }
 
   std::cout << "Testing with Image< double, 3 > " << std::endl;
   itkImageIteratorWithIndexTestIteratorTester< double > TesterD( 10.0 );
@@ -192,6 +260,10 @@ int itkImageIteratorWithIndexTest(int, char* [] )
     {
     testPassed = false;
     }
+  if( TesterD.TestReverseIteration() == false )
+    {
+    testPassed = false;
+    }
 
   std::cout << "Testing with Image< itk::Vector<char,4>, 3 > " << std::endl;
   typedef itk::Vector<char,4> VC;
@@ -206,6 +278,10 @@ int itkImageIteratorWithIndexTest(int, char* [] )
     {
     testPassed = false;
     }
+  if( TesterVC.TestReverseIteration() == false )
+    {
+    testPassed = false;
+    }
 
   std::cout << "Testing with Image< itk::Vector<unsigned char,4>, 3 > " << std::endl;
   typedef itk::Vector<unsigned char,4> VUC;
@@ -220,6 +296,10 @@ int itkImageIteratorWithIndexTest(int, char* [] )
     {
     testPassed = false;
     }
+  if( TesterVUC.TestReverseIteration() == false )
+    {
+    testPassed = false;
+    }
 
   std::cout << "Testing with Image< itk::Vector<short,4>, 3 > " << std::endl;
   typedef itk::Vector<short,4> VS;
@@ -234,6 +314,10 @@ int itkImageIteratorWithIndexTest(int, char* [] )
     {
     testPassed = false;
     }
+  if( TesterVS.TestReverseIteration() == false )
+    {
+    testPassed = false;
+    }
 
   std::cout << "Testing with Image< itk::Vector<unsigned short,4>, 3 > " << std::endl;
   typedef itk::Vector<unsigned short,4> VUS;
@@ -248,6 +332,10 @@ int itkImageIteratorWithIndexTest(int, char* [] )
     {
     testPassed = false;
     }
+  if( TesterVUS.TestReverseIteration() == false )
+    {
+    testPassed = false;
+    }
 
   std::cout << "Testing with Image< itk::Vector<int,4>, 3 > " << std::endl;
   typedef itk::Vector<int,4> VI;
@@ -262,6 +350,10 @@ int itkImageIteratorWithIndexTest(int, char* [] )
     {
     testPassed = false;
     }
+  if( TesterVI.TestReverseIteration() == false )
+    {
+    testPassed = false;
+    }
 
   std::cout << "Testing with Image< itk::Vector<unsigned int,4>, 3 > " << std::endl;
   typedef itk::Vector<unsigned int,4> VUI;
@@ -276,6 +368,10 @@ int itkImageIteratorWithIndexTest(int, char* [] )
     {
     testPassed = false;
     }
+  if( TesterVUI.TestReverseIteration() == false )
+    {
+    testPassed = false;
+    }
 
   std::cout << "Testing with Image< itk::Vector<float,4>, 3 > " << std::endl;
   typedef itk::Vector<float,4> VF;
@@ -290,6 +386,10 @@ int itkImageIteratorWithIndexTest(int, char* [] )
     {
     testPassed = false;
     }
+  if( TesterVF.TestReverseIteration() == false )
+    {
+    testPassed = false;
+    }
 
   std::cout << "Testing with Image< itk::Vector<double,4>, 3 > " << std::endl;
   typedef itk::Vector<double,4> VD;
@@ -304,6 +404,10 @@ int itkImageIteratorWithIndexTest(int, char* [] )
     {
     testPassed = false;
     }
+  if( TesterVD.TestReverseIteration() == false )
+    {
+    testPassed = false;
+    }
 
   if ( !testPassed )
     {
