@@ -54,7 +54,7 @@ int itkImageIteratorsForwardBackwardTest(int, char* [] )
 
   ImageType::PixelType value;
 
-  value = itk::NumericTraits< ImageType::PixelType >::Zero;
+  value = itk::NumericTraits< ImageType::PixelType >::ZeroValue();
 
   // Store information on the Image
   std::cout << "Storing data on the image ... " << std::endl;
@@ -71,7 +71,7 @@ int itkImageIteratorsForwardBackwardTest(int, char* [] )
   IteratorType ot( myImage, region );
   std::cout << "Verifying the data forwards... ";
 
-  value = itk::NumericTraits< ImageType::PixelType >::Zero;
+  value = itk::NumericTraits< ImageType::PixelType >::ZeroValue();
 
   while( !ot.IsAtEnd() )
   {
@@ -123,7 +123,7 @@ int itkImageIteratorsForwardBackwardTest(int, char* [] )
   ConstIteratorType cot( myImage, region );
   std::cout << "Const Iterator: Verifying the data forwards... ";
 
-  value = itk::NumericTraits< ImageType::PixelType >::Zero;
+  value = itk::NumericTraits< ImageType::PixelType >::ZeroValue();
 
   while( !cot.IsAtEnd() )
   {
