@@ -113,8 +113,7 @@ public:
   }
 
 private:
-  TestFactory(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(TestFactory);
 
   TestFactory()
     {
