@@ -18,12 +18,16 @@
 
 #include <iostream>
 #include "itkRealTimeInterval.h"
+#include "itkMacro.h"
 #include "itkNumericTraits.h"
 
 #define CHECK_FOR_VALUE(a,b) \
   { \
     double eps = 4.0*itk::NumericTraits<double>::epsilon();             \
+CLANG_PRAGMA_PUSH                                                       \
+CLANG_SUPPRESS_Wfloat_equal                                             \
     eps = ( b == 0.0 ) ? eps : std::fabs(b*eps);                         \
+CLANG_PRAGMA_POP                                                         \
     if( std::fabs( a - b ) > eps )                                       \
       {                                                                 \
       std::cerr << "Error in "#a << " expected " << b << " but got " << a << std::endl; \
