@@ -84,8 +84,7 @@ namespace itk
     TanHelperImageFilter() {}
     virtual ~TanHelperImageFilter() {}
   private:
-    TanHelperImageFilter(const Self &) ITK_DELETE_FUNCTION;
-    void operator=(const Self &) ITK_DELETE_FUNCTION;
+    ITK_DISALLOW_COPY_AND_ASSIGN(TanHelperImageFilter);
   };
 
 }
