@@ -77,8 +77,7 @@ public:
       }
 
     std::vector<DomainType> m_DomainInThreadedExecution;
-    TestDomainThreader( const Self & ) ITK_DELETE_FUNCTION;
-    void operator=( const Self & ) ITK_DELETE_FUNCTION;
+    ITK_DISALLOW_COPY_AND_ASSIGN(TestDomainThreader);
   }; // end TestDomainThreader class
 
   DomainThreaderAssociate()
