@@ -27,9 +27,9 @@ namespace itk
  * \class DenseFiniteDifferenceImageFilter
  *
  * This filter implements a layer of the finite difference solver hierarchy that
- * performs ``dense'' iteration, ie. iteration over all pixels in the input and
+ * performs "dense" iteration, ie. iteration over all pixels in the input and
  * output at each change calculation and update step. Dense iteration is in
- * contrast to a ``sparse'' iteration over a subset of the pixels.  See
+ * contrast to a "sparse" iteration over a subset of the pixels.  See
  * documentation for FiniteDifferenceImageFilter for an overview of the
  * iterative finite difference algorithm:
  *
@@ -66,7 +66,7 @@ namespace itk
  * \ingroup ITKFiniteDifference
  */
 template< typename TInputImage, typename TOutputImage >
-class DenseFiniteDifferenceImageFilter:
+class ITK_TEMPLATE_EXPORT DenseFiniteDifferenceImageFilter:
   public FiniteDifferenceImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -165,8 +165,7 @@ protected:
                                        ThreadIdType threadId);
 
 private:
-  DenseFiniteDifferenceImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(DenseFiniteDifferenceImageFilter);
 
   /** Structure for passing information into static callback methods.  Used in
    * the subclasses' threading mechanisms. */
