@@ -44,7 +44,7 @@ namespace itk
  * \ingroup ITKFiniteDifference
  */
 template< typename TSparseImageType >
-class FiniteDifferenceSparseImageFunction:
+class ITK_TEMPLATE_EXPORT FiniteDifferenceSparseImageFunction:
   public FiniteDifferenceFunction< TSparseImageType >
 {
 public:
@@ -113,8 +113,7 @@ protected:
   void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  FiniteDifferenceSparseImageFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(FiniteDifferenceSparseImageFunction);
 };
 } // end namespace itk
 
