@@ -44,8 +44,7 @@ private:
   GPUImageOps();
   virtual ~GPUImageOps();
 
-  GPUImageOps(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GPUImageOps);
 
 };
 
