@@ -35,7 +35,7 @@ namespace itk
  */
 template< typename TInputImage, typename TOutputImage = TInputImage, typename TParentImageFilter =
             InPlaceImageFilter< TInputImage, TOutputImage > >
-class GPUInPlaceImageFilter : public GPUImageToImageFilter< TInputImage, TOutputImage, TParentImageFilter >
+class ITK_TEMPLATE_EXPORT GPUInPlaceImageFilter : public GPUImageToImageFilter< TInputImage, TOutputImage, TParentImageFilter >
 {
 public:
   /** Standard class typedefs. */
@@ -97,8 +97,7 @@ protected:
   virtual void ReleaseInputs() ITK_OVERRIDE;
 
 private:
-  GPUInPlaceImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GPUInPlaceImageFilter);
 
 };
 
