@@ -34,7 +34,7 @@ namespace itk
  */
 template< typename TInputImage, typename TOutputImage, typename TFunction, typename TParentImageFilter =
             InPlaceImageFilter< TInputImage, TOutputImage > >
-class GPUUnaryFunctorImageFilter : public GPUInPlaceImageFilter< TInputImage, TOutputImage,
+class ITK_TEMPLATE_EXPORT GPUUnaryFunctorImageFilter : public GPUInPlaceImageFilter< TInputImage, TOutputImage,
                                                                             TParentImageFilter >
 {
 public:
@@ -96,8 +96,7 @@ protected:
   int m_UnaryFunctorImageFilterGPUKernelHandle;
 
 private:
-  GPUUnaryFunctorImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GPUUnaryFunctorImageFilter);
 
   FunctorType m_Functor;
 
