@@ -51,7 +51,7 @@ itkGPUKernelClassMacro(GPUDenseFiniteDifferenceImageFilterKernel);
  */
 template< typename TInputImage, typename TOutputImage, typename TParentImageFilter =
             DenseFiniteDifferenceImageFilter< TInputImage, TOutputImage > >
-class GPUDenseFiniteDifferenceImageFilter :
+class ITK_TEMPLATE_EXPORT GPUDenseFiniteDifferenceImageFilter :
   public GPUFiniteDifferenceImageFilter< TInputImage, TOutputImage, TParentImageFilter >
 {
 public:
@@ -133,8 +133,7 @@ protected:
   int m_ApplyUpdateGPUKernelHandle;
 
 private:
-  GPUDenseFiniteDifferenceImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GPUDenseFiniteDifferenceImageFilter);
 
 };
 } // end namespace itk
