@@ -98,8 +98,7 @@ protected:
   virtual ~AbsImageAdaptor() {}
 
 private:
-  AbsImageAdaptor(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(AbsImageAdaptor);
 };
 } // end namespace itk
 
