@@ -68,8 +68,7 @@ protected:
   virtual ~AddImageAdaptor() {}
 
 private:
-  AddImageAdaptor(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(AddImageAdaptor);
 };
 } // end namespace itk
 
