@@ -93,8 +93,7 @@ protected:
   virtual ~ComplexToPhaseImageAdaptor() {}
 
 private:
-  ComplexToPhaseImageAdaptor(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ComplexToPhaseImageAdaptor);
 };
 } // end namespace itk
 
