@@ -92,8 +92,7 @@ protected:
   virtual ~CosImageAdaptor() {}
 
 private:
-  CosImageAdaptor(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(CosImageAdaptor);
 };
 } // end namespace itk
 
