@@ -95,8 +95,7 @@ protected:
   virtual ~LogImageAdaptor() {}
 
 private:
-  LogImageAdaptor(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(LogImageAdaptor);
 };
 } // end namespace itk
 
