@@ -94,8 +94,7 @@ protected:
   virtual ~TanImageAdaptor() {}
 
 private:
-  TanImageAdaptor(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(TanImageAdaptor);
 };
 } // end namespace itk
 
