@@ -186,8 +186,7 @@ protected:
   virtual ~VectorImageToImageAdaptor() {}
 
 private:
-  VectorImageToImageAdaptor(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(VectorImageToImageAdaptor);
 };
 } // end namespace itk
 
