@@ -66,8 +66,7 @@ protected:
   virtual ~VectorToRGBImageAdaptor() {}
 
 private:
-  VectorToRGBImageAdaptor(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(VectorToRGBImageAdaptor);
 };
 } // end namespace itk
 
