@@ -70,7 +70,7 @@ namespace itk
  * \ingroup ITKImageFunction
  */
 template< typename TInputImage, typename TOutputImage >
-class BSplineDecompositionImageFilter:
+class ITK_TEMPLATE_EXPORT BSplineDecompositionImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -102,12 +102,21 @@ public:
   /** Iterator typedef support */
   typedef ImageLinearIteratorWithIndex< TOutputImage > OutputLinearIterator;
 
+  typedef std::vector< double > SplinePolesVectorType;
+
   /** Get/Sets the Spline Order, supports 0th - 5th order splines. The default
    *  is a 3rd order spline. */
   void SetSplineOrder(unsigned int SplineOrder);
 
   itkGetConstMacro(SplineOrder, int);
 
+  /** Get the poles calculated for a given spline order. */
+  itkGetConstMacro( SplinePoles, SplinePolesVectorType );
+
+  /** Get the number of poles. */
+  itkGetConstMacro( NumberOfPoles, int );
+
+
 #ifdef ITK_USE_CONCEPT_CHECKING
   // Begin concept checking
   itkConceptMacro( DimensionCheck,
@@ -133,25 +142,10 @@ protected:
   /** This filter must produce all of its output at once. */
   void EnlargeOutputRequestedRegion(DataObject *output) ITK_OVERRIDE;
 
-  /** These are needed by the smoothing spline routine. */
-  std::vector< CoeffType >           m_Scratch;   // temp storage for processing
-                                                  // of Coefficients
-  typename TInputImage::SizeType m_DataLength;    // Image size
-
-  unsigned int m_SplineOrder;                // User specified spline order (3rd
-                                             // or cubic is the default)
-  double m_SplinePoles[3];                   // Poles calculated for a given
-                                             // spline order
-  int m_NumberOfPoles;                       // number of poles
-
-  double m_Tolerance;                        // Tolerance used for determining
-                                             // initial causal coefficient
-  unsigned int m_IteratorDirection;          // Direction for iterator
-                                             // incrementing
-
 private:
-  BSplineDecompositionImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  typedef std::vector< CoeffType >  CoefficientsVectorType;
+
+  ITK_DISALLOW_COPY_AND_ASSIGN(BSplineDecompositionImageFilter);
 
   /** Determines the poles given the Spline Order. */
   virtual void SetPoles();
@@ -170,15 +164,38 @@ private:
     data. */
   virtual void SetInitialAntiCausalCoefficient(double z);
 
-  /** Used to initialize the Coefficients image before calculation. */
+  /** Copy the input image into the output image.
+   *  Used to initialize the Coefficients image before calculation. */
   void CopyImageToImage();
 
-  /** Copies a vector of data from the Coefficients image to the m_Scratch
-    vector. */
+  /** Copies a vector of data from the Coefficients image (one line of the
+   *  output image) to the scratch. */
   void CopyCoefficientsToScratch(OutputLinearIterator &);
 
-  /** Copies a vector of data from m_Scratch to the Coefficients image. */
+  /** Copies a vector of data from the scratch to the Coefficients image
+   *  (one line of the output image). */
   void CopyScratchToCoefficients(OutputLinearIterator &);
+
+  // Variables needed by the smoothing spline routine.
+
+  /** Temporary storage for processing of Coefficients. */
+  CoefficientsVectorType           m_Scratch;
+
+  /** Image size. */
+  typename TInputImage::SizeType m_DataLength;
+
+  /** User specified spline order (3rd or cubic is the default). */
+  unsigned int m_SplineOrder;
+
+  SplinePolesVectorType m_SplinePoles;
+
+  int m_NumberOfPoles;
+
+  /** Tolerance used for determining initial causal coefficient. Default is 1e-10.*/
+  double m_Tolerance;
+
+  /** Direction for iterator incrementing. Default is 0. */
+  unsigned int m_IteratorDirection;
 };
 } // namespace itk
 
