@@ -81,7 +81,7 @@ template<
   typename TImageType,
   typename TCoordRep = double,
   typename TCoefficientType = double >
-class BSplineInterpolateImageFunction:
+class ITK_TEMPLATE_EXPORT BSplineInterpolateImageFunction:
   public InterpolateImageFunction< TImageType, TCoordRep >
 {
 public:
@@ -366,8 +366,7 @@ protected:
   typename CoefficientImageType::ConstPointer m_Coefficients;
 
 private:
-  BSplineInterpolateImageFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BSplineInterpolateImageFunction);
 
   /** Determines the weights for interpolation of the value x */
   void SetInterpolationWeights(const ContinuousIndexType & x,
