@@ -75,7 +75,7 @@ template<
   typename TCoordRep = float,
   typename TOutputType = CovariantVector<double, TInputImage::ImageDimension >
   >
-class CentralDifferenceImageFunction:
+class ITK_TEMPLATE_EXPORT CentralDifferenceImageFunction:
   public ImageFunction< TInputImage,
                         TOutputType,
                         TCoordRep >
@@ -210,8 +210,7 @@ protected:
   void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  CentralDifferenceImageFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(CentralDifferenceImageFunction);
 
 
   /** Structure for specialization of Evaulate* methods on OutputType */
