@@ -55,7 +55,7 @@ template<
   typename TOutput,
   typename TCoordRep = float
   >
-class ImageFunction:
+class ITK_TEMPLATE_EXPORT ImageFunction:
     public FunctionBase< Point< TCoordRep, TInputImage::ImageDimension >, TOutput >
 {
 public:
@@ -226,8 +226,7 @@ protected:
   ContinuousIndexType m_EndContinuousIndex;
 
 private:
-  ImageFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ImageFunction);
 };
 } // end namespace itk
 
