@@ -60,7 +60,7 @@ namespace itk
 
 template <typename TInputImage, typename TCoordRep = double,
           typename TPixelCompare = std::less<typename itk::NumericTraits<typename TInputImage::PixelType>::RealType> >
-class LabelImageGaussianInterpolateImageFunction :
+class ITK_TEMPLATE_EXPORT LabelImageGaussianInterpolateImageFunction :
   public GaussianInterpolateImageFunction<TInputImage, TCoordRep>
 {
 public:
@@ -112,8 +112,7 @@ protected:
   ~LabelImageGaussianInterpolateImageFunction(){};
 
 private:
-  LabelImageGaussianInterpolateImageFunction( const Self& ) ITK_DELETE_FUNCTION;
-  void operator=( const Self& ) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(LabelImageGaussianInterpolateImageFunction);
 
   /**
    * Evaluate function value at the given index
