@@ -44,7 +44,7 @@ namespace itk
  * \endwiki
  */
 template< typename TInputImage, typename TCoordRep = float >
-class MedianImageFunction:
+class ITK_TEMPLATE_EXPORT MedianImageFunction:
   public ImageFunction< TInputImage, typename TInputImage::PixelType,
                         TCoordRep >
 {
@@ -115,8 +115,7 @@ protected:
   void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  MedianImageFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(MedianImageFunction);
 
   unsigned int m_NeighborhoodRadius;
 
