@@ -134,8 +134,7 @@ protected:
   { Superclass::PrintSelf(os, indent); }
 
 private:
-  NearestNeighborExtrapolateImageFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(NearestNeighborExtrapolateImageFunction);
 };
 } // end namespace itk
 
