@@ -35,7 +35,7 @@ namespace itk
  * \ingroup ITKImageFunction
  */
 template< typename TInputImage, typename TCoordRep = double >
-class NearestNeighborInterpolateImageFunction:
+class ITK_TEMPLATE_EXPORT NearestNeighborInterpolateImageFunction:
   public InterpolateImageFunction< TInputImage, TCoordRep >
 {
 public:
@@ -91,8 +91,7 @@ protected:
   { Superclass::PrintSelf(os, indent); }
 
 private:
-  NearestNeighborInterpolateImageFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(NearestNeighborInterpolateImageFunction);
 };
 } // end namespace itk
 
