@@ -103,8 +103,7 @@ protected:
   { Superclass::PrintSelf(os, indent); }
 
 private:
-  VectorNearestNeighborInterpolateImageFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(VectorNearestNeighborInterpolateImageFunction);
 };
 } // end namespace itk
 
