@@ -72,7 +72,7 @@ int itkNeighborhoodOperatorImageFunctionTest(int, char* [] )
 
   // since the input image is constant
   // the should be equal to the initial value
-  if( vnl_math_abs( initialValue - Blur ) > 10e-7 )
+  if( itk::Math::abs( initialValue - Blur ) > 10e-7 )
     {
     std::cerr << "[FAILED] : Error in Blur computation" << std::endl;
     return EXIT_FAILURE;
