@@ -108,7 +108,7 @@ namespace itk
  * \ingroup ITKMesh
  */
 template< typename TOutputMesh >
-class AutomaticTopologyMeshSource:public MeshSource< TOutputMesh >
+class ITK_TEMPLATE_EXPORT AutomaticTopologyMeshSource:public MeshSource< TOutputMesh >
 {
 public:
   /** Standard "Self" typedef. */
@@ -388,8 +388,7 @@ protected:
                           // are controlled manually
 
 private:
-  AutomaticTopologyMeshSource(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(AutomaticTopologyMeshSource);
 
   typedef itksys::hash_map<
     Array< IdentifierType >,
