@@ -68,7 +68,7 @@ namespace itk
  * \ingroup ITKMesh
  */
 template< typename TInputImage, typename TOutputMesh >
-class BinaryMask3DMeshSource:public ImageToMeshFilter< TInputImage, TOutputMesh >
+class ITK_TEMPLATE_EXPORT BinaryMask3DMeshSource:public ImageToMeshFilter< TInputImage, TOutputMesh >
 {
 public:
   /** Standard "Self" typedef. */
@@ -158,8 +158,7 @@ protected:
   virtual void GenerateOutputInformation() ITK_OVERRIDE {}  // do nothing ITK_OVERRIDE
 
 private:
-  BinaryMask3DMeshSource(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BinaryMask3DMeshSource);
 
   typedef typename InputImageType::SizeType InputImageSizeType;
 
