@@ -33,7 +33,7 @@ namespace itk
  * \ingroup ITKMesh
  */
 template< typename TInputImage, typename TOutputMesh >
-class ImageToMeshFilter:public MeshSource< TOutputMesh >
+class ITK_TEMPLATE_EXPORT ImageToMeshFilter:public MeshSource< TOutputMesh >
 {
 public:
   /** Standard class typedefs. */
@@ -87,8 +87,7 @@ protected:
   ~ImageToMeshFilter();
 
 private:
-  ImageToMeshFilter(const ImageToMeshFilter &) ITK_DELETE_FUNCTION;
-  void operator=(const ImageToMeshFilter &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ImageToMeshFilter);
 };
 } // end namespace itk
 
