@@ -44,7 +44,7 @@ namespace itk
  * \ingroup ITKMesh
  */
 template< typename TInputMesh, typename TOutputMesh >
-class MeshToMeshFilter:public MeshSource< TOutputMesh >
+class ITK_TEMPLATE_EXPORT MeshToMeshFilter:public MeshSource< TOutputMesh >
 {
 public:
   /** Standard class typedefs. */
@@ -89,8 +89,7 @@ protected:
   void CopyInputMeshToOutputMeshCellData();
 
 private:
-  MeshToMeshFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(MeshToMeshFilter);
 };
 } // end namespace itk
 
