@@ -44,7 +44,7 @@ namespace itk
  * \ingroup ITKMesh
  */
 template< typename TInputMesh, typename TOutputMesh >
-class ParametricSpaceToImageSpaceMeshFilter:
+class ITK_TEMPLATE_EXPORT ParametricSpaceToImageSpaceMeshFilter:
   public MeshToMeshFilter< TInputMesh, TOutputMesh >
 {
 public:
@@ -80,8 +80,7 @@ protected:
   virtual void GenerateOutputInformation(void) ITK_OVERRIDE;
 
 private:
-  ParametricSpaceToImageSpaceMeshFilter(const ParametricSpaceToImageSpaceMeshFilter &) ITK_DELETE_FUNCTION;
-  void operator=(const ParametricSpaceToImageSpaceMeshFilter &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ParametricSpaceToImageSpaceMeshFilter);
 };
 } // end namespace itk
 
