@@ -38,7 +38,7 @@ namespace itk
  * \ingroup ITKMesh
  */
 template< typename TOutputMesh >
-class RegularSphereMeshSource:public MeshSource< TOutputMesh >
+class ITK_TEMPLATE_EXPORT RegularSphereMeshSource:public MeshSource< TOutputMesh >
 {
 public:
   /** Standard "Self" typedef. */
@@ -111,8 +111,7 @@ protected:
   VectorType m_Scale;
 
 private:
-  RegularSphereMeshSource(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(RegularSphereMeshSource);
 };
 } // end namespace itk
 
