@@ -47,7 +47,7 @@ namespace itk
  */
 
 template< typename TInputMesh >
-class SimplexMeshVolumeCalculator:public Object
+class ITK_TEMPLATE_EXPORT SimplexMeshVolumeCalculator:public Object
 {
 public:
   /** Standard "Self" typedef. */
@@ -179,8 +179,7 @@ protected:
   virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  SimplexMeshVolumeCalculator(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(SimplexMeshVolumeCalculator);
 
   void Initialize();
 
