@@ -68,7 +68,7 @@ public:
  * \ingroup ITKMesh
  */
 template< typename TInputMesh, typename TOutputImage >
-class TriangleMeshToBinaryImageFilter:public ImageSource< TOutputImage >
+class ITK_TEMPLATE_EXPORT TriangleMeshToBinaryImageFilter:public ImageSource< TOutputImage >
 {
 public:
   /** Standard class typedefs. */
@@ -233,8 +233,7 @@ protected:
   virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  TriangleMeshToBinaryImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(TriangleMeshToBinaryImageFilter);
 
   static bool ComparePoints2D(Point2DType a, Point2DType b);
 
