@@ -39,7 +39,7 @@ namespace itk
  * \sa MeshFileWriter
  */
 template< typename TInputMesh >
-class VTKPolyDataWriter:public Object
+class ITK_TEMPLATE_EXPORT VTKPolyDataWriter:public Object
 {
 public:
   /** Standard "Self" typedef. */
@@ -104,8 +104,7 @@ protected:
   virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  VTKPolyDataWriter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(VTKPolyDataWriter);
 };
 } // namespace itk
 
