@@ -113,7 +113,7 @@ namespace itk
  */
 template< typename TPixel, unsigned int VDimension,
           typename TTraits = QuadEdgeMeshTraits< TPixel, VDimension, bool, bool > >
-class QuadEdgeMesh:public Mesh< TPixel, VDimension, TTraits >
+class ITK_TEMPLATE_EXPORT QuadEdgeMesh:public Mesh< TPixel, VDimension, TTraits >
 {
 public:
   /** Input template parameters. */
@@ -508,8 +508,7 @@ protected:
   CellsContainerPointer m_EdgeCellsContainer;
 
 private:
-  QuadEdgeMesh(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(QuadEdgeMesh);
 
   CellIdentifier m_NumberOfFaces;
   CellIdentifier m_NumberOfEdges;
