@@ -54,7 +54,7 @@ namespace itk
  * \ingroup ITKQuadEdgeMesh
  */
 template< typename TMesh, typename TQEType >
-class QuadEdgeMeshEulerOperatorJoinVertexFunction:
+class ITK_TEMPLATE_EXPORT QuadEdgeMeshEulerOperatorJoinVertexFunction:
   public QuadEdgeMeshFunctionBase< TMesh, TQEType * >
 {
 public:
@@ -151,8 +151,7 @@ protected:
                                );
 
 private:
-  QuadEdgeMeshEulerOperatorJoinVertexFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(QuadEdgeMeshEulerOperatorJoinVertexFunction);
 };
 } // namespace itk
 
