@@ -32,7 +32,7 @@ namespace itk
  * \ingroup ITKQuadEdgeMesh
  */
 template< typename TMesh, typename TQEType >
-class QuadEdgeMeshEulerOperatorSplitFacetFunction:
+class ITK_TEMPLATE_EXPORT QuadEdgeMeshEulerOperatorSplitFacetFunction:
   public QuadEdgeMeshFunctionBase< TMesh, TQEType * >
 {
 public:
@@ -61,8 +61,7 @@ protected:
   ~QuadEdgeMeshEulerOperatorSplitFacetFunction(){}
 
 private:
-  QuadEdgeMeshEulerOperatorSplitFacetFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(QuadEdgeMeshEulerOperatorSplitFacetFunction);
 };
 } // namespace itk
 
