@@ -92,8 +92,7 @@ protected:
   ~QuadEdgeMeshFunctionBase(){}
 
 private:
-  QuadEdgeMeshFunctionBase(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(QuadEdgeMeshFunctionBase);
 
 protected:
   /** Mesh on which to apply the modification */
