@@ -36,7 +36,7 @@ namespace itk
  * \ingroup ITKQuadEdgeMesh
  */
 template< typename TCellInterface >
-class QuadEdgeMeshLineCell:
+class ITK_TEMPLATE_EXPORT QuadEdgeMeshLineCell:
   public TCellInterface, public TCellInterface::CellTraits::QuadEdgeType
 {
 public:
@@ -198,8 +198,7 @@ public:
   virtual PointIdInternalConstIterator InternalPointIdsEnd() const;
 
 private:
-  QuadEdgeMeshLineCell(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(QuadEdgeMeshLineCell);
 
   /**
    * In order to have constant time access at the itk level instead of
