@@ -38,7 +38,7 @@ namespace itk
  * \ingroup ITKQuadEdgeMesh
  */
 template< typename TMesh >
-class QuadEdgeMeshTopologyChecker:public Object
+class ITK_TEMPLATE_EXPORT QuadEdgeMeshTopologyChecker:public Object
 {
 public:
   // Standard types
@@ -79,8 +79,7 @@ protected:
   virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  QuadEdgeMeshTopologyChecker(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(QuadEdgeMeshTopologyChecker);
 
   typedef typename MeshType::ConstPointer MeshPointer;
 
