@@ -30,7 +30,7 @@ namespace itk
  * \ingroup ITKQuadEdgeMesh
  */
 template< typename TMesh, typename TQEType >
-class QuadEdgeMeshZipMeshFunction:
+class ITK_TEMPLATE_EXPORT QuadEdgeMeshZipMeshFunction:
   public QuadEdgeMeshFunctionBase< TMesh, typename TQEType::OriginRefType >
 {
 public:
@@ -63,8 +63,7 @@ protected:
   ~QuadEdgeMeshZipMeshFunction(){}
 
 private:
-  QuadEdgeMeshZipMeshFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(QuadEdgeMeshZipMeshFunction);
 };
 } // namespace itk
 
