@@ -30,7 +30,6 @@ int itkQuadEdgeMeshAddFaceTest1( int argc, char* argv[] )
   typedef itk::QuadEdgeMesh< double, 3 > MeshType;
   typedef MeshType::PointType            PointType;
   typedef MeshType::PointIdentifier      PointIdentifier;
-  typedef MeshType::CellIdentifier       CellIdentifier;
   typedef std::vector< PointIdentifier > PointIdList;
 
   typedef itk::QuadEdgeMeshBoundaryEdgesMeshFunction< MeshType > BEFunctionType;
@@ -62,7 +61,7 @@ int itkQuadEdgeMeshAddFaceTest1( int argc, char* argv[] )
   const int NumPoints = 7;
   PointIdentifier pid[NumPoints];
 
-  PointType::CoordRepType        a = vcl_sqrt( 3.0 ) / 2.0;
+  PointType::CoordRepType        a = std::sqrt( 3.0 ) / 2.0;
 
   typedef PointType::ValueArrayType ValueArrayType;
 
