@@ -28,10 +28,8 @@ int itkQuadEdgeMeshEulerOperatorDeleteCenterVertexTest(int argc, char* argv[] )
   typedef itk::QuadEdgeMesh< double, 3 >                      MeshType;
   typedef MeshType::Pointer                                   MeshPointer;
   typedef MeshType::QEType                                    QEType;
-  typedef MeshType::PointIdentifier                           PointIdentifier;
   typedef MeshType::PointType                                 PointType;
   typedef MeshType::CellType                                  CellType;
-  typedef itk::QuadEdgeMeshLineCell< CellType >               LineCellType;
 
   typedef itk::QuadEdgeMeshEulerOperatorDeleteCenterVertexFunction< MeshType,
     QEType> DeleteCenterVertex;
@@ -88,7 +86,7 @@ int itkQuadEdgeMeshEulerOperatorDeleteCenterVertexTest(int argc, char* argv[] )
 
   deleteCenterVertex->SetInput( mesh );
   std::cout << "     " << "Test No QE Input";
-  if( deleteCenterVertex->Evaluate( (QEType*)0 ) )
+  if( deleteCenterVertex->Evaluate( (QEType*)ITK_NULLPTR ) )
     {
     std::cout << "FAILED." << std::endl;
     return EXIT_FAILURE;
