@@ -25,10 +25,6 @@ int itkQuadEdgeMeshEulerOperatorSplitEdgeTest( int, char * [] )
   typedef itk::QuadEdgeMesh< double, 3 >                      MeshType;
   typedef MeshType::Pointer                                   MeshPointer;
   typedef MeshType::QEType                                    QEType;
-  typedef MeshType::PointIdentifier                           PointIdentifier;
-  typedef MeshType::PointType                                 PointType;
-  typedef MeshType::CellType                                  CellType;
-  typedef itk::QuadEdgeMeshLineCell< CellType >               LineCellType;
 
   typedef itk::QuadEdgeMeshEulerOperatorSplitEdgeFunction< MeshType, QEType>
     SplitEdge;
@@ -55,7 +51,7 @@ int itkQuadEdgeMeshEulerOperatorSplitEdgeTest( int, char * [] )
 
   splitEdge->SetInput( mesh );
   std::cout << "     " << "Test No QE Input";
-  if( splitEdge->Evaluate( (QEType*)0 ) )
+  if( splitEdge->Evaluate( (QEType*)ITK_NULLPTR ) )
     {
     std::cout << "FAILED." << std::endl;
     return EXIT_FAILURE;
