@@ -30,7 +30,7 @@ namespace itk
  * \ingroup ITKSpatialObjects
  */
 template< typename TScalar = double, unsigned int NDimensions = 3 >
-class AffineGeometryFrame:public Object
+class ITK_TEMPLATE_EXPORT AffineGeometryFrame:public Object
 {
 public:
   typedef AffineGeometryFrame        Self;
@@ -115,8 +115,7 @@ protected:
   typename TransformType::Pointer m_IndexToWorldTransform;
 
 private:
-  AffineGeometryFrame(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(AffineGeometryFrame);
 };
 } // namespace itk
 
