@@ -28,7 +28,7 @@ namespace itk
  * \class BlobSpatialObject
  * \brief Spatial object representing a potentially amorphous object.
  *
- * The BlobSpatialObject is a discretized representation of a ``blob'',
+ * The BlobSpatialObject is a discretized representation of a "blob",
  * which can be taken to be an arbitrary, possibly amorphous shape.
  * The representation is a list of the points (voxel centers) contained
  * in the object.  This can be thought of as an alternate way to
@@ -43,7 +43,7 @@ namespace itk
  */
 
 template< unsigned int TDimension = 3 >
-class BlobSpatialObject:
+class ITK_TEMPLATE_EXPORT BlobSpatialObject:
   public PointBasedSpatialObject<  TDimension >
 {
 public:
@@ -117,8 +117,7 @@ public:
   bool ComputeLocalBoundingBox() const ITK_OVERRIDE;
 
 protected:
-  BlobSpatialObject(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BlobSpatialObject);
 
   PointListType m_Points;
 
