@@ -36,7 +36,7 @@ namespace itk
  */
 
 template< unsigned int TDimension = 3 >
-class ContourSpatialObject:
+class ITK_TEMPLATE_EXPORT ContourSpatialObject:
   public PointBasedSpatialObject<  TDimension >
 {
 public:
@@ -157,8 +157,7 @@ public:
   bool ComputeLocalBoundingBox(void) const ITK_OVERRIDE;
 
 protected:
-  ContourSpatialObject(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ContourSpatialObject);
 
   ControlPointListType      m_ControlPoints;
   InterpolatedPointListType m_InterpolatedPoints;
