@@ -36,7 +36,7 @@ namespace itk
  */
 
 template< unsigned int TDimension = 3 >
-class GroupSpatialObject:
+class ITK_TEMPLATE_EXPORT GroupSpatialObject:
   public SpatialObject< TDimension >
 {
 public:
@@ -59,8 +59,7 @@ public:
   bool ComputeLocalBoundingBox() const ITK_OVERRIDE { return false; }
 
 protected:
-  GroupSpatialObject(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GroupSpatialObject);
 
   GroupSpatialObject();
   virtual ~GroupSpatialObject();
