@@ -40,7 +40,7 @@ namespace itk
  */
 
 template< unsigned int TDimension = 3 >
-class LineSpatialObject:
+class ITK_TEMPLATE_EXPORT LineSpatialObject:
   public PointBasedSpatialObject<  TDimension >
 {
 public:
@@ -113,8 +113,7 @@ public:
   bool ComputeLocalBoundingBox() const ITK_OVERRIDE;
 
 protected:
-  LineSpatialObject(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(LineSpatialObject);
 
   PointListType m_Points;
 
