@@ -32,7 +32,7 @@ namespace itk
  *  \ingroup ITKSpatialObjects
  */
 template< unsigned int NDimensions = 3 >
-class MetaContourConverter :
+class ITK_TEMPLATE_EXPORT MetaContourConverter :
     public MetaConverterBase< NDimensions >
 {
 public:
@@ -72,8 +72,7 @@ protected:
   ~MetaContourConverter() {}
 
 private:
-  MetaContourConverter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(MetaContourConverter);
 
 };
 } // end namespace itk
