@@ -36,7 +36,7 @@ namespace itk
 template< unsigned int NDimensions = 3,
           typename TPixel = unsigned char,
           typename TSpatialObjectType = ImageSpatialObject< NDimensions,TPixel > >
-class MetaImageConverter :
+class ITK_TEMPLATE_EXPORT MetaImageConverter :
     public MetaConverterBase< NDimensions >
 {
 public:
@@ -79,8 +79,7 @@ protected:
   ~MetaImageConverter() {}
 
 private:
-  MetaImageConverter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(MetaImageConverter);
 };
 
 } // end namespace itk
