@@ -31,7 +31,7 @@ namespace itk
  *  \ingroup ITKSpatialObjects
  */
 template< unsigned int NDimensions = 3 >
-class MetaLandmarkConverter :
+class ITK_TEMPLATE_EXPORT MetaLandmarkConverter :
     public MetaConverterBase< NDimensions >
 {
 public:
@@ -71,8 +71,7 @@ protected:
   ~MetaLandmarkConverter() {}
 
 private:
-  MetaLandmarkConverter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(MetaLandmarkConverter);
 
 };
 
