@@ -35,7 +35,7 @@ template< unsigned int NDimensions = 3,
           typename TMeshTraits =
             DefaultStaticMeshTraits< PixelType, NDimensions, NDimensions >
           >
-class MetaMeshConverter :
+class ITK_TEMPLATE_EXPORT MetaMeshConverter :
     public MetaConverterBase< NDimensions >
 {
 public:
@@ -76,8 +76,7 @@ protected:
   ~MetaMeshConverter() {}
 
 private:
-  MetaMeshConverter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(MetaMeshConverter);
 
 };
 } // end namespace itk
