@@ -31,7 +31,7 @@ namespace itk
  *  \ingroup ITKSpatialObjects
  */
 template< unsigned int NDimensions = 3 >
-class MetaVesselTubeConverter :
+class ITK_TEMPLATE_EXPORT MetaVesselTubeConverter :
     public MetaConverterBase< NDimensions >
 {
 public:
@@ -71,8 +71,7 @@ protected:
   ~MetaVesselTubeConverter() {}
 
 private:
-  MetaVesselTubeConverter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(MetaVesselTubeConverter);
 
 };
 
