@@ -34,7 +34,7 @@ namespace itk
  */
 
 template< unsigned int TDimension = 3  >
-class PlaneSpatialObject:
+class ITK_TEMPLATE_EXPORT PlaneSpatialObject:
   public SpatialObject< TDimension >
 {
 public:
@@ -88,8 +88,7 @@ public:
   itkGetMacro(UpperPoint, PointType);
 
 protected:
-  PlaneSpatialObject(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(PlaneSpatialObject);
 
   PlaneSpatialObject();
   ~PlaneSpatialObject();
