@@ -27,7 +27,7 @@ namespace itk
  * \ingroup ITKSpatialObjects
  */
 template< unsigned int TDimension = 3 >
-class PolygonSpatialObject:
+class ITK_TEMPLATE_EXPORT PolygonSpatialObject:
   public BlobSpatialObject< TDimension >
 {
 public:
@@ -113,8 +113,7 @@ protected:
   void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  PolygonSpatialObject(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(PolygonSpatialObject);
 
   PolygonGroupOrientation m_Orientation;
   double                  m_Thickness;
