@@ -52,11 +52,12 @@ namespace itk
  * \ingroup ITKSpatialObjects
  */
 
+// Forward reference because of circular dependencies
 template< unsigned int VDimension >
-class SpatialObjectTreeNode;
+class ITK_FORWARD_EXPORT SpatialObjectTreeNode;
 
 template< unsigned int VDimension = 3 >
-class SpatialObject:
+class ITK_TEMPLATE_EXPORT SpatialObject:
   public DataObject
 {
 public:
@@ -159,10 +160,10 @@ public:
   void ComputeObjectToParentTransform();
 
   /** Return the Modified time of the LocalToWorldTransform */
-  unsigned long GetTransformMTime();
+  ModifiedTimeType GetTransformMTime();
 
   /** Return the Modified time of the WorldToLocalTransform */
-  unsigned long GetWorldTransformMTime();
+  ModifiedTimeType GetWorldTransformMTime();
 
   /** Returns the value at a point */
   virtual bool ValueAt(const PointType & point, double & value,
@@ -206,7 +207,7 @@ public:
 
   /** Returns the latest modified time of the spatial object, but not
    *  the modification time of the children */
-  unsigned long GetObjectMTime(void) const
+  ModifiedTimeType GetObjectMTime(void) const
   {
     return Superclass::GetMTime();
   }
@@ -561,8 +562,7 @@ protected:
 
 private:
 
-  SpatialObject(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(SpatialObject);
 
   BoundingBoxPointer       m_Bounds;
   mutable ModifiedTimeType m_BoundsMTime;
