@@ -90,8 +90,7 @@ protected:
   virtual ~SpatialObjectFactoryBase();
 
 private:
-  SpatialObjectFactoryBase(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(SpatialObjectFactoryBase);
 
   static ITKSpatialObjectExport SpatialObjectFactoryBase *m_Factory;
 };
