@@ -37,7 +37,7 @@ namespace itk
  * \endwiki
  */
 template< typename TInputSpatialObject, typename TOutputImage >
-class SpatialObjectToImageFilter:public ImageSource< TOutputImage >
+class ITK_TEMPLATE_EXPORT SpatialObjectToImageFilter:public ImageSource< TOutputImage >
 {
 public:
   /** Standard class typedefs. */
@@ -173,8 +173,7 @@ protected:
 
 private:
 
-  SpatialObjectToImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(SpatialObjectToImageFilter);
 };
 } // end namespace itk
 
