@@ -34,7 +34,7 @@ namespace itk
  * \ingroup ITKSpatialObjects
  */
 template< typename TInputImage, typename TInputSpatialObject, unsigned int TSampleDimension = 1 >
-class SpatialObjectToImageStatisticsCalculator:public Object
+class ITK_TEMPLATE_EXPORT SpatialObjectToImageStatisticsCalculator:public Object
 {
 public:
   /** Standard class typedefs. */
@@ -116,8 +116,7 @@ protected:
   bool ComputeStatistics();
 
 private:
-  SpatialObjectToImageStatisticsCalculator(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(SpatialObjectToImageStatisticsCalculator);
 
   ImageConstPointer    m_Image;
   SpatialObjectPointer m_SpatialObject;
