@@ -31,7 +31,7 @@ namespace itk
  * \ingroup ITKSpatialObjects
  */
 template< typename TInputSpatialObject, typename TOutputPointSet >
-class SpatialObjectToPointSetFilter:public MeshSource< TOutputPointSet >
+class ITK_TEMPLATE_EXPORT SpatialObjectToPointSetFilter:public MeshSource< TOutputPointSet >
 {
 public:
   /** Standard class typedefs. */
@@ -71,8 +71,8 @@ public:
 
   virtual void SetInput(unsigned int, const InputSpatialObjectType *object);
 
+  /** Get the input Spatial Object. */
   const InputSpatialObjectType * GetInput();
-
   const InputSpatialObjectType * GetInput(unsigned int idx);
 
   /** The spatial object being transformed can be part of a hierarchy.
@@ -94,15 +94,13 @@ protected:
   virtual void GenerateOutputInformation() ITK_OVERRIDE {}  // do nothing
   virtual void GenerateData() ITK_OVERRIDE;
 
-  unsigned int m_ChildrenDepth;
-
   virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  SpatialObjectToPointSetFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(SpatialObjectToPointSetFilter);
 
-  unsigned int m_SamplingFactor; //default 1
+  unsigned int m_ChildrenDepth;
+  unsigned int m_SamplingFactor;
 };
 } // end namespace itk
 
