@@ -23,8 +23,10 @@
 
 namespace itk
 {
+
+// Forward reference because of circular dependencies
 template< unsigned int TDimension >
-class SpatialObject;
+class ITK_FORWARD_EXPORT SpatialObject;
 
 /** \class SpatialObjectTreeContainer
  *  \brief Array class with size defined at construction time.
@@ -44,7 +46,7 @@ class SpatialObject;
  * \ingroup ITKSpatialObjects
  */
 template< unsigned int TDimension >
-class SpatialObjectTreeContainer:
+class ITK_TEMPLATE_EXPORT SpatialObjectTreeContainer:
   public TreeContainer< itk::SpatialObject< TDimension > * >
 {
 public:
