@@ -36,7 +36,7 @@ namespace itk
  */
 
 template< unsigned int TDimension = 3 >
-class SurfaceSpatialObject:
+class ITK_TEMPLATE_EXPORT SurfaceSpatialObject:
   public PointBasedSpatialObject<  TDimension >
 {
 public:
@@ -112,8 +112,7 @@ public:
   bool Approximate3DNormals();
 
 protected:
-  SurfaceSpatialObject(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(SurfaceSpatialObject);
 
   PointListType m_Points;
 
