@@ -68,8 +68,8 @@ int itkSpatialObjectToImageStatisticsCalculatorTest(int, char * [] )
   std::cout << "Sample mean = " << calculator->GetMean() << std::endl;
   std::cout << "Sample covariance = " << calculator->GetCovarianceMatrix();
 
-  if(calculator->GetMean() != 255
-    || calculator->GetCovarianceMatrix()[0][0] != 0
+  if(calculator->GetMean() != CalculatorType::VectorType(255)
+    || itk::Math::NotAlmostEquals( calculator->GetCovarianceMatrix()[0][0], itk::NumericTraits< CalculatorType::MatrixType::ValueType >::ZeroValue() )
     )
     {
     std::cout << "[FAILED]" << std::endl;
