@@ -63,8 +63,7 @@ public:
 protected:
 
 private:
-  DifferenceImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(DifferenceImageFilter);
 
 };
 } // end namespace itk
