@@ -51,7 +51,7 @@ namespace itk
  * \endwiki
  */
 template< typename TOutputImage >
-class RandomImageSource:public ImageSource< TOutputImage >
+class ITK_TEMPLATE_EXPORT RandomImageSource:public ImageSource< TOutputImage >
 {
 public:
   /** Standard class typedefs. */
@@ -136,8 +136,7 @@ protected:
   virtual void GenerateOutputInformation() ITK_OVERRIDE;
 
 private:
-  RandomImageSource(const RandomImageSource &) ITK_DELETE_FUNCTION;
-  void operator=(const RandomImageSource &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(RandomImageSource);
 
   SizeType      m_Size;      //size of the output image
   SpacingType   m_Spacing;   //spacing
