@@ -99,7 +99,7 @@ template<
   typename TParametersValueType = double,
   unsigned int NDimensions = 3 >
 // Number of dimensions in the input space
-class AffineTransform:
+class ITK_TEMPLATE_EXPORT AffineTransform:
   public MatrixOffsetTransformBase< TParametersValueType, NDimensions, NDimensions>
 {
 public:
@@ -264,7 +264,7 @@ public:
 
   /** Compute distance between two affine transformations
    *
-   * This method computes a ``distance'' between two affine
+   * This method computes a "distance" between two affine
    * transformations.  This distance is guaranteed to be a metric,
    * but not any particular metric.  (At the moment, the algorithm
    * is to collect all the elements of the matrix and offset into a
