@@ -82,7 +82,7 @@ namespace itk
  */
 template<typename TParametersValueType=double,
          unsigned int NDimensions = 3>
-class AzimuthElevationToCartesianTransform:
+class ITK_TEMPLATE_EXPORT AzimuthElevationToCartesianTransform:
   public AffineTransform<TParametersValueType, NDimensions>
 {
 public:
@@ -104,8 +104,9 @@ public:
   itkNewMacro(Self);
 
   /** Parameters type.   */
-  typedef typename Superclass::ParametersType      ParametersType;
-  typedef typename Superclass::FixedParametersType FixedParametersType;
+  typedef typename Superclass::ParametersType        ParametersType;
+  typedef typename Superclass::FixedParametersType   FixedParametersType;
+  typedef typename Superclass::TransformCategoryType TransformCategoryType;
 
   /** Jacobian type.   */
   typedef typename Superclass::JacobianType JacobianType;
@@ -159,6 +160,14 @@ public:
     return BackTransform(point);
   }
 
+
+  /** Overrides the TransformCategoryType to  UnknownTransformCategory. Even though
+  this class derives from AffineTransform, its not a linear transform */
+  virtual TransformCategoryType GetTransformCategory() const ITK_OVERRIDE
+  {
+       return Self::UnknownTransformCategory;
+  }
+
   /** Defines that the forward transform goes from azimuth,elevation to
    *  cartesian. */
   void SetForwardAzimuthElevationToCartesian();
@@ -216,8 +225,7 @@ protected:
   void PrintSelf(std::ostream & s, Indent indent) const ITK_OVERRIDE;
 
 private:
-  AzimuthElevationToCartesianTransform(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(AzimuthElevationToCartesianTransform);
 
   long   m_MaxAzimuth;
   long   m_MaxElevation;
