@@ -33,7 +33,7 @@ namespace itk
 template<typename TParametersValueType=double,
            unsigned int NDimensions = 3,
           unsigned int VSplineOrder = 3>
-class BSplineBaseTransform :
+class ITK_TEMPLATE_EXPORT BSplineBaseTransform :
   public Transform<TParametersValueType, NDimensions, NDimensions>
 {
 public:
@@ -364,8 +364,7 @@ protected:
   typename WeightsFunctionType::Pointer m_WeightsFunction;
 
 private:
-  BSplineBaseTransform( const Self & ) ITK_DELETE_FUNCTION;
-  void operator=( const Self & ) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BSplineBaseTransform);
 
   static CoefficientImageArray ArrayOfImagePointerGeneratorHelper();
 }; // class BSplineBaseTransform
