@@ -113,7 +113,7 @@ namespace itk
 template<typename TParametersValueType=double,
           unsigned int NDimensions = 3,
           unsigned int VSplineOrder = 3>
-class BSplineDeformableTransform :
+class ITK_TEMPLATE_EXPORT BSplineDeformableTransform :
   public BSplineBaseTransform<TParametersValueType,NDimensions,VSplineOrder>
 {
 public:
@@ -335,8 +335,7 @@ private:
   /** Construct control point grid size from transform domain information */
   virtual void SetCoefficientImageInformationFromFixedParameters() ITK_OVERRIDE;
 
-  BSplineDeformableTransform( const Self & ) ITK_DELETE_FUNCTION;
-  void operator=( const Self & ) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BSplineDeformableTransform);
 
   /** Check if a continuous index is inside the valid region. */
   virtual bool InsideValidRegion( ContinuousIndexType & ) const ITK_OVERRIDE;
