@@ -108,7 +108,7 @@ namespace itk
 template<typename TParametersValueType=double,
           unsigned int NDimensions = 3,
           unsigned int VSplineOrder = 3>
-class BSplineTransform :
+class ITK_TEMPLATE_EXPORT BSplineTransform :
   public BSplineBaseTransform<TParametersValueType,NDimensions,VSplineOrder>
 {
 public:
@@ -162,6 +162,8 @@ public:
   typedef typename Superclass::OutputPointType OutputPointType;
 
 
+  virtual std::string GetTransformTypeAsString() const ITK_OVERRIDE;
+
   /** This method sets the fixed parameters of the transform.
    * For a BSpline deformation transform, the fixed parameters are the
    * following: grid size, grid origin, grid spacing, and grid direction.
@@ -234,12 +236,13 @@ public:
   virtual void TransformPoint( const InputPointType & inputPoint, OutputPointType & outputPoint,
     WeightsType & weights, ParameterIndexArrayType & indices, bool & inside ) const ITK_OVERRIDE;
 
+  /** Compute the Jacobian in one position. */
   virtual void ComputeJacobianWithRespectToParameters( const InputPointType &, JacobianType & ) const ITK_OVERRIDE;
 
-  /** Return the number of parameters that completely define the Transfom */
+  /** Return the number of parameters that completely define the Transfom. */
   virtual NumberOfParametersType GetNumberOfParameters() const ITK_OVERRIDE;
 
-  /** Return the number of parameters per dimension */
+  /** Return the number of parameters per dimension. */
   NumberOfParametersType GetNumberOfParametersPerDimension() const ITK_OVERRIDE;
 
   typedef typename Superclass::SpacingType   PhysicalDimensionsType;
@@ -280,27 +283,28 @@ protected:
 
 private:
 
-  /** Construct control point grid size from transform domain information */
+  /** Construct control point grid size from transform domain information. */
   virtual void SetFixedParametersGridSizeFromTransformDomainInformation() const ITK_OVERRIDE;
 
-  /** Construct control point grid origin from transform domain information */
+  /** Construct control point grid origin from transform domain information. */
   virtual void SetFixedParametersGridOriginFromTransformDomainInformation() const ITK_OVERRIDE;
 
-  /** Construct control point grid spacing from transform domain information */
+  /** Construct control point grid spacing from transform domain information. */
   virtual void SetFixedParametersGridSpacingFromTransformDomainInformation() const ITK_OVERRIDE;
 
-  /** Construct control point grid direction from transform domain information */
+  /** Construct control point grid direction from transform domain information. */
   virtual void SetFixedParametersGridDirectionFromTransformDomainInformation() const ITK_OVERRIDE;
 
-  /** Construct control point grid size from transform domain information */
+  /** Construct control point grid size from transform domain information. */
   virtual void SetCoefficientImageInformationFromFixedParameters() ITK_OVERRIDE;
 
-  BSplineTransform( const Self & ) ITK_DELETE_FUNCTION;
-  void operator=( const Self & ) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BSplineTransform);
 
   /** Check if a continuous index is inside the valid region. */
   virtual bool InsideValidRegion( ContinuousIndexType & ) const ITK_OVERRIDE;
 
+private:
+
   OriginType             m_TransformDomainOrigin;
   PhysicalDimensionsType m_TransformDomainPhysicalDimensions;
   DirectionType          m_TransformDomainDirection;
