@@ -52,7 +52,7 @@ namespace itk
  * \ingroup ITKTransform
  */
 template<typename TParametersValueType=double>
-class CenteredSimilarity2DTransform :
+class ITK_TEMPLATE_EXPORT CenteredSimilarity2DTransform :
   public Similarity2DTransform<TParametersValueType>
 {
 public:
@@ -171,8 +171,7 @@ protected:
   virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  CenteredSimilarity2DTransform(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(CenteredSimilarity2DTransform);
 };
 
 } // end namespace itk
