@@ -84,7 +84,7 @@ namespace itk
  * \ingroup ITKTransform
  */
 template<typename TParametersValueType=double, unsigned int NDimensions = 3>
-class CompositeTransform :
+class ITK_TEMPLATE_EXPORT CompositeTransform :
   public MultiTransform<TParametersValueType, NDimensions, NDimensions>
 {
 public:
@@ -413,8 +413,7 @@ protected:
   mutable TransformsToOptimizeFlagsType m_TransformsToOptimizeFlags;
 
 private:
-  CompositeTransform( const Self & ) ITK_DELETE_FUNCTION;
-  void operator=( const Self & ) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(CompositeTransform);
 
   mutable ModifiedTimeType m_PreviousTransformsToOptimizeUpdateTime;
 
