@@ -36,7 +36,7 @@ namespace itk
  */
 template<typename TParametersValueType=double,
           unsigned int NDimensions=3>
-class ElasticBodyReciprocalSplineKernelTransform:
+class ITK_TEMPLATE_EXPORT ElasticBodyReciprocalSplineKernelTransform:
   public KernelTransform<TParametersValueType, NDimensions>
 {
 public:
@@ -104,8 +104,7 @@ protected:
   TParametersValueType m_Alpha;
 
 private:
-  ElasticBodyReciprocalSplineKernelTransform(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ElasticBodyReciprocalSplineKernelTransform);
 };
 } // namespace itk
 
