@@ -38,7 +38,7 @@ namespace itk
  * \ingroup ITKTransform
  */
 template<typename TParametersValueType=double>
-class Euler2DTransform:
+class ITK_TEMPLATE_EXPORT Euler2DTransform:
   public Rigid2DTransform<TParametersValueType>
 {
 public:
@@ -122,8 +122,7 @@ protected:
   void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  Euler2DTransform(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(Euler2DTransform);
 };                                //class Euler2DTransform
 }  // namespace itk
 
