@@ -44,7 +44,7 @@ namespace itk
  * \ingroup ITKTransform
  */
 template<typename TParametersValueType=double >
-class Euler3DTransform :
+class ITK_TEMPLATE_EXPORT Euler3DTransform :
   public Rigid3DTransform<TParametersValueType>
 {
 public:
@@ -142,8 +142,7 @@ protected:
   void ComputeMatrixParameters(void) ITK_OVERRIDE;
 
 private:
-  Euler3DTransform(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(Euler3DTransform);
 
   ScalarType m_AngleX;
   ScalarType m_AngleY;
