@@ -53,7 +53,7 @@ namespace itk
  * \ingroup ITKTransform
  */
 template<typename TParametersValueType=double>
-class Rigid2DTransform :
+class ITK_TEMPLATE_EXPORT Rigid2DTransform :
   public MatrixOffsetTransformBase<TParametersValueType, 2, 2>
 {
 public:
@@ -275,8 +275,7 @@ protected:
   }
 
 private:
-  Rigid2DTransform(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(Rigid2DTransform);
 
   TParametersValueType m_Angle;
 
