@@ -35,7 +35,7 @@ namespace itk
  */
 
 template<typename TParametersValueType=double>
-class Rigid3DPerspectiveTransform :
+class ITK_TEMPLATE_EXPORT Rigid3DPerspectiveTransform :
   public Transform<TParametersValueType, 3, 2>
 {
 public:
@@ -232,8 +232,7 @@ protected:
   void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  Rigid3DPerspectiveTransform(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(Rigid3DPerspectiveTransform);
 
   /** Offset of the transformation. */
   OffsetType m_Offset;
