@@ -54,7 +54,7 @@ namespace itk
  * \ingroup ITKTransform
  */
 template<typename TParametersValueType=double>
-class Rigid3DTransform:
+class ITK_TEMPLATE_EXPORT Rigid3DTransform:
   public MatrixOffsetTransformBase<TParametersValueType, 3, 3>
 {
 public:
@@ -217,8 +217,7 @@ protected:
   void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  Rigid3DTransform(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(Rigid3DTransform);
 };                                //class Rigid3DTransform
 }  // namespace itk
 
