@@ -51,7 +51,7 @@ namespace itk
  * \ingroup ITKTransform
  */
 template<typename TParametersValueType=double>
-class ScaleSkewVersor3DTransform :
+class ITK_TEMPLATE_EXPORT ScaleSkewVersor3DTransform :
   public VersorRigid3DTransform<TParametersValueType>
 {
 public:
@@ -168,8 +168,7 @@ protected:
   void ComputeMatrixParameters(void) ITK_OVERRIDE;
 
 private:
-  ScaleSkewVersor3DTransform(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ScaleSkewVersor3DTransform);
 
   /**  Vector containing the scale. */
   ScaleVectorType m_Scale;
