@@ -39,7 +39,7 @@ namespace itk
  */
 template<typename TParametersValueType=float,
           unsigned int NDimensions=3>
-class ScaleTransform : public MatrixOffsetTransformBase<TParametersValueType,
+class ITK_TEMPLATE_EXPORT ScaleTransform : public MatrixOffsetTransformBase<TParametersValueType,
                                                         NDimensions,
                                                         NDimensions>
 {
@@ -208,8 +208,7 @@ protected:
   virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  ScaleTransform(const Self & other) ITK_DELETE_FUNCTION;
-  const Self & operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ScaleTransform);
 
   ScaleType m_Scale;    // Scales of the transformation
 
