@@ -46,7 +46,7 @@ namespace itk
  * \ingroup ITKTransform
  */
 template<typename TParametersValueType=double>
-class ScaleVersor3DTransform : public VersorRigid3DTransform<TParametersValueType>
+class ITK_TEMPLATE_EXPORT ScaleVersor3DTransform : public VersorRigid3DTransform<TParametersValueType>
 {
 public:
   /** Standard class typedefs. */
@@ -146,8 +146,7 @@ protected:
   void ComputeMatrixParameters(void) ITK_OVERRIDE;
 
 private:
-  ScaleVersor3DTransform(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ScaleVersor3DTransform);
 
   /**  Vector containing the scale. */
   ScaleVectorType m_Scale;
