@@ -59,7 +59,7 @@ namespace itk
  * \ingroup ITKTransform
  */
 template<typename TParametersValueType=double>
-class Similarity2DTransform :
+class ITK_TEMPLATE_EXPORT Similarity2DTransform :
   public Rigid2DTransform<TParametersValueType>
 {
 public:
@@ -233,8 +233,7 @@ protected:
   }
 
 private:
-  Similarity2DTransform(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(Similarity2DTransform);
 
   ScaleType m_Scale;
 }; // class Similarity2DTransform
