@@ -35,7 +35,7 @@ namespace itk
 template<typename TParametersValueType,
           unsigned int NDimensions = 3>
 // Number of dimensions
-class ThinPlateR2LogRSplineKernelTransform:
+class ITK_TEMPLATE_EXPORT ThinPlateR2LogRSplineKernelTransform:
   public KernelTransform<TParametersValueType, NDimensions>
 {
 public:
@@ -93,8 +93,7 @@ protected:
                                               OutputPointType & result) const ITK_OVERRIDE;
 
 private:
-  ThinPlateR2LogRSplineKernelTransform(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ThinPlateR2LogRSplineKernelTransform);
 };
 } // namespace itk
 
