@@ -33,7 +33,7 @@ namespace itk
 template<typename TParametersValueType,
           unsigned int NDimensions = 3>
 // Number of dimensions
-class ThinPlateSplineKernelTransform:
+class ITK_TEMPLATE_EXPORT ThinPlateSplineKernelTransform:
   public KernelTransform<TParametersValueType, NDimensions>
 {
 public:
@@ -94,8 +94,7 @@ protected:
                                               OutputPointType & result) const ITK_OVERRIDE;
 
 private:
-  ThinPlateSplineKernelTransform(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ThinPlateSplineKernelTransform);
 };
 } // namespace itk
 
