@@ -79,7 +79,7 @@ namespace itk
 template<typename TParametersValueType,
           unsigned int NInputDimensions = 3,
           unsigned int NOutputDimensions = 3>
-class Transform : public TransformBaseTemplate<TParametersValueType>
+class ITK_TEMPLATE_EXPORT Transform : public TransformBaseTemplate<TParametersValueType>
 {
 public:
   /** Standard class typedefs. */
@@ -577,8 +577,7 @@ protected:
 
 
 private:
-  Transform(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(Transform);
 
   template <typename TType>
   static std::string GetTransformTypeAsString(TType *)
