@@ -142,8 +142,7 @@ protected:
   virtual ~TransformBaseTemplate() {}
 
 private:
-  TransformBaseTemplate(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(TransformBaseTemplate);
 };
 
 /** This helps to meet backward compatibility */
@@ -165,7 +164,7 @@ typedef TransformBaseTemplate< double > TransformBase;
 //
 #  if defined( ITKTransform_EXPORTS )
 //   We are building this library
-#    define ITKTransform_EXPORT_EXPLICIT
+#    define ITKTransform_EXPORT_EXPLICIT ITK_TEMPLATE_EXPORT
 #  else
 //   We are using this library
 #    define ITKTransform_EXPORT_EXPLICIT ITKTransform_EXPORT
