@@ -33,7 +33,7 @@ namespace itk
 template<typename TParametersValueType,
          unsigned int NDimensions=3>
 // Number of dimensions
-class VolumeSplineKernelTransform:
+class ITK_TEMPLATE_EXPORT VolumeSplineKernelTransform:
   public KernelTransform<TParametersValueType, NDimensions>
 {
 public:
@@ -97,8 +97,7 @@ protected:
     OutputPointType & result) const ITK_OVERRIDE;
 
 private:
-  VolumeSplineKernelTransform(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(VolumeSplineKernelTransform);
 };
 } // namespace itk
 
