@@ -34,7 +34,7 @@ namespace itk
  * analog of that equation and will be referred to below as the \em modified
  * \em curvature \em diffusion \em equation (MCDE).  MCDE does not exhibit
  * the edge enhancing properties of classic anisotropic diffusion, which can under
- * certain conditions undergo a ``negative'' diffusion,which enhances the
+ * certain conditions undergo a "negative" diffusion,which enhances the
  * contrast of edges.  Equations of the form of MCDE always undergo positive
  * diffusion, with the conductance term only varying the strength of that
  * diffusion.
@@ -72,7 +72,7 @@ namespace itk
  * \ingroup ITKAnisotropicSmoothing
  */
 template< typename TImage >
-class CurvatureNDAnisotropicDiffusionFunction:
+class ITK_TEMPLATE_EXPORT CurvatureNDAnisotropicDiffusionFunction:
   public ScalarAnisotropicDiffusionFunction< TImage >
 {
 public:
@@ -121,8 +121,7 @@ protected:
   ~CurvatureNDAnisotropicDiffusionFunction() {}
 
 private:
-  CurvatureNDAnisotropicDiffusionFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(CurvatureNDAnisotropicDiffusionFunction);
 
   /** Inner product function. */
   NeighborhoodInnerProduct< ImageType > m_InnerProduct;
