@@ -89,8 +89,7 @@ protected:
   ~GradientAnisotropicDiffusionImageFilter() {}
 
 private:
-  GradientAnisotropicDiffusionImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GradientAnisotropicDiffusionImageFilter);
 };
 } // end namspace itk
 
