@@ -58,7 +58,7 @@ namespace itk
  * \ingroup ITKAnisotropicSmoothing
  */
 template< typename TImage >
-class GradientNDAnisotropicDiffusionFunction:
+class ITK_TEMPLATE_EXPORT GradientNDAnisotropicDiffusionFunction:
   public ScalarAnisotropicDiffusionFunction< TImage >
 {
 public:
@@ -126,8 +126,7 @@ protected:
   static double m_MIN_NORM;
 
 private:
-  GradientNDAnisotropicDiffusionFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GradientNDAnisotropicDiffusionFunction);
 };
 } // end namespace itk
 
