@@ -38,7 +38,7 @@ namespace itk
  * \ingroup ITKAnisotropicSmoothing
  */
 template< typename TImage >
-class ScalarAnisotropicDiffusionFunction:
+class ITK_TEMPLATE_EXPORT ScalarAnisotropicDiffusionFunction:
   public AnisotropicDiffusionFunction< TImage >
 {
 public:
@@ -71,8 +71,7 @@ protected:
   ~ScalarAnisotropicDiffusionFunction() {}
 
 private:
-  ScalarAnisotropicDiffusionFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ScalarAnisotropicDiffusionFunction);
 };
 } // end namespace itk
 
