@@ -115,8 +115,7 @@ protected:
   }
 
 private:
-  VectorCurvatureAnisotropicDiffusionImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(VectorCurvatureAnisotropicDiffusionImageFilter);
 };
 } // end namspace itk
 
