@@ -103,8 +103,7 @@ protected:
   ~VectorGradientAnisotropicDiffusionImageFilter() {}
 
 private:
-  VectorGradientAnisotropicDiffusionImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(VectorGradientAnisotropicDiffusionImageFilter);
 };
 } // end namspace itk
 
