@@ -15,11 +15,12 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __itkCacheableScalarFunction_h
-#define __itkCacheableScalarFunction_h
+#ifndef itkCacheableScalarFunction_h
+#define itkCacheableScalarFunction_h
 
 #include "itkArray.h"
 #include "itkIntTypes.h"
+#include "ITKBiasCorrectionExport.h"
 
 namespace itk
 {
@@ -55,14 +56,14 @@ namespace itk
  * energy values again and again for each iteration.
  * \ingroup ITKBiasCorrection
  */
-class CacheableScalarFunction
+class ITKBiasCorrection_EXPORT CacheableScalarFunction
 {
 public:
   /** Constructor. */
   CacheableScalarFunction();
 
   /** Destructor. */
-  virtual ~CacheableScalarFunction() {}
+  virtual ~CacheableScalarFunction();
 
   /** Function's input and output value type. */
   typedef double               MeasureType;
@@ -84,8 +85,7 @@ public:
   /** y = f(x)
    * Subclasses of this class should override this member function
    * to provide their own functional operation . */
-  virtual MeasureType Evaluate(MeasureType x)
-  { return x; }
+  virtual MeasureType Evaluate(MeasureType x);
 
   /** Gets the interval of each cell between the upper and lower bound */
   double GetInterval()
