@@ -46,7 +46,7 @@ namespace itk {
  */
 
 template<typename TInputImage, typename TKernel>
-class BinaryClosingByReconstructionImageFilter :
+class ITK_TEMPLATE_EXPORT BinaryClosingByReconstructionImageFilter :
     public KernelImageFilter<TInputImage, TInputImage, TKernel>
 {
 public:
@@ -111,8 +111,7 @@ protected:
   void  GenerateData () ITK_OVERRIDE;
 
 private:
-  BinaryClosingByReconstructionImageFilter(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BinaryClosingByReconstructionImageFilter);
 
   InputPixelType m_ForegroundValue;
 
