@@ -52,7 +52,7 @@ namespace itk
  */
 
 template< typename TInputImage, typename TOutputImage, typename TKernel >
-class BinaryMorphologicalClosingImageFilter:
+class ITK_TEMPLATE_EXPORT BinaryMorphologicalClosingImageFilter:
   public KernelImageFilter< TInputImage, TOutputImage, TKernel >
 {
 public:
@@ -105,8 +105,7 @@ protected:
   void  GenerateData() ITK_OVERRIDE;
 
 private:
-  BinaryMorphologicalClosingImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BinaryMorphologicalClosingImageFilter);
 
   InputPixelType m_ForegroundValue;
 
