@@ -100,7 +100,7 @@ namespace itk
  * \ingroup ITKBinaryMathematicalMorphology
  */
 template< typename TInputImage, typename TOutputImage, typename TKernel >
-class BinaryMorphologyImageFilter:
+class ITK_TEMPLATE_EXPORT BinaryMorphologyImageFilter:
   public KernelImageFilter< TInputImage, TOutputImage, TKernel >
 {
 public:
@@ -224,8 +224,7 @@ protected:
   bool m_BoundaryToForeground;
 
 private:
-  BinaryMorphologyImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BinaryMorphologyImageFilter);
 
   /** Pixel value to dilate */
   InputPixelType m_ForegroundValue;
