@@ -46,7 +46,7 @@ namespace itk {
  */
 
 template<typename TInputImage, typename TKernel>
-class BinaryOpeningByReconstructionImageFilter :
+class ITK_TEMPLATE_EXPORT BinaryOpeningByReconstructionImageFilter :
     public KernelImageFilter<TInputImage, TInputImage, TKernel>
 {
 public:
@@ -116,8 +116,7 @@ protected:
   void  GenerateData () ITK_OVERRIDE;
 
 private:
-  BinaryOpeningByReconstructionImageFilter(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BinaryOpeningByReconstructionImageFilter);
 
   PixelType  m_ForegroundValue;
 
