@@ -51,7 +51,7 @@ namespace itk
  */
 
 template< typename TInputImage, typename TOutputImage >
-class BinaryPruningImageFilter:
+class ITK_TEMPLATE_EXPORT BinaryPruningImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -137,8 +137,7 @@ protected:
   void ComputePruneImage();
 
 private:
-  BinaryPruningImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BinaryPruningImageFilter);
 
   unsigned int m_Iteration;
 }; // end of BinaryThinningImageFilter class
