@@ -58,7 +58,7 @@ namespace itk
  */
 
 template< typename TInputImage, typename TOutputImage >
-class BinaryThinningImageFilter:
+class ITK_TEMPLATE_EXPORT BinaryThinningImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -142,8 +142,7 @@ protected:
   void ComputeThinImage();
 
 private:
-  BinaryThinningImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BinaryThinningImageFilter);
 };                                         // end of BinaryThinningImageFilter
                                            // class
 } //end namespace itk
