@@ -43,7 +43,7 @@ namespace itk
  * \ingroup ITKBinaryMathematicalMorphology
  */
 template< typename TInputImage, typename TOutputImage, typename TKernel >
-class ErodeObjectMorphologyImageFilter:
+class ITK_TEMPLATE_EXPORT ErodeObjectMorphologyImageFilter:
   public ObjectMorphologyImageFilter< TInputImage, TOutputImage, TKernel >
 {
 public:
@@ -117,8 +117,7 @@ protected:
                 const KernelType & kernel) ITK_OVERRIDE;
 
 private:
-  ErodeObjectMorphologyImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ErodeObjectMorphologyImageFilter);
 
   PixelType m_BackgroundValue;
 
