@@ -41,7 +41,7 @@ namespace Function
  * \ingroup ITKColormap
  */
 template< typename TScalar, typename TRGBPixel >
-class AutumnColormapFunction:
+class ITK_TEMPLATE_EXPORT AutumnColormapFunction:
   public ColormapFunction< TScalar, TRGBPixel >
 {
 public:
@@ -65,8 +65,7 @@ protected:
   ~AutumnColormapFunction() {}
 
 private:
-  AutumnColormapFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(AutumnColormapFunction);
 };
 } // end namespace functor
 } // end namespace itk
