@@ -41,7 +41,7 @@ namespace Function
  * \ingroup ITKColormap
  */
 template< typename TScalar, typename TRGBPixel >
-class CoolColormapFunction:
+class ITK_TEMPLATE_EXPORT CoolColormapFunction:
   public ColormapFunction< TScalar, TRGBPixel >
 {
 public:
@@ -65,8 +65,7 @@ protected:
   ~CoolColormapFunction() {}
 
 private:
-  CoolColormapFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(CoolColormapFunction);
 };
 } // end namespace functor
 } // end namespace itk
