@@ -41,7 +41,7 @@ namespace Function
  * \ingroup ITKColormap
  */
 template< typename TScalar, typename TRGBPixel >
-class CopperColormapFunction:
+class ITK_TEMPLATE_EXPORT CopperColormapFunction:
   public ColormapFunction< TScalar, TRGBPixel >
 {
 public:
@@ -65,8 +65,7 @@ protected:
   ~CopperColormapFunction() {}
 
 private:
-  CopperColormapFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(CopperColormapFunction);
 };
 } // end namespace functor
 } // end namespace itk
