@@ -42,7 +42,7 @@ namespace Function
  * \ingroup ITKColormap
  */
 template< typename TScalar, typename TRGBPixel >
-class CustomColormapFunction:
+class ITK_TEMPLATE_EXPORT CustomColormapFunction:
   public ColormapFunction< TScalar, TRGBPixel >
 {
 public:
@@ -98,8 +98,7 @@ protected:
   ~CustomColormapFunction() {}
 
 private:
-  CustomColormapFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(CustomColormapFunction);
 
   ChannelType m_RedChannel;
   ChannelType m_GreenChannel;
