@@ -42,7 +42,7 @@ namespace Function
  * \ingroup ITKColormap
  */
 template< typename TScalar, typename TRGBPixel >
-class GreyColormapFunction:
+class ITK_TEMPLATE_EXPORT GreyColormapFunction:
   public ColormapFunction< TScalar, TRGBPixel >
 {
 public:
@@ -66,8 +66,7 @@ protected:
   ~GreyColormapFunction() {}
 
 private:
-  GreyColormapFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GreyColormapFunction);
 };
 } // end namespace functor
 } // end namespace itk
