@@ -42,7 +42,7 @@ namespace Function
  * \ingroup ITKColormap
  */
 template< typename TScalar, typename TRGBPixel >
-class OverUnderColormapFunction:
+class ITK_TEMPLATE_EXPORT OverUnderColormapFunction:
   public ColormapFunction< TScalar, TRGBPixel >
 {
 public:
@@ -66,8 +66,7 @@ protected:
   ~OverUnderColormapFunction() {}
 
 private:
-  OverUnderColormapFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(OverUnderColormapFunction);
 };
 } // end namespace functor
 } // end namespace itk
