@@ -42,7 +42,7 @@ namespace Function
  * \ingroup ITKColormap
  */
 template< typename TScalar, typename TRGBPixel >
-class SummerColormapFunction:
+class ITK_TEMPLATE_EXPORT SummerColormapFunction:
   public ColormapFunction< TScalar, TRGBPixel >
 {
 public:
@@ -66,8 +66,7 @@ protected:
   ~SummerColormapFunction() {}
 
 private:
-  SummerColormapFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(SummerColormapFunction);
 };
 } // end namespace functor
 } // end namespace itk
