@@ -51,7 +51,7 @@ namespace itk
  *
  */
 template< typename TInputImage, typename TKernelImage = TInputImage, typename TOutputImage = TInputImage, typename TInternalPrecision=double >
-class FFTConvolutionImageFilter :
+class ITK_TEMPLATE_EXPORT FFTConvolutionImageFilter :
   public ConvolutionImageFilterBase< TInputImage, TKernelImage, TOutputImage >
 
 {
@@ -190,8 +190,7 @@ protected:
   virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  FFTConvolutionImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(FFTConvolutionImageFilter);
 
   SizeValueType m_SizeGreatestPrimeFactor;
 };
