@@ -136,7 +136,7 @@ namespace itk
  */
 
 template <typename TInputImage, typename TOutputImage, typename TMaskImage=TInputImage >
-class MaskedFFTNormalizedCorrelationImageFilter :
+class ITK_TEMPLATE_EXPORT MaskedFFTNormalizedCorrelationImageFilter :
     public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -316,8 +316,7 @@ protected:
   double CalculatePrecisionTolerance( LocalInputImageType * inputImage );
 
 private:
-  MaskedFFTNormalizedCorrelationImageFilter(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(MaskedFFTNormalizedCorrelationImageFilter);
 
   /** Larger values zero-out pixels on a larger border around the correlation image.
    * Thus, larger values remove less stable computations but also limit the capture range.
