@@ -48,7 +48,7 @@ namespace itk
  */
 template< typename TInputImage, typename TMaskImage, typename TOutputImage, typename TOperatorValueType =
             typename TOutputImage::PixelType >
-class NormalizedCorrelationImageFilter:
+class ITK_TEMPLATE_EXPORT NormalizedCorrelationImageFilter:
   public NeighborhoodOperatorImageFilter< TInputImage, TOutputImage, TOperatorValueType >
 {
 public:
@@ -163,8 +163,7 @@ protected:
   {  Superclass::PrintSelf(os, indent); }
 
 private:
-  NormalizedCorrelationImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(NormalizedCorrelationImageFilter);
 };
 } // end namespace itk
 
