@@ -39,7 +39,7 @@ namespace itk
  * \ingroup ITKCurvatureFlow
  */
 template< typename TImage >
-class BinaryMinMaxCurvatureFlowFunction:
+class ITK_TEMPLATE_EXPORT BinaryMinMaxCurvatureFlowFunction:
   public MinMaxCurvatureFlowFunction< TImage >
 {
 public:
@@ -84,8 +84,7 @@ protected:
   ~BinaryMinMaxCurvatureFlowFunction() {}
 
 private:
-  BinaryMinMaxCurvatureFlowFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BinaryMinMaxCurvatureFlowFunction);
 
   double m_Threshold;
 };
