@@ -73,7 +73,7 @@ namespace itk
  * \ingroup ITKCurvatureFlow
  */
 template< typename TInputImage, typename TOutputImage >
-class BinaryMinMaxCurvatureFlowImageFilter:
+class ITK_TEMPLATE_EXPORT BinaryMinMaxCurvatureFlowImageFilter:
   public MinMaxCurvatureFlowImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -124,8 +124,7 @@ protected:
   virtual void InitializeIteration() ITK_OVERRIDE;
 
 private:
-  BinaryMinMaxCurvatureFlowImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BinaryMinMaxCurvatureFlowImageFilter);
 
   double m_Threshold;
 };
