@@ -40,7 +40,7 @@ namespace itk
  * \ingroup ITKCurvatureFlow
  */
 template< typename TImage >
-class CurvatureFlowFunction:
+class ITK_TEMPLATE_EXPORT CurvatureFlowFunction:
   public FiniteDifferenceFunction< TImage >
 {
 public:
@@ -140,8 +140,7 @@ protected:
   ~CurvatureFlowFunction() {}
 
 private:
-  CurvatureFlowFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(CurvatureFlowFunction);
 
   TimeStepType m_TimeStep;
 };
