@@ -87,7 +87,7 @@ namespace itk
   * \ingroup ITKCurvatureFlow
   */
 template< typename TInputImage, typename TOutputImage >
-class CurvatureFlowImageFilter:
+class ITK_TEMPLATE_EXPORT CurvatureFlowImageFilter:
   public DenseFiniteDifferenceImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -189,8 +189,7 @@ protected:
   virtual void GenerateInputRequestedRegion() ITK_OVERRIDE;
 
 private:
-  CurvatureFlowImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(CurvatureFlowImageFilter);
 
   TimeStepType m_TimeStep;
 };
