@@ -39,7 +39,7 @@ namespace itk
  * \ingroup ITKCurvatureFlow
  */
 template< typename TImage >
-class MinMaxCurvatureFlowFunction:
+class ITK_TEMPLATE_EXPORT MinMaxCurvatureFlowFunction:
   public CurvatureFlowFunction< TImage >
 {
 public:
@@ -99,8 +99,7 @@ protected:
   void InitializeStencilOperator();
 
 private:
-  MinMaxCurvatureFlowFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(MinMaxCurvatureFlowFunction);
 
   RadiusValueType m_StencilRadius;
 
