@@ -76,8 +76,7 @@ protected:
   ~DummyFunction() {}
 
 private:
-  DummyFunction(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(DummyFunction);
 };
 
 }
