@@ -48,7 +48,7 @@ namespace itk
  * \ingroup ITKDeconvolution
  */
 template< typename TInputImage, typename TKernelImage=TInputImage, typename TOutputImage=TInputImage, typename TInternalPrecision=double >
-class IterativeDeconvolutionImageFilter :
+class ITK_TEMPLATE_EXPORT IterativeDeconvolutionImageFilter :
     public FFTConvolutionImageFilter< TInputImage, TKernelImage, TOutputImage, TInternalPrecision >
 {
 public:
@@ -137,8 +137,7 @@ protected:
   virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  IterativeDeconvolutionImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(IterativeDeconvolutionImageFilter);
 
   /** Number of iterations to run. */
   unsigned int m_NumberOfIterations;
