@@ -49,7 +49,7 @@ namespace itk
  * \sa LandweberDeconvolutionImageFilter
  */
 template< typename TInputImage, typename TKernelImage=TInputImage, typename TOutputImage=TInputImage, typename TInternalPrecision=double >
-class ProjectedLandweberDeconvolutionImageFilter :
+class ITK_TEMPLATE_EXPORT ProjectedLandweberDeconvolutionImageFilter :
     public ProjectedIterativeDeconvolutionImageFilter< LandweberDeconvolutionImageFilter< TInputImage, TKernelImage, TOutputImage, TInternalPrecision > >
 {
 public:
@@ -80,8 +80,7 @@ protected:
   virtual ~ProjectedLandweberDeconvolutionImageFilter();
 
 private:
-  ProjectedLandweberDeconvolutionImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ProjectedLandweberDeconvolutionImageFilter);
 
 };
 } // end namespace itk
