@@ -56,7 +56,7 @@ namespace itk
  *
  */
 template< typename TInputImage, typename TKernelImage=TInputImage, typename TOutputImage=TInputImage, typename TInternalPrecision=double >
-class RichardsonLucyDeconvolutionImageFilter :
+class ITK_TEMPLATE_EXPORT RichardsonLucyDeconvolutionImageFilter :
     public IterativeDeconvolutionImageFilter< TInputImage, TKernelImage, TOutputImage, TInternalPrecision >
 {
 public:
@@ -107,8 +107,7 @@ protected:
   virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  RichardsonLucyDeconvolutionImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(RichardsonLucyDeconvolutionImageFilter);
 
   /** Filters to compute each iterative update step. */
   typedef MultiplyImageFilter< InternalImageType >                 MultiplyFilterType;
