@@ -103,8 +103,7 @@ protected:
   virtual ~ExampleImageSource() {};
 
 private:
-  ExampleImageSource(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ExampleImageSource);
 };
 }
 
