@@ -176,7 +176,7 @@ int itkDiffusionTensor3DReconstructionImageFilterTest(int, char*[])
       for( unsigned int j = 0; j<3; j++ )
         {
         std::cout << tensorImage->GetPixel(tensorImageIndex)(i,j) << " ";
-        if( (vnl_math_abs(tensorImage->GetPixel(tensorImageIndex)(i,j) - expectedResult[i][j])) > precision )
+        if( (itk::Math::abs(tensorImage->GetPixel(tensorImageIndex)(i,j) - expectedResult[i][j])) > precision )
           {
           passed = false;
           }
