@@ -36,7 +36,7 @@ namespace itk
  * \ingroup ITKDisplacementField
  */
 template<typename TParametersValueType, unsigned int NDimensions>
-class GaussianSmoothingOnUpdateTimeVaryingVelocityFieldTransform
+class ITK_TEMPLATE_EXPORT GaussianSmoothingOnUpdateTimeVaryingVelocityFieldTransform
 : public TimeVaryingVelocityFieldTransform<TParametersValueType, NDimensions>
 {
 public:
@@ -132,8 +132,7 @@ protected:
   ScalarType                        m_GaussianTemporalSmoothingVarianceForTheTotalField;
 
 private:
-  GaussianSmoothingOnUpdateTimeVaryingVelocityFieldTransform( const Self& ) ITK_DELETE_FUNCTION;
-  void operator=( const Self& ) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GaussianSmoothingOnUpdateTimeVaryingVelocityFieldTransform);
 
 };
 
