@@ -62,7 +62,7 @@ namespace itk
  * \ingroup ITKDisplacementField
  */
 template< typename TInputImage, typename TOutputImage >
-class InverseDisplacementFieldImageFilter:
+class ITK_TEMPLATE_EXPORT InverseDisplacementFieldImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -189,8 +189,7 @@ protected:
   void PrepareKernelBaseSpline();
 
 private:
-  InverseDisplacementFieldImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(InverseDisplacementFieldImageFilter);
 
   SizeType                   m_Size;                 // Size of the output image
   KernelTransformPointerType m_KernelTransform;      // Coordinate transform to
