@@ -38,7 +38,7 @@ namespace itk
  */
 
 template <typename TInputImage, typename TOutputImage = TInputImage>
-class InvertDisplacementFieldImageFilter
+class ITK_TEMPLATE_EXPORT InvertDisplacementFieldImageFilter
   : public ImageToImageFilter<TInputImage, TOutputImage>
 {
 public:
@@ -151,8 +151,7 @@ protected:
   void ThreadedGenerateData( const RegionType &, ThreadIdType ) ITK_OVERRIDE;
 
 private:
-  InvertDisplacementFieldImageFilter( const Self& ) ITK_DELETE_FUNCTION;
-  void operator=( const Self& ) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(InvertDisplacementFieldImageFilter);
 
   /** The interpolator. */
   typename InterpolatorType::Pointer                m_Interpolator;
