@@ -49,7 +49,7 @@ namespace itk
  */
 
 template< typename TInputImage, typename TOutputImage >
-class IterativeInverseDisplacementFieldImageFilter:
+class ITK_TEMPLATE_EXPORT IterativeInverseDisplacementFieldImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -125,8 +125,7 @@ protected:
   double m_Time;
 
 private:
-  IterativeInverseDisplacementFieldImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(IterativeInverseDisplacementFieldImageFilter);
 };
 } // end namespace itk
 
