@@ -55,7 +55,7 @@ namespace itk
  * an extra iteration through the image is required.
  *
  * This filter uses the FastChamferDistanceImageFilter and the
- * IsoContourDistanceImageFilter inernally to perform the distance calculations.
+ * IsoContourDistanceImageFilter internally to perform the distance calculations.
  *
  * \sa DanielssonDistanceMapImageFilter
  * \sa SignedDanielssonDistanceMapImageFilter
@@ -67,12 +67,12 @@ namespace itk
  * \ingroup ITKDistanceMap
  *
  * \wiki
- * \wikiexample{ImageProcessing/ApproximateSignedDistanceMapImageFilter,Compute a distance map from objects in a binary image}
+ * \wikiexample{ImageProcessing/ApproximateSignedDistanceMapImageFilter, Compute a distance map from objects in a binary image}
  * \endwiki
  */
 
 template< typename TInputImage, typename TOutputImage >
-class ApproximateSignedDistanceMapImageFilter:public ImageToImageFilter< TInputImage, TOutputImage >
+class ITK_TEMPLATE_EXPORT ApproximateSignedDistanceMapImageFilter:public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
   /** Standard typedefs */
@@ -112,12 +112,12 @@ public:
   /** Pointer Type for the output image. */
   typedef typename OutputImageType::Pointer OutputImagePointer;
 
-  /** Set/Get intensity value representing the interior of objects in the mask
+  /** Set/Get intensity value representing the interior of objects in the mask.
     */
   itkSetMacro(InsideValue, InputPixelType);
   itkGetConstMacro(InsideValue, InputPixelType);
 
-  /** Set/Get intensity value representing non-objects in the mask */
+  /** Set/Get intensity value representing non-objects in the mask. */
   itkSetMacro(OutsideValue, InputPixelType);
   itkGetConstMacro(OutsideValue, InputPixelType);
 
@@ -136,8 +136,7 @@ protected:
   void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  ApproximateSignedDistanceMapImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ApproximateSignedDistanceMapImageFilter);
 
   typedef IsoContourDistanceImageFilter< InputImageType, OutputImageType >   IsoContourType;
   typedef FastChamferDistanceImageFilter< OutputImageType, OutputImageType > ChamferType;
