@@ -58,7 +58,7 @@ namespace itk
 template< typename TInputImage,
   typename TOutputImage,
   typename TVoronoiImage = TInputImage >
-class DanielssonDistanceMapImageFilter:
+class ITK_TEMPLATE_EXPORT DanielssonDistanceMapImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -224,8 +224,7 @@ protected:
                            const OffsetType &);
 
 private:
-  DanielssonDistanceMapImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(DanielssonDistanceMapImageFilter);
 
   bool m_SquaredDistance;
   bool m_InputIsBinary;
