@@ -69,7 +69,7 @@ namespace itk
  * \ingroup ITKDistanceMap
  */
 template< typename TInputImage1, typename TInputImage2 >
-class DirectedHausdorffDistanceImageFilter:
+class ITK_TEMPLATE_EXPORT DirectedHausdorffDistanceImageFilter:
   public ImageToImageFilter< TInputImage1, TInputImage1 >
 {
 public:
@@ -162,8 +162,7 @@ protected:
   void EnlargeOutputRequestedRegion(DataObject *data) ITK_OVERRIDE;
 
 private:
-  DirectedHausdorffDistanceImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(DirectedHausdorffDistanceImageFilter);
 
   typedef Image< RealType, itkGetStaticConstMacro(ImageDimension) > DistanceMapType;
   typedef typename DistanceMapType::Pointer                         DistanceMapPointer;
