@@ -22,6 +22,7 @@
 #include "itkNarrowBand.h"
 #include "itkNeighborhoodIterator.h"
 #include "itkBarrier.h"
+#include "itkNumericTraits.h"
 
 namespace itk
 {
@@ -54,7 +55,7 @@ namespace itk
  * \ingroup ITKDistanceMap
  */
 template< typename TInputImage, typename TOutputImage >
-class IsoContourDistanceImageFilter:
+class ITK_TEMPLATE_EXPORT IsoContourDistanceImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -83,8 +84,10 @@ public:
 
   /** The pixel type of the output image will be used in computations.
    * Inherited from the superclass. */
-  typedef typename OutputImageType::PixelType  PixelType;
-  typedef typename InputImageType::PixelType   InputPixelType;
+  typedef typename OutputImageType::PixelType                 PixelType;
+  typedef typename InputImageType::PixelType                  InputPixelType;
+  typedef typename NumericTraits< InputPixelType >::RealType  PixelRealType;
+
   typedef typename OutputImageType::RegionType OutputImageRegionType;
 
   typedef typename InputImageType::SizeType   InputSizeType;
@@ -105,8 +108,8 @@ public:
 
   /** Set/Get the value of the level set to be located. The default value is
     *  0. */
-  itkSetMacro(LevelSetValue, InputPixelType);
-  itkGetConstMacro(LevelSetValue, InputPixelType);
+  itkSetMacro(LevelSetValue, PixelRealType);
+  itkGetConstMacro(LevelSetValue, PixelRealType);
 
   /** Set/Get the value of the level set to be located. The default value is
   *  0. */
@@ -175,10 +178,9 @@ protected:
                      const std::vector< OffsetValueType >& stride );
 
 private:
-  IsoContourDistanceImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(IsoContourDistanceImageFilter);
 
-  InputPixelType m_LevelSetValue;
+  PixelRealType  m_LevelSetValue;
   PixelType      m_FarValue;
 
   InputSpacingType m_Spacing;
