@@ -59,7 +59,7 @@ namespace itk
  * \ingroup ITKDistanceMap
  */
 template< typename TInputImage, typename TOutputImage >
-class SignedMaurerDistanceMapImageFilter:
+class ITK_TEMPLATE_EXPORT SignedMaurerDistanceMapImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -169,8 +169,7 @@ protected:
                             ThreadIdType threadId) ITK_OVERRIDE;
 
 private:
-  SignedMaurerDistanceMapImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(SignedMaurerDistanceMapImageFilter);
 
   void Voronoi(unsigned int, OutputIndexType idx, OutputImageType *output );
   bool Remove(OutputPixelType, OutputPixelType, OutputPixelType,
