@@ -47,7 +47,7 @@ namespace itk
  * \sa InverseFFTImageFilter
  */
 template< typename TInputImage, typename TOutputImage=Image< typename TInputImage::PixelType::value_type, TInputImage::ImageDimension> >
-class FFTWHalfHermitianToRealInverseFFTImageFilter:
+class ITK_TEMPLATE_EXPORT FFTWHalfHermitianToRealInverseFFTImageFilter:
   public HalfHermitianToRealInverseFFTImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -121,8 +121,7 @@ protected:
   void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  FFTWHalfHermitianToRealInverseFFTImageFilter(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(FFTWHalfHermitianToRealInverseFFTImageFilter);
 
   bool m_CanUseDestructiveAlgorithm;
 
