@@ -41,7 +41,7 @@ namespace itk
  * \endwiki
  */
 template< typename TInputImage, typename TOutputImage=Image< std::complex<typename TInputImage::PixelType>, TInputImage::ImageDimension> >
-class VnlForwardFFTImageFilter:
+class ITK_TEMPLATE_EXPORT VnlForwardFFTImageFilter:
   public ForwardFFTImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -90,8 +90,7 @@ protected:
   virtual void GenerateData() ITK_OVERRIDE;
 
 private:
-  VnlForwardFFTImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(VnlForwardFFTImageFilter);
 
   typedef vnl_vector< std::complex< InputPixelType > > SignalVectorType;
 };
