@@ -39,10 +39,13 @@ namespace itk
  * the value of the variables at the know points and on containing the
  * value of the variables at the trail points.
  *
- * Implemenation of this class is based on Chapter 11 of
+ * Implementation of this class is based on Chapter 11 of
  * "Level Set Methods and Fast Marching Methods", J.A. Sethian,
  * Cambridge Press, Second edition, 1999.
  *
+ * For an alternative implementation, see itk::FastMarchingExtensionImageFilter.
+ *
+ * \sa FastMarchingExtensionImageFilter
  * \sa FastMarchingImageFilter
  * \sa LevelSetTypeDefault
  * \sa AuxVarTypeDefault
@@ -53,7 +56,7 @@ namespace itk
 template< typename TInput, typename TOutput,
          typename TAuxValue,
          unsigned int VAuxDimension >
-class FastMarchingExtensionImageFilterBase:
+class ITK_TEMPLATE_EXPORT FastMarchingExtensionImageFilterBase:
   public FastMarchingImageFilterBase< TInput, TOutput >
 {
 public:
@@ -143,11 +146,13 @@ protected:
   AuxValueContainerPointer m_AuxiliaryTrialValues;
 
 private:
-  FastMarchingExtensionImageFilterBase(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(FastMarchingExtensionImageFilterBase);
   AuxImageType * m_AuxImages[VAuxDimension];
 };
 } // namespace itk
 
+#ifndef ITK_MANUAL_INSTANTIATION
 #include "itkFastMarchingExtensionImageFilterBase.hxx"
 #endif
+
+#endif
