@@ -84,6 +84,8 @@ namespace itk
  * and SetOutputOrigin(). Else if the speed image is not ITK_NULLPTR, the output information
  * is copied from the input speed image.
  *
+ * For an alternative implementation, see itk::FastMarchingImageFilter.
+ *
  * Possible Improvements:
  * In the current implemenation, std::priority_queue only allows
  * taking nodes out from the front and putting nodes in from the back.
@@ -96,6 +98,7 @@ namespace itk
  * an image of back-pointers going from the image to heap in order
  * to locate the node which is to be updated.
  *
+ * \sa FastMarchingImageFilterBase
  * \sa LevelSetTypeDefault
  * \ingroup LevelSetSegmentation
  * \ingroup ITKFastMarching
@@ -103,7 +106,7 @@ namespace itk
 template<
   typename TLevelSet,
   typename TSpeedImage = Image< float,  TLevelSet ::ImageDimension > >
-class FastMarchingImageFilter:
+class ITK_TEMPLATE_EXPORT FastMarchingImageFilter:
   public ImageToImageFilter< TSpeedImage, TLevelSet >
 {
 public:
@@ -117,7 +120,7 @@ public:
   itkNewMacro(Self);
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro(FastMarchingImageFilter, ImageSource);
+  itkTypeMacro(FastMarchingImageFilter, ImageToImageFilter);
 
   /** Typedef support of level set method types. */
   typedef LevelSetTypeDefault< TLevelSet >            LevelSetType;
@@ -369,8 +372,7 @@ protected:
   itkGetConstReferenceMacro(LastIndex, LevelSetIndexType);
 
 private:
-  FastMarchingImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(FastMarchingImageFilter);
 
   NodeContainerPointer m_AlivePoints;
   NodeContainerPointer m_TrialPoints;
