@@ -93,8 +93,7 @@ protected:
   }
 
 private:
-  FastMarchingNumberOfElementsStoppingCriterion( const Self& );
-  void operator = ( const Self& );
+  ITK_DISALLOW_COPY_AND_ASSIGN(FastMarchingNumberOfElementsStoppingCriterion);
 };
 
 }
