@@ -202,8 +202,7 @@ protected:
   }
 
 private:
-  FastMarchingReachedTargetNodesStoppingCriterion( const Self& );
-  void operator = ( const Self& );
+  ITK_DISALLOW_COPY_AND_ASSIGN(FastMarchingReachedTargetNodesStoppingCriterion);
 };
 }
 #endif // itkFastMarchingThresholdStoppingCriterion_h
