@@ -33,7 +33,7 @@ namespace itk
  */
 template< typename TInputImage, typename TOutputImage, typename TParentImageFilter =
             AnisotropicDiffusionImageFilter< TInputImage, TOutputImage > >
-class GPUAnisotropicDiffusionImageFilter :
+class ITK_TEMPLATE_EXPORT GPUAnisotropicDiffusionImageFilter :
   public GPUDenseFiniteDifferenceImageFilter< TInputImage, TOutputImage, TParentImageFilter >
 {
 public:
@@ -73,8 +73,7 @@ protected:
   virtual void InitializeIteration() ITK_OVERRIDE;
 
 private:
-  GPUAnisotropicDiffusionImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GPUAnisotropicDiffusionImageFilter);
 
 };
 } // end namspace itk
