@@ -15,8 +15,8 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __itkGPUGradientNDAnisotropicDiffusionFunction_h
-#define __itkGPUGradientNDAnisotropicDiffusionFunction_h
+#ifndef itkGPUGradientNDAnisotropicDiffusionFunction_h
+#define itkGPUGradientNDAnisotropicDiffusionFunction_h
 
 #include "itkGPUScalarAnisotropicDiffusionFunction.h"
 #include "itkNeighborhoodAlgorithm.h"
@@ -56,7 +56,7 @@ namespace itk
 itkGPUKernelClassMacro(GPUGradientNDAnisotropicDiffusionFunctionKernel);
 
 template< typename TImage >
-class GPUGradientNDAnisotropicDiffusionFunction :
+class ITK_TEMPLATE_EXPORT GPUGradientNDAnisotropicDiffusionFunction :
   public GPUScalarAnisotropicDiffusionFunction< TImage >
 {
 public:
@@ -92,10 +92,10 @@ public:
 
   /** Compute the equation value. */
   virtual void GPUComputeUpdate( const typename TImage::Pointer output, typename TImage::Pointer buffer,
-                                 void *globalData );
+                                 void *globalData ) ITK_OVERRIDE;
 
   /** This method is called prior to each iteration of the solver. */
-  virtual void InitializeIteration()
+  virtual void InitializeIteration() ITK_OVERRIDE
   {
     m_K = static_cast< PixelType >( this->GetAverageGradientMagnitudeSquared()
                                     * this->GetConductanceParameter() * this->GetConductanceParameter() * -2.0f );
@@ -126,11 +126,7 @@ protected:
   static double m_MIN_NORM;
 
 private:
-  GPUGradientNDAnisotropicDiffusionFunction(const Self &); //purposely not
-                                                           // implemented
-  void operator=(const Self &);                            //purposely not
-
-  // implemented
+  ITK_DISALLOW_COPY_AND_ASSIGN(GPUGradientNDAnisotropicDiffusionFunction);
 };
 } // end namespace itk
 
