@@ -35,7 +35,7 @@ namespace itk
 itkGPUKernelClassMacro(GPUScalarAnisotropicDiffusionFunctionKernel);
 
 template< typename TImage >
-class GPUScalarAnisotropicDiffusionFunction :
+class ITK_TEMPLATE_EXPORT GPUScalarAnisotropicDiffusionFunction :
   public GPUAnisotropicDiffusionFunction< TImage >
 {
 public:
@@ -71,8 +71,7 @@ protected:
   }
 
 private:
-  GPUScalarAnisotropicDiffusionFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GPUScalarAnisotropicDiffusionFunction);
 
 };
 } // end namespace itk
