@@ -81,8 +81,7 @@ protected:
   }
 
 private:
-  GPUBoxImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GPUBoxImageFilter);
 
 };
 }
