@@ -44,7 +44,7 @@ namespace itk
  */
 
 template< typename TInputImage, typename TOutputImage >
-class GPUDiscreteGaussianImageFilter :
+class ITK_TEMPLATE_EXPORT GPUDiscreteGaussianImageFilter :
   public GPUImageToImageFilter< TInputImage, TOutputImage, DiscreteGaussianImageFilter< TInputImage, TOutputImage > >
 {
 public:
@@ -109,8 +109,7 @@ protected:
   void GPUGenerateData() ITK_OVERRIDE;
 
 private:
-  GPUDiscreteGaussianImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GPUDiscreteGaussianImageFilter);
 
   /** Intermediate 1D Gaussian filters */
   typename FirstFilterType::Pointer                       m_FirstFilter;
