@@ -39,7 +39,7 @@ namespace itk
 itkGPUKernelClassMacro(GPUMeanImageFilterKernel);
 
 template< typename TInputImage, typename TOutputImage >
-class GPUMeanImageFilter : //public GPUImageToImageFilter<
+class ITK_TEMPLATE_EXPORT GPUMeanImageFilter : //public GPUImageToImageFilter<
                                       // TInputImage, TOutputImage,
                                       // MeanImageFilter< TInputImage,
                                       // TOutputImage > >
@@ -47,15 +47,15 @@ class GPUMeanImageFilter : //public GPUImageToImageFilter<
 {
 public:
   /** Standard class typedefs. */
-  typedef GPUMeanImageFilter                                                                               Self;
-  typedef GPUImageToImageFilter< TInputImage, TOutputImage, MeanImageFilter< TInputImage, TOutputImage > > Superclass;
-  typedef SmartPointer< Self >                                                                             Pointer;
-  typedef SmartPointer< const Self >                                                                       ConstPointer;
+  typedef GPUMeanImageFilter                                                                           Self;
+  typedef GPUBoxImageFilter< TInputImage, TOutputImage, MeanImageFilter< TInputImage, TOutputImage > > Superclass;
+  typedef SmartPointer< Self >                                                                         Pointer;
+  typedef SmartPointer< const Self >                                                                   ConstPointer;
 
   itkNewMacro(Self);
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro(GPUMeanImageFilter, Superclass);
+  itkTypeMacro(GPUMeanImageFilter, GPUBoxImageFilter);
 
   /** Superclass typedefs. */
   typedef typename Superclass::OutputImageRegionType OutputImageRegionType;
@@ -86,8 +86,7 @@ protected:
   virtual void GPUGenerateData() ITK_OVERRIDE;
 
 private:
-  GPUMeanImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GPUMeanImageFilter);
 
   int m_MeanFilterGPUKernelHandle;
 };
@@ -130,8 +129,7 @@ public:
   }
 
 private:
-  GPUMeanImageFilterFactory(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GPUMeanImageFilterFactory);
 
 #define OverrideMeanFilterTypeMacro(ipt,opt,dm) \
     { \
