@@ -127,8 +127,7 @@ protected:
   virtual ~AbsoluteValueDifferenceImageFilter() {}
 
 private:
-  AbsoluteValueDifferenceImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(AbsoluteValueDifferenceImageFilter);
 };
 } // end namespace itk
 
