@@ -126,8 +126,7 @@ protected:
   virtual ~SquaredDifferenceImageFilter() {}
 
 private:
-  SquaredDifferenceImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(SquaredDifferenceImageFilter);
 };
 } // end namespace itk
 
