@@ -47,7 +47,7 @@ namespace itk
  * \ingroup ITKImageCompose
  */
 template< typename TInputImage, typename TOutputImage >
-class JoinSeriesImageFilter:
+class ITK_TEMPLATE_EXPORT JoinSeriesImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -123,8 +123,7 @@ protected:
                                     outputRegionForThread, ThreadIdType threadId) ITK_OVERRIDE;
 
 private:
-  JoinSeriesImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(JoinSeriesImageFilter);
 
   /** IndexValueType is used to switch among the inputs and
    * is used as the index value of the new dimension */
