@@ -72,7 +72,7 @@ namespace itk
  */
 
 template< typename TInputImage, typename TOutputImage >
-class BilateralImageFilter:
+class ITK_TEMPLATE_EXPORT BilateralImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -203,8 +203,7 @@ protected:
   virtual void GenerateInputRequestedRegion() ITK_OVERRIDE;
 
 private:
-  BilateralImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BilateralImageFilter);
 
   /** The standard deviation of the gaussian blurring kernel in the image
       range. Units are intensity. */
