@@ -73,7 +73,7 @@ namespace itk
  */
 
 template< typename  TPixel >
-class Hessian3DToVesselnessMeasureImageFilter:public
+class ITK_TEMPLATE_EXPORT Hessian3DToVesselnessMeasureImageFilter:public
   ImageToImageFilter< Image< SymmetricSecondRankTensor< double, 3 >, 3 >,
                       Image< TPixel, 3 > >
 {
@@ -137,8 +137,7 @@ protected:
   void GenerateData(void) ITK_OVERRIDE;
 
 private:
-  Hessian3DToVesselnessMeasureImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(Hessian3DToVesselnessMeasureImageFilter);
 
   typename EigenAnalysisFilterType::Pointer m_SymmetricEigenValueFilter;
 
