@@ -59,7 +59,7 @@ template<
   typename TImage,
   typename TMask = TImage,
   typename TFeatures = PointSet< Matrix< SpacePrecisionType, TImage::ImageDimension, TImage::ImageDimension>, TImage::ImageDimension > >
-class MaskFeaturePointSelectionFilter: public ImageToMeshFilter< TImage, TFeatures >
+class ITK_TEMPLATE_EXPORT MaskFeaturePointSelectionFilter: public ImageToMeshFilter< TImage, TFeatures >
 {
 public:
   /** Standard class typedefs. */
@@ -155,8 +155,7 @@ protected:
   void ComputeConnectivityOffsets( void ) throw ( ExceptionObject );
 
 private:
-  MaskFeaturePointSelectionFilter(const MaskFeaturePointSelectionFilter &) ITK_DELETE_FUNCTION;
-  void operator=(const MaskFeaturePointSelectionFilter &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(MaskFeaturePointSelectionFilter);
 
   unsigned                   m_NonConnectivity;
   std::vector< OffsetType >  m_NonConnectivityOffsets;
