@@ -47,7 +47,7 @@ namespace itk
   * \ingroup ITKImageFeature
 */
 template< typename TInputImage, typename TOutputImage >
-class SimpleContourExtractorImageFilter:
+class ITK_TEMPLATE_EXPORT SimpleContourExtractorImageFilter:
   public BoxImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -71,7 +71,7 @@ public:
   itkNewMacro(Self);
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro(SimpleContourExtractorImageFilter, ImageToImageFilter);
+  itkTypeMacro(SimpleContourExtractorImageFilter, BoxImageFilter);
 
   /** Image typedef support. */
   typedef typename InputImageType::PixelType                 InputPixelType;
@@ -130,22 +130,23 @@ protected:
   void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
   /** SimpleContourExtractorImageFilter can be implemented as a
-     * multithreaded filter. Therefore, this implementation provides a
-     * ThreadedGenerateData() routine which is called for each
-     * processing thread. The output image data is allocated
-     * automatically by the superclass prior to calling
-     * ThreadedGenerateData().  ThreadedGenerateData can only write to
-     * the portion of the output image specified by the parameter
-     * "outputRegionForThread"
-     *
-     * \sa ImageToImageFilter::ThreadedGenerateData(),
-     *     ImageToImageFilter::GenerateData() */
+   *  multithreaded filter. Therefore, this implementation provides a
+   *  ThreadedGenerateData() routine which is called for each
+   *  processing thread. The output image data is allocated
+   *  automatically by the superclass prior to calling
+   *  ThreadedGenerateData(). ThreadedGenerateData can only write to
+   *  the portion of the output image specified by the parameter
+   *  "outputRegionForThread"
+   *
+   *  \sa ImageToImageFilter::ThreadedGenerateData(),
+   *      ImageToImageFilter::GenerateData()
+   *
+   */
   void ThreadedGenerateData(const OutputImageRegionType & outputRegionForThread,
                             ThreadIdType threadId) ITK_OVERRIDE;
 
 private:
-  SimpleContourExtractorImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(SimpleContourExtractorImageFilter);
 
   InputPixelType  m_InputForegroundValue;
   InputPixelType  m_InputBackgroundValue;
