@@ -28,7 +28,7 @@ namespace itk
  *
  * The zero-crossing based edge detector looks for pixels in the Laplacian of
  * an image where the value of the Laplacian passes through zero --- points
- * where the Laplacian changes sign.  Such points often occur at ``edges'' in
+ * where the Laplacian changes sign.  Such points often occur at "edges" in
  * images --- i.e. points where the intensity of the image changes rapidly,
  * but they also occur at places that are not as easy to associate with edges.
  * It is best to think of the zero crossing detector as some sort of feature
@@ -67,7 +67,7 @@ namespace itk
  * \ingroup ITKImageFeature
  */
 template< typename TInputImage, typename TOutputImage >
-class ZeroCrossingBasedEdgeDetectionImageFilter:
+class ITK_TEMPLATE_EXPORT ZeroCrossingBasedEdgeDetectionImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -170,8 +170,7 @@ protected:
   void GenerateData() ITK_OVERRIDE;
 
 private:
-  ZeroCrossingBasedEdgeDetectionImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ZeroCrossingBasedEdgeDetectionImageFilter);
 
   /** The variance of the Gaussian Filter used in this filter */
   ArrayType m_Variance;
