@@ -38,10 +38,10 @@ namespace itk
  *
  *  \par
  *  The output of the filter is a binary, labeled image of user-specified type.
- *  By default, zero-crossing pixels are labeled with a default ``foreground''
+ *  By default, zero-crossing pixels are labeled with a default "foreground"
  *  value of itk::NumericTraits<OutputDataType>::OneValue(), where OutputDataType is
  *  the data type of the output image.  All other pixels are labeled with a
- *  default ``background'' value of itk::NumericTraits<OutputDataType>::ZeroValue().
+ *  default "background" value of itk::NumericTraits<OutputDataType>::ZeroValue().
  *
  *  \par Parameters
  *  There are two parameters for this filter.  ForegroundValue is the value
@@ -60,7 +60,7 @@ namespace itk
  * \endwiki
  */
 template< typename TInputImage, typename TOutputImage >
-class ZeroCrossingImageFilter:
+class ITK_TEMPLATE_EXPORT ZeroCrossingImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -154,8 +154,7 @@ protected:
                             ThreadIdType threadId) ITK_OVERRIDE;
 
 private:
-  ZeroCrossingImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ZeroCrossingImageFilter);
 
 };
 } //end of namespace itk
