@@ -37,7 +37,7 @@ namespace itk
  */
 
 template< typename TInputImage, typename TOutputImage >
-class BoxImageFilter:
+class ITK_TEMPLATE_EXPORT BoxImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -88,8 +88,7 @@ protected:
   virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  BoxImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BoxImageFilter);
 
   RadiusType m_Radius;
 };
