@@ -33,7 +33,7 @@ namespace Functor
  */
 
 template< typename TInput, typename TOutput >
-class Cast
+class ITK_TEMPLATE_EXPORT Cast
 {
 public:
   Cast() {}
@@ -94,7 +94,7 @@ public:
  * \endwiki
  */
 template< typename TInputImage, typename TOutputImage >
-class CastImageFilter:
+class ITK_TEMPLATE_EXPORT CastImageFilter:
     public UnaryFunctorImageFilter< TInputImage, TOutputImage,
                                     Functor::Cast<
                                       typename TInputImage::PixelType,
@@ -138,8 +138,7 @@ protected:
   void ThreadedGenerateData(const OutputImageRegionType & outputRegionForThread, ThreadIdType threadId) ITK_OVERRIDE;
 
 private:
-  CastImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(CastImageFilter);
 };
 } // end namespace itk
 
