@@ -48,7 +48,7 @@ namespace itk
  * \endwiki
  */
 template< typename TInputImage, typename TOutputImage >
-class NoiseImageFilter:
+class ITK_TEMPLATE_EXPORT NoiseImageFilter:
   public BoxImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -109,8 +109,7 @@ protected:
                             ThreadIdType threadId) ITK_OVERRIDE;
 
 private:
-  NoiseImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(NoiseImageFilter);
 };
 } // end namespace itk
 
