@@ -49,7 +49,7 @@ namespace itk
  * \ingroup ITKImageFilterBase
  */
 template< typename TInputImage, typename TOutputImage = TInputImage >
-class RecursiveSeparableImageFilter:
+class ITK_TEMPLATE_EXPORT RecursiveSeparableImageFilter:
   public InPlaceImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -225,8 +225,7 @@ protected:
     }
 
 private:
-  RecursiveSeparableImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(RecursiveSeparableImageFilter);
 
   /** Direction in which the filter is to be applied
    * this should be in the range [0,ImageDimension-1]. */
