@@ -37,7 +37,7 @@ namespace itk
  */
 template< typename TInputImage1, typename TInputImage2,
           typename TInputImage3, typename TOutputImage, typename TFunction    >
-class TernaryFunctorImageFilter:
+class ITK_TEMPLATE_EXPORT TernaryFunctorImageFilter:
   public InPlaceImageFilter< TInputImage1, TOutputImage >
 {
 public:
@@ -154,8 +154,7 @@ protected:
                             ThreadIdType threadId) ITK_OVERRIDE;
 
 private:
-  TernaryFunctorImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(TernaryFunctorImageFilter);
 
   FunctorType m_Functor;
 };
