@@ -113,8 +113,7 @@ protected:
   virtual ~VectorCastImageFilter() {}
 
 private:
-  VectorCastImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(VectorCastImageFilter);
 };
 } // end namespace itk
 
