@@ -55,7 +55,7 @@ namespace itk
  */
 
 template< typename TInputImage, typename TOutputImage >
-class VectorNeighborhoodOperatorImageFilter:
+class ITK_TEMPLATE_EXPORT VectorNeighborhoodOperatorImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -155,8 +155,7 @@ protected:
   { Superclass::PrintSelf(os, indent);  }
 
 private:
-  VectorNeighborhoodOperatorImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(VectorNeighborhoodOperatorImageFilter);
 
   /** Pointer to the internal operator used to filter the image. */
   Neighborhood< ScalarValueType, itkGetStaticConstMacro(ImageDimension) > m_Operator;
