@@ -40,13 +40,14 @@ namespace itk
  * \author Gaetan Lehmann. Biologie du Developpement et de la Reproduction, INRA de Jouy-en-Josas, France.
  * \author Richard Beare. Department of Medicine, Monash University, Melbourne, Australia.
  *
- * \sa ScalarToRGBPixelFunctor LabelOverlayImageFilter
+ * \sa  LabelOverlayImageFilter
+ * \sa  LabelMapToRGBImageFilter, LabelToRGBFunctor, ScalarToRGBPixelFunctor
  * \ingroup MultiThreaded
  *
  * \ingroup ITKImageFusion
  */
 template< typename TLabelImage, typename  TOutputImage >
-class LabelToRGBImageFilter:
+class ITK_TEMPLATE_EXPORT LabelToRGBImageFilter:
   public
   UnaryFunctorImageFilter< TLabelImage, TOutputImage,
                            Functor::LabelToRGBFunctor<
@@ -110,8 +111,7 @@ protected:
   void GenerateOutputInformation() ITK_OVERRIDE;
 
 private:
-  LabelToRGBImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(LabelToRGBImageFilter);
 
   OutputPixelType m_BackgroundColor;
   LabelPixelType  m_BackgroundValue;
