@@ -32,7 +32,7 @@ namespace itk
  * \ingroup ITKImageGradient
  */
 template< typename TInputImage, typename TDataType >
-class DifferenceOfGaussiansGradientImageFilter:
+class ITK_TEMPLATE_EXPORT DifferenceOfGaussiansGradientImageFilter:
   public ImageToImageFilter< TInputImage,
                              Image< CovariantVector< TDataType, TInputImage::ImageDimension >,
                                     TInputImage::ImageDimension > >
@@ -92,8 +92,7 @@ protected:
   void GenerateData() ITK_OVERRIDE;
 
 private:
-  DifferenceOfGaussiansGradientImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(DifferenceOfGaussiansGradientImageFilter);
 
   unsigned int m_Width;
 };
