@@ -57,7 +57,7 @@ template< typename TInputImage,
           typename TOutputImageType = Image< CovariantVector< TOutputValueType,
                                                            TInputImage::ImageDimension >,
                                           TInputImage::ImageDimension > >
-class GradientImageFilter:
+class ITK_TEMPLATE_EXPORT GradientImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImageType >
 {
 public:
@@ -65,7 +65,7 @@ public:
   itkStaticConstMacro(InputImageDimension, unsigned int,
                       TInputImage::ImageDimension);
   itkStaticConstMacro(OutputImageDimension, unsigned int,
-                      TInputImage::ImageDimension);
+                      TOutputImageType::ImageDimension);
 
   /** Convenient typedefs for simplifying declarations. */
   typedef TInputImage                       InputImageType;
@@ -117,6 +117,9 @@ public:
       image in its calculations */
   itkSetMacro(UseImageSpacing, bool);
   itkGetConstMacro(UseImageSpacing, bool);
+  itkBooleanMacro(UseImageSpacing);
+  /** Allows to change the default boundary condition */
+  void OverrideBoundaryCondition(ImageBoundaryCondition< TInputImage >* boundaryCondition);
 
 #ifdef ITK_USE_CONCEPT_CHECKING
   // Begin concept checking
@@ -160,8 +163,7 @@ protected:
                             ThreadIdType threadId) ITK_OVERRIDE;
 
 private:
-  GradientImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GradientImageFilter);
 
   virtual void GenerateOutputInformation() ITK_OVERRIDE;
 
@@ -202,6 +204,9 @@ private:
   // flag to take or not the image direction into account
   // when computing the derivatives.
   bool m_UseImageDirection;
+
+  // allow setting the the m_BoundaryCondition
+  ImageBoundaryCondition< TInputImage, TInputImage >* m_BoundaryCondition;
 };
 } // end namespace itk
 
