@@ -47,7 +47,7 @@ namespace itk
 // on the defaults of template parameters
 template< typename TInputImage,
           typename TOutputImage = TInputImage >
-class GradientMagnitudeRecursiveGaussianImageFilter:
+class ITK_TEMPLATE_EXPORT GradientMagnitudeRecursiveGaussianImageFilter:
   public InPlaceImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -162,8 +162,7 @@ protected:
   void EnlargeOutputRequestedRegion(DataObject *output) ITK_OVERRIDE;
 
 private:
-  GradientMagnitudeRecursiveGaussianImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GradientMagnitudeRecursiveGaussianImageFilter);
 
   class SqrSpacing
   {
