@@ -136,7 +136,7 @@ template< typename TInputImage,
           typename TOutputImage = Image< TRealType,
                                          TInputImage::ImageDimension >
           >
-class VectorGradientMagnitudeImageFilter:
+class ITK_TEMPLATE_EXPORT VectorGradientMagnitudeImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -488,8 +488,7 @@ private:
 
   typename ImageBaseType::ConstPointer m_RealValuedInputImage;
 
-  VectorGradientMagnitudeImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(VectorGradientMagnitudeImageFilter);
 };
 } // end namespace itk
 
