@@ -22,6 +22,8 @@
 #include "itkNullImageToImageFilterDriver.hxx"
 #include "itkTestingMacros.h"
 
+#include "itkPeriodicBoundaryCondition.h"
+
 inline std::ostream& operator<<(std::ostream &o, const itk::CovariantVector<float, 3> &v)
 {
   o << "["<< v[0] << " " << v[1] << " " << v[2] << "]";
@@ -36,6 +38,7 @@ int itkGradientImageFilterTest(int , char * [] )
     typedef itk::GradientImageFilter<ImageType, float, float> FilterType;
     typedef FilterType::OutputImageType                       OutputImageType;
 
+
     // Set up filter
     FilterType::Pointer filter = FilterType::New();
 
@@ -66,6 +69,10 @@ int itkGradientImageFilterTest(int , char * [] )
 
     FilterType::Pointer filter = FilterType::New();
 
+    typedef itk::PeriodicBoundaryCondition<InputImageType> PeriodicBoundaryType;
+    //Test the OverrideBoundaryCondition setting;
+    filter->OverrideBoundaryCondition( new PeriodicBoundaryType );
+
     EXERCISE_BASIC_OBJECT_METHODS( filter, GradientImageFilter, ImageToImageFilter );
 
     // Run test
