@@ -29,13 +29,12 @@
 #define itkBSplineCenteredResampleImageFilterBase_h
 
 #include "itkBSplineResampleImageFilterBase.h"
+#include "itkProgressReporter.h"
 #include <vector>
 
 namespace itk
 {
 
-class ProgressReporter;
-
 /** \class BSplineCenteredResampleImageFilterBase
  * \brief Evaluates the Centered B-Spline interpolation of an image.  Spline order may be from 0 to 5.
  *
@@ -62,7 +61,7 @@ class ProgressReporter;
  * \ingroup ITKImageGrid
  */
 template< typename TInputImage, typename TOutputImage >
-class BSplineCenteredResampleImageFilterBase:
+class ITK_TEMPLATE_EXPORT BSplineCenteredResampleImageFilterBase:
   public BSplineResampleImageFilterBase< TInputImage, TOutputImage >
 {
 public:
@@ -108,8 +107,7 @@ protected:
   void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  BSplineCenteredResampleImageFilterBase(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BSplineCenteredResampleImageFilterBase);
 
   typedef typename TInputImage::IndexValueType    IndexValueType;
   typedef typename TInputImage::SizeValueType     SizeValueType;
