@@ -57,7 +57,7 @@ namespace itk
  */
 
 template <typename TInputImage, typename TOutputImage = TInputImage>
-class BSplineControlPointImageFilter
+class ITK_TEMPLATE_EXPORT BSplineControlPointImageFilter
   : public ImageToImageFilter<TInputImage, TOutputImage>
 {
 public:
@@ -69,6 +69,9 @@ public:
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
 
+  /** Run-time type information (and related methods). */
+  itkTypeMacro(BSplineControlPointImageFilter, ImageToImageFilter);
+
   /** Extract dimension from input image. */
   itkStaticConstMacro( ImageDimension, unsigned int,
                        TInputImage::ImageDimension );
@@ -211,8 +214,7 @@ protected:
   void ThreadedGenerateData( const OutputImageRegionType &, ThreadIdType ) ITK_OVERRIDE;
 
 private:
-  BSplineControlPointImageFilter( const Self& ) ITK_DELETE_FUNCTION;
-  void operator=( const Self& ) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BSplineControlPointImageFilter);
 
 
   /**
