@@ -86,7 +86,7 @@ namespace itk
 //= typename BSplineResampleImageFilterBase<TInputImage, TOutputImage>
 template< typename TInputImage, typename TOutputImage,
           typename ResamplerType = BSplineResampleImageFilterBase< TInputImage, TOutputImage > >
-class BSplineDownsampleImageFilter:
+class ITK_TEMPLATE_EXPORT BSplineDownsampleImageFilter:
   public ResamplerType
 {
 public:
@@ -138,8 +138,7 @@ protected:
   virtual ~BSplineDownsampleImageFilter() {}
 
 private:
-  BSplineDownsampleImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BSplineDownsampleImageFilter);
 };
 } // namespace itk
 
