@@ -79,7 +79,7 @@ namespace itk
  * \ingroup ITKImageGrid
  */
 template< typename TInputImage, typename TOutputImage >
-class BSplineResampleImageFilterBase:
+class ITK_TEMPLATE_EXPORT BSplineResampleImageFilterBase:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -184,8 +184,7 @@ private:
   std::vector< double >       m_Scratch;        // temp storage for processing
                                                 // of Coefficients
 
-  BSplineResampleImageFilterBase(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BSplineResampleImageFilterBase);
 };
 } // namespace itk
 
