@@ -81,7 +81,7 @@ namespace itk
 
 template< typename TInputImage, typename TOutputImage, typename ResamplerType =
             BSplineResampleImageFilterBase< TInputImage, TOutputImage > >
-class BSplineUpsampleImageFilter:
+class ITK_TEMPLATE_EXPORT BSplineUpsampleImageFilter:
   public ResamplerType
 {
 public:
@@ -134,8 +134,7 @@ protected:
   void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  BSplineUpsampleImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BSplineUpsampleImageFilter);
 };
 } // namespace itk
 
