@@ -54,7 +54,7 @@ namespace itk
  * \ingroup ITKImageGrid
  */
 template<unsigned int VSplineOrder = 3, typename TRealValueType = double>
-class CoxDeBoorBSplineKernelFunction:
+class ITK_TEMPLATE_EXPORT CoxDeBoorBSplineKernelFunction:
   public KernelFunctionBase<TRealValueType>
 {
 public:
@@ -110,8 +110,7 @@ protected:
   void PrintSelf( std::ostream & os, Indent indent ) const ITK_OVERRIDE;
 
 private:
-  CoxDeBoorBSplineKernelFunction( const Self & ) ITK_DELETE_FUNCTION;
-  void operator=( const Self & ) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(CoxDeBoorBSplineKernelFunction);
 
   /**
    * For a specific order, generate the (this->m_SplineOrder+1) pieces of
