@@ -43,7 +43,7 @@ namespace itk
  * \ingroup ITKImageGrid
  */
 template< typename TInputImage, typename TOutputImage = TInputImage >
-class CyclicShiftImageFilter:
+class ITK_TEMPLATE_EXPORT CyclicShiftImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -102,8 +102,7 @@ protected:
   OffsetType m_Shift;
 
 private:
-  CyclicShiftImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(CyclicShiftImageFilter);
 
 }; // end of class
 } // end namespace itk
