@@ -41,7 +41,7 @@ namespace itk
  * \ingroup ITKImageGrid
  */
 template< typename TInputImage, typename TOutputImage >
-class InterpolateImageFilter:
+class ITK_TEMPLATE_EXPORT InterpolateImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -119,8 +119,7 @@ protected:
                             ThreadIdType threadId) ITK_OVERRIDE;
 
 private:
-  InterpolateImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(InterpolateImageFilter);
 
   typename InterpolatorType::Pointer m_Interpolator;
 
