@@ -49,7 +49,7 @@ namespace itk
  * \endwiki
  */
 template< typename TInputImage, typename TOutputImage >
-class MirrorPadImageFilter:
+class ITK_TEMPLATE_EXPORT MirrorPadImageFilter:
   public PadImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -200,8 +200,7 @@ protected:
   virtual void GenerateInputRequestedRegion() ITK_OVERRIDE;
 
 private:
-  MirrorPadImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(MirrorPadImageFilter);
 };
 } // end namespace itk
 
