@@ -50,7 +50,7 @@ namespace itk
  * \endwiki
  */
 template< typename TInputImage, typename TOutputImage >
-class RegionOfInterestImageFilter:
+class ITK_TEMPLATE_EXPORT RegionOfInterestImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -105,11 +105,10 @@ protected:
   virtual void EnlargeOutputRequestedRegion(DataObject *output) ITK_OVERRIDE;
 
   /** RegionOfInterestImageFilter can produce an image which is a different
-   * size than its input image.  As such, RegionOfInterestImageFilter
+   * size than its input image. As such, RegionOfInterestImageFilter
    * needs to provide an implementation for
    * GenerateOutputInformation() in order to inform the pipeline
-   * execution model.  The original documentation of this method is
-   * below.
+   * execution model.
    *
    * \sa ProcessObject::GenerateOutputInformaton()  */
   virtual void GenerateOutputInformation() ITK_OVERRIDE;
@@ -118,17 +117,16 @@ protected:
    * Therefore, this implementation provides a ThreadedGenerateData()
    * routine which is called for each processing thread. The output
    * image data is allocated automatically by the superclass prior to
-   * calling ThreadedGenerateData().  ThreadedGenerateData can only
+   * calling ThreadedGenerateData(). ThreadedGenerateData can only
    * write to the portion of the output image specified by the
-   * parameter "outputRegionForThread"
+   * parameter "outputRegionForThread".
    * \sa ImageToImageFilter::ThreadedGenerateData(),
    *     ImageToImageFilter::GenerateData()  */
   void ThreadedGenerateData(const RegionType & outputRegionForThread,
                             ThreadIdType threadId) ITK_OVERRIDE;
 
 private:
-  RegionOfInterestImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(RegionOfInterestImageFilter);
 
   RegionType m_RegionOfInterest;
 };
