@@ -78,7 +78,7 @@ template< typename TInputImage,
           class TOutputFilter = typename TInputFilter::Superclass,
           class TInternalInputImage = typename TInputFilter::InputImageType,
           class TInternalOutputImage = typename TOutputFilter::OutputImageType >
-class SliceBySliceImageFilter:
+class ITK_TEMPLATE_EXPORT SliceBySliceImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -170,8 +170,7 @@ protected:
   virtual void GenerateInputRequestedRegion() ITK_OVERRIDE;
 
 private:
-  SliceBySliceImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(SliceBySliceImageFilter);
 
   unsigned int m_Dimension;
 
