@@ -85,7 +85,7 @@ template<
   typename TOutputImage,
   typename TDisplacementField
   >
-class WarpImageFilter:
+class ITK_TEMPLATE_EXPORT WarpImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -213,7 +213,7 @@ public:
 
   /** WarpImageFilter produces an image which is a different
    * size than its input image. As such, it needs to provide an
-   * implemenation for GenerateOutputInformation() which set
+   * implementation for GenerateOutputInformation() which set
    * the output information according the OutputSpacing, OutputOrigin
    * and the displacement field's LargestPossibleRegion. */
   virtual void GenerateOutputInformation() ITK_OVERRIDE;
@@ -288,8 +288,7 @@ protected:
   IndexType m_StartIndex, m_EndIndex;
 
 private:
-  WarpImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(WarpImageFilter);
 
   PixelType     m_EdgePaddingValue;
   SpacingType   m_OutputSpacing;
