@@ -89,7 +89,7 @@ template<
   typename TOutputImage,
   typename TDisplacementField
   >
-class WarpVectorImageFilter:
+class ITK_TEMPLATE_EXPORT WarpVectorImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -209,7 +209,7 @@ public:
 
   /** WarpVectorImageFilter produces an image which is a different
    * size than its input image. As such, it needs to provide an
-   * implemenation for GenerateOutputInformation() which set
+   * implementation for GenerateOutputInformation() which set
    * the output information according the OutputSpacing, OutputOrigin
    * and the displacement field's LargestPossibleRegion. */
   virtual void GenerateOutputInformation() ITK_OVERRIDE;
@@ -249,8 +249,7 @@ protected:
                             ThreadIdType threadId) ITK_OVERRIDE;
 
 private:
-  WarpVectorImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(WarpVectorImageFilter);
 
   PixelType     m_EdgePaddingValue;
   SpacingType   m_OutputSpacing;
