@@ -50,7 +50,7 @@ namespace itk
  * \endwiki
  */
 template< typename TInputImage, typename TOutputImage >
-class WrapPadImageFilter:
+class ITK_TEMPLATE_EXPORT WrapPadImageFilter:
   public PadImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -102,8 +102,7 @@ protected:
   ~WrapPadImageFilter() {}
 
 private:
-  WrapPadImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(WrapPadImageFilter);
 
   PeriodicBoundaryCondition< TInputImage, TOutputImage > m_InternalBoundaryCondition;
 };
