@@ -169,8 +169,7 @@ protected:
   virtual ~AdaptImageFilter() {}
 
 private:
-  AdaptImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(AdaptImageFilter);
 };
 } // end namespace itk
 
