@@ -119,8 +119,7 @@ protected:
   virtual ~AndImageFilter() {}
 
 private:
-  AndImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(AndImageFilter);
 };
 } // end namespace itk
 
