@@ -125,8 +125,7 @@ protected:
   virtual ~Atan2ImageFilter() {}
 
 private:
-  Atan2ImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(Atan2ImageFilter);
 };
 } // end namespace itk
 
