@@ -112,8 +112,7 @@ protected:
   virtual ~AtanImageFilter() {}
 
 private:
-  AtanImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(AtanImageFilter);
 };
 } // end namespace itk
 
