@@ -96,8 +96,7 @@ protected:
   virtual ~ComplexToImaginaryImageFilter() {}
 
 private:
-  ComplexToImaginaryImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ComplexToImaginaryImageFilter);
 };
 } // end namespace itk
 
