@@ -97,8 +97,7 @@ protected:
   virtual ~ComplexToModulusImageFilter() {}
 
 private:
-  ComplexToModulusImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ComplexToModulusImageFilter);
 };
 } // end namespace itk
 
