@@ -96,8 +96,7 @@ protected:
   virtual ~ComplexToPhaseImageFilter() {}
 
 private:
-  ComplexToPhaseImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ComplexToPhaseImageFilter);
 };
 } // end namespace itk
 
