@@ -137,8 +137,7 @@ protected:
   virtual ~ConstrainedValueAdditionImageFilter() {}
 
 private:
-  ConstrainedValueAdditionImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ConstrainedValueAdditionImageFilter);
 };
 } // end namespace itk
 
