@@ -113,8 +113,7 @@ protected:
   virtual ~CosImageFilter() {}
 
 private:
-  CosImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(CosImageFilter);
 };
 } // end namespace itk
 
