@@ -148,8 +148,7 @@ protected:
   virtual ~DivideOrZeroOutImageFilter() {};
 
 private:
-  DivideOrZeroOutImageFilter(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(DivideOrZeroOutImageFilter);
 };
 
 } // end namespace itk
