@@ -98,8 +98,7 @@ protected:
   virtual ~EdgePotentialImageFilter() {}
 
 private:
-  EdgePotentialImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(EdgePotentialImageFilter);
 };
 } // end namespace itk
 
