@@ -102,8 +102,7 @@ protected:
   virtual ~ExpImageFilter() {}
 
 private:
-  ExpImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ExpImageFilter);
 };
 } // end namespace itk
 
