@@ -138,8 +138,7 @@ protected:
   virtual ~ExpNegativeImageFilter() {}
 
 private:
-  ExpNegativeImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ExpNegativeImageFilter);
 };
 } // end namespace itk
 
