@@ -65,7 +65,7 @@ namespace itk
 /* THistogramMeasurement -- The precision level for which to do
   HistogramMeasurmenets */
 template< typename TInputImage, typename TOutputImage, typename THistogramMeasurement = typename TInputImage::PixelType >
-class HistogramMatchingImageFilter:
+class ITK_TEMPLATE_EXPORT HistogramMatchingImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -193,8 +193,7 @@ protected:
                           const THistogramMeasurement maxValue);
 
 private:
-  HistogramMatchingImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(HistogramMatchingImageFilter);
 
   SizeValueType m_NumberOfHistogramLevels;
   SizeValueType m_NumberOfMatchPoints;
