@@ -101,8 +101,7 @@ protected:
   virtual ~Log10ImageFilter() {}
 
 private:
-  Log10ImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(Log10ImageFilter);
 };
 } // end namespace itk
 
