@@ -134,8 +134,7 @@ protected:
   virtual ~MagnitudeAndPhaseToComplexImageFilter() {}
 
 private:
-  MagnitudeAndPhaseToComplexImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(MagnitudeAndPhaseToComplexImageFilter);
 };
 } // end namespace itk
 
