@@ -246,8 +246,7 @@ protected:
   }
 
 private:
-  MaskImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(MaskImageFilter);
 
   template < typename TPixelType >
   void CheckOutsideValue( const TPixelType * ) {}
