@@ -15,8 +15,8 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __itkMatrixIndexSelectionImageFilter_h
-#define __itkMatrixIndexSelectionImageFilter_h
+#ifndef itkMatrixIndexSelectionImageFilter_h
+#define itkMatrixIndexSelectionImageFilter_h
 
 #include "itkUnaryFunctorImageFilter.h"
 
@@ -124,8 +124,7 @@ protected:
   virtual ~MatrixIndexSelectionImageFilter() {}
 
 private:
-  MatrixIndexSelectionImageFilter(const Self &); //purposely not implemented
-  void operator=(const Self &);                  //purposely not implemented
+  ITK_DISALLOW_COPY_AND_ASSIGN(MatrixIndexSelectionImageFilter);
 };
 } // end namespace itk
 
