@@ -116,8 +116,7 @@ protected:
   virtual ~MinimumImageFilter() {}
 
 private:
-  MinimumImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(MinimumImageFilter);
 };
 } // end namespace itk
 
