@@ -30,7 +30,7 @@ namespace Functor
  * \ingroup ITKImageIntensity
  */
 template< typename TInput1, typename TInput2 = TInput1, typename TOutput = TInput1 >
-class Mult
+class ITK_TEMPLATE_EXPORT Mult
 {
 public:
   Mult() {}
@@ -66,7 +66,7 @@ public:
  * \endwiki
  */
 template< typename TInputImage1, typename TInputImage2 = TInputImage1, typename TOutputImage = TInputImage1 >
-class MultiplyImageFilter:
+class ITK_TEMPLATE_EXPORT MultiplyImageFilter:
   public
   BinaryFunctorImageFilter< TInputImage1, TInputImage2, TOutputImage,
                             Functor::Mult<
@@ -107,8 +107,7 @@ protected:
   virtual ~MultiplyImageFilter() {}
 
 private:
-  MultiplyImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(MultiplyImageFilter);
 };
 } // end namespace itk
 
