@@ -132,8 +132,7 @@ protected:
   virtual ~NaryAddImageFilter() {}
 
 private:
-  NaryAddImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(NaryAddImageFilter);
 };
 } // end namespace itk
 
