@@ -39,7 +39,7 @@ namespace itk
  */
 
 template< typename TInputImage, typename TOutputImage, typename TFunction >
-class NaryFunctorImageFilter:
+class ITK_TEMPLATE_EXPORT NaryFunctorImageFilter:
   public InPlaceImageFilter< TInputImage, TOutputImage >
 
 {
@@ -121,8 +121,7 @@ protected:
                             ThreadIdType threadId) ITK_OVERRIDE;
 
 private:
-  NaryFunctorImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(NaryFunctorImageFilter);
 
   FunctorType m_Functor;
 };
