@@ -46,7 +46,7 @@ namespace itk
  */
 template< typename TInputImage, typename TPolyline,
           typename TOutputImage >
-class PolylineMask2DImageFilter:public ImageToImageFilter< TInputImage, TOutputImage >
+class ITK_TEMPLATE_EXPORT PolylineMask2DImageFilter:public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
   /** Standard class typedefs. */
@@ -108,8 +108,7 @@ protected:
   virtual void GenerateData() ITK_OVERRIDE;
 
 private:
-  PolylineMask2DImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(PolylineMask2DImageFilter);
 };
 } // end namespace itk
 
