@@ -97,8 +97,7 @@ protected:
   virtual ~RGBToLuminanceImageFilter() {}
 
 private:
-  RGBToLuminanceImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(RGBToLuminanceImageFilter);
 };
 } // end namespace itk
 
