@@ -36,7 +36,7 @@ namespace itk
  * \ingroup ITKImageIntensity
  */
 template< typename TInputImage, typename TOutputImage >
-class ShiftScaleImageFilter:
+class ITK_TEMPLATE_EXPORT ShiftScaleImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -121,8 +121,7 @@ protected:
                              ThreadIdType threadId) ITK_OVERRIDE;
 
 private:
-  ShiftScaleImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ShiftScaleImageFilter);
 
   RealType m_Shift;
   RealType m_Scale;
