@@ -99,8 +99,7 @@ protected:
   virtual ~SquareImageFilter() {}
 
 private:
-  SquareImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(SquareImageFilter);
 };
 } // end namespace itk
 
