@@ -131,8 +131,7 @@ protected:
   virtual ~SubtractImageFilter() {}
 
 private:
-  SubtractImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(SubtractImageFilter);
 };
 } // end namespace itk
 
