@@ -192,8 +192,7 @@ protected:
   virtual ~SymmetricEigenAnalysisImageFilter() {}
 
 private:
-  SymmetricEigenAnalysisImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(SymmetricEigenAnalysisImageFilter);
 };
 } // end namespace itk
 
