@@ -98,8 +98,7 @@ protected:
   virtual ~TanImageFilter() {}
 
 private:
-  TanImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(TanImageFilter);
 };
 } // end namespace itk
 
