@@ -48,7 +48,7 @@ public:
   inline TOutput operator()(const TInput1 & A,
                             const TInput2 & B,
                             const TInput3 & C) const
-  { return (TOutput)( A + B + C ); }
+  { return static_cast<TOutput>( A + B + C ); }
 };
 }
 /** \class TernaryAddImageFilter
@@ -98,8 +98,7 @@ protected:
   virtual ~TernaryAddImageFilter() {}
 
 private:
-  TernaryAddImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(TernaryAddImageFilter);
 };
 } // end namespace itk
 
