@@ -168,8 +168,7 @@ protected:
   }
 
 private:
-  VectorIndexSelectionCastImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(VectorIndexSelectionCastImageFilter);
 };
 } // end namespace itk
 
