@@ -104,8 +104,7 @@ protected:
   virtual ~VectorMagnitudeImageFilter() {}
 
 private:
-  VectorMagnitudeImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(VectorMagnitudeImageFilter);
 };
 } // end namespace itk
 
