@@ -174,8 +174,7 @@ protected:
   virtual ~WeightedAddImageFilter() {}
 
 private:
-  WeightedAddImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(WeightedAddImageFilter);
 };
 } // end namespace itk
 
