@@ -18,22 +18,24 @@
 
 #include "itkComplexToModulusImageFilter.h"
 #include "itkComplexToModulusImageAdaptor.h"
+#include "itkMath.h"
 #include "itkSubtractImageFilter.h"
+#include "itkTestingMacros.h"
 
-
-int itkComplexToModulusFilterAndAdaptorTest(int, char* [] )
+int itkComplexToModulusFilterAndAdaptorTest( int, char* [] )
 {
 
   // Define the dimension of the images
   const unsigned int ImageDimension = 3;
 
   // Declare the types of the images
-  typedef std::complex<float>                InputPixelType;
+  typedef std::complex< float >              InputPixelType;
+  typedef float                              OutputPixelType;
 
-  typedef itk::Image<InputPixelType, ImageDimension>  InputImageType;
-  typedef itk::Image<float,          ImageDimension>  OutputImageType;
+  typedef itk::Image< InputPixelType, ImageDimension >    InputImageType;
+  typedef itk::Image< OutputPixelType, ImageDimension >   OutputImageType;
 
-  // Declare Iterator types apropriated for each image
+  // Declare appropriate Iterator types for each image
   typedef itk::ImageRegionIteratorWithIndex<
                                   InputImageType>  InputIteratorType;
   typedef itk::ImageRegionIteratorWithIndex<
@@ -49,7 +51,7 @@ int itkComplexToModulusFilterAndAdaptorTest(int, char* [] )
   typedef itk::ImageRegion<ImageDimension>   RegionType;
 
   // Create two images
-  InputImageType::Pointer inputImage  = InputImageType::New();
+  InputImageType::Pointer inputImage = InputImageType::New();
 
   // Define their size, and start index
   SizeType size;
@@ -75,46 +77,42 @@ int itkComplexToModulusFilterAndAdaptorTest(int, char* [] )
   InputIteratorType it( inputImage, inputImage->GetBufferedRegion() );
 
   // Initialize the content of Image A
-  InputPixelType value( 13, 25);
+  InputPixelType value( 13, 25 );
 
-  double modulus = vcl_sqrt( value.real() * value.real() +
-                             value.imag() * value.imag()  );
+  double modulus = std::sqrt( value.real() * value.real() +
+                             value.imag() * value.imag() );
 
   std::cout << "Modulus of input pixel = " << modulus << std::endl;
-
-  std::cout << "Content of the Input " << std::endl;
   it.GoToBegin();
   while( !it.IsAtEnd() )
     {
     it.Set( value );
-    std::cout << it.Get() << std::endl;
     ++it;
     }
 
   // Declare the type for the ComplexToModulus filter
   typedef itk::ComplexToModulusImageFilter< InputImageType,
-                               OutputImageType  >  FilterType;
+                               OutputImageType > FilterType;
 
-
-  // Create an ADD Filter
+  // Create the filter
   FilterType::Pointer filter = FilterType::New();
 
+  EXERCISE_BASIC_OBJECT_METHODS( filter, ComplexToModulusImageFilter,
+    UnaryFunctorImageFilter );
 
-  // Connect the input images
+  // Set the input image
   filter->SetInput( inputImage );
 
-  // Get the Smart Pointer to the Filter Output
-  OutputImageType::Pointer outputImage = filter->GetOutput();
-
-
   // Execute the filter
   filter->Update();
 
+  // Get the filter output
+  OutputImageType::Pointer outputImage = filter->GetOutput();
+
   // Create an iterator for going through the image output
-  OutputIteratorType ot(outputImage, outputImage->GetRequestedRegion());
+  OutputIteratorType ot( outputImage, outputImage->GetRequestedRegion() );
 
   //  Check the content of the result image
-  std::cout << "Verification of the output " << std::endl;
   const OutputImageType::PixelType epsilon = 1e-6;
   ot.GoToBegin();
   it.GoToBegin();
@@ -123,17 +121,15 @@ int itkComplexToModulusFilterAndAdaptorTest(int, char* [] )
     const InputImageType::PixelType  input  = it.Get();
     const OutputImageType::PixelType output = ot.Get();
 
-    double normd = vcl_sqrt( input.real() * input.real() +
-                             input.imag() * input.imag()  );
+    double normd = std::sqrt( input.real() * input.real() +
+                             input.imag() * input.imag() );
 
     const OutputImageType::PixelType norm =
        static_cast<OutputImageType::PixelType>( normd );
 
-    std::cout <<  output << " = ";
-    std::cout <<  norm  << std::endl;
-
-    if( vcl_fabs( norm - output ) > epsilon )
+    if( !itk::Math::FloatAlmostEqual( norm, output, 10, epsilon ) )
       {
+      std::cerr.precision( static_cast< int >( itk::Math::abs( std::log10( epsilon ) ) ) );
       std::cerr << "Error in itkComplexToModulusImageFilterTest " << std::endl;
       std::cerr << " norm( " << input << ") = " << norm << std::endl;
       std::cerr << " differs from " << output;
@@ -144,21 +140,24 @@ int itkComplexToModulusFilterAndAdaptorTest(int, char* [] )
     ++it;
     }
 
-  //---------------------------------------
-  // This section tests for ComplexToModulusImageAdaptor
-  //---------------------------------------
+  //
+  // Test the itk::ComplexToModulusImageAdaptor
+  //
 
-  typedef itk::ComplexToModulusImageAdaptor<InputImageType,
-                          OutputImageType::PixelType>  AdaptorType;
+  typedef itk::ComplexToModulusImageAdaptor< InputImageType,
+                          OutputImageType::PixelType > AdaptorType;
 
   AdaptorType::Pointer imaginaryAdaptor = AdaptorType::New();
 
+  EXERCISE_BASIC_OBJECT_METHODS( imaginaryAdaptor, ComplexToModulusImageAdaptor,
+    ImageAdaptor );
+
   imaginaryAdaptor->SetImage( inputImage );
 
   typedef itk::SubtractImageFilter<
                         OutputImageType,
                         AdaptorType,
-                        OutputImageType   > DiffFilterType;
+                        OutputImageType > DiffFilterType;
 
   DiffFilterType::Pointer diffFilter = DiffFilterType::New();
 
@@ -167,23 +166,20 @@ int itkComplexToModulusFilterAndAdaptorTest(int, char* [] )
 
   diffFilter->Update();
 
-  // Get the Smart Pointer to the Diff filter Output
+  // Get the filter output
   OutputImageType::Pointer diffImage = diffFilter->GetOutput();
 
-  //  Check the content of the diff image
-  std::cout << "Comparing the results with those of an Adaptor" << std::endl;
-  std::cout << "Verification of the output " << std::endl;
-
+  // Check the content of the diff image:
   // Create an iterator for going through the image output
-  OutputIteratorType dt(diffImage, diffImage->GetRequestedRegion());
+  OutputIteratorType dt( diffImage, diffImage->GetRequestedRegion() );
 
   dt.GoToBegin();
   while( !dt.IsAtEnd() )
     {
-    std::cout <<  dt.Get() << std::endl;
     const OutputImageType::PixelType diff = dt.Get();
-    if( vcl_fabs( diff ) > epsilon )
+    if( std::fabs( diff ) > epsilon )
       {
+      std::cerr.precision( static_cast< int >( itk::Math::abs( std::log10( epsilon ) ) ) );
       std::cerr << "Error in itkComplexToModulusImageFilterTest " << std::endl;
       std::cerr << "Comparing results with Adaptors" << std::endl;
       std::cerr << " difference = " << diff << std::endl;
