@@ -18,22 +18,24 @@
 
 #include "itkComplexToRealImageFilter.h"
 #include "itkComplexToRealImageAdaptor.h"
+#include "itkMath.h"
 #include "itkSubtractImageFilter.h"
+#include "itkTestingMacros.h"
 
-
-int itkComplexToRealFilterAndAdaptorTest(int, char* [] )
+int itkComplexToRealFilterAndAdaptorTest( int, char* [] )
 {
 
   // Define the dimension of the images
   const unsigned int ImageDimension = 3;
 
   // Declare the types of the images
-  typedef std::complex<float>                InputPixelType;
+  typedef std::complex< float >               InputPixelType;
+  typedef float                               OutputPixelType;
 
-  typedef itk::Image<InputPixelType, ImageDimension>  InputImageType;
-  typedef itk::Image<float,          ImageDimension>  OutputImageType;
+  typedef itk::Image< InputPixelType, ImageDimension >    InputImageType;
+  typedef itk::Image< OutputPixelType, ImageDimension >   OutputImageType;
 
-  // Declare Iterator types apropriated for each image
+  // Declare appropriate Iterator types for each image
   typedef itk::ImageRegionIteratorWithIndex<
                                   InputImageType>  InputIteratorType;
   typedef itk::ImageRegionIteratorWithIndex<
@@ -75,53 +77,49 @@ int itkComplexToRealFilterAndAdaptorTest(int, char* [] )
   InputIteratorType it( inputImage, inputImage->GetBufferedRegion() );
 
   // Initialize the content of Image A
-  InputPixelType value( 13, 25);
-  std::cout << "Content of the Input " << std::endl;
+  InputPixelType value( 13, 25 );
   it.GoToBegin();
   while( !it.IsAtEnd() )
   {
     it.Set( value );
-    std::cout << it.Get() << std::endl;
     ++it;
   }
 
   // Declare the type for the ComplexToReal filter
   typedef itk::ComplexToRealImageFilter< InputImageType,
-                               OutputImageType  >  FilterType;
+                               OutputImageType > FilterType;
 
-
-  // Create an ADD Filter
+  // Create the Filter
   FilterType::Pointer filter = FilterType::New();
 
+  EXERCISE_BASIC_OBJECT_METHODS( filter, ComplexToRealImageFilter,
+    UnaryFunctorImageFilter );
 
-  // Connect the input images
+  // Set the input image
   filter->SetInput( inputImage );
 
-  // Get the Smart Pointer to the Filter Output
-  OutputImageType::Pointer outputImage = filter->GetOutput();
-
-
   // Execute the filter
   filter->Update();
 
-  // Create an iterator for going through the image output
-  OutputIteratorType ot(outputImage, outputImage->GetRequestedRegion());
+  // Get the filter output
+  OutputImageType::Pointer outputImage = filter->GetOutput();
 
-  //  Check the content of the result image
-  std::cout << "Verification of the output " << std::endl;
+  // Create an iterator for going through the image output
+  OutputIteratorType ot( outputImage, outputImage->GetRequestedRegion() );
+
+  // Check the content of the result image
   const OutputImageType::PixelType epsilon = 1e-6;
   ot.GoToBegin();
   it.GoToBegin();
   while( !ot.IsAtEnd() )
     {
-    std::cout <<  ot.Get() << " = ";
-    std::cout <<  it.Get().real()  << std::endl;
     const InputImageType::PixelType  input  = it.Get();
     const OutputImageType::PixelType output = ot.Get();
     const OutputImageType::PixelType real  = input.real();
-    if( std::fabs( real - output ) > epsilon )
+    if( !itk::Math::FloatAlmostEqual( real, output, 10, epsilon ) )
       {
-      std::cerr << "Error in itkComplexToRealImageFilterTest " << std::endl;
+      std::cerr.precision( static_cast< int >( itk::Math::abs( std::log10( epsilon ) ) ) );
+      std::cerr << "Error " << std::endl;
       std::cerr << " real( " << input << ") = " << real << std::endl;
       std::cerr << " differs from " << output;
       std::cerr << " by more than " << epsilon << std::endl;
@@ -131,48 +129,49 @@ int itkComplexToRealFilterAndAdaptorTest(int, char* [] )
     ++it;
     }
 
-  //---------------------------------------
-  // This section tests for ComplexToRealImageAdaptor
-  //---------------------------------------
+  //
+  // Test the itk::ComplexToRealImageAdaptor
+  //
 
-  typedef itk::ComplexToRealImageAdaptor<InputImageType,
-                          OutputImageType::PixelType>  AdaptorType;
+  typedef itk::ComplexToRealImageAdaptor< InputImageType,
+                          OutputImageType::PixelType > AdaptorType;
 
   AdaptorType::Pointer realAdaptor = AdaptorType::New();
 
+  EXERCISE_BASIC_OBJECT_METHODS( realAdaptor, ComplexToRealImageAdaptor,
+    ImageAdaptor );
+
   realAdaptor->SetImage( inputImage );
 
   typedef itk::SubtractImageFilter<
                         OutputImageType,
                         AdaptorType,
-                        OutputImageType   > DiffFilterType;
+                        OutputImageType > DiffFilterType;
 
   DiffFilterType::Pointer diffFilter = DiffFilterType::New();
 
   diffFilter->SetInput1( outputImage );
-  diffFilter->SetInput2( realAdaptor  );
+  diffFilter->SetInput2( realAdaptor );
 
   diffFilter->Update();
 
-  // Get the Smart Pointer to the Diff filter Output
+  // Get the filter output
   OutputImageType::Pointer diffImage = diffFilter->GetOutput();
 
-  //  Check the content of the diff image
-  std::cout << "Comparing the results with those of an Adaptor" << std::endl;
-  std::cout << "Verification of the output " << std::endl;
+  // Check the content of the diff image
+  //
 
   // Create an iterator for going through the image output
-  OutputIteratorType dt(diffImage, diffImage->GetRequestedRegion());
+  OutputIteratorType dt( diffImage, diffImage->GetRequestedRegion() );
 
   dt.GoToBegin();
   while( !dt.IsAtEnd() )
     {
-    std::cout <<  dt.Get() << std::endl;
     const OutputImageType::PixelType diff = dt.Get();
     if( std::fabs( diff ) > epsilon )
       {
-      std::cerr << "Error in itkComplexToRealImageFilterTest " << std::endl;
-      std::cerr << "Comparing results with Adaptors" << std::endl;
+      std::cerr.precision( static_cast< int >( itk::Math::abs( std::log10( epsilon ) ) ) );
+      std::cerr << "Error comparing results with Adaptors" << std::endl;
       std::cerr << " difference = " << diff << std::endl;
       std::cerr << " differs from 0 ";
       std::cerr << " by more than " << epsilon << std::endl;
@@ -181,6 +180,5 @@ int itkComplexToRealFilterAndAdaptorTest(int, char* [] )
     ++dt;
     }
 
-
   return EXIT_SUCCESS;
 }
