@@ -18,56 +18,49 @@
 
 #include "itkMinimumImageFilter.h"
 #include "itkImageRegionIteratorWithIndex.h"
+#include "itkTestingMacros.h"
 
 
-int itkMinimumImageFilterTest(int, char* [] )
+int itkMinimumImageFilterTest( int, char* [] )
 {
 
   // Define the dimension of the images
-  const unsigned int myDimension = 3;
+  const unsigned int Dimension = 3;
+
+  typedef unsigned char PixelType;
 
   // Declare the types of the images
-  typedef itk::Image<float, myDimension>  myImageType1;
-  typedef itk::Image<float, myDimension>  myImageType2;
-  typedef itk::Image<float, myDimension>  myImageType3;
+  typedef itk::Image< PixelType, Dimension >    ImageType;
 
   // Declare the type of the index to access images
-  typedef itk::Index<myDimension>         myIndexType;
+  typedef itk::Index< Dimension >               IndexType;
 
   // Declare the type of the size
-  typedef itk::Size<myDimension>          mySizeType;
+  typedef itk::Size< Dimension >                SizeType;
 
   // Declare the type of the Region
-  typedef itk::ImageRegion<myDimension>        myRegionType;
+  typedef itk::ImageRegion< Dimension >         RegionType;
 
   // Declare the type for the MULTIPLY filter
-  typedef itk::MinimumImageFilter<
-                                myImageType1,
-                                myImageType2,
-                                myImageType3  >       myFilterType;
-
-  // Declare the pointers to images
-  typedef myImageType1::Pointer   myImageType1Pointer;
-  typedef myImageType2::Pointer   myImageType2Pointer;
-  typedef myImageType3::Pointer   myImageType3Pointer;
-  typedef myFilterType::Pointer   myFilterTypePointer;
+  typedef itk::MinimumImageFilter< ImageType, ImageType,
+    ImageType > MinimumFilterType;
 
   // Create two images
-  myImageType1Pointer inputImageA  = myImageType1::New();
-  myImageType2Pointer inputImageB  = myImageType2::New();
+  ImageType::Pointer inputImageA = ImageType::New();
+  ImageType::Pointer inputImageB = ImageType::New();
 
   // Define their size, and start index
-  mySizeType size;
+  SizeType size;
   size[0] = 2;
   size[1] = 2;
   size[2] = 2;
 
-  myIndexType start;
+  IndexType start;
   start[0] = 0;
   start[1] = 0;
   start[2] = 0;
 
-  myRegionType region;
+  RegionType region;
   region.SetIndex( start );
   region.SetSize( size );
 
@@ -83,64 +76,59 @@ int itkMinimumImageFilterTest(int, char* [] )
   inputImageB->SetRequestedRegion( region );
   inputImageB->Allocate();
 
+  // Define the pixel values for each image
+  PixelType largePixelValue = 3;
+  PixelType smallPixelValue = 2;
 
   // Declare Iterator types apropriated for each image
-  typedef itk::ImageRegionIteratorWithIndex<myImageType1>  myIteratorType1;
-  typedef itk::ImageRegionIteratorWithIndex<myImageType2>  myIteratorType2;
-  typedef itk::ImageRegionIteratorWithIndex<myImageType3>  myIteratorType3;
+  typedef itk::ImageRegionIteratorWithIndex< ImageType > IteratorType;
 
   // Create one iterator for Image A (this is a light object)
-  myIteratorType1 it1( inputImageA, inputImageA->GetBufferedRegion() );
+  IteratorType it1( inputImageA, inputImageA->GetBufferedRegion() );
 
   // Initialize the content of Image A
-  std::cout << "First operand " << std::endl;
   while( !it1.IsAtEnd() )
   {
-    it1.Set( 2.0 );
-    std::cout << it1.Get() << std::endl;
+    it1.Set( smallPixelValue );
     ++it1;
   }
 
   // Create one iterator for Image B (this is a light object)
-  myIteratorType2 it2( inputImageB, inputImageB->GetBufferedRegion() );
+  IteratorType it2( inputImageB, inputImageB->GetBufferedRegion() );
 
   // Initialize the content of Image B
-  std::cout << "Second operand " << std::endl;
   while( !it2.IsAtEnd() )
   {
-    it2.Set( 3.0 );
-    std::cout << it2.Get() << std::endl;
+    it2.Set( largePixelValue );
     ++it2;
   }
 
+  // Create the filter
+  MinimumFilterType::Pointer minimumImageFilter = MinimumFilterType::New();
 
-  // Create an MULTIPLY Filter
-  myFilterTypePointer filter = myFilterType::New();
-
+  EXERCISE_BASIC_OBJECT_METHODS( minimumImageFilter, MinimumImageFilter,
+    BinaryFunctorImageFilter);
 
   // Connect the input images
-  filter->SetInput1( inputImageA );
-  filter->SetInput2( inputImageB );
+  minimumImageFilter->SetInput1( inputImageA );
+  minimumImageFilter->SetInput2( inputImageB );
 
-  // Get the Smart Pointer to the Filter Output
-  myImageType3Pointer outputImage = filter->GetOutput();
+  // Get the Smart Pointer to the filter output
+  ImageType::Pointer outputImage = minimumImageFilter->GetOutput();
 
+  minimumImageFilter->SetFunctor( minimumImageFilter->GetFunctor() );
 
   // Execute the filter
-  filter->Update();
-  filter->SetFunctor(filter->GetFunctor());
+  minimumImageFilter->Update();
 
-  // Create an iterator for going through the image output
-  myIteratorType3 it3(outputImage, outputImage->GetBufferedRegion());
+  // Test some pixels in the result image
+  // Note that we are not comparing the entirety of the filter output in order
+  // to keep compile time as small as possible
 
-  //  Print the content of the result image
-  std::cout << " Result " << std::endl;
-  while( !it3.IsAtEnd() )
-  {
-    std::cout << it3.Get() << std::endl;
-    ++it3;
-  }
+  ImageType::IndexType pixelIndex = {{0, 1, 1}};
 
+  TEST_EXPECT_EQUAL( outputImage->GetPixel( start ), smallPixelValue );
+  TEST_EXPECT_EQUAL( outputImage->GetPixel( pixelIndex ), smallPixelValue );
 
   // All objects should be automatically destroyed at this point
   return EXIT_SUCCESS;
