@@ -16,45 +16,48 @@
  *
  *=========================================================================*/
 
+#include "itkMath.h"
 #include "itkRGBPixel.h"
 #include "itkRGBToLuminanceImageFilter.h"
 #include "itkRGBToLuminanceImageAdaptor.h"
 #include "itkSubtractImageFilter.h"
+#include "itkTestingMacros.h"
 
 
-int itkRGBToLuminanceImageFilterAndAdaptorTest(int, char* [] )
+int itkRGBToLuminanceImageFilterAndAdaptorTest( int, char* [] )
 {
 
   // Define the dimension of the images
   const unsigned int ImageDimension = 3;
 
-  // Declare the types of the images
+  // Declare the pixel types of the images
   typedef itk::RGBPixel< float >                        InputPixelType;
   typedef float                                         OutputPixelType;
 
+  // Declare the types of the images
   typedef itk::Image< InputPixelType,  ImageDimension > InputImageType;
   typedef itk::Image< OutputPixelType, ImageDimension > OutputImageType;
 
-  // Declare Iterator types apropriated for each image
+  // Declare appropriate Iterator types for each image
   typedef itk::ImageRegionIteratorWithIndex<
-                                  InputImageType>  InputIteratorType;
+                                  InputImageType >  InputIteratorType;
 
   typedef itk::ImageRegionIteratorWithIndex<
-                                  OutputImageType>  OutputIteratorType;
+                                  OutputImageType > OutputIteratorType;
 
   // Declare the type of the index to access images
-  typedef itk::Index<ImageDimension>         IndexType;
+  typedef itk::Index< ImageDimension >         IndexType;
 
   // Declare the type of the size
-  typedef itk::Size<ImageDimension>          SizeType;
+  typedef itk::Size< ImageDimension >          SizeType;
 
   // Declare the type of the Region
-  typedef itk::ImageRegion<ImageDimension>   RegionType;
+  typedef itk::ImageRegion< ImageDimension >   RegionType;
 
-  // Create two images
-  InputImageType::Pointer inputImage  = InputImageType::New();
+  // Create the input image
+  InputImageType::Pointer inputImage = InputImageType::New();
 
-  // Define their size, and start index
+  // Define its size, and start index
   SizeType size;
   size[0] = 2;
   size[1] = 2;
@@ -69,67 +72,66 @@ int itkRGBToLuminanceImageFilterAndAdaptorTest(int, char* [] )
   region.SetIndex( start );
   region.SetSize( size );
 
-  // Initialize Image A
+  // Initialize the input image
   inputImage->SetLargestPossibleRegion( region );
   inputImage->SetBufferedRegion( region );
   inputImage->SetRequestedRegion( region );
   inputImage->Allocate();
+
   // Create one iterator for the Input Image (this is a light object)
   InputIteratorType it( inputImage, inputImage->GetBufferedRegion() );
 
-  // Initialize the content of Image A
+  // Initialize the content of the input image
   InputPixelType pixel;
   pixel.SetRed( 1.0 );
   pixel.SetGreen( 1.0 );
   pixel.SetBlue( 1.0 );
-  std::cout << "Content of the Input " << std::endl;
+
   it.GoToBegin();
   while( !it.IsAtEnd() )
   {
     it.Set( pixel );
-    std::cout << it.Get() << std::endl;
     ++it;
   }
 
   // Declare the type for the RGBToLuminance filter
   typedef itk::RGBToLuminanceImageFilter< InputImageType,
-                               OutputImageType  >  FilterType;
+                               OutputImageType > FilterType;
 
-
-  // Create an ADD Filter
+  // Create the filter
   FilterType::Pointer filter = FilterType::New();
 
+  EXERCISE_BASIC_OBJECT_METHODS( filter, RGBToLuminanceImageFilter,
+    UnaryFunctorImageFilter );
 
-  // Connect the input images
+  // Set the input image
   filter->SetInput( inputImage );
 
-  // Get the Smart Pointer to the Filter Output
-  OutputImageType::Pointer outputImage = filter->GetOutput();
-
+  filter->SetFunctor( filter->GetFunctor() );
 
   // Execute the filter
   filter->Update();
-  filter->SetFunctor(filter->GetFunctor());
+
+  // Get the filter output
+  OutputImageType::Pointer outputImage = filter->GetOutput();
 
   // Create an iterator for going through the image output
-  OutputIteratorType ot(outputImage, outputImage->GetRequestedRegion());
+  OutputIteratorType ot( outputImage, outputImage->GetRequestedRegion() );
 
-  //  Check the content of the result image
-  std::cout << "Verification of the output " << std::endl;
+  // Check the content of the result image
   const OutputImageType::PixelType epsilon = 1e-6;
 
   ot.GoToBegin();
   it.GoToBegin();
   while( !ot.IsAtEnd() )
     {
-    std::cout <<  ot.Get() << " = ";
-    std::cout <<  it.Get().GetLuminance()  << std::endl;
     const InputPixelType  input  = it.Get();
     const OutputPixelType output = ot.Get();
     const OutputPixelType value  = static_cast< OutputPixelType >( input.GetLuminance() );
-    if( std::fabs( value - output ) > epsilon )
+    if( !itk::Math::FloatAlmostEqual( value, output, 10, epsilon ) )
       {
-      std::cerr << "Error in itkRGBToLuminanceImageFilterTest " << std::endl;
+      std::cerr.precision( static_cast< int >( itk::Math::abs( std::log10( epsilon ) ) ) );
+      std::cerr << "Error " << std::endl;
       std::cerr << " Luminance( " << input << ") = " << value << std::endl;
       std::cerr << " differs from " << output;
       std::cerr << " by more than " << epsilon << std::endl;
@@ -139,48 +141,50 @@ int itkRGBToLuminanceImageFilterAndAdaptorTest(int, char* [] )
     ++it;
     }
 
-  //---------------------------------------
-  // This section tests for RGBToLuminanceImageAdaptor
-  //---------------------------------------
 
-  typedef itk::RGBToLuminanceImageAdaptor<InputImageType,
-                          OutputPixelType>  AdaptorType;
+  //
+  // Test the itk::RGBToLuminanceImageAdaptor
+  //
+
+  typedef itk::RGBToLuminanceImageAdaptor< InputImageType,
+                          OutputPixelType> AdaptorType;
 
   AdaptorType::Pointer luminanceAdaptor = AdaptorType::New();
 
+  EXERCISE_BASIC_OBJECT_METHODS( luminanceAdaptor, RGBToLuminanceImageAdaptor,
+    ImageAdaptor );
+
   luminanceAdaptor->SetImage( inputImage );
 
   typedef itk::SubtractImageFilter<
                         OutputImageType,
                         AdaptorType,
-                        OutputImageType   > DiffFilterType;
+                        OutputImageType > DiffFilterType;
 
   DiffFilterType::Pointer diffFilter = DiffFilterType::New();
 
   diffFilter->SetInput1( outputImage );
-  diffFilter->SetInput2( luminanceAdaptor  );
+  diffFilter->SetInput2( luminanceAdaptor );
 
   diffFilter->Update();
 
-  // Get the Smart Pointer to the Diff filter Output
+  // Get the filter output
   OutputImageType::Pointer diffImage = diffFilter->GetOutput();
 
-  //  Check the content of the diff image
-  std::cout << "Comparing the results with those of an Adaptor" << std::endl;
-  std::cout << "Verification of the output " << std::endl;
+  // Check the content of the diff image
+  //
 
   // Create an iterator for going through the image output
-  OutputIteratorType dt(diffImage, diffImage->GetRequestedRegion());
+  OutputIteratorType dt( diffImage, diffImage->GetRequestedRegion() );
 
   dt.GoToBegin();
   while( !dt.IsAtEnd() )
     {
-    std::cout <<  dt.Get() << std::endl;
     const OutputPixelType diff = dt.Get();
     if( std::fabs( diff ) > epsilon )
       {
-      std::cerr << "Error in itkRGBToLuminanceImageFilterTest " << std::endl;
-      std::cerr << "Comparing results with Adaptors" << std::endl;
+      std::cerr.precision( static_cast< int >( itk::Math::abs( std::log10( epsilon ) ) ) );
+      std::cerr << "Error comparing results with Adaptors" << std::endl;
       std::cerr << " difference = " << diff << std::endl;
       std::cerr << " differs from 0 ";
       std::cerr << " by more than " << epsilon << std::endl;
@@ -189,6 +193,5 @@ int itkRGBToLuminanceImageFilterAndAdaptorTest(int, char* [] )
     ++dt;
     }
 
-
   return EXIT_SUCCESS;
 }
