@@ -16,40 +16,45 @@
  *
  *=========================================================================*/
 
+#include "itkMath.h"
 #include "itkSqrtImageFilter.h"
 #include "itkSqrtImageAdaptor.h"
 #include "itkSubtractImageFilter.h"
+#include "itkTestingMacros.h"
 
 
-int itkSqrtImageFilterAndAdaptorTest(int, char* [] )
+int itkSqrtImageFilterAndAdaptorTest( int, char* [] )
 {
 
   // Define the dimension of the images
   const unsigned int ImageDimension = 3;
 
-  // Declare the types of the images
-  typedef itk::Image<float, ImageDimension>  InputImageType;
-  typedef itk::Image<float, ImageDimension>  OutputImageType;
+  // Declare the pixel types of the images
+  typedef float                PixelType;
 
-  // Declare Iterator types apropriated for each image
+  // Declare the types of the images
+  typedef itk::Image< PixelType, ImageDimension > InputImageType;
+  typedef itk::Image< PixelType, ImageDimension > OutputImageType;
+
+  // Declare appropriate Iterator types for each image
   typedef itk::ImageRegionIteratorWithIndex<
-                                  InputImageType>  InputIteratorType;
+                                  InputImageType >  InputIteratorType;
   typedef itk::ImageRegionIteratorWithIndex<
-                                  OutputImageType> OutputIteratorType;
+                                  OutputImageType > OutputIteratorType;
 
   // Declare the type of the index to access images
-  typedef itk::Index<ImageDimension>         IndexType;
+  typedef itk::Index< ImageDimension >         IndexType;
 
   // Declare the type of the size
-  typedef itk::Size<ImageDimension>          SizeType;
+  typedef itk::Size< ImageDimension >          SizeType;
 
   // Declare the type of the Region
-  typedef itk::ImageRegion<ImageDimension>   RegionType;
+  typedef itk::ImageRegion< ImageDimension >   RegionType;
 
-  // Create two images
-  InputImageType::Pointer inputImage  = InputImageType::New();
+  // Create the input image
+  InputImageType::Pointer inputImage = InputImageType::New();
 
-  // Define their size, and start index
+  // Define its size, and start index
   SizeType size;
   size[0] = 2;
   size[1] = 2;
@@ -64,63 +69,61 @@ int itkSqrtImageFilterAndAdaptorTest(int, char* [] )
   region.SetIndex( start );
   region.SetSize( size );
 
-  // Initialize Image A
+  // Initialize the input image
   inputImage->SetLargestPossibleRegion( region );
   inputImage->SetBufferedRegion( region );
   inputImage->SetRequestedRegion( region );
   inputImage->Allocate();
-  // Create one iterator for the Input Image (this is a light object)
+
+  // Create one iterator for the input image (this is a light object)
   InputIteratorType it( inputImage, inputImage->GetBufferedRegion() );
 
-  // Initialize the content of Image A
+  // Initialize the content of the input image
   const double value = itk::Math::pi / 6.0;
-  std::cout << "Content of the Input " << std::endl;
   it.GoToBegin();
   while( !it.IsAtEnd() )
   {
     it.Set( value );
-    std::cout << it.Get() << std::endl;
     ++it;
   }
 
   // Declare the type for the Sqrt filter
   typedef itk::SqrtImageFilter< InputImageType,
-                               OutputImageType  >  FilterType;
+                               OutputImageType > FilterType;
 
-
-  // Create an ADD Filter
+  // Create the filter
   FilterType::Pointer filter = FilterType::New();
 
+  EXERCISE_BASIC_OBJECT_METHODS( filter, SqrtImageFilter,
+    UnaryFunctorImageFilter );
 
-  // Connect the input images
+  // Set the input image
   filter->SetInput( inputImage );
 
-  // Get the Smart Pointer to the Filter Output
-  OutputImageType::Pointer outputImage = filter->GetOutput();
-
+  filter->SetFunctor( filter->GetFunctor() );
 
   // Execute the filter
   filter->Update();
-  filter->SetFunctor(filter->GetFunctor());
+
+  // Get the filter output
+  OutputImageType::Pointer outputImage = filter->GetOutput();
 
   // Create an iterator for going through the image output
-  OutputIteratorType ot(outputImage, outputImage->GetRequestedRegion());
+  OutputIteratorType ot( outputImage, outputImage->GetRequestedRegion() );
 
-  //  Check the content of the result image
-  std::cout << "Verification of the output " << std::endl;
+  // Check the content of the result image
   const OutputImageType::PixelType epsilon = 1e-6;
   ot.GoToBegin();
   it.GoToBegin();
   while( !ot.IsAtEnd() )
     {
-    std::cout <<  ot.Get() << " = ";
-    std::cout <<  std::sqrt( it.Get() )  << std::endl;
     const InputImageType::PixelType  input  = it.Get();
     const OutputImageType::PixelType output = ot.Get();
-    const OutputImageType::PixelType sqroot  = std::sqrt(input);
-    if( std::fabs( sqroot - output ) > epsilon )
+    const OutputImageType::PixelType sqroot = std::sqrt(input);
+    if( !itk::Math::FloatAlmostEqual( sqroot, output, 10, epsilon ) )
       {
-      std::cerr << "Error in itkSqrtImageFilterTest " << std::endl;
+      std::cerr.precision( static_cast< int >( itk::Math::abs( std::log10( epsilon ) ) ) );
+      std::cerr << "Error " << std::endl;
       std::cerr << " sqrt( " << input << ") = " << sqroot << std::endl;
       std::cerr << " differs from " << output;
       std::cerr << " by more than " << epsilon << std::endl;
@@ -130,48 +133,48 @@ int itkSqrtImageFilterAndAdaptorTest(int, char* [] )
     ++it;
     }
 
-  //---------------------------------------
-  // This section tests for SqrtImageAdaptor
-  //---------------------------------------
+  //
+  // Test the itk::SqrtImageAdaptor
+  //
 
-  typedef itk::SqrtImageAdaptor<InputImageType,
-                          OutputImageType::PixelType>  AdaptorType;
+  typedef itk::SqrtImageAdaptor< InputImageType,
+                          OutputImageType::PixelType > AdaptorType;
 
   AdaptorType::Pointer sqrtAdaptor = AdaptorType::New();
 
+  EXERCISE_BASIC_OBJECT_METHODS( sqrtAdaptor, SqrtImageAdaptor,
+    ImageAdaptor );
+
   sqrtAdaptor->SetImage( inputImage );
 
   typedef itk::SubtractImageFilter<
                         OutputImageType,
                         AdaptorType,
-                        OutputImageType   > DiffFilterType;
+                        OutputImageType > DiffFilterType;
 
   DiffFilterType::Pointer diffFilter = DiffFilterType::New();
 
   diffFilter->SetInput1( outputImage );
-  diffFilter->SetInput2( sqrtAdaptor  );
+  diffFilter->SetInput2( sqrtAdaptor );
 
   diffFilter->Update();
 
-  // Get the Smart Pointer to the Diff filter Output
+  // Get the filter output
   OutputImageType::Pointer diffImage = diffFilter->GetOutput();
 
-  //  Check the content of the diff image
-  std::cout << "Comparing the results with those of an Adaptor" << std::endl;
-  std::cout << "Verification of the output " << std::endl;
+  // Check the content of the diff image
+  //
 
   // Create an iterator for going through the image output
-  OutputIteratorType dt(diffImage, diffImage->GetRequestedRegion());
+  OutputIteratorType dt( diffImage, diffImage->GetRequestedRegion() );
 
   dt.GoToBegin();
   while( !dt.IsAtEnd() )
     {
-    std::cout <<  dt.Get() << std::endl;
     const OutputImageType::PixelType diff = dt.Get();
     if( std::fabs( diff ) > epsilon )
       {
-      std::cerr << "Error in itkSqrtImageFilterTest " << std::endl;
-      std::cerr << "Comparing results with Adaptors" << std::endl;
+      std::cerr << "Error comparing results with Adaptors" << std::endl;
       std::cerr << " difference = " << diff << std::endl;
       std::cerr << " differs from 0 ";
       std::cerr << " by more than " << epsilon << std::endl;
@@ -180,6 +183,5 @@ int itkSqrtImageFilterAndAdaptorTest(int, char* [] )
     ++dt;
     }
 
-
   return EXIT_SUCCESS;
 }
