@@ -16,40 +16,44 @@
  *
  *=========================================================================*/
 
+#include "itkMath.h"
 #include "itkTanImageFilter.h"
 #include "itkTanImageAdaptor.h"
 #include "itkSubtractImageFilter.h"
+#include "itkTestingMacros.h"
 
-
-int itkTanImageFilterAndAdaptorTest(int, char* [] )
+int itkTanImageFilterAndAdaptorTest( int, char* [] )
 {
 
   // Define the dimension of the images
   const unsigned int ImageDimension = 3;
 
-  // Declare the types of the images
-  typedef itk::Image<float, ImageDimension>  InputImageType;
-  typedef itk::Image<float, ImageDimension>  OutputImageType;
+  // Declare the pixel types of the images
+  typedef float                PixelType;
 
-  // Declare Iterator types apropriated for each image
+  // Declare the types of the images
+  typedef itk::Image< PixelType, ImageDimension > InputImageType;
+  typedef itk::Image< PixelType, ImageDimension > OutputImageType;
+
+  // Declare appropriate Iterator types for each image
   typedef itk::ImageRegionIteratorWithIndex<
-                                  InputImageType>  InputIteratorType;
+                                  InputImageType >  InputIteratorType;
   typedef itk::ImageRegionIteratorWithIndex<
-                                  OutputImageType> OutputIteratorType;
+                                  OutputImageType > OutputIteratorType;
 
   // Declare the type of the index to access images
-  typedef itk::Index<ImageDimension>         IndexType;
+  typedef itk::Index< ImageDimension >         IndexType;
 
   // Declare the type of the size
-  typedef itk::Size<ImageDimension>          SizeType;
+  typedef itk::Size< ImageDimension >          SizeType;
 
   // Declare the type of the Region
-  typedef itk::ImageRegion<ImageDimension>   RegionType;
+  typedef itk::ImageRegion< ImageDimension >   RegionType;
 
-  // Create two images
-  InputImageType::Pointer inputImage  = InputImageType::New();
+  // Create the input image
+  InputImageType::Pointer inputImage = InputImageType::New();
 
-  // Define their size, and start index
+  // Define its size, and start index
   SizeType size;
   size[0] = 2;
   size[1] = 2;
@@ -64,63 +68,61 @@ int itkTanImageFilterAndAdaptorTest(int, char* [] )
   region.SetIndex( start );
   region.SetSize( size );
 
-  // Initialize Image A
+  // Initialize the input image
   inputImage->SetLargestPossibleRegion( region );
   inputImage->SetBufferedRegion( region );
   inputImage->SetRequestedRegion( region );
   inputImage->Allocate();
-  // Create one iterator for the Input Image (this is a light object)
+
+  // Create one iterator for the input image (this is a light object)
   InputIteratorType it( inputImage, inputImage->GetBufferedRegion() );
 
-  // Initialize the content of Image A
+  // Initialize the content of the input image
   const double value = itk::Math::pi / 6.0;
-  std::cout << "Content of the Input " << std::endl;
   it.GoToBegin();
   while( !it.IsAtEnd() )
     {
     it.Set( value );
-    std::cout << it.Get() << std::endl;
     ++it;
     }
 
   // Declare the type for the Tan filter
   typedef itk::TanImageFilter< InputImageType,
-                               OutputImageType  >  FilterType;
+                               OutputImageType > FilterType;
 
-
-  // Create an ADD Filter
+  // Create the filter
   FilterType::Pointer filter = FilterType::New();
 
+  EXERCISE_BASIC_OBJECT_METHODS( filter, TanImageFilter,
+    UnaryFunctorImageFilter );
 
-  // Connect the input images
+  // Set the input image
   filter->SetInput( inputImage );
 
-  // Get the Smart Pointer to the Filter Output
-  OutputImageType::Pointer outputImage = filter->GetOutput();
-
+  filter->SetFunctor( filter->GetFunctor() );
 
   // Execute the filter
   filter->Update();
-  filter->SetFunctor(filter->GetFunctor());
+
+  // Get the filter output
+  OutputImageType::Pointer outputImage = filter->GetOutput();
 
   // Create an iterator for going through the image output
-  OutputIteratorType ot(outputImage, outputImage->GetRequestedRegion());
+  OutputIteratorType ot( outputImage, outputImage->GetRequestedRegion() );
 
-  //  Check the content of the result image
-  std::cout << "Verification of the output " << std::endl;
+  // Check the content of the result image
   const OutputImageType::PixelType epsilon = 1e-6;
   ot.GoToBegin();
   it.GoToBegin();
   while( !ot.IsAtEnd() )
     {
-    std::cout <<  ot.Get() << " = ";
-    std::cout <<  std::tan( it.Get() )  << std::endl;
     const InputImageType::PixelType  input  = it.Get();
     const OutputImageType::PixelType output = ot.Get();
-    const OutputImageType::PixelType tangent  = std::tan(input);
-    if( std::fabs( tangent - output ) > epsilon )
+    const OutputImageType::PixelType tangent = std::tan(input);
+    if( !itk::Math::FloatAlmostEqual( tangent, output, 10, epsilon ) )
       {
-      std::cerr << "Error in itkTanImageFilterTest " << std::endl;
+      std::cerr.precision( static_cast< int >( itk::Math::abs( std::log10( epsilon ) ) ) );
+      std::cerr << "Error " << std::endl;
       std::cerr << " std::tan( " << input << ") = " << tangent << std::endl;
       std::cerr << " differs from " << output;
       std::cerr << " by more than " << epsilon << std::endl;
@@ -130,48 +132,47 @@ int itkTanImageFilterAndAdaptorTest(int, char* [] )
     ++it;
     }
 
-  //---------------------------------------
-  // This section tests for TanImageAdaptor
-  //---------------------------------------
+  //
+  // Test the itk::TanImageAdaptor
 
-  typedef itk::TanImageAdaptor<InputImageType,
-                          OutputImageType::PixelType>  AdaptorType;
+  typedef itk::TanImageAdaptor< InputImageType,
+                          OutputImageType::PixelType > AdaptorType;
 
   AdaptorType::Pointer tanAdaptor = AdaptorType::New();
 
+  EXERCISE_BASIC_OBJECT_METHODS( tanAdaptor, TanImageAdaptor,
+    ImageAdaptor );
+
   tanAdaptor->SetImage( inputImage );
 
   typedef itk::SubtractImageFilter<
                         OutputImageType,
                         AdaptorType,
-                        OutputImageType   > DiffFilterType;
+                        OutputImageType > DiffFilterType;
 
   DiffFilterType::Pointer diffFilter = DiffFilterType::New();
 
   diffFilter->SetInput1( outputImage );
-  diffFilter->SetInput2( tanAdaptor  );
+  diffFilter->SetInput2( tanAdaptor );
 
   diffFilter->Update();
 
-  // Get the Smart Pointer to the Diff filter Output
+  // Get the filter output
   OutputImageType::Pointer diffImage = diffFilter->GetOutput();
 
-  //  Check the content of the diff image
-  std::cout << "Comparing the results with those of an Adaptor" << std::endl;
-  std::cout << "Verification of the output " << std::endl;
+  // Check the content of the diff image
+  //
 
   // Create an iterator for going through the image output
-  OutputIteratorType dt(diffImage, diffImage->GetRequestedRegion());
+  OutputIteratorType dt( diffImage, diffImage->GetRequestedRegion() );
 
   dt.GoToBegin();
   while( !dt.IsAtEnd() )
     {
-    std::cout <<  dt.Get() << std::endl;
     const OutputImageType::PixelType diff = dt.Get();
     if( std::fabs( diff ) > epsilon )
       {
-      std::cerr << "Error in itkTanImageFilterTest " << std::endl;
-      std::cerr << "Comparing results with Adaptors" << std::endl;
+      std::cerr << "Error comparing results with Adaptors" << std::endl;
       std::cerr << " difference = " << diff << std::endl;
       std::cerr << " differs from 0 ";
       std::cerr << " by more than " << epsilon << std::endl;
