@@ -50,7 +50,7 @@ namespace itk
 namespace Functor
 {
 template< typename TInput, typename TOutput >
-class ChangeLabel
+class ITK_TEMPLATE_EXPORT ChangeLabel
 {
 public:
   ChangeLabel() {}
@@ -108,7 +108,7 @@ private:
 }
 
 template< typename TInputImage, typename TOutputImage >
-class ChangeLabelImageFilter:
+class ITK_TEMPLATE_EXPORT ChangeLabelImageFilter:
   public
   UnaryFunctorImageFilter< TInputImage, TOutputImage,
                            Functor::ChangeLabel<
@@ -164,8 +164,7 @@ protected:
   void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  ChangeLabelImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ChangeLabelImageFilter);
 };
 } // end namespace itk
 
