@@ -47,7 +47,7 @@ int itkChangeLabelImageFilterTest(int, char* [] )
 
   // limit to a few labels
   InputPixelType upper = 10;
-  source->SetMin( itk::NumericTraits<InputPixelType>::Zero );
+  source->SetMin( itk::NumericTraits<InputPixelType>::ZeroValue() );
   source->SetMax( upper );
   source->SetSize( sizeArray );
 
