@@ -28,8 +28,26 @@ namespace itk
  *
  * \brief Alter an image with fixed value impulse noise, often called salt and pepper noise.
  *
+ * Salt and pepper noise is a special kind of impulse noise where the value
+ * of the noise is either the maximum possible value in the image or its
+ * minimum. It can be modeled as:
+ *
+ * \par
+ * \f$ I =
+ * \begin{cases}
+ * M,   & \quad \text{if } U < p/2 \\
+ * m,   & \quad \text{if } U > 1 - p/2 \\
+ * I_0, & \quad \text{if } p/2 \geq U \leq 1 - p/2
+ * \end{cases} \f$
+ *
+ * \par
+ * where \f$ p \f$ is the probability of the noise event, \f$ U \f$ is a
+ * uniformly distributed random variable in the \f$ [0,1] \f$ range, \f$ M \f$
+ * is the greatest possible pixel value, and \f$ m \f$ the smallest possible
+ * pixel value.
+ *
  * Pixel alteration occurs at a user defined probability.
- * Salt and pepper pixel are equally distributed.
+ * Salt and pepper pixels are equally distributed.
  *
  * \author Gaetan Lehmann
  *
@@ -39,7 +57,7 @@ namespace itk
  * \ingroup ITKImageNoise
  */
 template <class TInputImage, class TOutputImage=TInputImage>
-class SaltAndPepperNoiseImageFilter :
+class ITK_TEMPLATE_EXPORT SaltAndPepperNoiseImageFilter :
   public NoiseBaseImageFilter<TInputImage,TOutputImage >
 {
 public:
@@ -68,6 +86,8 @@ public:
   typedef typename InputImageType::RegionType   InputImageRegionType;
   typedef typename InputImageType::PixelType    InputImagePixelType;
 
+  /** Set/Get the probability of the salt and pepper noise event.
+   * Defaults to 0.01. */
   itkGetConstMacro(Probability, double);
   itkSetMacro(Probability, double);
 
@@ -90,13 +110,11 @@ protected:
                             ThreadIdType threadId ) ITK_OVERRIDE;
 
 private:
-  SaltAndPepperNoiseImageFilter(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(SaltAndPepperNoiseImageFilter);
 
   double m_Probability;
 
 };
-
 } // end namespace itk
 
 #ifndef ITK_MANUAL_INSTANTIATION
