@@ -33,7 +33,7 @@ namespace itk
  * \ingroup ITKImageNoise
  */
 template < class TInputImage >
-class PeakSignalToNoiseRatioCalculator : public Object
+class ITK_TEMPLATE_EXPORT PeakSignalToNoiseRatioCalculator : public Object
 {
 public:
   /** Standard class typedefs. */
@@ -93,8 +93,7 @@ protected:
   virtual void PrintSelf(std::ostream& os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  PeakSignalToNoiseRatioCalculator(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(PeakSignalToNoiseRatioCalculator);
 
   bool   m_Valid;                              // Have moments been computed
                                                // yet?
