@@ -41,7 +41,7 @@ namespace itk
  * \ingroup ITKImageSources
  */
 template <typename TOutputImage>
-class ParametricImageSource
+class ITK_TEMPLATE_EXPORT ParametricImageSource
   : public GenerateImageSource< TOutputImage >
 {
 public:
@@ -88,8 +88,7 @@ protected:
   virtual void PrintSelf(std::ostream& os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  ParametricImageSource(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ParametricImageSource);
 
 };
 } // end namespace itk
