@@ -35,7 +35,7 @@ namespace itk
  * \ingroup ITKImageSources
  */
 template< typename TOutputImage >
-class PhysicalPointImageSource
+class ITK_TEMPLATE_EXPORT PhysicalPointImageSource
   : public GenerateImageSource< TOutputImage >
 {
 public:
@@ -70,14 +70,12 @@ protected:
   virtual void ThreadedGenerateData (const RegionType &outputRegionForThread, ThreadIdType threadId) ITK_OVERRIDE;
 
 private:
-  PhysicalPointImageSource( const PhysicalPointImageSource &) ITK_DELETE_FUNCTION;
-  void operator=( const PhysicalPointImageSource &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(PhysicalPointImageSource);
 };
-
 }
 
 #ifndef ITK_MANUAL_INSTANTIATION
 #include "itkPhysicalPointImageSource.hxx"
 #endif
 
-#endif //itkPhysicalPointImageSource_h
+#endif
