@@ -51,7 +51,7 @@ namespace itk
  * \ingroup ITKImageStatistics
  */
 template< typename TInputImage, typename TOutputImage >
-class AccumulateImageFilter:public ImageToImageFilter< TInputImage, TOutputImage >
+class ITK_TEMPLATE_EXPORT AccumulateImageFilter:public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
   /** Standard class typedefs. */
@@ -88,8 +88,8 @@ public:
 #ifdef ITK_USE_CONCEPT_CHECKING
   // Begin concept checking
   itkConceptMacro( ImageDimensionCheck,
-                   ( Concept::SameDimensionOrMinusOne< itkGetStaticConstMacro(InputImageDimension),
-                                                       itkGetStaticConstMacro(OutputImageDimension) > ) );
+                   ( Concept::SameDimension< itkGetStaticConstMacro(InputImageDimension),
+                                             itkGetStaticConstMacro(OutputImageDimension) > ) );
   // End concept checking
 #endif
 
@@ -126,8 +126,7 @@ protected:
   void GenerateData(void) ITK_OVERRIDE;
 
 private:
-  AccumulateImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(AccumulateImageFilter);
 
   unsigned int m_AccumulateDimension;
   bool         m_Average;
