@@ -31,7 +31,7 @@ namespace itk
  *
  * This class was contributed to the Insight Journal by Gaetan Lehmann.
  * The original paper can be found at
- *      http://hdl.handle.net/1926/164
+ *      https://hdl.handle.net/1926/164
  *
  * \author Gaetan Lehmann. Biologie du Developpement et de la Reproduction,
  * INRA de Jouy-en-Josas, France.
@@ -111,8 +111,7 @@ protected:
   virtual ~MedianProjectionImageFilter() {}
 
 private:
-  MedianProjectionImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(MedianProjectionImageFilter);
 };                                           // end MedianProjectionImageFilter
 } //end namespace itk
 
