@@ -148,9 +148,8 @@ protected:
   virtual ~StandardDeviationProjectionImageFilter() {}
 
 private:
-  StandardDeviationProjectionImageFilter(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(StandardDeviationProjectionImageFilter);
 
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
 };                              // end StandardDeviationProjectionImageFilter
 } //end namespace itk
 
