@@ -40,7 +40,7 @@ namespace itk {
  */
 template<typename TImage, typename TAttributeAccessor=
     typename Functor::AttributeLabelObjectAccessor< typename TImage::LabelObjectType > >
-class AttributeKeepNObjectsLabelMapFilter :
+class ITK_TEMPLATE_EXPORT AttributeKeepNObjectsLabelMapFilter :
     public InPlaceLabelMapFilter<TImage>
 {
 public:
@@ -131,8 +131,7 @@ protected:
     };
 
 private:
-  AttributeKeepNObjectsLabelMapFilter(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(AttributeKeepNObjectsLabelMapFilter);
 
   bool           m_ReverseOrdering;
   SizeValueType  m_NumberOfObjects;
