@@ -41,7 +41,7 @@ namespace itk {
  */
 template<typename TImage, typename TAttributeAccessor=
     typename Functor::AttributeLabelObjectAccessor< typename TImage::LabelObjectType >, bool VPhysicalPosition=true >
-class AttributePositionLabelMapFilter :
+class ITK_TEMPLATE_EXPORT AttributePositionLabelMapFilter :
     public InPlaceLabelMapFilter<TImage>
 {
 public:
@@ -93,8 +93,7 @@ protected:
   void PrintSelf(std::ostream& os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  AttributePositionLabelMapFilter(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(AttributePositionLabelMapFilter);
 
 }; // end of class
 
