@@ -41,7 +41,7 @@ namespace itk {
  */
 template<typename TImage, typename TAttributeAccessor=
     typename Functor::AttributeLabelObjectAccessor< typename TImage::LabelObjectType > >
-class AttributeRelabelLabelMapFilter :
+class ITK_TEMPLATE_EXPORT AttributeRelabelLabelMapFilter :
     public InPlaceLabelMapFilter<TImage>
 {
 public:
@@ -126,8 +126,7 @@ protected:
     };
 
 private:
-  AttributeRelabelLabelMapFilter(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(AttributeRelabelLabelMapFilter);
 
   bool m_ReverseOrdering;
 
