@@ -44,7 +44,7 @@ namespace itk {
  */
 template<typename TImage, typename TAttributeAccessor=
     typename Functor::AttributeLabelObjectAccessor< typename TImage::LabelObjectType > >
-class AttributeUniqueLabelMapFilter :
+class ITK_TEMPLATE_EXPORT AttributeUniqueLabelMapFilter :
     public InPlaceLabelMapFilter<TImage>
 {
 public:
@@ -109,8 +109,7 @@ protected:
   bool m_ReverseOrdering;
 
 private:
-  AttributeUniqueLabelMapFilter(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(AttributeUniqueLabelMapFilter);
 
   struct LineOfLabelObject
     {
