@@ -50,7 +50,7 @@ namespace itk
  * \ingroup ITKLabelMap
  */
 template< typename TInputImage >
-class AutoCropLabelMapFilter:
+class ITK_TEMPLATE_EXPORT AutoCropLabelMapFilter:
   public ChangeRegionLabelMapFilter< TInputImage >
 {
 public:
@@ -107,8 +107,7 @@ protected:
   virtual void GenerateOutputInformation() ITK_OVERRIDE;
 
 private:
-  AutoCropLabelMapFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(AutoCropLabelMapFilter);
 
   SizeType  m_CropBorder;
 };
