@@ -42,7 +42,7 @@ namespace itk {
  * \ingroup ITKLabelMap
  */
 template<typename TInputImage>
-class BinaryFillholeImageFilter :
+class ITK_TEMPLATE_EXPORT BinaryFillholeImageFilter :
     public ImageToImageFilter<TInputImage, TInputImage>
 {
 public:
@@ -120,8 +120,7 @@ protected:
   void GenerateData() ITK_OVERRIDE;
 
 private:
-  BinaryFillholeImageFilter(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BinaryFillholeImageFilter);
 
   InputImagePixelType m_ForegroundValue;
 
