@@ -60,7 +60,7 @@ namespace itk
 template< typename TInputImage,
           typename TOutputImage =
             LabelMap< LabelObject< SizeValueType, TInputImage::ImageDimension > > >
-class BinaryImageToLabelMapFilter:
+class ITK_TEMPLATE_EXPORT BinaryImageToLabelMapFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -183,8 +183,7 @@ protected:
   virtual const ImageRegionSplitterBase* GetImageRegionSplitter() const ITK_OVERRIDE;
 
 private:
-  BinaryImageToLabelMapFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BinaryImageToLabelMapFilter);
 
   // some additional types
   typedef typename TOutputImage::RegionType::SizeType OutSizeType;
