@@ -59,7 +59,7 @@ namespace itk
  */
 template< typename TInputImage, typename TOutputImage =
             LabelMap< ShapeLabelObject< SizeValueType, TInputImage::ImageDimension > > >
-class BinaryImageToShapeLabelMapFilter:
+class ITK_TEMPLATE_EXPORT BinaryImageToShapeLabelMapFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -149,6 +149,15 @@ public:
   itkGetConstReferenceMacro(ComputePerimeter, bool);
   itkBooleanMacro(ComputePerimeter);
 
+  /**
+   * Set/Get whether the oriented bounding box should be
+   * computed or not. Default value is false because of potential
+   * memory consumption issues with sparse labels.
+   */
+  itkSetMacro(ComputeOrientedBoundingBox, bool);
+  itkGetConstReferenceMacro(ComputeOrientedBoundingBox, bool);
+  itkBooleanMacro(ComputeOrientedBoundingBox);
+
 protected:
   BinaryImageToShapeLabelMapFilter();
   ~BinaryImageToShapeLabelMapFilter() {}
@@ -166,14 +175,14 @@ protected:
   void GenerateData() ITK_OVERRIDE;
 
 private:
-  BinaryImageToShapeLabelMapFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BinaryImageToShapeLabelMapFilter);
 
   bool                 m_FullyConnected;
   OutputImagePixelType m_OutputBackgroundValue;
   InputImagePixelType  m_InputForegroundValue;
   bool                 m_ComputeFeretDiameter;
   bool                 m_ComputePerimeter;
+  bool                 m_ComputeOrientedBoundingBox;
 }; // end of class
 } // end namespace itk
 
