@@ -39,7 +39,7 @@ namespace itk
  */
 template< typename TInputImage, typename TFeatureImage, typename TOutputImage =
             LabelMap< StatisticsLabelObject< SizeValueType, TInputImage::ImageDimension > > >
-class BinaryImageToStatisticsLabelMapFilter:
+class ITK_TEMPLATE_EXPORT BinaryImageToStatisticsLabelMapFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -198,8 +198,7 @@ protected:
   void GenerateData() ITK_OVERRIDE;
 
 private:
-  BinaryImageToStatisticsLabelMapFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BinaryImageToStatisticsLabelMapFilter);
 
   bool                 m_FullyConnected;
   OutputImagePixelType m_OutputBackgroundValue;
