@@ -52,7 +52,7 @@ namespace itk {
  * \ingroup ITKLabelMap
  */
 template<typename TInputImage>
-class BinaryReconstructionByDilationImageFilter :
+class ITK_TEMPLATE_EXPORT BinaryReconstructionByDilationImageFilter :
     public ImageToImageFilter<TInputImage, TInputImage>
 {
 public:
@@ -161,8 +161,7 @@ protected:
   void GenerateData() ITK_OVERRIDE;
 
 private:
-  BinaryReconstructionByDilationImageFilter(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BinaryReconstructionByDilationImageFilter);
 
   bool                 m_FullyConnected;
   OutputImagePixelType m_BackgroundValue;
