@@ -53,7 +53,7 @@ namespace itk
  * \ingroup ITKLabelMap
  */
 template< typename TInputImage >
-class ChangeRegionLabelMapFilter:public InPlaceLabelMapFilter< TInputImage >
+class ITK_TEMPLATE_EXPORT ChangeRegionLabelMapFilter:public InPlaceLabelMapFilter< TInputImage >
 {
 public:
   /** Standard class typedefs. */
@@ -116,8 +116,7 @@ protected:
   void GenerateData() ITK_OVERRIDE;
 
 private:
-  ChangeRegionLabelMapFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ChangeRegionLabelMapFilter);
 
   OutputImageRegionType m_Region;
 };
