@@ -40,7 +40,7 @@ namespace itk
  * \ingroup ITKLabelMap
  */
 template< typename TInputImage, typename TOutputImage >
-class ConvertLabelMapFilter:
+class ITK_TEMPLATE_EXPORT ConvertLabelMapFilter:
   public LabelMapFilter< TInputImage, TOutputImage >
 {
 public:
@@ -83,8 +83,7 @@ protected:
   virtual void GenerateData() ITK_OVERRIDE;
 
 private:
-  ConvertLabelMapFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ConvertLabelMapFilter);
 };                                          // end of class
 } // end namespace itk
 
