@@ -80,7 +80,7 @@ namespace itk
  * \ingroup ITKLabelMap
  */
 template< typename TInputImage >
-class InPlaceLabelMapFilter:public LabelMapFilter< TInputImage, TInputImage >
+class ITK_TEMPLATE_EXPORT InPlaceLabelMapFilter:public LabelMapFilter< TInputImage, TInputImage >
 {
 public:
   /** Standard class typedefs. */
@@ -170,8 +170,7 @@ protected:
   }
 
 private:
-  InPlaceLabelMapFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(InPlaceLabelMapFilter);
 
   bool m_InPlace;
 };
