@@ -40,7 +40,7 @@ namespace itk
 template< typename TInputImage, typename TFeatureImage, typename TOutputImage =
             LabelMap< StatisticsLabelObject< typename TInputImage::PixelType,
                                              TInputImage::ImageDimension > > >
-class LabelImageToStatisticsLabelMapFilter:
+class ITK_TEMPLATE_EXPORT LabelImageToStatisticsLabelMapFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -182,8 +182,7 @@ protected:
   void GenerateData() ITK_OVERRIDE;
 
 private:
-  LabelImageToStatisticsLabelMapFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(LabelImageToStatisticsLabelMapFilter);
 
   OutputImagePixelType m_BackgroundValue;
   bool                 m_ComputeFeretDiameter;
