@@ -67,7 +67,7 @@ namespace itk
  * \endwiki
  */
 template< typename TLabelObject >
-class LabelMap:public ImageBase< TLabelObject::ImageDimension >
+class ITK_TEMPLATE_EXPORT LabelMap:public ImageBase< TLabelObject::ImageDimension >
 {
 public:
   /** Standard class typedefs */
@@ -138,7 +138,7 @@ public:
   /**  */
   virtual void Allocate(bool initialize = false) ITK_OVERRIDE;
 
-  virtual void Graft(const DataObject *data) ITK_OVERRIDE;
+  virtual void Graft(const Self *imgData);
 
   /**
    * Return the LabelObject with the label given in parameter.
@@ -449,10 +449,11 @@ protected:
   LabelMap();
   virtual ~LabelMap() {}
   void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
+  virtual void Graft(const DataObject *data) ITK_OVERRIDE;
+  using Superclass::Graft;
 
 private:
-  LabelMap(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(LabelMap);
 
   /** the LabelObject container type */
   typedef std::map< LabelType, LabelObjectPointerType > LabelObjectContainerType;
