@@ -54,7 +54,7 @@ namespace itk
  * \ingroup ITKLabelMap
  */
 template< typename TInputImage, typename TOutputImage >
-class LabelMapFilter:
+class ITK_TEMPLATE_EXPORT LabelMapFilter:
   public
   ImageToImageFilter< TInputImage, TOutputImage >
 {
@@ -121,8 +121,7 @@ protected:
   typename FastMutexLock::Pointer m_LabelObjectContainerLock;
 
 private:
-  LabelMapFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(LabelMapFilter);
 
   typename InputImageType::Iterator m_LabelObjectIterator;
   float                             m_InverseNumberOfLabelObjects;
