@@ -44,7 +44,7 @@ namespace itk {
  * \ingroup ITKLabelMap
  */
 template<typename TInputImage, typename TOutputImage>
-class LabelMapMaskImageFilter :
+class ITK_TEMPLATE_EXPORT LabelMapMaskImageFilter :
     public LabelMapFilter<TInputImage, TOutputImage>
 {
 public:
@@ -86,8 +86,7 @@ public:
   itkNewMacro(Self);
 
   /** Runtime information support. */
-  itkTypeMacro(LabelMapMaskImageFilter,
-               ImageToImageFilter);
+  itkTypeMacro(LabelMapMaskImageFilter, LabelMapFilter);
 
    /** Set the feature image */
   void SetFeatureImage(const TOutputImage *input)
@@ -171,8 +170,7 @@ protected:
   void PrintSelf(std::ostream& os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  LabelMapMaskImageFilter(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(LabelMapMaskImageFilter);
 
   InputImagePixelType       m_Label;
   OutputImagePixelType      m_BackgroundValue;
