@@ -126,8 +126,7 @@ protected:
   ~LabelSelectionLabelMapFilter() {};
 
 private:
-  LabelSelectionLabelMapFilter(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(LabelSelectionLabelMapFilter);
 
 }; // end of class
 
