@@ -44,7 +44,7 @@ namespace itk
  * \ingroup ITKLabelMap
  */
 template< typename TInputImage >
-class LabelShapeOpeningImageFilter:
+class ITK_TEMPLATE_EXPORT LabelShapeOpeningImageFilter:
   public ImageToImageFilter< TInputImage, TInputImage >
 {
 public:
@@ -154,8 +154,7 @@ protected:
   void GenerateData() ITK_OVERRIDE;
 
 private:
-  LabelShapeOpeningImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(LabelShapeOpeningImageFilter);
 
   OutputImagePixelType m_BackgroundValue;
   double               m_Lambda;
