@@ -43,7 +43,7 @@ namespace itk
  * \ingroup ITKLabelMap
  */
 template< typename TInputImage, typename TFeatureImage >
-class LabelStatisticsKeepNObjectsImageFilter:
+class ITK_TEMPLATE_EXPORT LabelStatisticsKeepNObjectsImageFilter:
   public ImageToImageFilter< TInputImage, TInputImage >
 {
 public:
@@ -180,8 +180,7 @@ protected:
   void GenerateData() ITK_OVERRIDE;
 
 private:
-  LabelStatisticsKeepNObjectsImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(LabelStatisticsKeepNObjectsImageFilter);
 
   OutputImagePixelType m_BackgroundValue;
   SizeValueType        m_NumberOfObjects;
