@@ -43,7 +43,7 @@ namespace itk
  * \ingroup ITKLabelMap
  */
 template< typename TInputImage, typename TFeatureImage >
-class LabelStatisticsOpeningImageFilter:
+class ITK_TEMPLATE_EXPORT LabelStatisticsOpeningImageFilter:
   public ImageToImageFilter< TInputImage, TInputImage >
 {
 public:
@@ -181,8 +181,7 @@ protected:
   void GenerateData() ITK_OVERRIDE;
 
 private:
-  LabelStatisticsOpeningImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(LabelStatisticsOpeningImageFilter);
 
   OutputImagePixelType m_BackgroundValue;
   double               m_Lambda;
