@@ -50,7 +50,7 @@ namespace itk
  * \ingroup ITKLabelMap
  */
 template< typename TImage >
-class MergeLabelMapFilter:
+class ITK_TEMPLATE_EXPORT MergeLabelMapFilter:
   public InPlaceLabelMapFilter< TImage >
 {
 public:
@@ -114,8 +114,7 @@ protected:
   MethodChoice m_Method;
 
 private:
-  MergeLabelMapFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(MergeLabelMapFilter);
 
   void MergeWithKeep();
 
