@@ -52,7 +52,7 @@ namespace itk
  * \ingroup ITKLabelMap
  */
 template< typename TInputImage >
-class PadLabelMapFilter:public ChangeRegionLabelMapFilter< TInputImage >
+class ITK_TEMPLATE_EXPORT PadLabelMapFilter:public ChangeRegionLabelMapFilter< TInputImage >
 {
 public:
   /** Standard class typedefs. */
@@ -62,7 +62,7 @@ public:
   typedef SmartPointer< const Self >                ConstPointer;
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro(PadLabelMapFilter, ChangeRegionImageFilter);
+  itkTypeMacro(PadLabelMapFilter, ChangeRegionLabelMapFilter);
 
   /** Standard New method. */
   itkNewMacro(Self);
@@ -119,8 +119,7 @@ protected:
   void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  PadLabelMapFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(PadLabelMapFilter);
 
   SizeType m_UpperBoundaryPadSize;
   SizeType m_LowerBoundaryPadSize;
