@@ -41,7 +41,7 @@ namespace itk
  * \ingroup ITKLabelMap
  */
 template< typename TImage >
-class ShapeKeepNObjectsLabelMapFilter:
+class ITK_TEMPLATE_EXPORT ShapeKeepNObjectsLabelMapFilter:
   public InPlaceLabelMapFilter< TImage >
 {
 public:
@@ -179,8 +179,7 @@ protected:
   AttributeType m_Attribute;
 
 private:
-  ShapeKeepNObjectsLabelMapFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ShapeKeepNObjectsLabelMapFilter);
 };                                               // end of class
 } // end namespace itk
 
