@@ -50,7 +50,7 @@ namespace itk
 
 template< typename TImage, typename TLabelImage =
             Image< typename TImage::PixelType,  TImage ::ImageDimension > >
-class ShapeLabelMapFilter:
+class ITK_TEMPLATE_EXPORT ShapeLabelMapFilter:
   public
   InPlaceLabelMapFilter< TImage >
 {
@@ -109,12 +109,21 @@ public:
 
   /**
    * Set/Get whether the perimeter should be computed or not.
-   * Default value is false because of the high computation time required.
+   * Default value is true;
    */
   itkSetMacro(ComputePerimeter, bool);
   itkGetConstReferenceMacro(ComputePerimeter, bool);
   itkBooleanMacro(ComputePerimeter);
 
+  /**
+   * Set/Get whether the oriented bounding box should be
+   * computed or not. Default value is false because of potential
+   * memory consumption issues with sparse labels.
+   */
+  itkSetMacro(ComputeOrientedBoundingBox, bool);
+  itkGetConstReferenceMacro(ComputeOrientedBoundingBox, bool);
+  itkBooleanMacro(ComputeOrientedBoundingBox);
+
   /** Set the label image */
   void SetLabelImage(const TLabelImage *input)
   {
@@ -134,15 +143,16 @@ protected:
   void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  ShapeLabelMapFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ShapeLabelMapFilter);
 
   bool                   m_ComputeFeretDiameter;
   bool                   m_ComputePerimeter;
+  bool                   m_ComputeOrientedBoundingBox;
   LabelImageConstPointer m_LabelImage;
 
   void ComputeFeretDiameter(LabelObjectType *labelObject);
   void ComputePerimeter(LabelObjectType *labelObject);
+  void ComputeOrientedBoundingBox(LabelObjectType *labelObject);
 
   typedef itk::Offset<2>                                                          Offset2Type;
   typedef itk::Offset<3>                                                          Offset3Type;
