@@ -46,7 +46,7 @@ namespace itk
  * \endwiki
  */
 template< typename TImage >
-class ShapeOpeningLabelMapFilter:
+class ITK_TEMPLATE_EXPORT ShapeOpeningLabelMapFilter:
   public InPlaceLabelMapFilter< TImage >
 {
 public:
@@ -169,8 +169,7 @@ protected:
   AttributeType m_Attribute;
 
 private:
-  ShapeOpeningLabelMapFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ShapeOpeningLabelMapFilter);
 };                                          // end of class
 } // end namespace itk
 
