@@ -35,7 +35,7 @@ namespace itk {
  * \ingroup ITKLabelMap
  */
 template<typename TImage>
-class ShapePositionLabelMapFilter :
+class ITK_TEMPLATE_EXPORT ShapePositionLabelMapFilter :
     public InPlaceLabelMapFilter<TImage>
 {
 public:
@@ -135,8 +135,7 @@ protected:
   AttributeType m_Attribute;
 
 private:
-  ShapePositionLabelMapFilter(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ShapePositionLabelMapFilter);
 
 }; // end of class
 
