@@ -43,7 +43,7 @@ namespace itk
  * \ingroup ITKLabelMap
  */
 template< typename TInputImage >
-class ShapeRelabelImageFilter:
+class ITK_TEMPLATE_EXPORT ShapeRelabelImageFilter:
   public ImageToImageFilter< TInputImage, TInputImage >
 {
 public:
@@ -145,8 +145,7 @@ protected:
   void GenerateData() ITK_OVERRIDE;
 
 private:
-  ShapeRelabelImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ShapeRelabelImageFilter);
 
   OutputImagePixelType m_BackgroundValue;
   bool                 m_ReverseOrdering;
