@@ -40,7 +40,7 @@ namespace itk
  * \ingroup ITKLabelMap
  */
 template< typename TImage >
-class ShapeUniqueLabelMapFilter:
+class ITK_TEMPLATE_EXPORT ShapeUniqueLabelMapFilter:
   public InPlaceLabelMapFilter< TImage >
 {
 public:
@@ -318,8 +318,7 @@ protected:
   AttributeType m_Attribute;
 
 private:
-  ShapeUniqueLabelMapFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ShapeUniqueLabelMapFilter);
 
   bool m_ReverseOrdering;
   struct LineOfLabelObject {
