@@ -43,7 +43,7 @@ namespace itk
  * \ingroup ITKLabelMap
  */
 template< typename TImage >
-class StatisticsKeepNObjectsLabelMapFilter:
+class ITK_TEMPLATE_EXPORT StatisticsKeepNObjectsLabelMapFilter:
   public ShapeKeepNObjectsLabelMapFilter< TImage >
 {
 public:
@@ -92,8 +92,7 @@ protected:
   void GenerateData() ITK_OVERRIDE;
 
 private:
-  StatisticsKeepNObjectsLabelMapFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(StatisticsKeepNObjectsLabelMapFilter);
 };                                                    // end of class
 } // end namespace itk
 
