@@ -39,7 +39,7 @@ namespace itk {
  * \ingroup ITKLabelMap
  */
 template<typename TImage>
-class StatisticsPositionLabelMapFilter :
+class ITK_TEMPLATE_EXPORT StatisticsPositionLabelMapFilter :
     public ShapePositionLabelMapFilter<TImage>
 {
 public:
@@ -88,8 +88,7 @@ protected:
   virtual void ThreadedProcessLabelObject( LabelObjectType * labelObject ) ITK_OVERRIDE;
 
 private:
-  StatisticsPositionLabelMapFilter(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(StatisticsPositionLabelMapFilter);
 
 }; // end of class
 
