@@ -42,7 +42,7 @@ namespace itk
  * \ingroup ITKLabelMap
  */
 template< typename TInputImage, typename TFeatureImage >
-class StatisticsRelabelImageFilter:
+class ITK_TEMPLATE_EXPORT StatisticsRelabelImageFilter:
   public ImageToImageFilter< TInputImage, TInputImage >
 {
 public:
@@ -172,8 +172,7 @@ protected:
   void GenerateData() ITK_OVERRIDE;
 
 private:
-  StatisticsRelabelImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(StatisticsRelabelImageFilter);
 
   OutputImagePixelType m_BackgroundValue;
   bool                 m_ReverseOrdering;
