@@ -42,7 +42,7 @@ namespace itk
  * \ingroup ITKLabelMap
  */
 template< typename TImage >
-class StatisticsRelabelLabelMapFilter:
+class ITK_TEMPLATE_EXPORT StatisticsRelabelLabelMapFilter:
   public ShapeRelabelLabelMapFilter< TImage >
 {
 public:
@@ -91,8 +91,7 @@ protected:
   void GenerateData() ITK_OVERRIDE;
 
 private:
-  StatisticsRelabelLabelMapFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(StatisticsRelabelLabelMapFilter);
 };                                               // end of class
 } // end namespace itk
 
