@@ -37,7 +37,7 @@ namespace itk
  */
 template< typename TImage, typename TKernel,
           typename TFunction1 >
-class AnchorErodeDilateImageFilter:
+class ITK_TEMPLATE_EXPORT AnchorErodeDilateImageFilter:
   public KernelImageFilter< TImage, TImage, TKernel >
 {
 public:
@@ -90,8 +90,7 @@ protected:
   InputImagePixelType m_Boundary;
 
 private:
-  AnchorErodeDilateImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(AnchorErodeDilateImageFilter);
 
   typedef BresenhamLine< itkGetStaticConstMacro(InputImageDimension) > BresType;
 
