@@ -43,7 +43,7 @@ namespace itk
  * \ingroup ITKMathematicalMorphology
  */
 template< typename TInputImage, typename TOutputImage, typename TKernel >
-class BasicErodeImageFilter:
+class ITK_TEMPLATE_EXPORT BasicErodeImageFilter:
   public MorphologyImageFilter< TInputImage, TOutputImage, TKernel >
 {
 public:
@@ -116,8 +116,7 @@ protected:
                              const KernelIteratorType kernelEnd) ITK_OVERRIDE;
 
 private:
-  BasicErodeImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BasicErodeImageFilter);
 
   // Default boundary condition for erosion filter, defaults to
   // NumericTraits<PixelType>::max()
