@@ -23,11 +23,11 @@
 namespace itk
 {
 /** \class BlackTopHatImageFilter
- * \brief Black top hat extract local minima that are smaller than the structuring element
+ * \brief Black top hat extracts local minima that are smaller than the structuring element
  *
- * Black top hat extract local minima that are smaller than the structuring
- * element. It subtract the background in the input image.
- * The output of the filter transforms the black peaks in white peaks.
+ * Black top hat extracts local minima that are smaller than the structuring
+ * element. It subtracts the background from the input image.
+ * The output of the filter transforms the black valleys into white peaks.
  *
  * Top-hats are described in Chapter 4.5 of Pierre Soille's book
  * "Morphological Image Analysis: Principles and Applications",
@@ -39,7 +39,7 @@ namespace itk
  * \ingroup ITKMathematicalMorphology
  */
 template< typename TInputImage, typename TOutputImage, typename TKernel >
-class BlackTopHatImageFilter:
+class ITK_TEMPLATE_EXPORT BlackTopHatImageFilter:
   public KernelImageFilter< TInputImage, TOutputImage, TKernel >
 {
 public:
@@ -107,8 +107,7 @@ protected:
   void GenerateData() ITK_OVERRIDE;
 
 private:
-  BlackTopHatImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BlackTopHatImageFilter);
 
   bool m_SafeBorder;
 
