@@ -42,7 +42,7 @@ namespace itk
  * \ingroup ITKMathematicalMorphology
  */
 template< typename TInputImage, typename TOutputImage >
-class GrayscaleConnectedClosingImageFilter:
+class ITK_TEMPLATE_EXPORT GrayscaleConnectedClosingImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -121,8 +121,7 @@ protected:
   void GenerateData() ITK_OVERRIDE;
 
 private:
-  GrayscaleConnectedClosingImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GrayscaleConnectedClosingImageFilter);
 
   unsigned long       m_NumberOfIterationsUsed;
   InputImageIndexType m_Seed;
