@@ -43,7 +43,7 @@ namespace itk
  * \ingroup ITKMathematicalMorphology
  */
 template< typename TInputImage, typename TOutputImage >
-class GrayscaleConnectedOpeningImageFilter:
+class ITK_TEMPLATE_EXPORT GrayscaleConnectedOpeningImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -122,8 +122,7 @@ protected:
   void GenerateData() ITK_OVERRIDE;
 
 private:
-  GrayscaleConnectedOpeningImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GrayscaleConnectedOpeningImageFilter);
 
   unsigned long       m_NumberOfIterationsUsed;
   InputImageIndexType m_Seed;
