@@ -31,9 +31,9 @@ namespace itk
 {
 /**
  * \class GrayscaleErodeImageFilter
- * \brief gray scale dilation of an image
+ * \brief Grayscale erosion of an image.
  *
- * Erode an image using grayscale morphology. Dilation takes the
+ * Erode an image using grayscale morphology. Erosion takes the
  * maximum of all the pixels identified by the structuring element.
  *
  * The structuring element is assumed to be composed of binary
@@ -50,7 +50,7 @@ namespace itk
  */
 
 template< typename TInputImage, typename TOutputImage, typename TKernel >
-class GrayscaleErodeImageFilter:
+class ITK_TEMPLATE_EXPORT GrayscaleErodeImageFilter:
   public KernelImageFilter< TInputImage, TOutputImage, TKernel >
 {
 public:
@@ -137,8 +137,7 @@ protected:
   void GenerateData() ITK_OVERRIDE;
 
 private:
-  GrayscaleErodeImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GrayscaleErodeImageFilter);
 
   PixelType m_Boundary;
 
