@@ -53,7 +53,7 @@ namespace itk
  * \ingroup ITKMathematicalMorphology
  */
 template< typename TInputImage, typename TOutputImage >
-class GrayscaleFillholeImageFilter:
+class ITK_TEMPLATE_EXPORT GrayscaleFillholeImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -123,8 +123,7 @@ protected:
   void GenerateData() ITK_OVERRIDE;
 
 private:
-  GrayscaleFillholeImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GrayscaleFillholeImageFilter);
 
   unsigned long m_NumberOfIterationsUsed;
 
