@@ -61,7 +61,7 @@ namespace itk
  * \ingroup ITKMathematicalMorphology
  */
 template< typename TInputImage, typename TOutputImage >
-class GrayscaleGeodesicDilateImageFilter:
+class ITK_TEMPLATE_EXPORT GrayscaleGeodesicDilateImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -185,8 +185,7 @@ protected:
                             ThreadIdType threadId) ITK_OVERRIDE;
 
 private:
-  GrayscaleGeodesicDilateImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GrayscaleGeodesicDilateImageFilter);
 
   bool          m_RunOneIteration;
   unsigned long m_NumberOfIterationsUsed;
