@@ -67,7 +67,7 @@ namespace itk
  * \ingroup ITKMathematicalMorphology
  */
 template< typename TInputImage, typename TOutputImage >
-class GrayscaleGrindPeakImageFilter:
+class ITK_TEMPLATE_EXPORT GrayscaleGrindPeakImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -137,8 +137,7 @@ protected:
   void GenerateData() ITK_OVERRIDE;
 
 private:
-  GrayscaleGrindPeakImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GrayscaleGrindPeakImageFilter);
 
   unsigned long m_NumberOfIterationsUsed;
 
