@@ -49,7 +49,7 @@ namespace itk
  */
 
 template< typename TInputImage, typename TOutputImage, typename TKernel >
-class GrayscaleMorphologicalClosingImageFilter:
+class ITK_TEMPLATE_EXPORT GrayscaleMorphologicalClosingImageFilter:
   public KernelImageFilter< TInputImage, TOutputImage, TKernel >
 {
 public:
@@ -136,8 +136,7 @@ protected:
   void GenerateData() ITK_OVERRIDE;
 
 private:
-  GrayscaleMorphologicalClosingImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GrayscaleMorphologicalClosingImageFilter);
 
   // the filters used internally
   typename HistogramErodeFilterType::Pointer m_HistogramErodeFilter;
