@@ -42,7 +42,7 @@ namespace itk
  * \ingroup ITKMathematicalMorphology
  */
 template< typename TInputImage, typename TOutputImage >
-class HConvexImageFilter:
+class ITK_TEMPLATE_EXPORT HConvexImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -123,8 +123,7 @@ protected:
   void GenerateData() ITK_OVERRIDE;
 
 private:
-  HConvexImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(HConvexImageFilter);
 
   InputImagePixelType m_Height;
   unsigned long       m_NumberOfIterationsUsed;
