@@ -89,8 +89,7 @@ protected:
   ~MovingHistogramDilateImageFilter() {}
 
 private:
-  MovingHistogramDilateImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(MovingHistogramDilateImageFilter);
 };                                                // end of class
 } // end namespace itk
 
