@@ -52,7 +52,7 @@ namespace itk
  * \ingroup ITKMathematicalMorphology
  */
 template< typename TInputImage, typename TOutputImage, typename TKernel >
-class OpeningByReconstructionImageFilter:
+class ITK_TEMPLATE_EXPORT OpeningByReconstructionImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -137,8 +137,7 @@ protected:
   void GenerateData() ITK_OVERRIDE;
 
 private:
-  OpeningByReconstructionImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(OpeningByReconstructionImageFilter);
 
   /** kernel or structuring element to use. */
   KernelType m_Kernel;
