@@ -113,8 +113,7 @@ protected:
   virtual ~ReconstructionByDilationImageFilter() {}
 
 private:
-  ReconstructionByDilationImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ReconstructionByDilationImageFilter);
 };
 // end ReconstructionByDilationImageFilter
 }
