@@ -111,8 +111,7 @@ protected:
   virtual ~ReconstructionByErosionImageFilter() {}
 
 private:
-  ReconstructionByErosionImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ReconstructionByErosionImageFilter);
 };                                                  // end
                                                     //
                                                     //
