@@ -67,8 +67,7 @@ protected:
 
 private:
 
-  VanHerkGilWermanErodeImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(VanHerkGilWermanErodeImageFilter);
 };
 } // namespace itk
 
