@@ -23,7 +23,7 @@
 namespace itk
 {
 /** \class WhiteTopHatImageFilter
- * \brief White top hat extract local maxima that are larger than the structuring element
+ * \brief White top hat extracts local maxima that are larger than the structuring element
  *
  * Top-hats are described in Chapter 4.5 of Pierre Soille's book
  * "Morphological Image Analysis: Principles and Applications",
@@ -35,7 +35,7 @@ namespace itk
  * \ingroup ITKMathematicalMorphology
  */
 template< typename TInputImage, typename TOutputImage, typename TKernel >
-class WhiteTopHatImageFilter:
+class ITK_TEMPLATE_EXPORT WhiteTopHatImageFilter:
   public KernelImageFilter< TInputImage, TOutputImage, TKernel >
 {
 public:
@@ -103,8 +103,7 @@ protected:
   void GenerateData() ITK_OVERRIDE;
 
 private:
-  WhiteTopHatImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(WhiteTopHatImageFilter);
 
   bool m_SafeBorder;
 
