@@ -20,7 +20,6 @@
 
 #include "itkChainCodePath.h"
 #include "itkIndex.h"
-#include "ITKPathExport.h"
 
 #include <vector>
 #include <string>
@@ -48,7 +47,7 @@ namespace itk
  * \ingroup PathObjects
  * \ingroup ITKPath
  */
-class ITKPath_EXPORT ChainCodePath2D:public
+class ITK_TEMPLATE_EXPORT ChainCodePath2D:public
   ChainCodePath< 2 >
 {
 public:
@@ -100,7 +99,7 @@ public:
   itkNewMacro(Self);
 
   /** How many steps in the chaincode? */
-  virtual inline ChainCodeSizeType NumberOfSteps() const ITK_OVERRIDE { return m_Chain2D.size(); }
+  virtual ChainCodeSizeType NumberOfSteps() const ITK_OVERRIDE { return m_Chain2D.size(); }
 
   /** Insert a new step into the chaincode at a specified position */
   inline void InsertStep(InputType position, int encodedStep)
@@ -109,7 +108,7 @@ public:
     this->Modified();
   }
 
-  virtual inline void InsertStep(InputType position, OffsetType step) ITK_OVERRIDE
+  virtual void InsertStep(InputType position, OffsetType step) ITK_OVERRIDE
   {
     m_Chain2D.insert( m_Chain2D.begin() + position, EncodeOffset(step) );
     this->Modified();
@@ -122,14 +121,14 @@ public:
     this->Modified();
   }
 
-  virtual inline void ChangeStep(InputType position, OffsetType step) ITK_OVERRIDE
+  virtual void ChangeStep(InputType position, OffsetType step) ITK_OVERRIDE
   {
     m_Chain2D[position] = EncodeOffset(step);
     this->Modified();
   }
 
   /** Remove all steps from the chain code */
-  virtual inline void Clear() ITK_OVERRIDE
+  virtual void Clear() ITK_OVERRIDE
   {
     m_Chain2D.clear();
     this->Modified();
@@ -154,8 +153,7 @@ protected:
   }
 
 private:
-  ChainCodePath2D(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ChainCodePath2D);
 
   ChainCode2DType m_Chain2D;    // the Freeman-encoded chain code
 
