@@ -38,7 +38,7 @@ namespace itk
  * \ingroup ITKPath
  */
 template< typename TInputChainCodePath, typename TOutputFourierSeriesPath >
-class ChainCodeToFourierSeriesPathFilter:public
+class ITK_TEMPLATE_EXPORT ChainCodeToFourierSeriesPathFilter:public
   PathToPathFilter< TInputChainCodePath, TOutputFourierSeriesPath >
 {
 public:
@@ -84,8 +84,7 @@ protected:
   void GenerateData(void) ITK_OVERRIDE;
 
 private:
-  ChainCodeToFourierSeriesPathFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ChainCodeToFourierSeriesPathFilter);
 
   unsigned int m_NumberOfHarmonics;
 };
