@@ -39,7 +39,7 @@ namespace itk
  * \ingroup ITKPath
  */
 template< typename TImage >
-class ExtractOrthogonalSwath2DImageFilter:public
+class ITK_TEMPLATE_EXPORT ExtractOrthogonalSwath2DImageFilter:public
   ImageAndPathToImageFilter< TImage, ParametricPath< 2 >, TImage >
 {
 public:
@@ -154,8 +154,7 @@ protected:
   //--------------------------------------------------------------------------
 
 private:
-  ExtractOrthogonalSwath2DImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ExtractOrthogonalSwath2DImageFilter);
 
   ImagePixelType m_DefaultPixelValue;
   SizeType       m_Size;
