@@ -21,7 +21,6 @@
 #include "itkParametricPath.h"
 #include "itkVectorContainer.h"
 #include "itkIndex.h"
-#include "itkPathTemplateExport.h"
 
 namespace itk
 {
@@ -42,7 +41,7 @@ namespace itk
  * \ingroup PathObjects
  * \ingroup ITKPath
  */
-class ITKPath_EXPORT_INHERIT_TEMPLATE
+class ITK_TEMPLATE_EXPORT
   OrthogonallyCorrected2DParametricPath:public
   ParametricPath< 2 >
 {
@@ -99,12 +98,12 @@ public:
   }
 
   /** These are determined by the original path */
-  virtual inline InputType StartOfInput() const ITK_OVERRIDE
+  virtual InputType StartOfInput() const ITK_OVERRIDE
   {
     return m_OriginalPath->StartOfInput();
   }
 
-  virtual inline InputType EndOfInput() const ITK_OVERRIDE
+  virtual InputType EndOfInput() const ITK_OVERRIDE
   {
     return m_OriginalPath->EndOfInput();
   }
@@ -115,8 +114,7 @@ protected:
   virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  OrthogonallyCorrected2DParametricPath(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(OrthogonallyCorrected2DParametricPath);
 
   OriginalPathConstPointer         m_OriginalPath;
   OrthogonalCorrectionTablePointer m_OrthogonalCorrectionTable;
