@@ -58,7 +58,7 @@ namespace itk
  * \ingroup ITKPath
  */
 template< unsigned int VDimension >
-class ParametricPath:public
+class ITK_TEMPLATE_EXPORT ParametricPath:public
   Path< double, ContinuousIndex< SpacePrecisionType, VDimension >, VDimension >
 {
 public:
@@ -134,8 +134,7 @@ protected:
   InputType m_DefaultInputStepSize;
 
 private:
-  ParametricPath(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ParametricPath);
 };
 
 } // namespace itk
@@ -144,4 +143,4 @@ private:
 #include "itkParametricPath.hxx"
 #endif
 
-#endif
+#endif // itkParametricPath.h
