@@ -50,7 +50,7 @@ namespace itk
  * \ingroup ITKPath
  */
 template< typename TInput, typename TOutput, unsigned int VDimension >
-class Path: public DataObject
+class ITK_TEMPLATE_EXPORT Path: public DataObject
 {
 public:
   /** Standard class typedefs. */
@@ -117,8 +117,7 @@ protected:
   itkGetConstMacro(ZeroIndex, IndexType);
 
 private:
-  Path(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(Path);
 
   // These "constants" are initialized in the constructor
   OffsetType m_ZeroOffset;  // = 0 for all dimensions
