@@ -38,7 +38,7 @@ namespace itk
  */
 
 template< typename TOutputPath >
-class PathSource:public ProcessObject
+class ITK_TEMPLATE_EXPORT PathSource:public ProcessObject
 {
 public:
   /** Standard class typedefs. */
@@ -181,8 +181,7 @@ protected:
   // (Image replaces w/ empty function)
 
 private:
-  PathSource(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(PathSource);
 };
 } // end namespace itk
 
