@@ -25,7 +25,7 @@
 namespace itk
 {
 /** \class PathToChainCodePathFilter
- * \brief Filter that produces a chain code version of a path
+ * \brief Filter that produces a chain code version of a path.
  *
  * PathToChainCodePathFilter produces a chain code representation of a path.
  * If MaximallyConnectedOn() is called, then the resulting chain code will be
@@ -35,7 +35,7 @@ namespace itk
  * \ingroup ITKPath
  */
 template< typename TInputPath, typename TOutputChainCodePath >
-class PathToChainCodePathFilter:public
+class ITK_TEMPLATE_EXPORT PathToChainCodePathFilter:public
   PathToPathFilter< TInputPath, TOutputChainCodePath >
 {
 public:
@@ -61,8 +61,9 @@ public:
   typedef typename InputPathType::IndexType  IndexType;
   typedef typename InputPathType::OffsetType OffsetType;
 
-  /** Set the direction in which to reflect the data. */
+  /** Set/Get the direction in which to reflect the data. Default is "Off". */
   itkSetMacro(MaximallyConnected, bool)
+  itkGetConstMacro(MaximallyConnected, bool)
   itkBooleanMacro(MaximallyConnected)
 
 protected:
@@ -73,8 +74,7 @@ protected:
   void GenerateData(void) ITK_OVERRIDE;
 
 private:
-  PathToChainCodePathFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(PathToChainCodePathFilter);
 
   bool m_MaximallyConnected;
 };
