@@ -33,7 +33,7 @@ namespace itk
  * \ingroup ITKPath
  */
 template< typename TInputPath, typename TOutputImage >
-class PathToImageFilter:public ImageSource< TOutputImage >
+class ITK_TEMPLATE_EXPORT PathToImageFilter:public ImageSource< TOutputImage >
 {
 public:
   /** Standard class typedefs. */
@@ -119,8 +119,7 @@ protected:
   virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  PathToImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(PathToImageFilter);
 };
 } // end namespace itk
 
