@@ -48,7 +48,7 @@ namespace itk
  * \ingroup ITKQuadEdgeMeshFiltering
  */
 template< typename TInputMesh, typename TOutputMesh=TInputMesh >
-class BorderQuadEdgeMeshFilter:
+class ITK_TEMPLATE_EXPORT BorderQuadEdgeMeshFilter:
   public QuadEdgeMeshToQuadEdgeMeshFilter< TInputMesh, TOutputMesh >
 {
 public:
@@ -169,8 +169,7 @@ protected:
   void ArcLengthSquareTransform();
 
 private:
-  BorderQuadEdgeMeshFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &); //purposely ont implemented
+  ITK_DISALLOW_COPY_AND_ASSIGN(BorderQuadEdgeMeshFilter);
 };
 } // end namespace itk
 
