@@ -33,7 +33,7 @@ namespace itk
  * \ingroup ITKQuadEdgeMeshFiltering
  */
 template< typename TInputMesh, typename TOutputMesh=TInputMesh >
-class CleanQuadEdgeMeshFilter:
+class ITK_TEMPLATE_EXPORT CleanQuadEdgeMeshFilter:
   public QuadEdgeMeshToQuadEdgeMeshFilter< TInputMesh, TOutputMesh >
 {
 public:
@@ -122,8 +122,7 @@ protected:
   void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  CleanQuadEdgeMeshFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(CleanQuadEdgeMeshFilter);
 
   InputCoordRepType m_AbsoluteTolerance;
   InputCoordRepType m_RelativeTolerance;
