@@ -116,8 +116,7 @@ protected:
 private:
   /** Cache output pointer to avoid calls in inner loop to GetOutput() */
   OutputMeshType *m_OutputMesh;
-  DiscreteCurvatureQuadEdgeMeshFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(DiscreteCurvatureQuadEdgeMeshFilter);
 };
 } // end namespace itk
 
