@@ -82,8 +82,7 @@ protected:
   }
 
 private:
-  DiscreteMinimumCurvatureQuadEdgeMeshFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(DiscreteMinimumCurvatureQuadEdgeMeshFilter);
 };
 }
 
