@@ -90,7 +90,7 @@ namespace itk {
  *  \ingroup ITKQuadEdgeMeshFiltering
  */
 template< class TInputMesh, class TOutputMesh, class TSolverTraits >
-class LaplacianDeformationQuadEdgeMeshFilter:
+class ITK_TEMPLATE_EXPORT LaplacianDeformationQuadEdgeMeshFilter:
   public QuadEdgeMeshToQuadEdgeMeshFilter< TInputMesh, TOutputMesh >
 {
 public:
@@ -256,8 +256,7 @@ protected:
 
 
 private:
-  LaplacianDeformationQuadEdgeMeshFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(LaplacianDeformationQuadEdgeMeshFilter);
 
   struct Triple
   {
