@@ -53,7 +53,7 @@ namespace itk {
  * \endwiki
  */
 template< typename TInputMesh, typename TOutputMesh, typename TSolverTraits >
-class ParameterizationQuadEdgeMeshFilter:
+class ITK_TEMPLATE_EXPORT ParameterizationQuadEdgeMeshFilter:
   public QuadEdgeMeshToQuadEdgeMeshFilter< TInputMesh, TOutputMesh >
 {
 public:
@@ -192,8 +192,7 @@ protected:
 
 private:
 
-  ParameterizationQuadEdgeMeshFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ParameterizationQuadEdgeMeshFilter);
 };
 } // end namespace itk
 
