@@ -194,9 +194,9 @@ public:
   typedef typename Superclass::PriorityQueueWrapperType  PriorityQueueWrapperType;
   typedef typename Superclass::PriorityType              PriorityType;
 
-  inline bool is_satisfied( MeshType *iMesh,
-                            const ElementType & itkNotUsed(iElement),
-                            const MeasureType & itkNotUsed(iValue) ) const ITK_OVERRIDE
+  bool is_satisfied( MeshType *iMesh,
+                     const ElementType & itkNotUsed(iElement),
+                     const MeasureType & itkNotUsed(iValue) ) const ITK_OVERRIDE
   {
     return ( iMesh->GetNumberOfFaces() <= this->m_NumberOfElements );
   }
@@ -245,9 +245,9 @@ public:
   typedef typename Superclass::PriorityQueueWrapperType  PriorityQueueWrapperType;
   typedef typename Superclass::PriorityType              PriorityType;
 
-  inline bool is_satisfied(MeshType *itkNotUsed(iMesh),
-                           const ElementType & itkNotUsed(iElement),
-                           const MeasureType & iValue) const ITK_OVERRIDE
+  bool is_satisfied(MeshType *itkNotUsed(iMesh),
+                    const ElementType & itkNotUsed(iElement),
+                    const MeasureType & iValue) const ITK_OVERRIDE
   {
     return ( iValue <= this->m_MeasureBound );
   }
