@@ -29,7 +29,7 @@ namespace itk
  * \ingroup ITKQuadEdgeMeshFiltering
  */
 template< typename TInput, typename TOutput, typename TCriterion >
-class QuadricDecimationQuadEdgeMeshFilter:
+class ITK_TEMPLATE_EXPORT QuadricDecimationQuadEdgeMeshFilter:
   public EdgeDecimationQuadEdgeMeshFilter< TInput, TOutput, TCriterion >
 {
 public:
@@ -117,7 +117,7 @@ protected:
    * \param[in] iEdge input edge
    * \return measure value, here the corresponding quadric error
    */
-  inline MeasureType MeasureEdge(OutputQEType *iEdge) ITK_OVERRIDE
+  MeasureType MeasureEdge(OutputQEType *iEdge) ITK_OVERRIDE
   {
     OutputPointIdentifier id_org = iEdge->GetOrigin();
     OutputPointIdentifier id_dest = iEdge->GetDestination();
@@ -151,8 +151,7 @@ protected:
   virtual void Initialize() ITK_OVERRIDE;
 
 private:
-  QuadricDecimationQuadEdgeMeshFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(QuadricDecimationQuadEdgeMeshFilter);
 
   QuadricElementMapType m_Quadric;
 };
