@@ -40,7 +40,7 @@ namespace itk
  * \endwiki
  */
 template< typename TInputImage, typename TOutputImage >
-class BinomialBlurImageFilter:
+class ITK_TEMPLATE_EXPORT BinomialBlurImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -110,8 +110,7 @@ protected:
   void GenerateData() ITK_OVERRIDE;
 
 private:
-  BinomialBlurImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BinomialBlurImageFilter);
 
   /** How many times should we apply the blur? */
   unsigned int m_Repetitions;
