@@ -59,7 +59,7 @@ namespace itk
  */
 
 template< typename TInputImage, typename TOutputImage >
-class DiscreteGaussianImageFilter:
+class ITK_TEMPLATE_EXPORT DiscreteGaussianImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -251,8 +251,7 @@ protected:
   void GenerateData() ITK_OVERRIDE;
 
 private:
-  DiscreteGaussianImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(DiscreteGaussianImageFilter);
 
   /** The variance of the gaussian blurring kernel in each dimensional
     direction. */
