@@ -49,7 +49,7 @@ namespace itk
  * \endwiki
  */
 template< typename TInputImage, typename TOutputImage >
-class MedianImageFilter:
+class ITK_TEMPLATE_EXPORT MedianImageFilter:
   public BoxImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -113,8 +113,7 @@ protected:
                             ThreadIdType threadId) ITK_OVERRIDE;
 
 private:
-  MedianImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(MedianImageFilter);
 };
 } // end namespace itk
 
