@@ -19,24 +19,26 @@
 #include "itkRandomImageSource.h"
 #include "itkMeanImageFilter.h"
 #include "itkTextOutput.h"
+#include "itkTestingMacros.h"
 
-
-int itkMeanImageFilterTest(int, char* [] )
+int itkMeanImageFilterTest( int, char* [] )
 {
   // Comment the following if you want to use the itk text output window
   itk::OutputWindow::SetInstance(itk::TextOutput::New());
 
+  const unsigned int Dimension = 2;
+  typedef float PixelType;
 
-  typedef itk::Image<float,2> FloatImage2DType;
+  typedef itk::Image< PixelType, Dimension > FloatImage2DType;
 
   itk::RandomImageSource<FloatImage2DType>::Pointer random;
-  random = itk::RandomImageSource<FloatImage2DType>::New();
-  random->SetMin(0.0);
-  random->SetMax(1000.0);
+  random = itk::RandomImageSource< FloatImage2DType >::New();
+  random->SetMin( 0.0 );
+  random->SetMax( 1000.0 );
 
   FloatImage2DType::SizeValueType randomSize[2];
   randomSize[0] = randomSize[1] = 8;
-  random->SetSize(randomSize);
+  random->SetSize( randomSize );
 
   FloatImage2DType::SpacingValueType spacing[2] = {0.7, 2.1};
   random->SetSpacing( spacing );
@@ -45,25 +47,30 @@ int itkMeanImageFilterTest(int, char* [] )
   random->SetOrigin( origin );
 
   // Create a mean image
-  itk::MeanImageFilter<FloatImage2DType, FloatImage2DType>::Pointer mean;
-  mean = itk::MeanImageFilter<FloatImage2DType,FloatImage2DType>::New();
-  mean->SetInput(random->GetOutput());
+  itk::MeanImageFilter< FloatImage2DType, FloatImage2DType >::Pointer mean =
+    itk::MeanImageFilter< FloatImage2DType, FloatImage2DType >::New();
 
-  // define the neighborhood size used for the mean filter (5x5)
+  EXERCISE_BASIC_OBJECT_METHODS( mean, MeanImageFilter, BoxImageFilter );
+
+  TRY_EXPECT_NO_EXCEPTION( random->Update() );
+
+  mean->SetInput( random->GetOutput() );
+
+  // Define the neighborhood size used for the mean filter (5x5)
   FloatImage2DType::SizeType neighRadius;
   neighRadius[0] = 1;
   neighRadius[1] = 1;
-  mean->SetRadius(neighRadius);
+  mean->SetRadius( neighRadius );
+  TEST_SET_GET_VALUE( neighRadius, mean->GetRadius() );
 
-  // run the algorithm
-  mean->Update();
+  TRY_EXPECT_NO_EXCEPTION( mean->Update() );
 
-  itk::ImageRegionIterator<FloatImage2DType> it;
-  it = itk::ImageRegionIterator<FloatImage2DType>(random->GetOutput(),
-                               random->GetOutput()->GetBufferedRegion());
+  itk::ImageRegionIterator< FloatImage2DType > it;
+  it = itk::ImageRegionIterator< FloatImage2DType >( random->GetOutput(),
+                               random->GetOutput()->GetBufferedRegion() );
   std::cout << "Input image" << std::endl;
   unsigned int i;
-  for (i=1; !it.IsAtEnd(); ++i, ++it)
+  for ( i = 1; !it.IsAtEnd(); ++i, ++it )
     {
     std::cout << "\t" << it.Get();
     if ((i % 8) == 0)
@@ -73,9 +80,9 @@ int itkMeanImageFilterTest(int, char* [] )
     }
 
   std::cout << "Output image" << std::endl;
-  it = itk::ImageRegionIterator<FloatImage2DType>(mean->GetOutput(),
-                               mean->GetOutput()->GetBufferedRegion());
-  for (i=1; !it.IsAtEnd(); ++i, ++it)
+  it = itk::ImageRegionIterator< FloatImage2DType >( mean->GetOutput(),
+                               mean->GetOutput()->GetBufferedRegion() );
+  for ( i = 1; !it.IsAtEnd(); ++i, ++it )
     {
     std::cout << "\t" << it.Get();
     if ((i % 8) == 0)
@@ -84,9 +91,5 @@ int itkMeanImageFilterTest(int, char* [] )
       }
     }
 
-  // Test the itkGetConstReferenceMacro
-  const FloatImage2DType::SizeType & radius = mean->GetRadius();
-  std::cout << "mean->GetRadius():" << radius << std::endl;
-
   return EXIT_SUCCESS;
 }
