@@ -40,7 +40,7 @@ namespace itk
  * \ingroup ITKSpatialFunction
  */
 template< typename TSpatialFunction, typename TInputImage, typename TOutputImage >
-class SpatialFunctionImageEvaluatorFilter:
+class ITK_TEMPLATE_EXPORT SpatialFunctionImageEvaluatorFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -93,8 +93,7 @@ protected:
   void GenerateData() ITK_OVERRIDE;
 
 private:
-  SpatialFunctionImageEvaluatorFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(SpatialFunctionImageEvaluatorFilter);
 
   /** The function that will be evaluated over the image */
   FunctionType *m_PixelFunction;
