@@ -63,7 +63,7 @@ namespace itk
 namespace Functor
 {
 template< typename TInput, typename TOutput >
-class BinaryThreshold
+class ITK_TEMPLATE_EXPORT BinaryThreshold
 {
 public:
   BinaryThreshold()
@@ -120,7 +120,7 @@ private:
 }
 
 template< typename TInputImage, typename TOutputImage >
-class BinaryThresholdImageFilter:
+class ITK_TEMPLATE_EXPORT BinaryThresholdImageFilter:
   public
   UnaryFunctorImageFilter< TInputImage, TOutputImage,
                            Functor::BinaryThreshold<
@@ -213,8 +213,7 @@ protected:
   virtual void BeforeThreadedGenerateData() ITK_OVERRIDE;
 
 private:
-  BinaryThresholdImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BinaryThresholdImageFilter);
 
   OutputPixelType m_InsideValue;
   OutputPixelType m_OutsideValue;
