@@ -114,8 +114,7 @@ protected:
   using ProcessObject::SetInput;
 
 private:
-  HistogramThresholdCalculator(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(HistogramThresholdCalculator);
 
 };
 
