@@ -49,20 +49,20 @@ namespace itk
  * \ingroup ITKThresholding
  */
 template <typename THistogram, typename TOutput=double>
-class HuangThresholdCalculator : public HistogramThresholdCalculator<THistogram, TOutput>
+class ITK_TEMPLATE_EXPORT HuangThresholdCalculator : public HistogramThresholdCalculator<THistogram, TOutput>
 {
 public:
   /** Standard class typedefs. */
-  typedef HuangThresholdCalculator        Self;
-  typedef Object                          Superclass;
-  typedef SmartPointer<Self>              Pointer;
-  typedef SmartPointer<const Self>        ConstPointer;
+  typedef HuangThresholdCalculator                          Self;
+  typedef HistogramThresholdCalculator<THistogram, TOutput> Superclass;
+  typedef SmartPointer<Self>                                Pointer;
+  typedef SmartPointer<const Self>                          ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro(HuangThresholdCalculator, Object);
+  itkTypeMacro(HuangThresholdCalculator, HistogramThresholdCalculator);
 
   /** Type definition for the input image. */
   typedef THistogram  HistogramType;
@@ -73,6 +73,8 @@ protected:
   virtual ~HuangThresholdCalculator() {}
   void GenerateData(void) ITK_OVERRIDE;
 
+  void PrintSelf(std::ostream& os, Indent indent) const ITK_OVERRIDE;
+
   typedef typename HistogramType::TotalAbsoluteFrequencyType  TotalAbsoluteFrequencyType;
   typedef typename HistogramType::AbsoluteFrequencyType       AbsoluteFrequencyType;
   typedef typename HistogramType::InstanceIdentifier          InstanceIdentifier;
@@ -80,8 +82,7 @@ protected:
   typedef typename HistogramType::MeasurementType             MeasurementType;
 
 private:
-  HuangThresholdCalculator(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(HuangThresholdCalculator);
 
   InstanceIdentifier  m_FirstBin;
   InstanceIdentifier  m_LastBin;
