@@ -53,20 +53,20 @@ namespace itk
  * \ingroup ITKThresholding
  */
 template <typename THistogram, typename TOutput=double>
-class IntermodesThresholdCalculator : public HistogramThresholdCalculator<THistogram, TOutput>
+class ITK_TEMPLATE_EXPORT IntermodesThresholdCalculator : public HistogramThresholdCalculator<THistogram, TOutput>
 {
 public:
   /** Standard class typedefs. */
-  typedef IntermodesThresholdCalculator   Self;
-  typedef Object                          Superclass;
-  typedef SmartPointer<Self>              Pointer;
-  typedef SmartPointer<const Self>        ConstPointer;
+  typedef IntermodesThresholdCalculator                     Self;
+  typedef HistogramThresholdCalculator<THistogram, TOutput> Superclass;
+  typedef SmartPointer<Self>                                Pointer;
+  typedef SmartPointer<const Self>                          ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro(IntermodesThresholdCalculator, Object);
+  itkTypeMacro(IntermodesThresholdCalculator, HistogramThresholdCalculator);
 
   /** Type definition for the input image. */
   typedef THistogram  HistogramType;
@@ -77,10 +77,11 @@ public:
   itkSetMacro( MaximumSmoothingIterations, SizeValueType );
   itkGetConstMacro( MaximumSmoothingIterations, SizeValueType );
 
-  /** select whether midpoint (intermode=true) or minimum between
-  peaks is used */
+  /** Select whether midpoint (intermode = true) or minimum between
+  peaks is used. Default is "On". */
   itkSetMacro( UseInterMode, bool);
   itkGetConstMacro( UseInterMode, bool );
+  itkBooleanMacro( UseInterMode );
 
 protected:
   IntermodesThresholdCalculator()
@@ -98,8 +99,7 @@ protected:
   typedef typename HistogramType::AbsoluteFrequencyType       AbsoluteFrequencyType;
 
 private:
-  IntermodesThresholdCalculator(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(IntermodesThresholdCalculator);
   bool BimodalTest(const std::vector<double> & h);
 
   SizeValueType m_MaximumSmoothingIterations;
