@@ -22,7 +22,8 @@
 #include "itkHistogramThresholdImageFilter.h"
 #include "itkLiThresholdCalculator.h"
 
-namespace itk {
+namespace itk
+{
 
 /** \class LiThresholdImageFilter
  * \brief Threshold an image using the Li Threshold
@@ -30,7 +31,7 @@ namespace itk {
  * This filter creates a binary thresholded image that separates an
  * image into foreground and background components. The filter
  * computes the threshold using the LiThresholdCalculator and
- * applies that theshold to the input image using the
+ * applies that threshold to the input image using the
  * BinaryThresholdImageFilter.
  *
  * \author Richard Beare. Department of Medicine, Monash University,
@@ -105,9 +106,8 @@ protected:
   ~LiThresholdImageFilter(){};
 
 private:
-  LiThresholdImageFilter(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
-}; // end of class
+  ITK_DISALLOW_COPY_AND_ASSIGN(LiThresholdImageFilter);
+};
 
 } // end namespace itk
 
