@@ -31,7 +31,7 @@ namespace itk
  * This filter creates a labeled image that separates the input
  * image into various classes. The filter
  * computes the thresholds using the OtsuMultipleThresholdsCalculator and
- * applies those thesholds to the input image using the
+ * applies those thresholds to the input image using the
  * ThresholdLabelerImageFilter. The NumberOfHistogramBins and
  * NumberOfThresholds can be set
  * for the Calculator. The LabelOffset can be set
@@ -53,7 +53,7 @@ namespace itk
  */
 
 template< typename TInputImage, typename TOutputImage >
-class OtsuMultipleThresholdsImageFilter:
+class ITK_TEMPLATE_EXPORT OtsuMultipleThresholdsImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -139,15 +139,14 @@ protected:
   void GenerateData() ITK_OVERRIDE;
 
 private:
-  OtsuMultipleThresholdsImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(OtsuMultipleThresholdsImageFilter);
 
   SizeValueType       m_NumberOfHistogramBins;
   SizeValueType       m_NumberOfThresholds;
   OutputPixelType     m_LabelOffset;
   ThresholdVectorType m_Thresholds;
   bool                m_ValleyEmphasis;
-}; // end of class
+};
 } // end namespace itk
 
 #ifndef ITK_MANUAL_INSTANTIATION
