@@ -48,20 +48,20 @@ namespace itk
  * \ingroup ITKThresholding
  */
 template <typename THistogram, typename TOutput=double>
-class RenyiEntropyThresholdCalculator : public HistogramThresholdCalculator<THistogram, TOutput>
+class ITK_TEMPLATE_EXPORT RenyiEntropyThresholdCalculator : public HistogramThresholdCalculator<THistogram, TOutput>
 {
 public:
   /** Standard class typedefs. */
-  typedef RenyiEntropyThresholdCalculator Self;
-  typedef Object                          Superclass;
-  typedef SmartPointer<Self>              Pointer;
-  typedef SmartPointer<const Self>        ConstPointer;
+  typedef RenyiEntropyThresholdCalculator                   Self;
+  typedef HistogramThresholdCalculator<THistogram, TOutput> Superclass;
+  typedef SmartPointer<Self>                                Pointer;
+  typedef SmartPointer<const Self>                          ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro(RenyiEntropyThresholdCalculator, Object);
+  itkTypeMacro(RenyiEntropyThresholdCalculator, HistogramThresholdCalculator);
 
   /** Type definition for the input image. */
   typedef THistogram  HistogramType;
@@ -73,6 +73,8 @@ protected:
 
   void GenerateData(void) ITK_OVERRIDE;
 
+  void PrintSelf(std::ostream& os, Indent indent) const ITK_OVERRIDE;
+
   typedef typename HistogramType::TotalAbsoluteFrequencyType  TotalAbsoluteFrequencyType;
   typedef typename HistogramType::AbsoluteFrequencyType       AbsoluteFrequencyType;
   typedef typename HistogramType::InstanceIdentifier          InstanceIdentifier;
@@ -94,8 +96,7 @@ protected:
                                               const std::vector< double >& P2 );
 
 private:
-  RenyiEntropyThresholdCalculator(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(RenyiEntropyThresholdCalculator);
 
   InstanceIdentifier  m_FirstBin;
   InstanceIdentifier  m_LastBin;
