@@ -42,7 +42,7 @@ namespace itk
 namespace Functor
 {
 template< typename TInput, typename TOutput >
-class ThresholdLabeler
+class ITK_TEMPLATE_EXPORT ThresholdLabeler
 {
 public:
   ThresholdLabeler() { m_LabelOffset = NumericTraits< TOutput >::OneValue(); }
@@ -76,7 +76,7 @@ public:
 
   inline TOutput operator()(const TInput & A) const
   {
-    unsigned int size = m_Thresholds.size();
+    size_t size = m_Thresholds.size();
 
     if ( size == 0 )
       {
@@ -86,7 +86,7 @@ public:
       {
       return m_LabelOffset;
       }
-    for ( unsigned int i = 0; i < size - 1; i++ )
+    for ( size_t i = 0; i < size - 1; i++ )
       {
       /* Value is in this class if it equals the upper bound. */
       if ( m_Thresholds[i] < A && A <= m_Thresholds[i + 1] )
@@ -105,7 +105,7 @@ private:
 }
 
 template< typename TInputImage, typename TOutputImage >
-class ThresholdLabelerImageFilter:
+class ITK_TEMPLATE_EXPORT ThresholdLabelerImageFilter:
   public
   UnaryFunctorImageFilter< TInputImage, TOutputImage,
                            Functor::ThresholdLabeler<
@@ -203,8 +203,7 @@ protected:
   virtual void BeforeThreadedGenerateData() ITK_OVERRIDE;
 
 private:
-  ThresholdLabelerImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ThresholdLabelerImageFilter);
 
   ThresholdVector     m_Thresholds;
   RealThresholdVector m_RealThresholds;
