@@ -49,20 +49,20 @@ namespace itk
  * \ingroup ITKThresholding
  */
 template <typename THistogram, typename TOutput=double>
-class TriangleThresholdCalculator : public HistogramThresholdCalculator<THistogram, TOutput>
+class ITK_TEMPLATE_EXPORT TriangleThresholdCalculator : public HistogramThresholdCalculator<THistogram, TOutput>
 {
 public:
   /** Standard class typedefs. */
-  typedef TriangleThresholdCalculator     Self;
-  typedef Object                          Superclass;
-  typedef SmartPointer<Self>              Pointer;
-  typedef SmartPointer<const Self>        ConstPointer;
+  typedef TriangleThresholdCalculator                       Self;
+  typedef HistogramThresholdCalculator<THistogram, TOutput> Superclass;
+  typedef SmartPointer<Self>                                Pointer;
+  typedef SmartPointer<const Self>                          ConstPointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro(TriangleThresholdCalculator, Object);
+  itkTypeMacro(TriangleThresholdCalculator, HistogramThresholdCalculator);
 
   /** Type definition for the input image. */
   typedef THistogram  HistogramType;
@@ -74,8 +74,7 @@ protected:
   void GenerateData(void) ITK_OVERRIDE;
 
 private:
-  TriangleThresholdCalculator(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(TriangleThresholdCalculator);
 
 };
 
