@@ -22,7 +22,8 @@
 #include "itkHistogramThresholdImageFilter.h"
 #include "itkYenThresholdCalculator.h"
 
-namespace itk {
+namespace itk
+{
 
 /** \class YenThresholdImageFilter
  * \brief Threshold an image using the Yen Threshold
@@ -30,14 +31,14 @@ namespace itk {
  * This filter creates a binary thresholded image that separates an
  * image into foreground and background components. The filter
  * computes the threshold using the YenThresholdCalculator and
- * applies that theshold to the input image using the
+ * applies that threshold to the input image using the
  * BinaryThresholdImageFilter.
  *
  * \author Richard Beare
  * \author Gaetan Lehmann. Biologie du Developpement et de la Reproduction, INRA de Jouy-en-Josas, France.
  *
  * This implementation was taken from the Insight Journal paper:
- * http://hdl.handle.net/10380/3279  or
+ * https://hdl.handle.net/10380/3279  or
  * http://www.insight-journal.org/browse/publication/811
  *
  * \sa HistogramThresholdImageFilter
@@ -104,9 +105,8 @@ protected:
   ~YenThresholdImageFilter(){};
 
 private:
-  YenThresholdImageFilter(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
-}; // end of class
+  ITK_DISALLOW_COPY_AND_ASSIGN(YenThresholdImageFilter);
+};
 
 } // end namespace itk
 
