@@ -61,8 +61,7 @@ protected:
   ~BMPImageIOFactory();
 
 private:
-  BMPImageIOFactory(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BMPImageIOFactory);
 };
 } // end namespace itk
 
