@@ -95,8 +95,7 @@ protected:
   void InternalReadImageInformation(std::ifstream & file);
 
 private:
-  BioRadImageIO(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BioRadImageIO);
 };
 } // end namespace itk
 
