@@ -43,7 +43,7 @@ namespace itk
  */
 
 template <typename TData>
-class CSVArray2DDataObject:public DataObject
+class ITK_TEMPLATE_EXPORT CSVArray2DDataObject:public DataObject
 {
 public:
   /* Standard class typedefs */
@@ -56,7 +56,7 @@ public:
   itkNewMacro(Self);
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro(Self,Superclass);
+  itkTypeMacro(CSVArray2DDataObject, DataObject);
 
   /* Vector typedefs. */
   typedef typename std::vector<TData>              NumericVectorType;
@@ -159,8 +159,7 @@ private:
   bool                   m_HasRowHeaders;
   bool                   m_HasColumnHeaders;
 
-  CSVArray2DDataObject(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(CSVArray2DDataObject);
 };
 
 } //end namespace itk
