@@ -75,7 +75,7 @@ namespace itk
  * \ingroup ITKIOCSV
  */
 template <typename TData>
-class CSVArray2DFileReader:public CSVFileReaderBase
+class ITK_TEMPLATE_EXPORT CSVArray2DFileReader:public CSVFileReaderBase
 {
 public:
   /** Standard class typedefs */
@@ -88,7 +88,7 @@ public:
   itkNewMacro(Self);
 
   /** Run-time type information (and related methods) */
-  itkTypeMacro(Self,Superclass);
+  itkTypeMacro(CSVArray2DFileReader, CSVFileReaderBase);
 
   /** DataFrame Object types */
   typedef typename itk::CSVArray2DDataObject<TData>    Array2DDataObjectType;
@@ -127,8 +127,7 @@ private:
 
   Array2DDataObjectPointer   m_Array2DDataObject;
 
-  CSVArray2DFileReader(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(CSVArray2DFileReader);
 };
 
 } //end namespace itk
