@@ -60,8 +60,7 @@ protected:
   DCMTKImageIOFactory();
   ~DCMTKImageIOFactory();
 private:
-  DCMTKImageIOFactory(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(DCMTKImageIOFactory);
 };
 } // end namespace itk
 
