@@ -61,8 +61,7 @@ protected:
   ~GDCMImageIOFactory();
 
 private:
-  GDCMImageIOFactory(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GDCMImageIOFactory);
 };
 } // end namespace itk
 
