@@ -183,8 +183,7 @@ protected:
   virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  GDCMSeriesFileNames(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GDCMSeriesFileNames);
 
   /** Contains the input directory where the DICOM serie is found */
   std::string m_InputDirectory;
