@@ -116,8 +116,7 @@ protected:
   virtual GEImageHeader * ReadHeader(const char *FileNameToRead) ITK_OVERRIDE;
 
 private:
-  GEAdwImageIO(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GEAdwImageIO);
 
   enum GE_ADW_DEFINES {
     GE_ADW_SU_ID = 0,    /**< Site id - String  */
