@@ -80,8 +80,7 @@ public:
   virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  GiplImageIO(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GiplImageIO);
 
   void SwapBytesIfNecessary(void *buffer, SizeValueType numberOfPixels);
 
