@@ -27,6 +27,8 @@
 #include "ITKIOHDF5Export.h"
 
 #include "itkAutoPointer.h"
+#include "itkMetaDataObjectBase.h"
+#include "itkMetaDataDictionary.h"
 
 // itk namespace first suppresses
 // kwstyle error for the H5 namespace below
@@ -44,8 +46,6 @@ class DataSet;
 
 namespace itk
 {
-class MetaDataObjectBase;
-class MetaDataDictionary;
 /** \class HDF5ImageIO
  *
  * \author Kent Williams
@@ -84,19 +84,19 @@ class MetaDataDictionary;
  *
  */
 
-class ITKIOHDF5_EXPORT HDF5ImageIO:public StreamingImageIOBase
+class ITKIOHDF5_EXPORT HDF5ImageIO: public StreamingImageIOBase
 {
 public:
   /** Standard class typedefs. */
   typedef HDF5ImageIO          Self;
-  typedef ImageIOBase          Superclass;
+  typedef StreamingImageIOBase Superclass;
   typedef SmartPointer< Self > Pointer;
 
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
 
   /** Run-time type information (and related methods). */
-  itkTypeMacro(HDF5ImageIO, Superclass);
+  itkTypeMacro(HDF5ImageIO, StreamingImageIOBase);
 
   /*-------- This part of the interfaces deals with reading data. ----- */
 
@@ -140,8 +140,7 @@ protected:
   virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  HDF5ImageIO(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(HDF5ImageIO);
 
   void WriteString(const std::string &path,
                    const std::string &value);
@@ -190,6 +189,7 @@ private:
                       H5::DataSpace *slabSpace);
 
   void CloseH5File();
+  void CloseDataSet();
 
   H5::H5File  *m_H5File;
   H5::DataSet *m_VoxelDataSet;
