@@ -173,8 +173,7 @@ protected:
   double hdr2Double(char *hdr);
 
 private:
-  IPLCommonImageIO(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(IPLCommonImageIO);
 };
 } // end namespace itk
 #define RAISE_EXCEPTION()                                    \
