@@ -110,8 +110,7 @@ protected:
   void Scan();
 
 private:
-  ArchetypeSeriesFileNames(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ArchetypeSeriesFileNames);
 
   /** A string for formatting the names of files in the series. */
   std::string m_Archetype;
