@@ -57,8 +57,7 @@ protected:
   ~ImageIOFactory();
 
 private:
-  ImageIOFactory(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ImageIOFactory);
 };
 } // end namespace itk
 
