@@ -120,7 +120,7 @@ int itkImageFileWriterStreamingTest2(int argc, char* argv[])
 
   reader->Modified();
   // get the size of the image
-  reader->GenerateOutputInformation();
+  reader->UpdateOutputInformation();
   ImageType::RegionType largestRegion;
   largestRegion = reader->GetOutput()->GetLargestPossibleRegion().GetSize();
   itk::ImageIORegion  ioregion(3);
