@@ -46,7 +46,7 @@ int itkLargeImageWriteConvertReadTest(int ac, char* av[])
 
   const size_t numberOfPixelsInOneDimension = atol( av[2] );
 
-  size.Fill( numberOfPixelsInOneDimension );
+  size.Fill( static_cast<OutputImageType::SizeValueType>( numberOfPixelsInOneDimension ) );
   index.Fill(0);
   region.SetSize(size);
   region.SetIndex(index);
