@@ -71,8 +71,7 @@ protected:
   ~LSMImageIOFactory();
 
 private:
-  LSMImageIOFactory(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(LSMImageIOFactory);
 };
 } // end namespace itk
 
