@@ -42,7 +42,7 @@ extern "C"
 {
 static void TagExtender(TIFF *tiff)
 {
-  static ITK_CONSTEXPR TIFFFieldInfo xtiffFieldInfo[] = {
+  static ITK_CONSTEXPR_VAR TIFFFieldInfo xtiffFieldInfo[] = {
           { TIF_CZ_LSMINFO, TIFF_VARIABLE, TIFF_VARIABLE, TIFF_BYTE,
           FIELD_CUSTOM, 0, 1, const_cast< char * >( "LSM Private Tag" ) }
     };
@@ -249,7 +249,10 @@ void LSMImageIO::Write(const void *buffer)
   const unsigned char *outPtr = (const unsigned char *)buffer;
 
   unsigned int width, height, page, pages = 1;
-
+  if ( this->GetNumberOfDimensions() < 2 )
+    {
+    itkExceptionMacro("TIFF requires images to have at least 2 dimensions");
+    }
   width =  m_Dimensions[0];
   height = m_Dimensions[1];
   if ( m_NumberOfDimensions == 3 )
