@@ -137,13 +137,12 @@ protected:
 
 protected:
   BYUMeshIO();
-  virtual ~BYUMeshIO(){}
+  virtual ~BYUMeshIO();
 
   virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  BYUMeshIO(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BYUMeshIO);
 
   StreamOffsetType m_FilePosition;
   SizeValueType    m_PartId;
