@@ -152,8 +152,7 @@ protected:
 
 protected:
   FreeSurferAsciiMeshIO();
-  virtual ~FreeSurferAsciiMeshIO(){}
-
+  virtual ~FreeSurferAsciiMeshIO();
   virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
   void OpenFile();
@@ -161,8 +160,7 @@ protected:
   void CloseFile();
 
 private:
-  FreeSurferAsciiMeshIO(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(FreeSurferAsciiMeshIO);
 
   std::ifstream m_InputFile;
 };
