@@ -53,7 +53,7 @@ public:
     {
     FreeSurferAsciiMeshIOFactory::Pointer freesurferFactory = FreeSurferAsciiMeshIOFactory::New();
 
-    ObjectFactoryBase::RegisterFactory(freesurferFactory);
+    ObjectFactoryBase::RegisterFactoryInternal(freesurferFactory);
     }
 
 protected:
@@ -63,8 +63,7 @@ protected:
   virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  FreeSurferAsciiMeshIOFactory(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(FreeSurferAsciiMeshIOFactory);
 };
 } // end namespace itk
 
