@@ -142,8 +142,7 @@ private:
   DirectionType m_Direction;
 
 private:
-  GiftiMeshIO(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GiftiMeshIO);
 
 };
 } // end namespace itk
