@@ -53,7 +53,7 @@ public:
   {
     GiftiMeshIOFactory::Pointer giftiFactory = GiftiMeshIOFactory::New();
 
-    ObjectFactoryBase::RegisterFactory(giftiFactory);
+    ObjectFactoryBase::RegisterFactoryInternal(giftiFactory);
   }
 
 protected:
@@ -63,8 +63,7 @@ protected:
   virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  GiftiMeshIOFactory(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GiftiMeshIOFactory);
 };
 // /////////////////////////////////////////////////////////////////////
 } // end namespace itk
