@@ -73,7 +73,7 @@ namespace itk
 template< typename TOutputMesh,
           typename ConvertPointPixelTraits = MeshConvertPixelTraits< typename TOutputMesh::PixelType >,
           class ConvertCellPixelTraits = MeshConvertPixelTraits< typename TOutputMesh::CellPixelType > >
-class MeshFileReader:public MeshSource< TOutputMesh >
+class ITK_TEMPLATE_EXPORT MeshFileReader:public MeshSource< TOutputMesh >
 {
 public:
   /** Standard class typedefs. */
@@ -168,8 +168,7 @@ protected:
   std::string m_FileName;                    // The file to be read
 
 private:
-  MeshFileReader(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(MeshFileReader);
 
   std::string m_ExceptionMessage;
 };
