@@ -69,8 +69,7 @@ protected:
   ~MeshIOFactory();
 
 private:
-  MeshIOFactory(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(MeshIOFactory);
 };
 } // end namespace itk
 
