@@ -53,7 +53,7 @@ public:
     {
     OFFMeshIOFactory::Pointer offFactory = OFFMeshIOFactory::New();
 
-    ObjectFactoryBase::RegisterFactory(offFactory);
+    ObjectFactoryBase::RegisterFactoryInternal(offFactory);
     }
 
 protected:
@@ -63,8 +63,7 @@ protected:
   virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  OFFMeshIOFactory(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(OFFMeshIOFactory);
 };
 } // end namespace itk
 
