@@ -107,7 +107,7 @@ public:
 
 protected:
   VTKPolyDataMeshIO();
-  virtual ~VTKPolyDataMeshIO() {}
+  virtual ~VTKPolyDataMeshIO();
 
   virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
@@ -1144,8 +1144,7 @@ protected:
   }
 
 private:
-  VTKPolyDataMeshIO(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(VTKPolyDataMeshIO);
 };
 } // end namespace itk
 
