@@ -84,7 +84,7 @@ MeshIOFactory
       }
     }
 
-  return 0;
+  return ITK_NULLPTR;
 }
 
 
