@@ -19,6 +19,8 @@
 #include <cstdlib>
 #include <metaImage.h>
 #include "itksys/SystemTools.hxx"
+#include "itkMacro.h"
+#include "itkMath.h"
 
 int testMetaImage(int , char * [])
   {
@@ -32,7 +34,7 @@ int testMetaImage(int , char * [])
 
   for(i=0; i<64; i++)
     {
-    if(i != tIm.ElementData(i))
+    if(itk::Math::NotExactlyEquals(i, tIm.ElementData(i)))
       {
       std::cout << "Assigned Element Values Maintained: FAIL" << std::endl;
       return EXIT_FAILURE;
@@ -109,7 +111,7 @@ int testMetaImage(int , char * [])
   tIm2.PrintInfo();
   for(i=0; i<64; i++)
     {
-    if(i != tIm.ElementData(i))
+    if(itk::Math::NotExactlyEquals(i, tIm.ElementData(i)))
       {
       std::cout << "Read Element Values: FAIL" << std::endl;
       return EXIT_FAILURE;
