@@ -23,7 +23,6 @@
 
 #include <fstream>
 #include "itkImageIOBase.h"
-#include <nifti1_io.h>
 
 namespace itk
 {
@@ -111,6 +110,13 @@ protected:
   virtual bool GetUseLegacyModeForTwoFileWriting(void) const { return false; }
 
 private:
+  //Try to use the Q and S form codes from MetaDataDictionary if they are specified
+  //there, otherwise default to the backwards compatible values from earlier
+  //versions of ITK. The qform guess would probably been better to have
+  //been guessed as NIFTI_XFORM_SCANNER_ANAT
+  unsigned int getSFormCodeFromDictionary() const;
+  unsigned int getQFormCodeFromDictionary() const;
+
   bool  MustRescale();
 
   void  DefineHeaderObjectDataType();
@@ -121,7 +127,29 @@ private:
 
   void  SetImageIOMetadataFromNIfTI();
 
-  nifti_image *m_NiftiImage;
+  //This proxy class provides a nifti_image pointer interface to the internal implementation
+  //of itk::NiftiImageIO, while hiding the niftilib interface from the external ITK interface.
+  class NiftiImageProxy;
+
+  //This class has ownership of the proxy and is thereby holder of the nifti_image pointer.
+  class NiftiImageHolder
+  {
+  private:
+    NiftiImageProxy* const m_NiftiImageProxy;
+  public:
+    NiftiImageHolder();
+    ~NiftiImageHolder();
+    NiftiImageProxy& GetNiftiImageProxy();
+
+  private:
+    NiftiImageHolder(const NiftiImageHolder&) ITK_DELETED_FUNCTION;
+    NiftiImageHolder& operator=(const NiftiImageHolder &) ITK_DELETED_FUNCTION;
+  };
+
+  //Note that it is essential that m_NiftiImageHolder is defined before m_NiftiImage, to ensure that
+  //m_NiftiImage can directly get a proxy from m_NiftiImageHolder during NiftiImageIO construction.
+  NiftiImageHolder m_NiftiImageHolder;
+  NiftiImageProxy& m_NiftiImage;
 
   double m_RescaleSlope;
   double m_RescaleIntercept;
@@ -130,8 +158,7 @@ private:
 
   bool m_LegacyAnalyze75Mode;
 
-  NiftiImageIO(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(NiftiImageIO);
 };
 } // end namespace itk
 
