@@ -61,8 +61,7 @@ protected:
   ~NrrdImageIOFactory();
 
 private:
-  NrrdImageIOFactory(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(NrrdImageIOFactory);
 };
 } // end namespace itk
 
