@@ -298,8 +298,7 @@ protected:
   void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  PhilipsPAR(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(PhilipsPAR);
 
   /** Function used internally to get PAR version. */
   int GetPARVersion(std::string parFile);
