@@ -145,8 +145,7 @@ protected:
 
 private:
 
-  PhilipsRECImageIO(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(PhilipsRECImageIO);
 
   void SwapBytesIfNecessary(void *buffer, SizeValueType numberOfPixels);
 
