@@ -73,8 +73,7 @@ protected:
   ~PhilipsRECImageIOFactory();
 
 private:
-  PhilipsRECImageIOFactory(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(PhilipsRECImageIOFactory);
 };
 } // end namespace itk
 
