@@ -45,7 +45,7 @@ namespace itk
  */
 
 template< typename TPixel, unsigned int VImageDimension = 2 >
-class RawImageIO:public ImageIOBase
+class ITK_TEMPLATE_EXPORT RawImageIO:public ImageIOBase
 {
 public:
   /** Standard class typedefs. */
@@ -139,8 +139,7 @@ protected:
   //void ComputeInternalFileName(unsigned long slice);
 
 private:
-  RawImageIO(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(RawImageIO);
 
   std::string m_InternalFileName;
 
@@ -151,7 +150,7 @@ private:
 };
 
 template< typename TPixel, unsigned int VImageDimension >
-class RawImageIOFactory:public ObjectFactoryBase
+class ITK_TEMPLATE_EXPORT RawImageIOFactory:public ObjectFactoryBase
 {
 public:
   /** Standard class typedefs. */
@@ -190,8 +189,7 @@ protected:
   const myProductType *m_MyProduct;
 
 private:
-  RawImageIOFactory(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(RawImageIOFactory);
 };
 } // namespace itk
 
