@@ -34,7 +34,7 @@ template< unsigned int NDimensions = 3,
           typename PixelType = unsigned char,
           typename TMeshTraits = DefaultStaticMeshTraits< PixelType, NDimensions, NDimensions >
           >
-class SpatialObjectReader:public Object
+class ITK_TEMPLATE_EXPORT SpatialObjectReader:public Object
 {
 public:
 
@@ -85,8 +85,7 @@ public:
                              MetaConverterBaseType *converter);
 
 protected:
-  SpatialObjectReader(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(SpatialObjectReader);
 
   std::string m_FileName;
 
