@@ -71,8 +71,7 @@ protected:
   ~StimulateImageIOFactory();
 
 private:
-  StimulateImageIOFactory(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(StimulateImageIOFactory);
 };
 } // end namespace itk
 
