@@ -140,8 +140,7 @@ protected:
     StreamingImageIOBase::SizeType num);
 
 private:
-  VTKImageIO(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(VTKImageIO);
   void SetPixelTypeFromString(const std::string & pixelType);
 
   /** Return the number of pixels in the IOregion. */
