@@ -71,8 +71,7 @@ protected:
   ~VTKImageIOFactory();
 
 private:
-  VTKImageIOFactory(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(VTKImageIOFactory);
 };
 } // end namespace itk
 
