@@ -60,8 +60,7 @@ protected:
   virtual void GenerateData() ITK_OVERRIDE;
 
 private:
-  ConstantImageSource(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ConstantImageSource);
 
   typename TOutputImage::PixelType m_Value;
 };
