@@ -31,7 +31,6 @@
 #include "itkColorTable.h"
 #include "itkConicShellInteriorExteriorSpatialFunction.h"
 #include "itkCosImageAdaptor.h"
-#include "itkDynamicLoader.h"
 #include "itkElasticBodyReciprocalSplineKernelTransform.h"
 #include "itkElasticBodySplineKernelTransform.h"
 #include "itkEllipsoidInteriorExteriorSpatialFunction.h"
@@ -209,10 +208,6 @@ int itkCommonPrintTest(int , char* [])
   std::cout << "------------DifferenceImageFilter" << DifferenceImageFilterObj;
 #endif
 
-  itk::DynamicLoader::Pointer DynamicLoaderObj =
-    itk::DynamicLoader::New();
-  std::cout << "------------DynamicLoader" << DynamicLoaderObj;
-
   itk::ElasticBodyReciprocalSplineKernelTransform<double,3>::Pointer ElasticBodyReciprocalSplineKernelTransformObj =
     itk::ElasticBodyReciprocalSplineKernelTransform<double,3>::New();
   std::cout << "------------ElasticBodyReciprocalSplineKernelTransform" << ElasticBodyReciprocalSplineKernelTransformObj;
