@@ -41,7 +41,7 @@ namespace itk
  * \ingroup ITKReview
  */
 template< typename TImageType, typename TCoordRep = double, typename TCoefficientType = double >
-class ComplexBSplineInterpolateImageFunction:
+class ITK_TEMPLATE_EXPORT ComplexBSplineInterpolateImageFunction:
   public InterpolateImageFunction< TImageType, TCoordRep >
 {
 public:
@@ -124,12 +124,11 @@ public:
 protected:
   ComplexBSplineInterpolateImageFunction();
   virtual ~ComplexBSplineInterpolateImageFunction() {}
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
 
   void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  ComplexBSplineInterpolateImageFunction(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ComplexBSplineInterpolateImageFunction);
 
   unsigned int m_SplineOrder;
 
