@@ -57,7 +57,7 @@ namespace itk
  */
 
 template< typename TInputImage, typename TOutputImage >
-class DiscreteGaussianDerivativeImageFilter :
+class ITK_TEMPLATE_EXPORT DiscreteGaussianDerivativeImageFilter :
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -216,8 +216,7 @@ protected:
 
 private:
 
-  DiscreteGaussianDerivativeImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(DiscreteGaussianDerivativeImageFilter);
 
   /** The order of the derivatives in each dimensional direction. */
   OrderArrayType m_Order;
