@@ -57,7 +57,7 @@ namespace itk
  * \ingroup ITKReview
  */
 template< typename TFixedImage, typename TMovingImage, typename TDisplacementField >
-class ESMDemonsRegistrationFunction:
+class ITK_TEMPLATE_EXPORT ESMDemonsRegistrationFunction:
   public PDEDeformableRegistrationFunction< TFixedImage,
                                             TMovingImage, TDisplacementField >
 {
@@ -232,8 +232,7 @@ protected:
   };
 
 private:
-  ESMDemonsRegistrationFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ESMDemonsRegistrationFunction);
 
   /** Cache fixed image information. */
   PointType     m_FixedImageOrigin;
