@@ -110,8 +110,7 @@ protected:
   }
 
 private:
-  FastApproximateRankImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(FastApproximateRankImageFilter);
 
   float m_Rank;
 };
