@@ -44,6 +44,10 @@ namespace itk
  * Typically the mapped position does not correspond to an integer pixel
  * position in the output image. We round it.
  *
+ * Warning: the functionality provided by this class is currently implemented
+ * with more options and multi-threaded in itk::GridImageSource by setting up
+ * an appropriate itk::ResampleImageFilter instance to such an object.
+ *
  * \author Tom Vercauteren, INRIA & Mauna Kea Technologies
  *
  * This implementation was taken from the Insight Journal paper:
@@ -55,7 +59,7 @@ template<
   typename TDisplacementField,
   typename TOutputImage
   >
-class GridForwardWarpImageFilter:
+class ITK_TEMPLATE_EXPORT GridForwardWarpImageFilter:
   public ImageToImageFilter< TDisplacementField, TOutputImage >
 {
 public:
@@ -120,14 +124,10 @@ protected:
 
   void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
-  /**
-   * GenerateData()
-   */
   void GenerateData() ITK_OVERRIDE;
 
 private:
-  GridForwardWarpImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GridForwardWarpImageFilter);
 
   PixelType    m_BackgroundValue;
   PixelType    m_ForegroundValue;
