@@ -112,8 +112,7 @@ protected:
   virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  JPEG2000ImageIO(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(JPEG2000ImageIO);
 
   AutoPointer< JPEG2000ImageIOInternal >  m_Internal;
 
