@@ -40,7 +40,7 @@ namespace itk
  */
 
 template< typename TInputImage, typename TMaskImage, typename TOutputImage, typename TKernel, typename THistogram >
-class MaskedMovingHistogramImageFilter:
+class ITK_TEMPLATE_EXPORT MaskedMovingHistogramImageFilter:
   public MovingHistogramImageFilterBase< TInputImage, TOutputImage, TKernel >
 {
 public:
@@ -162,8 +162,7 @@ protected:
                      const IndexType currentIdx);
 
 private:
-  MaskedMovingHistogramImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(MaskedMovingHistogramImageFilter);
 
   bool m_GenerateOutputMask;
 
