@@ -47,7 +47,7 @@ namespace itk
  */
 
 template< typename TInputImage, typename TOutputImage, typename TFilter >
-class MiniPipelineSeparableImageFilter:
+class ITK_TEMPLATE_EXPORT MiniPipelineSeparableImageFilter:
   public BoxImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -106,8 +106,7 @@ protected:
   typename CastType::Pointer m_Cast;
 
 private:
-  MiniPipelineSeparableImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(MiniPipelineSeparableImageFilter);
 };
 }
 
