@@ -32,9 +32,9 @@ namespace itk
  * \class MultiphaseDenseFiniteDifferenceImageFilter
  *
  * This filter implements a layer of the finite difference solver hierarchy that
- * performs ``dense'' iteration, ie. iteration over all pixels in the input and
+ * performs "dense" iteration, ie. iteration over all pixels in the input and
  * output at each change calculation and update step. Dense iteration is in
- * contrast to a ``sparse'' iteration over a subset of the pixels.  See
+ * contrast to a "sparse" iteration over a subset of the pixels.  See
  * documentation for FiniteDifferenceImageFilter for an overview of the
  * iterative finite difference algorithm:
  *
@@ -99,7 +99,7 @@ namespace itk
  */
 template< typename TInputImage, typename TFeatureImage, typename TOutputImage, typename TFunction,
           typename TIdCell = unsigned int >
-class MultiphaseDenseFiniteDifferenceImageFilter:
+class ITK_TEMPLATE_EXPORT MultiphaseDenseFiniteDifferenceImageFilter:
   public MultiphaseFiniteDifferenceImageFilter< TInputImage, TFeatureImage,
                                                 TOutputImage, TFunction, TIdCell >
 {
@@ -210,8 +210,7 @@ protected:
   // unsigned int m_UpdateCounter;        // FIXME: Should this be a boolean ?
 
 private:
-  MultiphaseDenseFiniteDifferenceImageFilter(const Self &);
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(MultiphaseDenseFiniteDifferenceImageFilter);
 
   /** This method allocates storage in m_UpdateBuffer.  It is called from
    * Superclass::GenerateData(). */
