@@ -38,7 +38,7 @@ namespace itk
  * \ingroup ITKReview
  */
 template< typename TInputImage, typename TGradientImage >
-class RobustAutomaticThresholdCalculator:public Object
+class ITK_TEMPLATE_EXPORT RobustAutomaticThresholdCalculator:public Object
 {
 public:
   /** Standard class typedefs. */
@@ -108,21 +108,19 @@ protected:
   virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  RobustAutomaticThresholdCalculator(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(RobustAutomaticThresholdCalculator);
 
-  bool           m_Valid;                      // Have moments been computed
-                                               // yet?
+  bool           m_Valid; // Have moments been computed yet?
   double         m_Pow;
   InputPixelType m_Output;
 
   InputImageConstPointer    m_Input;
   GradientImageConstPointer m_Gradient;
-};  // class RobustAutomaticThresholdCalculator
+};
 } // end namespace itk
 
 #ifndef ITK_MANUAL_INSTANTIATION
 #include "itkRobustAutomaticThresholdCalculator.hxx"
 #endif
 
-#endif /* itkRobustAutomaticThresholdCalculator_h */
+#endif
