@@ -52,7 +52,7 @@ namespace itk
 template< typename TInputImage, typename TMaskImage = Image< unsigned char,
                                                        TInputImage::ImageDimension >,
           class TOutputImage = TInputImage >
-class StochasticFractalDimensionImageFilter:
+class ITK_TEMPLATE_EXPORT StochasticFractalDimensionImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -102,8 +102,7 @@ protected:
   void GenerateData() ITK_OVERRIDE;
 
 private:
-  StochasticFractalDimensionImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(StochasticFractalDimensionImageFilter);
 
   RadiusType m_NeighborhoodRadius;
 
