@@ -50,7 +50,7 @@ public:
   itkNewMacro( Self );
 
 protected:
-  CommandProgressUpdate() {}; // purposely not implemented
+  CommandProgressUpdate() {};
 
   typedef const ReconstructionFilterType * ReconstructionFilterPointer;
 
@@ -61,7 +61,7 @@ protected:
 
   virtual void Execute( const itk::Object * caller, const itk::EventObject & event ) ITK_OVERRIDE
     {
-    ReconstructionFilterPointer reconstructor = dynamic_cast< ReconstructionFilterPointer >( caller );
+    ReconstructionFilterPointer reconstructor = static_cast< ReconstructionFilterPointer >( caller );
 
     if ( ! itk::ProgressEvent().CheckEvent( &event ) )
       {
