@@ -132,7 +132,7 @@ int itkNeuralNetworkIOTest(int argc,char* argv[])
     tv = iter2.GetMeasurementVector();
     ov.SetVnlVector(network->GenerateOutput(mv));
     flag = 0;
-    if( vnl_math_abs(tv[0]-ov[0])>0.5 && !((tv[0]*ov[0])>0) )
+    if( itk::Math::abs(tv[0]-ov[0])>0.5 && !((tv[0]*ov[0])>0) )
       {
       flag = 1;
       }
