@@ -41,7 +41,7 @@ namespace itk
  */
 
 template< typename TInputImage, typename TEigenValueImage, typename TEigenVectorImage >
-class EigenAnalysis2DImageFilter:
+class ITK_TEMPLATE_EXPORT EigenAnalysis2DImageFilter:
   public ImageToImageFilter< TInputImage, TEigenValueImage >
 {
 public:
@@ -121,8 +121,7 @@ protected:
   void GenerateData(void) ITK_OVERRIDE;
 
 private:
-  EigenAnalysis2DImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(EigenAnalysis2DImageFilter);
 };
 } // end namespace itk
 
