@@ -16,11 +16,12 @@
  *
  *=========================================================================*/
 
-#ifndef __itkFEMElement2DC0LinearQuadrilateralMembrane_h
-#define __itkFEMElement2DC0LinearQuadrilateralMembrane_h
+#ifndef itkFEMElement2DC0LinearQuadrilateralMembrane_h
+#define itkFEMElement2DC0LinearQuadrilateralMembrane_h
 
 #include "itkFEMElement2DC0LinearQuadrilateral.h"
 #include "itkFEMElement2DMembrane.h"
+#include "ITKFEMExport.h"
 
 namespace itk
 {
@@ -54,7 +55,7 @@ namespace fem
  * \sa Element2DC0LinearQuadrilateralStrain
  *
  */
-class Element2DC0LinearQuadrilateralMembrane : public Element2DMembrane<Element2DC0LinearQuadrilateral>
+class ITKFEM_EXPORT Element2DC0LinearQuadrilateralMembrane : public Element2DMembrane<Element2DC0LinearQuadrilateral>
 {
 public:
   /** Standard class typedefs. */
@@ -96,4 +97,4 @@ protected:
 }
 }  // end namespace itk::fem
 
-#endif  // #ifndef __itkFEMElement2DC0LinearQuadrilateralMembrane_h
+#endif  // #ifndef itkFEMElement2DC0LinearQuadrilateralMembrane_h
