@@ -16,11 +16,12 @@
  *
  *=========================================================================*/
 
-#ifndef __itkFEMElement2DC0LinearTriangularStrain_h
-#define __itkFEMElement2DC0LinearTriangularStrain_h
+#ifndef itkFEMElement2DC0LinearTriangularStrain_h
+#define itkFEMElement2DC0LinearTriangularStrain_h
 
 #include "itkFEMElement2DC0LinearTriangular.h"
 #include "itkFEMElement2DStrain.h"
+#include "ITKFEMExport.h"
 
 namespace itk
 {
@@ -56,7 +57,7 @@ namespace fem
  * \sa Element2DC0LinearTriangularMembrane
  * \sa Element2DC0LinearTriangularStress
  */
-class Element2DC0LinearTriangularStrain : public Element2DStrain<Element2DC0LinearTriangular>
+class ITKFEM_EXPORT Element2DC0LinearTriangularStrain : public Element2DStrain<Element2DC0LinearTriangular>
 {
 public:
   /** Standard class typedefs. */
@@ -94,4 +95,4 @@ protected:
 }
 }  // end namespace itk::fem
 
-#endif  // #ifndef __itkFEMElement2DC0LinearTriangularStrain_h
+#endif  // #ifndef itkFEMElement2DC0LinearTriangularStrain_h
