@@ -16,10 +16,11 @@
  *
  *=========================================================================*/
 
-#ifndef __itkFEMElement2DC0QuadraticTriangular_h
-#define __itkFEMElement2DC0QuadraticTriangular_h
+#ifndef itkFEMElement2DC0QuadraticTriangular_h
+#define itkFEMElement2DC0QuadraticTriangular_h
 
 #include "itkFEMElementStd.h"
+#include "ITKFEMExport.h"
 
 namespace itk
 {
@@ -54,7 +55,7 @@ namespace fem
  * \sa Element2DC0QuadraticTriangularStrain
  * \sa Element2DC0QuadraticTriangularStress
  */
-class Element2DC0QuadraticTriangular : public ElementStd<6, 2>
+class ITKFEM_EXPORT Element2DC0QuadraticTriangular : public ElementStd<6, 2>
 {
 public:
   /** Standard class typedefs. */
@@ -110,4 +111,4 @@ protected:
 }
 }  // end namespace itk::fem
 
-#endif  // #ifndef __itkFEMElement2DC0QuadraticTriangular_h
+#endif  // #ifndef itkFEMElement2DC0QuadraticTriangular_h
