@@ -16,10 +16,11 @@
  *
  *=========================================================================*/
 
-#ifndef __itkFEMElement3DC0LinearHexahedron_h
-#define __itkFEMElement3DC0LinearHexahedron_h
+#ifndef itkFEMElement3DC0LinearHexahedron_h
+#define itkFEMElement3DC0LinearHexahedron_h
 
 #include "itkFEMElementStd.h"
+#include "ITKFEMExport.h"
 
 namespace itk
 {
@@ -60,7 +61,7 @@ namespace fem
  *
  * \ingroup ITKFEM
  */
-class Element3DC0LinearHexahedron : public ElementStd<8, 3>
+class ITKFEM_EXPORT Element3DC0LinearHexahedron : public ElementStd<8, 3>
 {
 public:
   /** Standard class typedefs. */
@@ -114,4 +115,4 @@ protected:
 }
 }  // end namespace itk::fem
 
-#endif  // #ifndef __itkFEMElement3DC0LinearHexahedron_h
+#endif  // #ifndef itkFEMElement3DC0LinearHexahedron_h
