@@ -44,7 +44,7 @@ public:
   typedef LinearSystemWrapper::Float Float;
 
   /* superclass */
-  typedef LinearSystemWrapper SuperClass;
+  typedef LinearSystemWrapper Superclass;
 
   /* matrix typedef */
   typedef vnl_matrix<Float> MatrixRepresentation;
