@@ -16,10 +16,11 @@
  *
  *=========================================================================*/
 
-#ifndef __itkFEMLoadElementBase_h
-#define __itkFEMLoadElementBase_h
+#ifndef itkFEMLoadElementBase_h
+#define itkFEMLoadElementBase_h
 
 #include "itkFEMLoadBase.h"
+#include "ITKFEMExport.h"
 
 namespace itk
 {
@@ -41,7 +42,7 @@ namespace fem
  * load class, which it can handle and return the element's force vector.
  * \ingroup ITKFEM
  */
-class LoadElement : public Load
+class ITKFEM_EXPORT LoadElement : public Load
 {
 public:
   /** Standard class typedefs. */
@@ -85,7 +86,7 @@ public:
 
   Element::ConstPointer GetElement(int i);
 
-  unsigned int GetNumberOfElements(void);
+  unsigned int GetNumberOfElements();
 
   ElementPointersVectorType & GetElementArray()
     {
@@ -110,4 +111,4 @@ protected:
 }
 }  // end namespace itk::fem
 
-#endif // #ifndef __itkFEMLoadElementBase_h
+#endif // #ifndef itkFEMLoadElementBase_h
