@@ -72,7 +72,7 @@ namespace fem
  */
 
 template <unsigned int VDimension = 3>
-class  FEMObject : public DataObject
+class ITK_TEMPLATE_EXPORT  FEMObject : public DataObject
 {
 public:
   /** Standard class typedefs. */
@@ -335,8 +335,7 @@ protected:
   MaterialContainerPointer m_MaterialContainer;
 
 private:
-  FEMObject(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(FEMObject);
 
   void AddNextLoadInternal(Load *l);
 };  // End Class: FEMObject
