@@ -80,7 +80,7 @@ namespace fem
  */
 
 template <unsigned int VDimension = 3>
-class RobustSolver : public Solver<VDimension>
+class ITK_TEMPLATE_EXPORT RobustSolver : public Solver<VDimension>
 {
 public:
   /** Standard class typedefs. */
@@ -302,8 +302,7 @@ protected:
 
 private:
 
-  RobustSolver(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(RobustSolver);
 
   /**
    * The number of outlier rejection.
