@@ -68,7 +68,7 @@ namespace fem
  */
 
 template <unsigned int TDimension = 3>
-class SolverCrankNicolson : public Solver<TDimension>
+class ITK_TEMPLATE_EXPORT SolverCrankNicolson : public Solver<TDimension>
 {
 public:
   typedef SolverCrankNicolson      Self;
@@ -251,8 +251,7 @@ protected:
   unsigned int m_DiffMatrixBySolutionTMinus1Index;
 
 private:
-  SolverCrankNicolson(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(SolverCrankNicolson);
 
 };
 }
