@@ -47,8 +47,7 @@ public:
   itkNewMacro(Self);
 
 protected:
-  FEMSpatialObjectReader(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(FEMSpatialObjectReader);
 
   std::string m_FileName;
 
