@@ -40,7 +40,7 @@ namespace fem
  */
 
 template <typename TInputImage>
-class ImageToRectilinearFEMObjectFilter : public ProcessObject
+class ITK_TEMPLATE_EXPORT ImageToRectilinearFEMObjectFilter : public ProcessObject
 {
 public:
   /** Standard class typedefs. */
@@ -154,8 +154,7 @@ protected:
   void Generate3DRectilinearMesh();
 
 private:
-  ImageToRectilinearFEMObjectFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ImageToRectilinearFEMObjectFilter);
 
   vnl_vector<unsigned int> m_NumberOfElements;
   vnl_vector<unsigned int> m_PixelsPerElement;
