@@ -41,7 +41,7 @@ namespace itk
  */
 
 template< unsigned int NDimensions = 3 >
-class MetaFEMObjectConverter :
+class ITK_TEMPLATE_EXPORT MetaFEMObjectConverter :
     public MetaConverterBase< NDimensions >
 {
 public:
@@ -81,8 +81,7 @@ protected:
   ~MetaFEMObjectConverter() {}
 
 private:
-  MetaFEMObjectConverter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(MetaFEMObjectConverter);
 
 };
 } // end namespace itk
