@@ -15,8 +15,18 @@
  *  limitations under the License.
  *
  *=========================================================================*/
+
+#include "itkFEMElement2DC0LinearQuadrilateralMembrane.h"
 #include "itkFEMElementBase.h"
+#include "itkFEMLinearSystemWrapperDenseVNL.h"
+#include "itkFEMLinearSystemWrapperItpack.h"
+#include "itkFEMLinearSystemWrapperVNL.h"
+#include "itkFEMLoadNode.h"
+#include "itkFEMLoadPoint.h"
 #include "itkFEMObject.h"
+#include "itkFEMSolver.h"
+#include "itkTestingMacros.h"
+
 
 #include <iostream>
 using std::ofstream;
@@ -25,6 +35,7 @@ using std::ifstream;
 //
 int itkFEMLoadPointTestUser(int, char *[])
 {
+
   //Need to register default FEM object types,
   //and setup SpatialReader to recognize FEM types
   //which is all currently done as a HACK in
@@ -34,9 +45,13 @@ int itkFEMLoadPointTestUser(int, char *[])
   typedef itk::fem::FEMObject<2> FEMObjectType;
   FEMObjectType::Pointer femObject = FEMObjectType::New();
 
-  itk::fem::Node::Pointer n1;
+  typedef itk::fem::Solver<2> Solver2DType;
+  Solver2DType::Pointer solver = Solver2DType::New();
 
-  n1 = itk::fem::Node::New();
+
+  itk::fem::Element::Node::Pointer n1;
+
+  n1 = itk::fem::Element::Node::New();
   itk::fem::Element::VectorType pt(2);
 
   pt[0] = 0.;
@@ -46,21 +61,21 @@ int itkFEMLoadPointTestUser(int, char *[])
 
   femObject->AddNextNode(n1);
 
-  n1 = itk::fem::Node::New();
+  n1 = itk::fem::Element::Node::New();
   pt[0] = 1.;
   pt[1] = 1.;
   n1->SetGlobalNumber(1);
   n1->SetCoordinates(pt);
   femObject->AddNextNode(n1);
 
-  n1 = itk::fem::Node::New();
+  n1 = itk::fem::Element::Node::New();
   pt[0] = 3.;
   pt[1] = 2.;
   n1->SetGlobalNumber(2);
   n1->SetCoordinates(pt);
   femObject->AddNextNode(n1);
 
-  n1 = itk::fem::Node::New();
+  n1 = itk::fem::Element::Node::New();
   pt[0] = 0.;
   pt[1] = 3.;
   n1->SetGlobalNumber(3);
@@ -69,7 +84,6 @@ int itkFEMLoadPointTestUser(int, char *[])
 
   femObject->RenumberNodeContainer();
 
-  // std::cout << "Nodes\n";
 
   itk::fem::MaterialLinearElasticity::Pointer m;
   m = itk::fem::MaterialLinearElasticity::New();
@@ -79,7 +93,6 @@ int itkFEMLoadPointTestUser(int, char *[])
   m->SetMomentOfInertia(0.004);
   femObject->AddNextMaterial(m);
 
-  // std::cout << "Material\n";
 
   itk::fem::Element2DC0LinearQuadrilateralMembrane::Pointer e0 =
     itk::fem::Element2DC0LinearQuadrilateralMembrane::New();
@@ -89,11 +102,10 @@ int itkFEMLoadPointTestUser(int, char *[])
   e0->SetNode( 1, femObject->GetNode(1) );
   e0->SetNode( 2, femObject->GetNode(2) );
   e0->SetNode( 3, femObject->GetNode(3) );
-  e0->SetMaterial( femObject->GetMaterial(0) );
+  e0->SetMaterial( femObject->GetMaterial(0).GetPointer() );
 
-  femObject->AddNextElement( e0);
+  femObject->AddNextElement(e0.GetPointer());
 
-  // std::cout << "Element\n";
 
   itk::fem::LoadBC::Pointer l1 = itk::fem::LoadBC::New();
   l1->SetElement(e0);
@@ -102,25 +114,68 @@ int itkFEMLoadPointTestUser(int, char *[])
   l1->SetValue( vnl_vector<double>(1, 0.0) );
   femObject->AddNextLoad( l1 );
 
-  // std::cout << "BC\n";
+
   itk::fem::LoadPoint::Pointer lm0 = itk::fem::LoadPoint::New();
+
+  EXERCISE_BASIC_OBJECT_METHODS( lm0, LoadPoint, LoadElement );
+
   lm0->SetGlobalNumber(1);
   vnl_vector<double> pt1(2);
-  pt1[0] = 0.5; pt1[1] = 0.5;
+  pt1[0] = 0.5;
+  pt1[1] = 0.5;
   // it is assumed that source is same as the point.
   lm0->SetPoint( pt1 );
-  pt1[0] = 0.0; pt1[1] = 1.0;
+  TEST_SET_GET_VALUE( pt1, lm0->GetPoint() );
+
+  pt1[0] = 0.0;
+  pt1[1] = 1.0;
   lm0->SetForce( pt1 );
-  lm0->AddNextElement(e0);
-  femObject->AddNextLoad( lm0 );
+  TEST_SET_GET_VALUE( pt1, lm0->GetForce() );
 
-  femObject->Solve();
+  femObject->AddNextLoad(lm0.GetPointer());
 
-  int               numDOF = femObject->GetNumberOfDegreesOfFreedom();
-  vnl_vector<float> soln(numDOF);
-  for( int i = 0; i < numDOF; i++ )
+  femObject->FinalizeMesh();
+
+  solver->SetInput(femObject);
+
+  itk::fem::LinearSystemWrapperDenseVNL lsw_dvnl;
+  itk::fem::LinearSystemWrapperItpack   lsw_itpack;
+  itk::fem::LinearSystemWrapperVNL      lsw_vnl;
+
+  // Solvers being tested
+  int numsolvers = 3;
+
+  for( int s = 0; s < numsolvers; s++ )
     {
-    soln[i] = femObject->GetSolution(i);
+    if( s == 2 )
+      {
+      // Itpack
+      std::cout << "Using LinearSystemWrapperItpack" << std::endl;
+      lsw_itpack.SetMaximumNonZeroValuesInMatrix(1000);
+      solver->SetLinearSystemWrapper(&lsw_itpack);
+      }
+    else if( s == 1 )
+      {
+      // Dense VNL
+      std::cout << "Using LinearSystemWrapperDenseVNL" << std::endl;
+      solver->SetLinearSystemWrapper(&lsw_dvnl);
+      }
+    else
+      {
+      // Sparse VNL - default
+      std::cout << "Using LinearSystemWrapperVNL" << std::endl;
+      solver->SetLinearSystemWrapper(&lsw_vnl);
+      }
+
+    solver->Update();
+
+    int numDOF = femObject->GetNumberOfDegreesOfFreedom();
+    vnl_vector<float> soln(numDOF);
+    for( int i = 0; i < numDOF; i++ )
+      {
+      soln[i] = solver->GetSolution(i);
+      }
+
     }
 
   std::cout << "Test PASSED!\n";
