@@ -154,8 +154,7 @@ protected:
   typedef Superclass::CostFunctionAdaptorType CostFunctionAdaptorType;
 
 private:
-  AmoebaOptimizer(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(AmoebaOptimizer);
 
   /**Check that the settings are valid. If not throw an exception.*/
   void ValidateSettings();
