@@ -33,7 +33,7 @@ namespace itk
  * \ingroup ITKOptimizers
  */
 template< typename TInternalComputationValueType >
-class CostFunctionTemplate:public Object
+class ITK_TEMPLATE_EXPORT CostFunctionTemplate:public Object
 {
 public:
   /** Standard class typedefs. */
@@ -61,8 +61,7 @@ protected:
   virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  CostFunctionTemplate(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(CostFunctionTemplate);
 };
 
 /** This helps to meet backward compatibility */
