@@ -136,8 +136,7 @@ protected:
   double m_LearningRate;
 
 private:
-  GradientDescentOptimizer(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GradientDescentOptimizer);
 
   bool               m_Stop;
   double             m_Value;
