@@ -120,8 +120,7 @@ protected:
   virtual void UpdateSwarm() ITK_OVERRIDE;
 
 private:
-  InitializationBiasedParticleSwarmOptimizer(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(InitializationBiasedParticleSwarmOptimizer);
 
   ParametersType::ValueType                    m_InertiaCoefficient;
   ParametersType::ValueType                    m_PersonalCoefficient;
