@@ -32,7 +32,7 @@ namespace itk
  * vnl_lbfgsb into iteration events in ITK.
  * \ingroup ITKOptimizers
  */
-class ITKOptimizers_EXPORT LBFGSBOptimizerHelper;
+class ITK_FORWARD_EXPORT LBFGSBOptimizerHelper;
 
 /** \class LBFGSBOptimizer
  * \brief Limited memory Broyden Fletcher Goldfarb Shannon minimization with simple bounds.
@@ -186,8 +186,7 @@ protected:
   typedef Superclass::CostFunctionAdaptorType CostFunctionAdaptorType;
 
 private:
-  LBFGSBOptimizer(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(LBFGSBOptimizer);
 
   // give the helper access to member variables, to update iteration
   // counts, etc.
