@@ -25,7 +25,59 @@
 namespace itk
 {
 /** \class LBFGSOptimizer
- * \brief Wrap of the vnl_lbfgs algorithm
+ * \brief Wrap of the vnl_lbfgs algorithm for use in ITKv4 registration framework.
+ * The vnl_lbfgs is a wrapper for the NETLIB fortran code by Nocedal [1].
+ *
+ * LBFGS is a quasi-Newton method. Quasi-Newton methods use an approximate estimate
+ * of the inverse Hessian \f$ (\nabla^2 f(x) )^{-1} \f$ to scale the gradient step:
+ * \f[
+ * x_{n+1} = x_n - s (\nabla^2 f(x_n) )^-{1} \nabla f(x)
+ * \f]
+ * with \f$ s \f$ the step size.
+ *
+ * The inverse Hessian is approximated from the gradients of previous iteration and
+ * thus only the gradient of the objective function is required.
+ *
+ * The step size \f$ s \f$ is determined through line search with the approach
+ * by More and Thuente [4]. This line search approach finds a step size such that
+ * \f[
+ * \lVert \nabla f(x + s (\nabla^2 f(x_n) )^{-1} \nabla f(x) ) \rVert
+ *   \le
+ * \nu \lVert \nabla f(x) \rVert
+ * \f]
+ * The parameter \f$ \nu \f$ is set through SetLineSearchAccuracy() (default 0.9)
+ * The default step length, i.e. starting step length for the line search,
+ * is set through SetDefaultStepLength() (default 1.0).
+ *
+ * The optimization stops when either the gradient satisfies the condition
+ * \f[
+ * \lVert \nabla f(x) \rVert \le \epsilon \max(1, \lVert X \rVert)
+ * \f]
+ * or a maximum number of function evaluations has been reached.
+ * The tolerance \f$\epsilon\f$ is set through SetGradientConvergenceTolerance()
+ * (default 1e-5) and the maximum number of function evaluations is set
+ * through SetMaximumNumberOfFunctionEvaluations() (default 2000).
+ *
+ * Note: The scales set through SetScales should be set or left at one.
+ * Otherwise the Hessian approximation will be disturbed and the
+ * optimizer is unlikely to find a minima.
+ *
+ *
+ * References:
+ *
+ * [1] [NETLIB lbfgs](http://users.iems.northwestern.edu/~nocedal/lbfgs.html)
+ *
+ * [2] Jorge Nocedal.
+ * Updating Quasi-Newton Matrices with Limited Storage.
+ * Mathematics of Computation, Vol. 35, No. 151, pp. 773–782, 1980.
+ *
+ * [3] Dong C. Liu and Jorge Nocedal.
+ * On the limited memory BFGS method for large scale optimization.
+ * Mathematical Programming B, Vol. 45, No. 3, pp. 503-528, 1989.
+ *
+ * [4] More, J. J. and D. J. Thuente.
+ * Line Search Algorithms with Guaranteed Sufficient Decrease.
+ * ACM Transactions on Mathematical Software 20, no. 3 (1994): 286–307.
  *
  * \ingroup Numerics Optimizers
  * \ingroup ITKOptimizers
@@ -115,8 +167,7 @@ protected:
   typedef Superclass::CostFunctionAdaptorType CostFunctionAdaptorType;
 
 private:
-  LBFGSOptimizer(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(LBFGSOptimizer);
 
   bool                       m_OptimizerInitialized;
   InternalOptimizerType *    m_VnlOptimizer;
