@@ -76,8 +76,7 @@ protected:
   CostFunctionPointer m_CostFunction;
 
 private:
-  MultipleValuedNonLinearOptimizer(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(MultipleValuedNonLinearOptimizer);
 };
 } // end namespace itk
 
