@@ -57,8 +57,7 @@ protected:
   virtual ~NonLinearOptimizer();
 
 private:
-  NonLinearOptimizer(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(NonLinearOptimizer);
 };
 } // end namespace itk
 
