@@ -99,8 +99,7 @@ protected:
   virtual void UpdateSwarm() ITK_OVERRIDE;
 
 private:
-  ParticleSwarmOptimizer(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ParticleSwarmOptimizer);
 
   ParametersType::ValueType                    m_InertiaCoefficient;
   ParametersType::ValueType                    m_PersonalCoefficient;
