@@ -128,8 +128,7 @@ protected:
   }
 
 private:
-  RegularStepGradientDescentBaseOptimizer(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(RegularStepGradientDescentBaseOptimizer);
 
 protected:
   DerivativeType m_Gradient;
