@@ -77,8 +77,7 @@ protected:
   virtual ~SingleValuedCostFunction();
 
 private:
-  SingleValuedCostFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(SingleValuedCostFunction);
 };
 } // end namespace itk
 
