@@ -82,8 +82,7 @@ protected:
   CostFunctionPointer m_CostFunction;
 
 private:
-  SingleValuedNonLinearOptimizer(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(SingleValuedNonLinearOptimizer);
 };
 } // end namespace itk
 
