@@ -111,8 +111,7 @@ private:
   /** Callback function for the Command Observer */
   void IterationReport(const EventObject & event);
 
-  SingleValuedNonLinearVnlOptimizer(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(SingleValuedNonLinearVnlOptimizer);
 
   CostFunctionAdaptorType *m_CostFunctionAdaptor;
 
