@@ -29,7 +29,7 @@ LevenbergMarquardtOptimizer
 ::LevenbergMarquardtOptimizer()
 {
   m_OptimizerInitialized    = false;
-  m_VnlOptimizer            = 0;
+  m_VnlOptimizer            = ITK_NULLPTR;
   m_NumberOfIterations      = 2000;
   m_ValueTolerance          = 1e-8;
   m_GradientTolerance       = 1e-5;
