@@ -17,7 +17,7 @@
  *=========================================================================*/
 
 #include "itkRegularStepGradientDescentOptimizer.h"
-#include "vnl/vnl_math.h"
+#include "itkMath.h"
 
 /**
  *  The objectif function is the quadratic form:
@@ -171,7 +171,7 @@ int itkRegularStepGradientDescentOptimizerTest(int, char* [] )
   double trueParameters[2] = { 2, -2 };
   for( unsigned int j = 0; j < 2; j++ )
     {
-    if( vnl_math_abs( finalPosition[j] - trueParameters[j] ) > 0.01 )
+    if( itk::Math::abs( finalPosition[j] - trueParameters[j] ) > 0.01 )
       {
       pass = false;
       }
@@ -214,7 +214,7 @@ int itkRegularStepGradientDescentOptimizerTest(int, char* [] )
   pass = true;
   for( unsigned int j = 0; j < 2; j++ )
     {
-    if( vnl_math_abs( finalPosition[j] - trueParameters[j] ) > 0.01 )
+    if( itk::Math::abs( finalPosition[j] - trueParameters[j] ) > 0.01 )
       {
       pass = false;
       }
