@@ -44,7 +44,7 @@ namespace itk
    * \ingroup ITKOptimizersv4
    */
 template<typename TInternalComputationValueType>
-class ConjugateGradientLineSearchOptimizerv4Template
+class ITK_TEMPLATE_EXPORT ConjugateGradientLineSearchOptimizerv4Template
 : public GradientDescentLineSearchOptimizerv4Template<TInternalComputationValueType>
 {
 public:
@@ -93,8 +93,7 @@ private:
   DerivativeType               m_LastGradient;
   DerivativeType               m_ConjugateGradient;
 
-  ConjugateGradientLineSearchOptimizerv4Template( const Self & ) ITK_DELETE_FUNCTION;
-  void operator=( const Self& ) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ConjugateGradientLineSearchOptimizerv4Template);
 
 };
 
