@@ -116,8 +116,7 @@ protected:
   EnergyValueContainerType          m_EnergyValues;
 
 private:
-  ConvergenceMonitoringFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ConvergenceMonitoringFunction);
 
 };
 } // end namespace function
