@@ -75,7 +75,7 @@ namespace itk
  * \ingroup ITKOptimizersv4
  */
 template<typename TInternalComputationValueType>
-class ExhaustiveOptimizerv4:
+class ITK_TEMPLATE_EXPORT ExhaustiveOptimizerv4:
   public ObjectToObjectOptimizerBaseTemplate<TInternalComputationValueType>
 {
 public:
@@ -160,8 +160,7 @@ protected:
   ParametersType  m_MaximumMetricValuePosition;
 
 private:
-  ExhaustiveOptimizerv4(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ExhaustiveOptimizerv4);
 
   std::ostringstream m_StopConditionDescription;
 };
