@@ -56,7 +56,7 @@ namespace itk
  * \ingroup ITKOptimizersv4
  */
 template<typename TInternalComputationValueType>
-class GradientDescentLineSearchOptimizerv4Template
+class ITK_TEMPLATE_EXPORT GradientDescentLineSearchOptimizerv4Template
 : public GradientDescentOptimizerv4Template<TInternalComputationValueType>
 {
 public:
@@ -134,8 +134,7 @@ protected:
   unsigned int      m_LineSearchIterations;
 
 private:
-  GradientDescentLineSearchOptimizerv4Template( const Self & ) ITK_DELETE_FUNCTION;
-  void operator=( const Self& ) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GradientDescentLineSearchOptimizerv4Template);
 
 };
 
