@@ -33,7 +33,8 @@ namespace itk
  *
  * \ingroup ITKOptimizersv4
  */
-class ITKOptimizersv4_EXPORT LBFGSBOptimizerHelperv4;
+// Forward reference because of private implementation
+class ITK_FORWARD_EXPORT LBFGSBOptimizerHelperv4;
 
 /** \class LBFGSBOptimizerv4
  * \brief Limited memory Broyden Fletcher Goldfarb Shannon minimization with simple bounds.
@@ -168,8 +169,7 @@ protected:
   friend class LBFGSBOptimizerHelperv4;
 
 private:
-  LBFGSBOptimizerv4(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(LBFGSBOptimizerv4);
 
   unsigned int m_MaximumNumberOfCorrections;
 
