@@ -35,8 +35,9 @@ namespace itk
  *
  * \ingroup ITKOptimizersv4
  */
+// Forward reference because of circular dependencies
 template< typename TInternalVnlOptimizerType >
-class  LBFGSOptimizerBaseHelperv4;
+class  ITK_TEMPLATE_EXPORT LBFGSOptimizerBaseHelperv4;
 
 /** \class LBFGSOptimizerBasev4
  * \brief Abstract base for vnl lbfgs algorithm optimizers in ITKv4 registration framework.
@@ -70,7 +71,7 @@ class  LBFGSOptimizerBaseHelperv4;
  * \ingroup ITKOptimizersv4
  */
 template< typename TInternalVnlOptimizerType >
-class  LBFGSOptimizerBasev4:
+class ITK_TEMPLATE_EXPORT  LBFGSOptimizerBasev4:
     public SingleValuedNonLinearVnlOptimizerv4
 {
 public:
@@ -156,8 +157,7 @@ protected:
   friend class LBFGSBOptimizerHelperv4;
 
 private:
-  LBFGSOptimizerBasev4(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(LBFGSOptimizerBasev4);
 
 };
 } // end namespace itk
