@@ -43,7 +43,7 @@ namespace itk
    * \ingroup ITKOptimizersv4
    */
 template<typename TInternalComputationValueType>
-class MultiGradientOptimizerv4Template
+class ITK_TEMPLATE_EXPORT MultiGradientOptimizerv4Template
 : public GradientDescentOptimizerv4Template<TInternalComputationValueType>
 {
 public:
@@ -136,8 +136,7 @@ public:
   MeasureType                   m_MaximumMetricValue;
 
   private:
-  MultiGradientOptimizerv4Template( const Self & ) ITK_DELETE_FUNCTION;
-  void operator=( const Self& ) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(MultiGradientOptimizerv4Template);
 
 };
 
