@@ -86,7 +86,7 @@ namespace itk
  */
 template<unsigned int TFixedDimension, unsigned int TMovingDimension, typename TVirtualImage = Image<double, TFixedDimension>,
          typename TParametersValueType=double>
-class ObjectToObjectMetric:
+class ITK_TEMPLATE_EXPORT ObjectToObjectMetric:
   public ObjectToObjectMetricBaseTemplate<TParametersValueType>
 {
 public:
@@ -339,8 +339,7 @@ protected:
   mutable SizeValueType                   m_NumberOfValidPoints;
 
 private:
-  ObjectToObjectMetric(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ObjectToObjectMetric);
 
 };
 } // end namespace itk
