@@ -47,7 +47,7 @@ namespace itk
    * \ingroup ITKOptimizersv4
    */
 template<typename TInternalComputationValueType=double>
-class ObjectToObjectMetricBaseTemplate:
+class ITK_TEMPLATE_EXPORT ObjectToObjectMetricBaseTemplate:
   public SingleValuedCostFunctionv4Template<TInternalComputationValueType>
 {
 public:
@@ -201,8 +201,7 @@ protected:
   mutable MeasureType             m_Value;
 
 private:
-  ObjectToObjectMetricBaseTemplate(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ObjectToObjectMetricBaseTemplate);
 };
 
 /** This helps to meet backward compatibility */
