@@ -78,8 +78,7 @@ protected:
     }
 
 private:
-  OptimizerParameterScalesEstimatorTemplate(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(OptimizerParameterScalesEstimatorTemplate);
 
 }; //class OptimizerParameterScalesEstimatorTemplate
 
