@@ -56,7 +56,7 @@ namespace itk
  * \ingroup ITKOptimizersv4
  */
 template<typename TInternalComputationValueType>
-class QuasiNewtonOptimizerv4Template :
+class ITK_TEMPLATE_EXPORT QuasiNewtonOptimizerv4Template :
   public         GradientDescentOptimizerv4Template<TInternalComputationValueType>
 {
 public:
@@ -191,8 +191,7 @@ protected:
   virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  QuasiNewtonOptimizerv4Template(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(QuasiNewtonOptimizerv4Template);
 
   /** Threader for Newton step estimation. */
   typename DomainThreader<ThreadedIndexedContainerPartitioner, Self>::Pointer m_EstimateNewtonStepThreader;
