@@ -19,7 +19,7 @@
 #include "itkOnePlusOneEvolutionaryOptimizerv4.h"
 #include "itkNormalVariateGenerator.h"
 #include "itkCommand.h"
-#include "vnl/vnl_math.h"
+#include "itkMath.h"
 
 namespace itk
 {
@@ -244,7 +244,7 @@ int itkOnePlusOneEvolutionaryOptimizerv4Test(int, char* [] )
   double trueParameters[2] = { 2, -2 };
   for( unsigned int j = 0; j < 2; j++ )
     {
-    if( vnl_math_abs( finalPosition[j] - trueParameters[j] ) > 0.01 )
+    if( itk::Math::abs( finalPosition[j] - trueParameters[j] ) > 0.01 )
       {
       pass = false;
       }
