@@ -66,8 +66,7 @@ protected:
   ~OptimizerParameterScalesEstimatorTest(){};
 
 private:
-  OptimizerParameterScalesEstimatorTest(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(OptimizerParameterScalesEstimatorTest);
 
 };
 
