@@ -197,8 +197,7 @@ protected:
   ~RegistrationParameterScalesEstimatorTest(){};
 
 private:
-  RegistrationParameterScalesEstimatorTest(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(RegistrationParameterScalesEstimatorTest);
 
 };
 
