@@ -20,6 +20,7 @@
 
 #include "itkAffineTransform.h"
 #include "itkDisplacementFieldTransform.h"
+#include "itkMath.h"
 
 /**
  *  \class RegistrationParameterScalesFromIndexShiftTestMetric for test.
@@ -47,28 +48,28 @@ public:
   itkNewMacro(Self);
 
   // Pure virtual functions that all Metrics must provide
-  unsigned int GetNumberOfParameters() const { return 5; }
+  unsigned int GetNumberOfParameters() const ITK_OVERRIDE { return 5; }
 
-  MeasureType GetValue() const
+  MeasureType GetValue() const ITK_OVERRIDE
     {
     return 1.0;
     }
 
-  void GetValueAndDerivative( MeasureType & value, DerivativeType & derivative ) const
+  void GetValueAndDerivative( MeasureType & value, DerivativeType & derivative ) const ITK_OVERRIDE
     {
     value = 1.0;
     derivative.Fill(0.0);
     }
 
-  unsigned int GetNumberOfLocalParameters() const
+  unsigned int GetNumberOfLocalParameters() const ITK_OVERRIDE
   { return 0; }
 
-  void UpdateTransformParameters( const DerivativeType &, ParametersValueType ) {}
+  void UpdateTransformParameters( const DerivativeType &, ParametersValueType ) ITK_OVERRIDE {}
 
-  const ParametersType & GetParameters() const
+  const ParametersType & GetParameters() const ITK_OVERRIDE
   { return m_Parameters; }
 
-  void Initialize(void) throw ( itk::ExceptionObject ) {}
+  void Initialize(void) throw ( itk::ExceptionObject ) ITK_OVERRIDE {}
 
   ParametersType  m_Parameters;
 
@@ -197,7 +198,7 @@ int itkRegistrationParameterScalesFromIndexShiftTest(int , char* [])
   bool nonUniformForAffine = false;
   for (itk::SizeValueType p = 1; p < movingScales.GetSize(); p++)
     {
-    if (movingScales[p] != movingScales[0])
+    if (itk::Math::NotExactlyEquals(movingScales[p], movingScales[0]))
       {
       nonUniformForAffine = true;
       break;
@@ -353,7 +354,7 @@ int itkRegistrationParameterScalesFromIndexShiftTest(int , char* [])
   bool uniformForTranslation = true;
   for (itk::SizeValueType p = 1; p < fixedScales.GetSize(); p++)
     {
-    if (fixedScales[p] != fixedScales[0])
+    if (itk::Math::NotExactlyEquals(fixedScales[p], fixedScales[0]))
       {
       uniformForTranslation = false;
       break;
