@@ -15,13 +15,14 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __itkMultivariateLegendrePolynomial_h
-#define __itkMultivariateLegendrePolynomial_h
+#ifndef itkMultivariateLegendrePolynomial_h
+#define itkMultivariateLegendrePolynomial_h
 
 #include "itkIntTypes.h"
 #include "itkIndent.h"
 #include <vector>
 #include "itkArray.h"
+#include "ITKPolynomialsExport.h"
 
 namespace itk
 {
@@ -71,7 +72,7 @@ namespace itk
  * \ingroup ITKPolynomials
  */
 
-class MultivariateLegendrePolynomial
+class ITKPolynomials_EXPORT MultivariateLegendrePolynomial
 {
 public:
   typedef MultivariateLegendrePolynomial Self;
@@ -147,7 +148,7 @@ public:
   throw ( CoefficientVectorSizeMismatch );
 
   /** \brief Gets Legendre polynomials' coefficients. */
-  const CoefficientArrayType & GetCoefficients(void) const;
+  const CoefficientArrayType & GetCoefficients() const;
 
   /** In the case which the bias field is 2D, it returns bias value at
    * the point which is specified by the index */
@@ -300,7 +301,7 @@ private:
   IndexValueType  m_PrevZ;
 }; // end of class
 
- std::ostream & operator<<(std::ostream & os,
+ ITKPolynomials_EXPORT std::ostream & operator<<(std::ostream & os,
                           MultivariateLegendrePolynomial & poly);
 } // end of namespace itk
 #endif
