@@ -202,8 +202,7 @@ protected:
   virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  ChiSquareDistribution(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ChiSquareDistribution);
 };                                     // end of class
 } // end of namespace Statistics
 } // end namespace itk
