@@ -49,7 +49,7 @@ namespace Statistics
  */
 
 template< typename TSample >
-class CovarianceSampleFilter:
+class ITK_TEMPLATE_EXPORT CovarianceSampleFilter:
   public ProcessObject
 {
 public:
@@ -127,8 +127,7 @@ protected:
   virtual void GenerateData() ITK_OVERRIDE;
 
 private:
-  CovarianceSampleFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(CovarianceSampleFilter);
 
 };  // end of class
 } // end of namespace Statistics
