@@ -127,8 +127,7 @@ protected:
   virtual ~HistogramToEntropyImageFilter() {}
 
 private:
-  HistogramToEntropyImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(HistogramToEntropyImageFilter);
 };
 } // end namespace itk
 
