@@ -112,8 +112,7 @@ protected:
   virtual ~HistogramToProbabilityImageFilter() {}
 
 private:
-  HistogramToProbabilityImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(HistogramToProbabilityImageFilter);
 };
 } // end namespace itk
 
