@@ -63,7 +63,7 @@ namespace Statistics {
  */
 
 template< typename THistogram >
-class HistogramToRunLengthFeaturesFilter : public ProcessObject
+class ITK_TEMPLATE_EXPORT HistogramToRunLengthFeaturesFilter : public ProcessObject
 {
 public:
   /** Standard typedefs */
@@ -171,8 +171,7 @@ protected:
   virtual void GenerateData() ITK_OVERRIDE;
 
 private:
-  HistogramToRunLengthFeaturesFilter(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(HistogramToRunLengthFeaturesFilter);
 
   unsigned long                           m_TotalNumberOfRuns;
 
