@@ -50,7 +50,7 @@ namespace Statistics
  */
 
 template< typename TImage >
-class ImageToListSampleAdaptor:
+class ITK_TEMPLATE_EXPORT ImageToListSampleAdaptor:
   public ListSample< typename MeasurementVectorPixelTraits< typename TImage::PixelType >::MeasurementVectorType >
 {
 public:
@@ -199,9 +199,8 @@ public:
       m_InstanceIdentifier(iid)
     {}
 
-    ConstIterator() ITK_DELETE_FUNCTION;
-
   private:
+    ConstIterator() ITK_DELETED_FUNCTION;
     ImageConstIteratorType        m_Iter;
     mutable MeasurementVectorType m_MeasurementVectorCache;
     InstanceIdentifier            m_InstanceIdentifier;
@@ -233,19 +232,18 @@ public:
     }
 
   protected:
-    // To ensure const-correctness these method must not be in the public API.
-    // The are purposly not implemented, since they should never be called.
-    Iterator() ITK_DELETE_FUNCTION;
-    Iterator(const Self *adaptor) ITK_DELETE_FUNCTION;
-    Iterator(const ImageConstIteratorType & iter, InstanceIdentifier iid) ITK_DELETE_FUNCTION;
-    Iterator(const ConstIterator & it) ITK_DELETE_FUNCTION;
-    ConstIterator & operator=(const ConstIterator & it) ITK_DELETE_FUNCTION;
-
     Iterator(const ImageIteratorType & iter, InstanceIdentifier iid) :
       ConstIterator(iter, iid)
     {}
 
   private:
+    // To ensure const-correctness these method must not be in the public API.
+    // The are purposly not implemented, since they should never be called.
+    Iterator() ITK_DELETED_FUNCTION;
+    Iterator(const Self *adaptor) ITK_DELETED_FUNCTION;
+    Iterator(const ImageConstIteratorType & iter, InstanceIdentifier iid) ITK_DELETED_FUNCTION;
+    Iterator(const ConstIterator & it) ITK_DELETED_FUNCTION;
+    ConstIterator & operator=(const ConstIterator & it) ITK_DELETED_FUNCTION;
   };
 
   /** returns an iterator that points to the beginning of the container */
@@ -297,8 +295,7 @@ protected:
   void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  ImageToListSampleAdaptor(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ImageToListSampleAdaptor);
 
   ImageConstPointer             m_Image;
   mutable MeasurementVectorType m_MeasurementVectorInternal;
