@@ -52,7 +52,7 @@ namespace Statistics
  * \ingroup ITKStatistics
  */
 template< typename TImage, typename TMaskImage = TImage >
-class ImageToListSampleFilter:
+class ITK_TEMPLATE_EXPORT ImageToListSampleFilter:
   public ProcessObject
 {
 public:
@@ -132,8 +132,7 @@ protected:
   virtual void GenerateOutputInformation() ITK_OVERRIDE;
 
 private:
-  ImageToListSampleFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ImageToListSampleFilter);
 
   MaskPixelType m_MaskValue;
 };  // end of class ImageToListSampleFilter
