@@ -61,7 +61,7 @@ namespace Statistics
  */
 template<typename TSample>
 
-struct KdTreeNode
+struct ITK_TEMPLATE_EXPORT KdTreeNode
   {
   /** type alias for itself */
   typedef KdTreeNode<TSample> Self;
@@ -135,7 +135,7 @@ struct KdTreeNode
  */
 template<typename TSample>
 
-struct KdTreeNonterminalNode:public KdTreeNode<TSample>
+struct ITK_TEMPLATE_EXPORT KdTreeNonterminalNode:public KdTreeNode<TSample>
   {
   typedef KdTreeNode<TSample>                     Superclass;
   typedef typename Superclass::MeasurementType    MeasurementType;
@@ -242,7 +242,7 @@ private:
  * \ingroup ITKStatistics
  */
 template<typename TSample>
-struct KdTreeWeightedCentroidNonterminalNode:public KdTreeNode<TSample>
+struct ITK_TEMPLATE_EXPORT KdTreeWeightedCentroidNonterminalNode:public KdTreeNode<TSample>
   {
   typedef KdTreeNode<TSample>                         Superclass;
   typedef typename Superclass::MeasurementType        MeasurementType;
@@ -359,7 +359,7 @@ private:
  * \ingroup ITKStatistics
  */
 template<typename TSample>
-struct KdTreeTerminalNode:public KdTreeNode<TSample>
+struct ITK_TEMPLATE_EXPORT KdTreeTerminalNode:public KdTreeNode<TSample>
   {
   typedef KdTreeNode<TSample>                     Superclass;
   typedef typename Superclass::MeasurementType    MeasurementType;
@@ -480,7 +480,7 @@ private:
  */
 
 template<typename TSample>
-class KdTree:public Object
+class ITK_TEMPLATE_EXPORT KdTree:public Object
 {
 public:
   /** Standard class typedefs */
@@ -589,7 +589,7 @@ public:
     }
 
   private:
-    NearestNeighbors() ITK_DELETE_FUNCTION;
+    NearestNeighbors() ITK_DELETED_FUNCTION;
     /** The index of the farthest neighbor among k-neighbors */
     unsigned int m_FarthestNeighborIndex;
 
@@ -736,8 +736,7 @@ protected:
     InstanceIdentifierVectorType & ) const;
 
 private:
-  KdTree( const Self & ) ITK_DELETE_FUNCTION;
-  void operator=( const Self & ) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(KdTree);
 
   /** Pointer to the input sample */
   const TSample *m_Sample;
