@@ -67,7 +67,7 @@ namespace Statistics
  */
 
 template< typename TSample >
-class KdTreeGenerator:public Object
+class ITK_TEMPLATE_EXPORT KdTreeGenerator:public Object
 {
 public:
   /** Standard class typedefs */
@@ -164,8 +164,7 @@ protected:
                                     unsigned int level);
 
 private:
-  KdTreeGenerator(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(KdTreeGenerator);
 
   /** Pointer to the input (source) sample */
   TSample *m_SourceSample;
