@@ -48,7 +48,7 @@ namespace Statistics
  */
 
 template< typename TMeasurementVector >
-class ListSample:public Sample< TMeasurementVector >
+class ITK_TEMPLATE_EXPORT ListSample:public Sample< TMeasurementVector >
 {
 public:
   /** Standard class typedef. */
@@ -190,9 +190,8 @@ protected:
       m_InstanceIdentifier = iid;
     }
 
-    ConstIterator() ITK_DELETE_FUNCTION;
-
 private:
+    ConstIterator() ITK_DELETED_FUNCTION;
     typedef typename InternalDataContainerType::const_iterator InternalIterator;
     InternalIterator   m_Iter;
     InstanceIdentifier m_InstanceIdentifier;
@@ -221,13 +220,6 @@ public:
     }
 
 protected:
-    // To ensure const-correctness these method must not be in the public API.
-    // The are purposly not implemented, since they should never be called.
-    Iterator() ITK_DELETE_FUNCTION;
-    Iterator(const Self *sample) ITK_DELETE_FUNCTION;
-    Iterator(typename InternalDataContainerType::const_iterator iter, InstanceIdentifier iid) ITK_DELETE_FUNCTION;
-    Iterator(const ConstIterator & it) ITK_DELETE_FUNCTION;
-    ConstIterator & operator=(const ConstIterator & it) ITK_DELETE_FUNCTION;
 
     Iterator(
       typename InternalDataContainerType::iterator iter,
@@ -235,6 +227,13 @@ protected:
     {}
 
 private:
+    // To ensure const-correctness these method must not be in the public API.
+    // The are purposly not implemented, since they should never be called.
+    Iterator() ITK_DELETED_FUNCTION;
+    Iterator(const Self *sample) ITK_DELETED_FUNCTION;
+    Iterator(typename InternalDataContainerType::const_iterator iter, InstanceIdentifier iid) ITK_DELETED_FUNCTION;
+    Iterator(const ConstIterator & it) ITK_DELETED_FUNCTION;
+    ConstIterator & operator=(const ConstIterator & it) ITK_DELETED_FUNCTION;
   };
 
   /** returns an iterator that points to the beginning of the container */
@@ -276,8 +275,7 @@ protected:
   void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  ListSample(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ListSample);
 
   InternalDataContainerType m_InternalContainer;
 };
