@@ -39,7 +39,7 @@ namespace Statistics
  *
  * This class can be considered as a macro class that encapsulates the
  * storage for the weights, model (subclasses of MembershipFunctionBase),
- * and model parameter estimators (implemenation of analytical expressions).
+ * and model parameter estimators (implementation of analytical expressions).
  *
  * Subclasses of this class should define their own distribution specific
  * membership function. For example, GaussianMixtureModelComponent class
@@ -53,7 +53,7 @@ namespace Statistics
  */
 
 template< typename TSample >
-class MixtureModelComponentBase:
+class ITK_TEMPLATE_EXPORT MixtureModelComponentBase:
   public Object
 {
 public:
