@@ -41,7 +41,7 @@ namespace Statistics
  */
 
 template< typename TSample >
-class NeighborhoodSampler:public SampleToSubsampleFilter< TSample >
+class ITK_TEMPLATE_EXPORT NeighborhoodSampler:public SampleToSubsampleFilter< TSample >
 {
 public:
   /** Standard class typedefs. */
@@ -80,8 +80,7 @@ protected:
   void GenerateData() ITK_OVERRIDE;
 
 private:
-  NeighborhoodSampler(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(NeighborhoodSampler);
 };                                   // end of class
 } // end of namespace Statistics
 } // end of namespace itk
