@@ -43,7 +43,7 @@ namespace Statistics
  */
 
 template< typename TPointSet >
-class PointSetToListSampleAdaptor:
+class ITK_TEMPLATE_EXPORT PointSetToListSampleAdaptor:
   public ListSample< typename TPointSet::PointType >
 {
 public:
@@ -169,9 +169,8 @@ protected:
       m_InstanceIdentifier = iid;
     }
 
-    ConstIterator() ITK_DELETE_FUNCTION;
-
 private:
+    ConstIterator() ITK_DELETED_FUNCTION;
     PointsContainerConstIteratorType m_Iter;
     InstanceIdentifier               m_InstanceIdentifier;
   };
@@ -198,20 +197,20 @@ public:
     }
 
 protected:
-    // To ensure const-correctness these method must not be in the public API.
-    // The are not implemented, since they should never be called.
-    Iterator() ITK_DELETE_FUNCTION;
-    Iterator(const Self *adaptor) ITK_DELETE_FUNCTION;
-    Iterator(PointsContainerConstIteratorType iter, InstanceIdentifier iid) ITK_DELETE_FUNCTION;
-    Iterator(const ConstIterator & it) ITK_DELETE_FUNCTION;
-    ConstIterator & operator=(const ConstIterator & it) ITK_DELETE_FUNCTION;
-
     Iterator(
       PointsContainerIteratorType iter,
       InstanceIdentifier iid):ConstIterator(iter, iid)
     {}
 
 private:
+    // To ensure const-correctness these method must not be in the public API.
+    // The are not implemented, since they should never be called.
+    Iterator() ITK_DELETED_FUNCTION;
+    Iterator(const Self *adaptor) ITK_DELETED_FUNCTION;
+    Iterator(PointsContainerConstIteratorType iter, InstanceIdentifier iid) ITK_DELETED_FUNCTION;
+    Iterator(const ConstIterator & it) ITK_DELETED_FUNCTION;
+    ConstIterator & operator=(const ConstIterator & it) ITK_DELETED_FUNCTION;
+
   };
 
   /** returns an iterator that points to the beginning of the container */
@@ -258,8 +257,7 @@ protected:
   void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  PointSetToListSampleAdaptor(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(PointSetToListSampleAdaptor);
 
   /** the PointSet data source pointer */
   PointSetConstPointer m_PointSet;
