@@ -48,7 +48,7 @@ namespace Statistics {
  */
 
 template < typename TSample, typename TRegion >
-class RegionConstrainedSubsampler : public SubsamplerBase<TSample>
+class ITK_TEMPLATE_EXPORT RegionConstrainedSubsampler : public SubsamplerBase<TSample>
 {
 public:
   /** Standard class typedefs */
@@ -125,8 +125,7 @@ protected:
   bool       m_SampleRegionInitialized;
 
 private:
-  RegionConstrainedSubsampler(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(RegionConstrainedSubsampler);
 
 }; // end of class RegionConstrainedSubsampler
 
