@@ -186,8 +186,7 @@ protected:
   }
 
 private:
-  Sample(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(Sample);
 
   MeasurementVectorSizeType m_MeasurementVectorSize;
 };  // end of class
