@@ -41,7 +41,7 @@ namespace Statistics
  */
 
 template< typename TSample >
-class SampleClassifierFilter:
+class ITK_TEMPLATE_EXPORT SampleClassifierFilter:
   public ProcessObject
 {
 public:
@@ -130,8 +130,7 @@ protected:
   virtual ~SampleClassifierFilter() {}
   virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
-  SampleClassifierFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(SampleClassifierFilter);
 
   /** Starts the classification process */
   virtual void GenerateData() ITK_OVERRIDE;
