@@ -48,7 +48,7 @@ namespace Statistics
  */
 
 template< typename TImage >
-class ScalarImageToCooccurrenceListSampleFilter:
+class ITK_TEMPLATE_EXPORT ScalarImageToCooccurrenceListSampleFilter:
   public ProcessObject
 {
 public:
@@ -113,8 +113,7 @@ protected:
   virtual void GenerateData() ITK_OVERRIDE;
 
 private:
-  ScalarImageToCooccurrenceListSampleFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ScalarImageToCooccurrenceListSampleFilter);
 
   OffsetTable m_OffsetTable;
 };  // end of class ScalarImageToListSampleFilter
