@@ -92,7 +92,7 @@ namespace Statistics
 
 template< typename TImageType,
           typename THistogramFrequencyContainer = DenseFrequencyContainer2 >
-class ScalarImageToCooccurrenceMatrixFilter:public ProcessObject
+class ITK_TEMPLATE_EXPORT ScalarImageToCooccurrenceMatrixFilter:public ProcessObject
 {
 public:
   /** Standard typedefs */
@@ -190,8 +190,7 @@ protected:
   virtual void GenerateData() ITK_OVERRIDE;
 
 private:
-  ScalarImageToCooccurrenceMatrixFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ScalarImageToCooccurrenceMatrixFilter);
 
   void NormalizeHistogram();
 
