@@ -33,7 +33,7 @@ namespace Statistics
  * \ingroup ITKStatistics
  */
 template< typename TImageType >
-class ScalarImageToHistogramGenerator:public Object
+class ITK_TEMPLATE_EXPORT ScalarImageToHistogramGenerator:public Object
 {
 public:
   /** Standard typedefs */
@@ -108,8 +108,7 @@ private:
 
   GeneratorPointer m_HistogramGenerator;
 
-  ScalarImageToHistogramGenerator(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ScalarImageToHistogramGenerator);
 };
 } // end of namespace Statistics
 } // end of namespace itk
