@@ -103,7 +103,7 @@ namespace Statistics
 
 template< typename TImageType,
           typename THistogramFrequencyContainer = DenseFrequencyContainer2 >
-class ScalarImageToTextureFeaturesFilter:public ProcessObject
+class ITK_TEMPLATE_EXPORT ScalarImageToTextureFeaturesFilter:public ProcessObject
 {
 public:
   /** Standard typedefs */
