@@ -102,8 +102,7 @@ protected:
   virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  SparseFrequencyContainer2(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(SparseFrequencyContainer2);
 
   // Container of histogram
   FrequencyContainerType     m_FrequencyContainer;
