@@ -38,7 +38,7 @@ namespace Statistics
  * \ingroup ITKStatistics
  */
 template< typename TSample >
-class Subsample:
+class ITK_TEMPLATE_EXPORT Subsample:
   public TSample
 {
 public:
@@ -285,8 +285,7 @@ protected:
   void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  Subsample(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(Subsample);
 
   const TSample *            m_Sample;
   InstanceIdentifierHolder   m_IdHolder;
