@@ -43,7 +43,7 @@ namespace Statistics {
  */
 
 template < typename TSample >
-class SubsamplerBase : public Object
+class ITK_TEMPLATE_EXPORT SubsamplerBase : public Object
 {
 public:
   /** Standard class typedefs */
@@ -127,8 +127,7 @@ protected:
   SeedType           m_Seed;
 
 private:
-  SubsamplerBase(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(SubsamplerBase);
 
 }; // end of class SubsamplerBase
 
