@@ -39,7 +39,7 @@ namespace Statistics
  * \ingroup ITKStatistics
  */
 template< typename TSample >
-class WeightedMeanSampleFilter : public MeanSampleFilter< TSample >
+class ITK_TEMPLATE_EXPORT WeightedMeanSampleFilter : public MeanSampleFilter< TSample >
 {
 public:
   /**Standard class typedefs. */
@@ -105,8 +105,7 @@ protected:
   void ComputeMeanWithWeightingFunction();
 
 private:
-  WeightedMeanSampleFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(WeightedMeanSampleFilter);
 };                                        // end of class
 } // end of namespace Statistics
 } // end of namespace itk
