@@ -102,7 +102,7 @@ int itkCovarianceSampleFilterTest(int, char* [] )
 
   if ( covarianceFilter->GetInput() != ITK_NULLPTR )
     {
-    std::cerr << "GetInput() should return NULL if the input \
+    std::cerr << "GetInput() should return ITK_NULLPTR if the input \
                      has not been set" << std::endl;
     return EXIT_FAILURE;
     }
