@@ -43,7 +43,7 @@ public:
   itkNewMacro(Self);
 
   /** Evaluate membership score */
-  double Evaluate(const TMeasurementVector & ) const
+  double Evaluate(const TMeasurementVector & ) const ITK_OVERRIDE
     {
     double score;
     score = 1;
