@@ -52,8 +52,7 @@ protected:
     }
 
 private:
-  SubsamplerTester(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(SubsamplerTester);
 
 
 };
