@@ -86,8 +86,8 @@ int itkSpatialNeighborSubsamplerTest(int, char * [] )
   region.SetIndex(idx);
 
   inImage->SetRegions(region);
-  inImage->Allocate();
-  inImage->FillBuffer(0);
+  inImage->Allocate(true); // initialize buffer
+                                                  // to zero
 
   SizeType szConstraint;
   szConstraint[0] = 23;
