@@ -116,7 +116,7 @@ int itkWeightedCentroidKdTreeGeneratorTest8(int argc , char * argv [] )
       const double distance =
         distanceMetric->Evaluate( tree->GetMeasurementVector( neighbors[i] ));
 
-      if( distance > vnl_math::eps )
+      if( distance > itk::Math::eps )
         {
         std::cout << "kd-tree knn search result:" << std::endl
                   << "query point = [" << queryPoint << "]" << std::endl
@@ -186,7 +186,7 @@ int itkWeightedCentroidKdTreeGeneratorTest8(int argc , char * argv [] )
         }
       }
 
-    if( std::fabs( min_dist - result_dist ) > vnl_math::eps )
+    if( std::fabs( min_dist - result_dist ) > itk::Math::eps )
       {
       std::cerr << "Problem found " << std::endl;
       std::cerr << "Query point " << queryPoint << std::endl;
