@@ -123,7 +123,7 @@ int itkWeightedMeanSampleFilterTest(int, char* [] )
 
   if ( filter->GetInput() != ITK_NULLPTR )
     {
-    std::cerr << "GetInput() should return NULL if the input \
+    std::cerr << "GetInput() should return ITK_NULLPTR if the input \
                      has not been set" << std::endl;
     return EXIT_FAILURE;
     }
