@@ -62,7 +62,7 @@ namespace itk
  * \ingroup ITKRegistrationCommon
  */
 template<typename TTransform>
-class BSplineTransformParametersAdaptor
+class ITK_TEMPLATE_EXPORT BSplineTransformParametersAdaptor
 : public TransformParametersAdaptor<TTransform>
 {
 public:
@@ -140,8 +140,7 @@ protected:
   void PrintSelf( std::ostream & os, Indent indent ) const ITK_OVERRIDE;
 
 private:
-  BSplineTransformParametersAdaptor( const Self & ) ITK_DELETE_FUNCTION;
-  void operator=( const Self & ) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BSplineTransformParametersAdaptor);
 
   /** Helper function to set m_RequiredFixedParameters */
   void UpdateRequiredFixedParameters();
