@@ -60,7 +60,7 @@ namespace itk
 template< typename TTransform,
           typename TFixedImage,
           typename TMovingImage >
-class CenteredTransformInitializer:public Object
+class ITK_TEMPLATE_EXPORT CenteredTransformInitializer:public Object
 {
 public:
   /** Standard class typedefs. */
@@ -140,8 +140,7 @@ protected:
   itkGetModifiableObjectMacro(Transform, TransformType);
 
 private:
-  CenteredTransformInitializer(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(CenteredTransformInitializer);
 
   TransformPointer m_Transform;
 
