@@ -38,7 +38,7 @@ namespace itk
  */
 template< typename TFixedImage,
           typename TMovingImage >
-class CenteredVersorTransformInitializer:
+class ITK_TEMPLATE_EXPORT CenteredVersorTransformInitializer:
   public CenteredTransformInitializer<
     VersorRigid3DTransform< double >,
     TFixedImage, TMovingImage >
@@ -101,8 +101,7 @@ protected:
   void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  CenteredVersorTransformInitializer(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(CenteredVersorTransformInitializer);
 
   bool m_ComputeRotation;
 }; //class CenteredVersorTransformInitializer
