@@ -64,7 +64,7 @@ namespace itk
  * \ingroup ITKRegistrationCommon
  */
 template< typename TFixedImage, typename TMovingImage >
-class MatchCardinalityImageToImageMetric:
+class ITK_TEMPLATE_EXPORT MatchCardinalityImageToImageMetric:
   public ImageToImageMetric< TFixedImage, TMovingImage >
 {
 public:
@@ -167,8 +167,7 @@ protected:
   };
 
 private:
-  MatchCardinalityImageToImageMetric(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(MatchCardinalityImageToImageMetric);
 
   bool                         m_MeasureMatches;
   std::vector< MeasureType >   m_ThreadMatches;
