@@ -38,7 +38,7 @@ namespace itk
  * \ingroup ITKRegistrationCommon
  */
 template< typename TFixedPointSet, typename TMovingImage >
-class MeanSquaresPointSetToImageMetric:
+class ITK_TEMPLATE_EXPORT MeanSquaresPointSetToImageMetric:
   public PointSetToImageMetric< TFixedPointSet, TMovingImage >
 {
 public:
@@ -91,8 +91,7 @@ protected:
   virtual ~MeanSquaresPointSetToImageMetric() {}
 
 private:
-  MeanSquaresPointSetToImageMetric(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(MeanSquaresPointSetToImageMetric);
 };
 } // end namespace itk
 
