@@ -45,7 +45,7 @@ namespace itk
  */
 
 template< typename TFixedPointSet,  typename TMovingImage >
-class PointSetToImageMetric:public SingleValuedCostFunction
+class ITK_TEMPLATE_EXPORT PointSetToImageMetric:public SingleValuedCostFunction
 {
 public:
   /** Standard class typedefs. */
@@ -186,8 +186,7 @@ protected:
   GradientImagePointer m_GradientImage;
 
 private:
-  PointSetToImageMetric(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(PointSetToImageMetric);
 };
 } // end namespace itk
 
