@@ -42,7 +42,7 @@ namespace itk
  */
 
 template< typename TFixedPointSet,  typename TMovingPointSet >
-class PointSetToPointSetMetric:public MultipleValuedCostFunction
+class ITK_TEMPLATE_EXPORT PointSetToPointSetMetric:public MultipleValuedCostFunction
 {
 public:
 
@@ -137,8 +137,7 @@ protected:
   mutable TransformPointer m_Transform;
 
 private:
-  PointSetToPointSetMetric(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(PointSetToPointSetMetric);
 };
 } // end namespace itk
 
