@@ -41,7 +41,7 @@ namespace itk
 template<
   typename TPointsContainer = VectorContainer< IdentifierType, Point< float, 3 > >
   >
-class PointsLocator : public Object
+class ITK_TEMPLATE_EXPORT PointsLocator : public Object
 {
 public:
   /** Standard class typedefs. */
@@ -115,8 +115,7 @@ protected:
   virtual void PrintSelf(std::ostream& os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  PointsLocator( const Self& ) ITK_DELETE_FUNCTION;
-  void operator=( const Self& ) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(PointsLocator);
 
   PointsContainerPointer   m_Points;
   SampleAdaptorPointer     m_SampleAdaptor;
