@@ -40,7 +40,6 @@ bool RunTest(
 
   // Transform Type
   typedef itk::VersorRigid3DTransform< double >     TransformType;
-  typedef TransformType::ParametersType             ParametersType;
 
   // calculate image centers
   TransformType::InputPointType   fixedCenter;
@@ -105,7 +104,7 @@ bool RunTest(
   // Verfications for the Geometry Mode
   for(unsigned int k=0; k < Dimension; k++ )
     {
-    if( vcl_fabs( center1[k] - fixedCenter[k] ) > tolerance )
+    if( std::fabs( center1[k] - fixedCenter[k] ) > tolerance )
       {
       std::cerr << "Center differs from expected value" << std::endl;
       std::cerr << "It should be " << fixedCenter << std::endl;
@@ -113,7 +112,7 @@ bool RunTest(
       pass = false;
       break;
       }
-    if( vcl_fabs( translation1[k] - relativeCenter[k] ) > tolerance )
+    if( std::fabs( translation1[k] - relativeCenter[k] ) > tolerance )
       {
       std::cerr << "Translation differs from expected value" << std::endl;
       std::cerr << "It should be " << relativeCenter << std::endl;
@@ -121,7 +120,7 @@ bool RunTest(
       pass = false;
       break;
       }
-    if( vcl_fabs( offset1[k] - relativeCenter[k] ) > tolerance )
+    if( std::fabs( offset1[k] - relativeCenter[k] ) > tolerance )
       {
       std::cerr << "Offset differs from expected value" << std::endl;
       std::cerr << "It should be " << relativeCenter << std::endl;
@@ -146,7 +145,7 @@ bool RunTest(
   // Verfications for the Moments Mode
   for(unsigned int k=0; k < Dimension; k++ )
     {
-    if( vcl_fabs( center2[k] - fixedCenter[k] ) > tolerance )
+    if( std::fabs( center2[k] - fixedCenter[k] ) > tolerance )
       {
       std::cerr << "Center differs from expected value" << std::endl;
       std::cerr << "It should be " << fixedCenter << std::endl;
@@ -154,7 +153,7 @@ bool RunTest(
       pass = false;
       break;
       }
-    if( vcl_fabs( translation2[k] - relativeCenter[k] ) > tolerance )
+    if( std::fabs( translation2[k] - relativeCenter[k] ) > tolerance )
       {
       std::cerr << "Translation differs from expected value" << std::endl;
       std::cerr << "It should be " << relativeCenter << std::endl;
@@ -162,7 +161,7 @@ bool RunTest(
       pass = false;
       break;
       }
-    if( vcl_fabs( offset2[k] - relativeCenter[k] ) > tolerance )
+    if( std::fabs( offset2[k] - relativeCenter[k] ) > tolerance )
       {
       std::cerr << "Offset differs from expected value" << std::endl;
       std::cerr << "It should be " << relativeCenter << std::endl;
