@@ -39,8 +39,6 @@ int itkCorrelationCoefficientHistogramImageToImageMetricTest(int, char* [])
     // Declare Gaussian Sources
     typedef itk::GaussianImageSource<MovingImageType> MovingImageSourceType;
     typedef itk::GaussianImageSource<FixedImageType>  FixedImageSourceType;
-    typedef MovingImageSourceType::Pointer            MovingImageSourcePointer;
-    typedef FixedImageSourceType::Pointer             FixedImageSourcePointer;
 
     // Note: the following declarations are classical arrays
     FixedImageType::SizeValueType  fixedImageSize[] = {100,  100};
