@@ -172,7 +172,7 @@ bool DoRegistration ()
     // the parameters are negated in order to get the inverse transformation.
     // this only works for comparing translation parameters....
     std::cout << finalParameters[i+offsetOrder] << " == " << -actualParameters[i] << std::endl;
-    if( vnl_math_abs ( finalParameters[i+offsetOrder] - (-actualParameters[i]) ) > tolerance )
+    if( itk::Math::abs ( finalParameters[i+offsetOrder] - (-actualParameters[i]) ) > tolerance )
       {
       std::cout << "Tolerance exceeded at component " << i << std::endl;
       pass = false;
