@@ -50,7 +50,7 @@ namespace itk
  * \ingroup ITKFEMRegistration
  */
 template< typename TFixedImage, typename TMovingImage, typename TDisplacementField >
-class MIRegistrationFunction:
+class ITK_TEMPLATE_EXPORT MIRegistrationFunction:
   public PDEDeformableRegistrationFunction< TFixedImage,
                                             TMovingImage, TDisplacementField >
 {
@@ -101,7 +101,7 @@ public:
   typedef typename InterpolatorType::Pointer                        InterpolatorPointer;
   typedef typename InterpolatorType::PointType                      PointType;
   typedef LinearInterpolateImageFunction< MovingImageType, CoordRepType >
-  DefaultInterpolatorType;
+    DefaultInterpolatorType;
 
   /** Covariant vector type. */
   typedef CovariantVector< double, itkGetStaticConstMacro(ImageDimension) > CovariantVectorType;
@@ -112,41 +112,44 @@ public:
 
   /** Set the moving image interpolator. */
   void SetMovingImageInterpolator(InterpolatorType *ptr)
-  { m_MovingImageInterpolator = ptr; }
+    { m_MovingImageInterpolator = ptr; }
 
   /** Get the moving image interpolator. */
   InterpolatorType * GetMovingImageInterpolator(void)
-  { return m_MovingImageInterpolator; }
+    { return m_MovingImageInterpolator; }
 
   /** This class uses a constant timestep of 1. */
   virtual TimeStepType ComputeGlobalTimeStep( void *itkNotUsed(GlobalData) ) const ITK_OVERRIDE
-  { return m_TimeStep; }
+    { return m_TimeStep; }
 
   /** Return a pointer to a global data structure that is passed to
-   * this object from the solver at each calculation.  */
+   * this object from the solver at each calculation. */
   virtual void * GetGlobalDataPointer() const ITK_OVERRIDE
-  {
-    GlobalDataStruct *global = new GlobalDataStruct();
+    {
+      GlobalDataStruct *global = new GlobalDataStruct();
 
-    return global;
-  }
+      return global;
+    }
 
   /** Release memory for global data structure. */
   virtual void ReleaseGlobalDataPointer(void *GlobalData) const ITK_OVERRIDE
-  { delete (GlobalDataStruct *)GlobalData;  }
+    { delete (GlobalDataStruct *)GlobalData; }
 
   /** Set the object's state before each iteration. */
   virtual void InitializeIteration() ITK_OVERRIDE;
 
-  /** This method is called by a finite difference solver image filter at
-   * each pixel that does not lie on a data set boundary */
-  virtual PixelType  ComputeUpdate( const NeighborhoodType & neighborhood,
+  /** Compute update at a non boundary neighbourhood.
+   * This method is called by a finite difference solver image filter at each
+   * pixel that does not lie on a data set boundary. */
+  virtual PixelType ComputeUpdate( const NeighborhoodType & neighborhood,
                                     void *globalData,
                                     const FloatOffsetType & offset = FloatOffsetType(0.0) ) ITK_OVERRIDE;
 
-  void SetMinNorm(float ts = 1.0) { m_Minnorm = ts; }
+  void SetMinNorm( float ts = 1.0 )
+    { m_Minnorm = ts; }
 
-  void SetDoInverse(bool b = false) { m_DoInverse = b; }
+  void SetDoInverse( bool b = false )
+    { m_DoInverse = b; }
 
 protected:
   MIRegistrationFunction();
@@ -162,24 +165,18 @@ protected:
     FixedImageNeighborhoodIteratorType m_FixedImageIterator;
   };
 
+private:
+  ITK_DISALLOW_COPY_AND_ASSIGN(MIRegistrationFunction);
+
   /** The global timestep. */
   TimeStepType m_TimeStep;
 
-private:
-  MIRegistrationFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
-
-  /** Cache fixed image information. */
   SpacingType m_FixedImageSpacing;
   PointType   m_FixedImageOrigin;
 
-  /** Function to compute derivatives of the fixed image. */
   GradientCalculatorPointer m_FixedImageGradientCalculator;
-
-  /** Function to compute derivatives of the moving image. */
   GradientCalculatorPointer m_MovingImageGradientCalculator;
 
-  /** Function to interpolate the moving image. */
   InterpolatorPointer m_MovingImageInterpolator;
 
   /** Threshold below which the denominator term is considered zero. */
