@@ -58,7 +58,7 @@ namespace fem
 
 
 template <typename TFixedImage, typename TMovingImage, typename TMaskImage, typename TMesh, typename TDeformationField>
-class PhysicsBasedNonRigidRegistrationMethod : public ImageToImageFilter<TMovingImage, TDeformationField>
+class ITK_TEMPLATE_EXPORT PhysicsBasedNonRigidRegistrationMethod : public ImageToImageFilter<TMovingImage, TDeformationField>
 {
 public:
   typedef PhysicsBasedNonRigidRegistrationMethod               Self;
@@ -164,10 +164,8 @@ protected:
   virtual void GenerateData() ITK_OVERRIDE;
 
 private:
-  PhysicsBasedNonRigidRegistrationMethod( const PhysicsBasedNonRigidRegistrationMethod & ) ITK_DELETE_FUNCTION;
-  void operator=( const PhysicsBasedNonRigidRegistrationMethod & ) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(PhysicsBasedNonRigidRegistrationMethod);
 
-  // algorithm parameters
   double         m_SelectFraction;
   unsigned int   m_NonConnectivity;
   ImageSizeType  m_BlockRadius;
