@@ -171,8 +171,7 @@ protected:
   mutable double m_GradientStep;
 
 private:
-  GPUPDEDeformableRegistrationFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GPUPDEDeformableRegistrationFunction);
 
 };
 } // end namespace itk
