@@ -67,7 +67,7 @@ namespace itk
 template< typename TFixedImage, typename TMovingImage, typename TDisplacementField,
           typename TParentImageFilter = itk::DemonsRegistrationFilter< TFixedImage, TMovingImage, TDisplacementField >
           >
-class GPUDemonsRegistrationFilter :
+class ITK_TEMPLATE_EXPORT GPUDemonsRegistrationFilter :
   public GPUPDEDeformableRegistrationFilter< TFixedImage, TMovingImage,
                                              TDisplacementField, TParentImageFilter >
 {
@@ -143,8 +143,7 @@ protected:
   virtual void ApplyUpdate(const TimeStepType& dt) ITK_OVERRIDE;
 
 private:
-  GPUDemonsRegistrationFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GPUDemonsRegistrationFilter);
 
   bool m_UseMovingImageGradient;
 };
@@ -187,8 +186,7 @@ public:
   }
 
 private:
-  GPUDemonsRegistrationFilterFactory(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GPUDemonsRegistrationFilterFactory);
 
 #define OverrideDemonsRegistrationFilterTypeMacro(ipt,opt,dm) \
     { \
