@@ -54,7 +54,7 @@ namespace itk
 itkGPUKernelClassMacro(GPUDemonsRegistrationFunctionKernel);
 
 template< typename TFixedImage, typename TMovingImage, typename TDisplacementField >
-class GPUDemonsRegistrationFunction :
+class ITK_TEMPLATE_EXPORT GPUDemonsRegistrationFunction :
   public GPUPDEDeformableRegistrationFunction< TFixedImage,
                                                TMovingImage,
                                                TDisplacementField >
@@ -239,8 +239,7 @@ protected:
   int m_ComputeUpdateGPUKernelHandle;
 
 private:
-  GPUDemonsRegistrationFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GPUDemonsRegistrationFunction);
 
   /** Cache fixed image information. */
   //SpacingType                  m_FixedImageSpacing;
