@@ -78,7 +78,7 @@ itkGPUKernelClassMacro(GPUPDEDeformableRegistrationFilterKernel);
 template< typename TFixedImage, typename TMovingImage, typename TDisplacementField,
           typename TParentImageFilter = PDEDeformableRegistrationFilter< TFixedImage, TMovingImage, TDisplacementField >
           >
-class GPUPDEDeformableRegistrationFilter :
+class ITK_TEMPLATE_EXPORT GPUPDEDeformableRegistrationFilter :
   public GPUDenseFiniteDifferenceImageFilter< TDisplacementField, TDisplacementField, TParentImageFilter >
 {
 public:
@@ -212,8 +212,7 @@ protected:
   virtual void GenerateInputRequestedRegion() ITK_OVERRIDE;
 
 private:
-  GPUPDEDeformableRegistrationFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GPUPDEDeformableRegistrationFilter);
 
   /** Temporary deformation field use for smoothing the
    * the deformation field. */
