@@ -73,7 +73,7 @@ template <typename TFixedImage, typename TMovingImage, typename TVirtualImage =
           typename TInternalComputationValueType = double,
           typename TMetricTraits = DefaultImageToImageMetricTraitsv4<TFixedImage,TMovingImage,TVirtualImage,TInternalComputationValueType>
           >
-class CorrelationImageToImageMetricv4 :
+class ITK_TEMPLATE_EXPORT CorrelationImageToImageMetricv4 :
   public ImageToImageMetricv4<TFixedImage, TMovingImage, TVirtualImage, TInternalComputationValueType, TMetricTraits>
 {
 public:
@@ -156,8 +156,7 @@ protected:
   void PrintSelf(std::ostream& os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  CorrelationImageToImageMetricv4(const Self &) ITK_DELETE_FUNCTION;
-  void operator = (const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(CorrelationImageToImageMetricv4);
 };
 
 } // end namespace itk
