@@ -33,7 +33,7 @@ namespace itk
  * \ingroup ITKMetricsv4
  */
 template < typename TDomainPartitioner, typename TImageToImageMetric, typename TCorrelationMetric >
-class CorrelationImageToImageMetricv4HelperThreader
+class ITK_TEMPLATE_EXPORT CorrelationImageToImageMetricv4HelperThreader
   : public ImageToImageMetricv4GetValueAndDerivativeThreader< TDomainPartitioner, TImageToImageMetric >
 {
 public:
@@ -117,8 +117,7 @@ protected:
   }
 
 private:
-  CorrelationImageToImageMetricv4HelperThreader( const Self & ) ITK_DELETE_FUNCTION;
-  void operator=( const Self & ) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(CorrelationImageToImageMetricv4HelperThreader);
 
   struct CorrelationMetricPerThreadStruct
     {
