@@ -55,7 +55,7 @@ template <typename TFixedImage, typename TMovingImage, typename TVirtualImage =
           typename TInternalComputationValueType = double,
           typename TMetricTraits = DefaultImageToImageMetricTraitsv4<TFixedImage,TMovingImage,TVirtualImage,TInternalComputationValueType>
           >
-class DemonsImageToImageMetricv4 :
+class ITK_TEMPLATE_EXPORT DemonsImageToImageMetricv4 :
   public ImageToImageMetricv4<TFixedImage, TMovingImage, TVirtualImage, TInternalComputationValueType, TMetricTraits>
 {
 public:
@@ -142,8 +142,7 @@ private:
   /* Used to normalize derivative calculation. Automatically calculated */
   TInternalComputationValueType   m_Normalizer;
 
-  DemonsImageToImageMetricv4(const Self &) ITK_DELETE_FUNCTION;
-  void operator = (const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(DemonsImageToImageMetricv4);
 };
 
 } // end namespace itk
