@@ -168,7 +168,7 @@ template<typename TFixedImage,typename TMovingImage,typename TVirtualImage = TFi
          typename TInternalComputationValueType = double,
          typename TMetricTraits = DefaultImageToImageMetricTraitsv4< TFixedImage, TMovingImage, TVirtualImage, TInternalComputationValueType >
          >
-class ImageToImageMetricv4
+class ITK_TEMPLATE_EXPORT ImageToImageMetricv4
   : public ObjectToObjectMetric<TFixedImage::ImageDimension, TMovingImage::ImageDimension, TVirtualImage, TInternalComputationValueType>
 {
 public:
@@ -193,7 +193,7 @@ public:
   typedef typename Superclass::ParametersType       ParametersType;
   typedef typename Superclass::ParametersValueType  ParametersValueType;
 
-  /** Graident source type */
+  /** Gradient source type */
   typedef typename Superclass::GradientSourceType GradientSourceType;
 
   /** Dimension type */
@@ -747,8 +747,7 @@ private:
    *  GetValue implementation is improved. */
   mutable bool m_HaveMadeGetValueWarning;
 
-  ImageToImageMetricv4(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ImageToImageMetricv4);
 
   /** Keep track of the number of sampled fixed points that are
    * deemed invalid during conversion to virtual domain.
