@@ -41,7 +41,7 @@ namespace itk
  *
  * \ingroup ITKMetricsv4 */
 template < typename TDomainPartitioner, typename TImageToImageMetricv4 >
-class ImageToImageMetricv4GetValueAndDerivativeThreaderBase
+class ITK_TEMPLATE_EXPORT ImageToImageMetricv4GetValueAndDerivativeThreaderBase
   : public DomainThreader< TDomainPartitioner, TImageToImageMetricv4 >
 {
 public:
@@ -191,8 +191,7 @@ protected:
   mutable NumberOfParametersType                      m_CachedNumberOfLocalParameters;
 
 private:
-  ImageToImageMetricv4GetValueAndDerivativeThreaderBase( const Self & ) ITK_DELETE_FUNCTION;
-  void operator=( const Self & ) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ImageToImageMetricv4GetValueAndDerivativeThreaderBase);
 };
 
 } // end namespace itk
