@@ -41,7 +41,7 @@ template <typename TFixedImage, typename TMovingImage, typename TVirtualImage =
           typename TInternalComputationValueType = double,
           typename TMetricTraits = DefaultImageToImageMetricTraitsv4<TFixedImage,TMovingImage,TVirtualImage,TInternalComputationValueType>
           >
-class MeanSquaresImageToImageMetricv4 :
+class ITK_TEMPLATE_EXPORT MeanSquaresImageToImageMetricv4 :
   public ImageToImageMetricv4<TFixedImage, TMovingImage, TVirtualImage, TInternalComputationValueType, TMetricTraits>
 {
 public:
@@ -93,8 +93,7 @@ protected:
   void PrintSelf(std::ostream& os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  MeanSquaresImageToImageMetricv4(const Self &) ITK_DELETE_FUNCTION;
-  void operator = (const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(MeanSquaresImageToImageMetricv4);
 };
 
 } // end namespace itk
