@@ -68,7 +68,7 @@ namespace itk
 
 template<typename TFixedPointSet,  typename TMovingPointSet,
   class TInternalComputationValueType = double>
-class PointSetToPointSetMetricv4
+class ITK_TEMPLATE_EXPORT PointSetToPointSetMetricv4
 : public ObjectToObjectMetric<TFixedPointSet::PointDimension, TMovingPointSet::PointDimension,
    Image<TInternalComputationValueType, TFixedPointSet::PointDimension>, TInternalComputationValueType>
 {
@@ -413,8 +413,7 @@ protected:
 
 
 private:
-  PointSetToPointSetMetricv4( const Self & ) ITK_DELETE_FUNCTION;
-  void operator=( const Self & ) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(PointSetToPointSetMetricv4);
 
   mutable bool m_MovingTransformPointLocatorsNeedInitialization;
   mutable bool m_FixedTransformPointLocatorsNeedInitialization;
