@@ -83,7 +83,7 @@ int itkExpectationBasedPointSetMetricRegistrationTest( int argc, char *argv[] )
 /*
   // Having trouble with these, as soon as there's a slight rotation added.
   unsigned long count = 0;
-  for( float theta = 0; theta < 2.0 * vnl_math::pi; theta += 0.1 )
+  for( float theta = 0; theta < 2.0 * itk::Math::pi; theta += 0.1 )
     {
     float radius = 100.0;
     PointType fixedPoint;
@@ -92,8 +92,8 @@ int itkExpectationBasedPointSetMetricRegistrationTest( int argc, char *argv[] )
     fixedPoints->SetPoint( count, fixedPoint );
 
     PointType movingPoint;
-    movingPoint[0] = 2 * radius * std::cos( theta + (0.02 * vnl_math::pi) ) + 2.0;
-    movingPoint[1] = radius * std::sin( theta + (0.02 * vnl_math::pi) ) + 2.0;
+    movingPoint[0] = 2 * radius * std::cos( theta + (0.02 * itk::Math::pi) ) + 2.0;
+    movingPoint[1] = radius * std::sin( theta + (0.02 * itk::Math::pi) ) + 2.0;
     movingPoints->SetPoint( count, movingPoint );
 
     count++;
@@ -107,7 +107,7 @@ int itkExpectationBasedPointSetMetricRegistrationTest( int argc, char *argv[] )
     offset[d] = 2.0;
     }
   unsigned long count = 0;
-  for( float theta = 0; theta < 2.0 * vnl_math::pi; theta += 0.1 )
+  for( float theta = 0; theta < 2.0 * itk::Math::pi; theta += 0.1 )
     {
     PointType fixedPoint;
     float radius = 100.0;
