@@ -42,7 +42,7 @@ int itkExpectationBasedPointSetMetricTestRun()
     offset[d] = 2;
     }
   unsigned long count = 0;
-  for( float theta = 0; theta < 2.0 * vnl_math::pi; theta += 0.1 )
+  for( float theta = 0; theta < 2.0 * itk::Math::pi; theta += 0.1 )
     {
     PointType fixedPoint;
     float radius = 100.0;
