@@ -166,8 +166,7 @@ protected:
   }
 
 private:
-  ImageToImageMetricv4TestMetric(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ImageToImageMetricv4TestMetric);
 
 }; // Metric ///////////////////////////////////////////////////
 
