@@ -45,10 +45,10 @@ int itkLabeledPointSetMetricTestRun()
     }
   unsigned long count = 0;
   float pointSetRadius = 100.0;
-  for( float theta = 0; theta < 2.0 * vnl_math::pi; theta += 0.1 )
+  for( float theta = 0; theta < 2.0 * itk::Math::pi; theta += 0.1 )
     {
     LabelType label = 1;
-    if( theta > vnl_math::pi )
+    if( theta > itk::Math::pi )
       {
       label = 2;
       }
