@@ -50,7 +50,7 @@ namespace itk
  * \ingroup ITKPDEDeformableRegistration
  */
 template< typename TFixedImage, typename TMovingImage, typename TDisplacementField >
-class DemonsRegistrationFunction:
+class ITK_TEMPLATE_EXPORT DemonsRegistrationFunction:
   public PDEDeformableRegistrationFunction< TFixedImage,
                                             TMovingImage,
                                             TDisplacementField >
@@ -203,8 +203,7 @@ protected:
   };
 
 private:
-  DemonsRegistrationFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(DemonsRegistrationFunction);
 
   /** Cache fixed image information. */
   //SpacingType                  m_FixedImageSpacing;
