@@ -88,7 +88,7 @@ namespace itk
  * \ingroup ITKPDEDeformableRegistration
  */
 template< typename TFixedImage, typename TMovingImage, typename TDisplacementField >
-class LevelSetMotionRegistrationFilter:
+class ITK_TEMPLATE_EXPORT LevelSetMotionRegistrationFilter:
   public PDEDeformableRegistrationFilter< TFixedImage, TMovingImage,
                                           TDisplacementField >
 {
@@ -196,8 +196,7 @@ protected:
   virtual bool Halt() ITK_OVERRIDE;
 
 private:
-  LevelSetMotionRegistrationFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(LevelSetMotionRegistrationFilter);
 };
 } // end namespace itk
 
