@@ -51,7 +51,7 @@ namespace itk
  * \ingroup ITKPDEDeformableRegistration
  */
 template< typename TFixedImage, typename TMovingImage, typename TDisplacementField >
-class LevelSetMotionRegistrationFunction:
+class ITK_TEMPLATE_EXPORT LevelSetMotionRegistrationFunction:
   public PDEDeformableRegistrationFunction< TFixedImage,
                                             TMovingImage,
                                             TDisplacementField >
@@ -224,8 +224,7 @@ protected:
   };
 
 private:
-  LevelSetMotionRegistrationFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(LevelSetMotionRegistrationFunction);
 
   /** Cache fixed image information. */
   SpacingType m_FixedImageSpacing;
