@@ -58,7 +58,7 @@ namespace itk
  * \ingroup ITKPDEDeformableRegistration
  */
 template< typename TFixedImage, typename TMovingImage, typename TDisplacementField >
-class SymmetricForcesDemonsRegistrationFunction:
+class ITK_TEMPLATE_EXPORT SymmetricForcesDemonsRegistrationFunction:
   public PDEDeformableRegistrationFunction< TFixedImage,
                                             TMovingImage, TDisplacementField >
 {
@@ -189,8 +189,7 @@ protected:
   };
 
 private:
-  SymmetricForcesDemonsRegistrationFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(SymmetricForcesDemonsRegistrationFunction);
 
   /** Cache fixed image information. */
   SpacingType m_FixedImageSpacing;
