@@ -46,7 +46,7 @@ template<typename TFixedImage, typename TMovingImage, typename TOutputTransform
   BSplineSmoothingOnUpdateDisplacementFieldTransform<double, TFixedImage::ImageDimension>,
   typename TVirtualImage = TFixedImage,
   typename TPointSet = PointSet<unsigned int, TFixedImage::ImageDimension> >
-class BSplineSyNImageRegistrationMethod
+class ITK_TEMPLATE_EXPORT BSplineSyNImageRegistrationMethod
 : public SyNImageRegistrationMethod<TFixedImage, TMovingImage, TOutputTransform, TVirtualImage, TPointSet>
 {
 public:
@@ -142,8 +142,7 @@ protected:
     const ArrayType &, const WeightedMaskImageType *, const BSplinePointSetType * );
 
 private:
-  BSplineSyNImageRegistrationMethod( const Self & ) ITK_DELETE_FUNCTION;
-  void operator=( const Self & ) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BSplineSyNImageRegistrationMethod);
 };
 } // end namespace itk
 
