@@ -91,7 +91,7 @@ template<typename TFixedImage,
          typename TOutputTransform = Transform<double, TFixedImage::ImageDimension, TFixedImage::ImageDimension>,
          typename TVirtualImage = TFixedImage,
          typename TPointSet = PointSet<unsigned int, TFixedImage::ImageDimension> >
-class ImageRegistrationMethodv4
+class ITK_TEMPLATE_EXPORT ImageRegistrationMethodv4
 :public ProcessObject
 {
 public:
@@ -261,6 +261,20 @@ public:
   itkSetMacro( MetricSamplingStrategy, MetricSamplingStrategyType );
   itkGetConstMacro( MetricSamplingStrategy, MetricSamplingStrategyType );
 
+  /** Reinitialize the seed for the random number generators that
+   * select the samples for some metric sampling strategies.
+   *
+   * By initializing the random number generator seed to a value the
+   * same deterministic sampling will be used each Update
+   * execution. On the other hand, calling the method
+   * ReinitializeSeed() without arguments will use the wall clock in
+   * order to have psuedo-random initialization of the seeds. This
+   * will indeed increase the non-deterministic behavior of the
+   * metric.
+   */
+  void MetricSamplingReinitializeSeed();
+  void MetricSamplingReinitializeSeed(int seed);
+
   /** Set the metric sampling percentage. Valid values are in (0.0, 1.0] */
   void SetMetricSamplingPercentage( const RealType );
 
@@ -491,6 +505,11 @@ protected:
   SmoothingSigmasArrayType                                        m_SmoothingSigmasPerLevel;
   bool                                                            m_SmoothingSigmasAreSpecifiedInPhysicalUnits;
 
+  bool                                                            m_ReseedIterator;
+  int                                                             m_RandomSeed;
+  int                                                             m_CurrentRandomSeed;
+
+
   TransformParametersAdaptorsContainerType                        m_TransformParametersAdaptorsPerLevel;
 
   CompositeTransformPointer                                       m_CompositeTransform;
@@ -501,8 +520,7 @@ protected:
 
 
 private:
-  ImageRegistrationMethodv4( const Self & ) ITK_DELETE_FUNCTION;
-  void operator=( const Self & ) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ImageRegistrationMethodv4);
 
   bool                                                            m_InPlace;
 
