@@ -67,7 +67,7 @@ template<typename TFixedImage, typename TMovingImage, typename TOutputTransform
   DisplacementFieldTransform<double, TFixedImage::ImageDimension>,
   typename TVirtualImage = TFixedImage,
   typename TPointSet = PointSet<unsigned int, TFixedImage::ImageDimension> >
-class SyNImageRegistrationMethod
+class ITK_TEMPLATE_EXPORT SyNImageRegistrationMethod
 : public ImageRegistrationMethodv4<TFixedImage, TMovingImage, TOutputTransform, TVirtualImage, TPointSet>
 {
 public:
@@ -235,8 +235,7 @@ protected:
   bool                                                            m_AverageMidPointGradients;
 
 private:
-  SyNImageRegistrationMethod( const Self & ) ITK_DELETE_FUNCTION;
-  void operator=( const Self & ) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(SyNImageRegistrationMethod);
 
   RealType                                                        m_GaussianSmoothingVarianceForTheUpdateField;
   RealType                                                        m_GaussianSmoothingVarianceForTheTotalField;
