@@ -87,7 +87,7 @@ template<typename TFixedImage, typename TMovingImage, typename TOutputTransform
   TimeVaryingBSplineVelocityFieldTransform<double, TFixedImage::ImageDimension>,
   typename TVirtualImage = TFixedImage,
   typename TPointSet = PointSet<unsigned int, TFixedImage::ImageDimension> >
-class TimeVaryingBSplineVelocityFieldImageRegistrationMethod
+class ITK_TEMPLATE_EXPORT TimeVaryingBSplineVelocityFieldImageRegistrationMethod
 : public ImageRegistrationMethodv4<TFixedImage, TMovingImage, TOutputTransform, TVirtualImage, TPointSet>
 {
 public:
@@ -220,8 +220,7 @@ protected:
     const PointSetsContainerType, const TransformBaseType *, const FixedImageMasksContainerType );
 
 private:
-  TimeVaryingBSplineVelocityFieldImageRegistrationMethod( const Self & ) ITK_DELETE_FUNCTION;
-  void operator=( const Self & ) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(TimeVaryingBSplineVelocityFieldImageRegistrationMethod);
 
   DisplacementFieldTransformPointer                   m_IdentityDisplacementFieldTransform;
 
