@@ -52,10 +52,11 @@ public:
 
   virtual void Execute(const itk::Object * object, const itk::EventObject & event) ITK_OVERRIDE
     {
-    const TFilter * filter =
-      dynamic_cast< const TFilter * >( object );
+    const TFilter * filter = static_cast< const TFilter * >( object );
     if( typeid( event ) != typeid( itk::IterationEvent ) )
-      { return; }
+      {
+      return;
+      }
 
     unsigned int currentLevel = filter->GetCurrentLevel();
     typename TFilter::ShrinkFactorsPerDimensionContainerType shrinkFactors = filter->GetShrinkFactorsPerDimension( currentLevel );
@@ -161,9 +162,10 @@ int PerformExpImageRegistration( int argc, char *argv[] )
   typedef itk::GradientDescentOptimizerv4 GradientDescentOptimizerv4Type;
   typename GradientDescentOptimizerv4Type::Pointer affineOptimizer =
     dynamic_cast<GradientDescentOptimizerv4Type * >( affineSimple->GetModifiableOptimizer() );
-  if( !affineOptimizer )
+  if( affineOptimizer.IsNull())
     {
-    itkGenericExceptionMacro( "Error dynamic_cast failed" );
+    std::cerr << "Error dynamic_cast failed" << std::endl;
+    return EXIT_FAILURE;
     }
 #ifdef NDEBUG
   affineOptimizer->SetNumberOfIterations( atoi( argv[5] ) );
@@ -180,7 +182,11 @@ int PerformExpImageRegistration( int argc, char *argv[] )
   {
   typedef itk::ImageToImageMetricv4<FixedImageType, MovingImageType> ImageMetricType;
   typename ImageMetricType::Pointer imageMetric = dynamic_cast<ImageMetricType*>( affineSimple->GetModifiableMetric() );
-  //imageMetric->SetUseFloatingPointCorrection(true);
+  if(imageMetric.IsNull())
+    {
+    std::cerr << "Error dynamic_cast failed" << std::endl;
+    return EXIT_FAILURE;
+    }
   imageMetric->SetFloatingPointCorrectionResolution(1e4);
   }
 
