@@ -26,6 +26,7 @@
 #include "itkGaussianSmoothingOnUpdateDisplacementFieldTransform.h"
 #include "itkGaussianSmoothingOnUpdateDisplacementFieldTransformParametersAdaptor.h"
 #include "itkJointHistogramMutualInformationImageToImageMetricv4.h"
+#include "itkMersenneTwisterRandomVariateGenerator.h"
 
 template<typename TFilter>
 class CommandIterationUpdate : public itk::Command
@@ -396,6 +397,8 @@ int itkSimpleImageRegistrationTest( int argc, char *argv[] )
     exit( 1 );
     }
 
+  itk::Statistics::MersenneTwisterRandomVariateGenerator::GetInstance()->SetSeed( 121212 );
+
   switch( atoi( argv[2] ) )
    {
    case 2:
