@@ -73,7 +73,7 @@ namespace itk
  * \ingroup ITKClassifiers
  */
 template< typename TInputImage, typename TProbabilityPrecisionType = float >
-class BayesianClassifierInitializationImageFilter:
+class ITK_TEMPLATE_EXPORT BayesianClassifierInitializationImageFilter:
   public
   ImageToImageFilter< TInputImage, VectorImage< TProbabilityPrecisionType,
                                                 TInputImage::ImageDimension > >
@@ -176,8 +176,7 @@ protected:
   virtual void GenerateData() ITK_OVERRIDE;
 
 private:
-  BayesianClassifierInitializationImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BayesianClassifierInitializationImageFilter);
 
   bool         m_UserSuppliesMembershipFunctions;
   unsigned int m_NumberOfClasses;
