@@ -68,7 +68,7 @@ namespace itk
 
 template< typename TInputImage,
           typename TClassifiedImage >
-class ImageClassifierBase:
+class ITK_TEMPLATE_EXPORT ImageClassifierBase:
   public ClassifierBase< TInputImage >
 {
 public:
@@ -149,8 +149,7 @@ protected:
   void GenerateData() ITK_OVERRIDE;
 
 private:
-  ImageClassifierBase(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ImageClassifierBase);
 
   typedef typename TInputImage::SizeType InputImageSizeType;
 
