@@ -74,7 +74,7 @@ namespace itk
 template< typename TInputImage,
           typename TMembershipFunction,
           typename TTrainingImage >
-class ImageGaussianModelEstimator:
+class ITK_TEMPLATE_EXPORT ImageGaussianModelEstimator:
   public ImageModelEstimatorBase< TInputImage, TMembershipFunction >
 {
 public:
@@ -131,8 +131,7 @@ protected:
   void GenerateData() ITK_OVERRIDE;
 
 private:
-  ImageGaussianModelEstimator(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ImageGaussianModelEstimator);
 
   typedef vnl_matrix< double > MatrixType;
 
