@@ -29,7 +29,7 @@ namespace itk
  * objects. It provides the basic function definitions that are inherent to
  * ImageModelEstimator objects.
  *
- * This is the SuperClass for the ImageModelEstimator framework. This is an
+ * This is the Superclass for the ImageModelEstimator framework. This is an
  * abstract class defining an interface for all such objects
  * available through the ImageModelEstimator framework in the ITK toolkit.
  *
@@ -61,7 +61,7 @@ namespace itk
  */
 template< typename TInputImage,
           typename TMembershipFunction >
-class ImageModelEstimatorBase:public LightProcessObject
+class ITK_TEMPLATE_EXPORT ImageModelEstimatorBase:public LightProcessObject
 {
 public:
   /** Standard class typedefs. */
@@ -137,8 +137,7 @@ protected:
 
 private:
 
-  ImageModelEstimatorBase(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ImageModelEstimatorBase);
 
   unsigned int m_NumberOfModels;
 
