@@ -78,7 +78,7 @@ namespace itk
  */
 
 template< typename TInputImage, typename TOutputImage >
-class RelabelComponentImageFilter:
+class ITK_TEMPLATE_EXPORT RelabelComponentImageFilter:
   public InPlaceImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -303,8 +303,7 @@ protected:
   };
 
 private:
-  RelabelComponentImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(RelabelComponentImageFilter);
 
   LabelType      m_NumberOfObjects;
   LabelType      m_NumberOfObjectsToPrint;
