@@ -155,8 +155,7 @@ protected:
   virtual ~ScalarConnectedComponentImageFilter() {}
 
 private:
-  ScalarConnectedComponentImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ScalarConnectedComponentImageFilter);
 };
 } // end namespace itk
 
