@@ -71,7 +71,7 @@ namespace itk
  * \ingroup ITKConnectedComponents
  */
 template< typename TInputImage, typename TOutputImage = TInputImage >
-class ThresholdMaximumConnectedComponentsImageFilter:
+class ITK_TEMPLATE_EXPORT ThresholdMaximumConnectedComponentsImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -175,8 +175,7 @@ private:
 
   typedef typename FilterImageType::Pointer FilterImagePointer;
 
-  ThresholdMaximumConnectedComponentsImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ThresholdMaximumConnectedComponentsImageFilter);
 
   //
   // Binary Threshold Filter
