@@ -73,7 +73,7 @@ namespace itk
   * \ingroup ITKDeformableMesh
   */
 template< typename TInputMesh, typename TOutputMesh >
-class DeformableSimplexMesh3DFilter:public MeshToMeshFilter< TInputMesh, TOutputMesh >
+class ITK_TEMPLATE_EXPORT DeformableSimplexMesh3DFilter:public MeshToMeshFilter< TInputMesh, TOutputMesh >
 {
 public:
   /** Standard "Self" typedef. */
@@ -202,8 +202,7 @@ public:
 protected:
   DeformableSimplexMesh3DFilter();
   ~DeformableSimplexMesh3DFilter();
-  DeformableSimplexMesh3DFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(DeformableSimplexMesh3DFilter);
 
   void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
