@@ -133,7 +133,8 @@ public:
  * \ingroup ITKKLMRegionGrowing
  */
 
-class KLMSegmentationRegion;
+// Forward reference because of circular dependencies
+class ITK_FORWARD_EXPORT KLMSegmentationRegion;
 
 class ITKKLMRegionGrowing_EXPORT KLMSegmentationBorder:public SegmentationBorder
 {
@@ -184,8 +185,7 @@ protected:
   virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  KLMSegmentationBorder(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(KLMSegmentationBorder);
 
   double                 m_Lambda;
   KLMSegmentationRegion *m_Region1;
