@@ -1320,7 +1320,7 @@ unsigned int test_regiongrowKLM2D()
   std::cout << "Label entropy = " << labelEntropy << " bits " << std::endl;
   std::cout << "Ideal entropy = " << idealEntropy << " bits " << std::endl;
 
-  if( vnl_math_abs( idealEntropy - labelEntropy ) > 0.2 )
+  if( itk::Math::abs( idealEntropy - labelEntropy ) > 0.2 )
     {
     std::cout << "Test FAILED" << std::endl;
     return EXIT_FAILURE;
@@ -1959,7 +1959,7 @@ unsigned int test_regiongrowKLM3D()
   std::cout << "Label entropy = " << labelEntropy << " bits " << std::endl;
   std::cout << "Ideal entropy = " << idealEntropy << " bits " << std::endl;
 
-  if( vnl_math_abs( idealEntropy - labelEntropy ) > 0.2 )
+  if( itk::Math::abs( idealEntropy - labelEntropy ) > 0.2 )
     {
     std::cout << "Test FAILED" << std::endl;
     return EXIT_FAILURE;
@@ -2365,7 +2365,7 @@ unsigned int test_regiongrowKLM4D()
   std::cout << "Label entropy = " << labelEntropy << " bits " << std::endl;
   std::cout << "Ideal entropy = " << idealEntropy << " bits " << std::endl;
 
-  if( vnl_math_abs( idealEntropy - labelEntropy ) > 0.15 )
+  if( itk::Math::abs( idealEntropy - labelEntropy ) > 0.15 )
     {
     std::cout << "Test FAILED" << std::endl;
     return EXIT_FAILURE;
