@@ -46,7 +46,7 @@ namespace itk
  * \ingroup ITKLabelVoting
  */
 template< typename TInputImage, typename TOutputImage >
-class BinaryMedianImageFilter:
+class ITK_TEMPLATE_EXPORT BinaryMedianImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -138,8 +138,7 @@ protected:
                             ThreadIdType threadId) ITK_OVERRIDE;
 
 private:
-  BinaryMedianImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BinaryMedianImageFilter);
 
   InputSizeType m_Radius;
 
