@@ -115,7 +115,7 @@ namespace itk
  * \ingroup ITKLabelVoting
  */
 template <typename TInputImage, typename TOutputImage = TInputImage, typename TWeights = float >
-class MultiLabelSTAPLEImageFilter :
+class ITK_TEMPLATE_EXPORT MultiLabelSTAPLEImageFilter :
     public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -294,8 +294,7 @@ protected:
   void EnlargeOutputRequestedRegion( DataObject * ) ITK_OVERRIDE;
 
 private:
-  MultiLabelSTAPLEImageFilter(const Self&) ITK_DELETE_FUNCTION;
-  void operator=(const Self&) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(MultiLabelSTAPLEImageFilter);
 
   size_t m_TotalLabelCount;
 
