@@ -36,7 +36,7 @@ namespace itk
  * \ingroup ITKLabelVoting
  */
 template< typename TInputImage, typename TOutputImage >
-class VotingBinaryImageFilter:
+class ITK_TEMPLATE_EXPORT VotingBinaryImageFilter:
   public ImageToImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -139,8 +139,7 @@ protected:
                             ThreadIdType threadId) ITK_OVERRIDE;
 
 private:
-  VotingBinaryImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(VotingBinaryImageFilter);
 
   InputSizeType m_Radius;
 
