@@ -52,7 +52,7 @@ namespace itk
  * \ingroup ITKLabelVoting
  */
 template< typename TImage >
-class VotingBinaryIterativeHoleFillingImageFilter:
+class ITK_TEMPLATE_EXPORT VotingBinaryIterativeHoleFillingImageFilter:
   public ImageToImageFilter< TImage, TImage >
 {
 public:
@@ -149,8 +149,7 @@ protected:
   void GenerateData() ITK_OVERRIDE;
 
 private:
-  VotingBinaryIterativeHoleFillingImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(VotingBinaryIterativeHoleFillingImageFilter);
 
   InputSizeType m_Radius;
 
