@@ -51,7 +51,7 @@ namespace itk
  * \ingroup ITKLevelSets
  */
 template< typename TInputImage, typename TOutputMesh >
-class BinaryMaskToNarrowBandPointSetFilter:
+class ITK_TEMPLATE_EXPORT BinaryMaskToNarrowBandPointSetFilter:
   public ImageToMeshFilter< TInputImage, TOutputMesh >
 {
 public:
@@ -142,8 +142,7 @@ protected:
   void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
-  BinaryMaskToNarrowBandPointSetFilter(const BinaryMaskToNarrowBandPointSetFilter &) ITK_DELETE_FUNCTION;
-  void operator=(const BinaryMaskToNarrowBandPointSetFilter &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BinaryMaskToNarrowBandPointSetFilter);
 
   DistanceFilterPointer m_DistanceFilter;
   RescaleFilterPointer  m_RescaleFilter;
