@@ -32,7 +32,7 @@ namespace itk
  * \ingroup ITKLevelSets
  */
 template< typename TImageType, typename TFeatureImageType = TImageType >
-class CannySegmentationLevelSetFunction:
+class ITK_TEMPLATE_EXPORT CannySegmentationLevelSetFunction:
   public SegmentationLevelSetFunction< TImageType, TFeatureImageType >
 {
 public:
@@ -108,8 +108,7 @@ protected:
 
   virtual ~CannySegmentationLevelSetFunction() {}
 
-  CannySegmentationLevelSetFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(CannySegmentationLevelSetFunction);
 
 private:
   ScalarValueType m_Variance;
