@@ -129,7 +129,7 @@ namespace itk
 template< typename TInputImage,
           typename TFeatureImage,
           typename TOutputPixelType = float >
-class CannySegmentationLevelSetImageFilter:
+class ITK_TEMPLATE_EXPORT CannySegmentationLevelSetImageFilter:
   public SegmentationLevelSetImageFilter< TInputImage, TFeatureImage, TOutputPixelType >
 {
 public:
@@ -190,8 +190,7 @@ protected:
   CannySegmentationLevelSetImageFilter();
 
 private:
-  CannySegmentationLevelSetImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(CannySegmentationLevelSetImageFilter);
 
   typename CannyFunctionType::Pointer m_CannyFunction;
 };
