@@ -59,7 +59,7 @@ namespace itk
  * \ingroup ITKLevelSets
  */
 template< typename TImageType, typename TFeatureImageType = TImageType >
-class CurvesLevelSetFunction:
+class ITK_TEMPLATE_EXPORT CurvesLevelSetFunction:
   public SegmentationLevelSetFunction< TImageType, TFeatureImageType >
 {
 public:
@@ -126,8 +126,7 @@ protected:
 
   virtual ~CurvesLevelSetFunction() {}
 
-  CurvesLevelSetFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(CurvesLevelSetFunction);
 
   void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE
   {
