@@ -90,7 +90,7 @@ namespace itk
  * \ingroup ITKLevelSets
  */
 template< typename TImageType, typename TFeatureImageType = TImageType >
-class GeodesicActiveContourShapePriorLevelSetFunction:
+class ITK_TEMPLATE_EXPORT GeodesicActiveContourShapePriorLevelSetFunction:
   public ShapePriorSegmentationLevelSetFunction< TImageType, TFeatureImageType >
 {
 public:
@@ -105,7 +105,7 @@ public:
   /** Method for creation through the object factory. */
   itkNewMacro(Self);
 
-  /** Run-time type information (and related methods) */
+  /** Run-time type information (and related methods). */
   itkTypeMacro(GeodesicActiveContourShapePriorLevelSetFunction,
                ShapePriorSegmentationLevelSetFunction);
 
@@ -164,14 +164,9 @@ protected:
 
   virtual ~GeodesicActiveContourShapePriorLevelSetFunction() {}
 
-  GeodesicActiveContourShapePriorLevelSetFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(GeodesicActiveContourShapePriorLevelSetFunction);
 
-  void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE
-  {
-    Superclass::PrintSelf(os, indent);
-    os << indent << "DerivativeSigma: " << m_DerivativeSigma << std::endl;
-  }
+  void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
 private:
   double m_DerivativeSigma;
