@@ -70,7 +70,7 @@ namespace itk
  * \ingroup ITKLevelSets
  */
 template< typename TInputImage, typename TSparseOutputImage >
-class ImplicitManifoldNormalVectorFilter:
+class ITK_TEMPLATE_EXPORT ImplicitManifoldNormalVectorFilter:
   public FiniteDifferenceSparseImageFilter< TInputImage, TSparseOutputImage >
 {
 public:
@@ -178,8 +178,7 @@ protected:
   virtual void PostProcessOutput() ITK_OVERRIDE;
 
 private:
-  ImplicitManifoldNormalVectorFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ImplicitManifoldNormalVectorFilter);
 
   /** The finite difference function. */
   NormalFunctionType *m_NormalFunction;
