@@ -71,7 +71,7 @@ namespace itk
  * \ingroup ITKLevelSets
  */
 template< typename TInputImage, typename TOutputImage >
-class IsotropicFourthOrderLevelSetImageFilter:
+class ITK_TEMPLATE_EXPORT IsotropicFourthOrderLevelSetImageFilter:
   public SparseFieldFourthOrderLevelSetImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -121,8 +121,7 @@ protected:
   }
 
 private:
-  IsotropicFourthOrderLevelSetImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(IsotropicFourthOrderLevelSetImageFilter);
 };
 } // end namespace itk
 
