@@ -63,7 +63,7 @@ namespace itk
  * \ingroup ITKLevelSets
   */
 template< typename TImageType >
-class LevelSetFunction:
+class ITK_TEMPLATE_EXPORT LevelSetFunction:
   public FiniteDifferenceFunction< TImageType >
 {
 public:
@@ -342,8 +342,7 @@ protected:
   ScalarValueType m_LaplacianSmoothingWeight;
 
 private:
-  LevelSetFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(LevelSetFunction);
 };
 } // namespace itk
 
