@@ -45,7 +45,7 @@ namespace itk
  * provided, the alogrithm will only search pixels within the
  * narrowband.
  *
- * Implemenation of this class is based on Chapter 11 of
+ * Implementation of this class is based on Chapter 11 of
  * "Level Set Methods and Fast Marching Methods", J.A. Sethian,
  * Cambridge Press, Second edition, 1999.
  *
@@ -54,7 +54,7 @@ namespace itk
  * \ingroup ITKLevelSets
  */
 template< typename TLevelSet >
-class LevelSetNeighborhoodExtractor:
+class ITK_TEMPLATE_EXPORT LevelSetNeighborhoodExtractor:
   public LightProcessObject
 {
 public:
@@ -151,8 +151,7 @@ protected:
   { return m_LastPointIsInside; }
 
 private:
-  LevelSetNeighborhoodExtractor(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(LevelSetNeighborhoodExtractor);
 
   void      GenerateDataFull();
 
@@ -169,8 +168,8 @@ private:
   double               m_NarrowBandwidth;
   NodeContainerPointer m_InputNarrowBand;
 
-  SizeValueType m_ImageSize[SetDimension];
-  typename LevelSetImageType::PixelType m_LargeValue;
+  typename LevelSetImageType::RegionType m_ImageRegion;
+  typename LevelSetImageType::PixelType  m_LargeValue;
 
   std::vector< NodeType > m_NodesUsed;
 
