@@ -42,7 +42,7 @@ namespace itk
  * the level set, the type of the auxiliary/velocity variables and the
  * number of auxiliary/velocity variables.
  *
- * Implemenation of this class is based on Chapter 11 of
+ * Implementation of this class is based on Chapter 11 of
  * "Level Set Methods and Fast Marching Methods", J.A. Sethian,
  * Cambridge Press, Second edition, 1999.
  *
@@ -55,7 +55,7 @@ template<
   typename TAuxValue,
   unsigned int VAuxDimension = 1
   >
-class LevelSetVelocityNeighborhoodExtractor:
+class ITK_TEMPLATE_EXPORT LevelSetVelocityNeighborhoodExtractor:
   public LevelSetNeighborhoodExtractor< TLevelSet >
 {
 public:
@@ -133,8 +133,7 @@ protected:
   virtual double CalculateDistance(Index & index) ITK_OVERRIDE;
 
 private:
-  LevelSetVelocityNeighborhoodExtractor(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(LevelSetVelocityNeighborhoodExtractor);
 
   typename AuxValueContainer::Pointer m_AuxInsideValues;
   typename AuxValueContainer::Pointer m_AuxOutsideValues;
