@@ -15,8 +15,8 @@
  *  limitations under the License.
  *
  *=========================================================================*/
-#ifndef __itkNarrowBandCurvesLevelSetImageFilter_h
-#define __itkNarrowBandCurvesLevelSetImageFilter_h
+#ifndef itkNarrowBandCurvesLevelSetImageFilter_h
+#define itkNarrowBandCurvesLevelSetImageFilter_h
 
 #include "itkNarrowBandLevelSetImageFilter.h"
 #include "itkCurvesLevelSetFunction.h"
@@ -100,7 +100,7 @@ namespace itk
 template< typename TInputImage,
           typename TFeatureImage,
           typename TOutputPixelType = float >
-class NarrowBandCurvesLevelSetImageFilter:
+class ITK_TEMPLATE_EXPORT NarrowBandCurvesLevelSetImageFilter:
   public NarrowBandLevelSetImageFilter< TInputImage, TFeatureImage, TOutputPixelType,
                                         Image< TOutputPixelType,
                                                TInputImage::ImageDimension > >
@@ -153,15 +153,13 @@ protected:
   ~NarrowBandCurvesLevelSetImageFilter() {}
   NarrowBandCurvesLevelSetImageFilter();
 
-  virtual void PrintSelf(std::ostream & os, Indent indent) const;
+  virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
-  NarrowBandCurvesLevelSetImageFilter(const Self &); // purposely not
-                                                     // implemented
-  void operator=(const Self &);                      //purposely not implemented
+  ITK_DISALLOW_COPY_AND_ASSIGN(NarrowBandCurvesLevelSetImageFilter);
 
   /** Overridden from Superclass to handle the case when Propagation
    *  Scaling is zero.*/
-  void GenerateData();
+  void GenerateData() ITK_OVERRIDE;
 
 private:
   CurvesFunctionPointer m_CurvesFunction;
