@@ -35,7 +35,7 @@ namespace itk
  *
  * \par OVERVIEW
  * This object defines the framework for a class of segmentation filters which
- * use level set methods.  These filters work by constructing a ``feature image''
+ * use level set methods.  These filters work by constructing a "feature image"
  * onto which the evolving level set locks as it moves.  In the feature image,
  * values that are close to zero are associated with object boundaries.  An
  * original (or preprocessed) image is given to the filter as the feature image
@@ -145,7 +145,7 @@ template< typename TInputImage,
           typename TOutputPixelType = float,
           typename TOutputImage = Image< TOutputPixelType,
                                       TInputImage::ImageDimension > >
-class NarrowBandLevelSetImageFilter:
+class ITK_TEMPLATE_EXPORT NarrowBandLevelSetImageFilter:
   public NarrowBandImageFilterBase< TInputImage, TOutputImage >
 {
 public:
@@ -358,11 +358,9 @@ public:
 protected:
   virtual ~NarrowBandLevelSetImageFilter() {}
   NarrowBandLevelSetImageFilter();
-  NarrowBandLevelSetImageFilter(const Self &) ITK_DELETE_FUNCTION;
 
   virtual void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE;
 
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
 
   /** Overrides parent implementation */
   virtual void InitializeIteration() ITK_OVERRIDE
@@ -398,6 +396,8 @@ protected:
   typename ChamferFilterType::Pointer m_ChamferFilter;
 
 private:
+  ITK_DISALLOW_COPY_AND_ASSIGN(NarrowBandLevelSetImageFilter);
+
   SegmentationFunctionType *m_SegmentationFunction;
 };
 } // end namespace itk
