@@ -57,7 +57,7 @@ namespace itk
  * \ingroup ITKLevelSets
  */
 template< typename TSparseImageType >
-class NormalVectorDiffusionFunction:
+class ITK_TEMPLATE_EXPORT NormalVectorDiffusionFunction:
   public NormalVectorFunctionBase< TSparseImageType >
 {
 public:
@@ -157,8 +157,7 @@ private:
   /** The isotropic/anisotropic filtering choice parameter. */
   int m_NormalProcessType;
 
-  NormalVectorDiffusionFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(NormalVectorDiffusionFunction);
 };
 } // end namespace itk
 
