@@ -49,7 +49,7 @@ namespace itk
  */
 
 template< typename TSparseImageType >
-class NormalVectorFunctionBase:
+class ITK_TEMPLATE_EXPORT NormalVectorFunctionBase:
   public FiniteDifferenceSparseImageFunction< TSparseImageType >
 {
 public:
@@ -107,8 +107,7 @@ private:
   /** The time step for normal vector finite difference computations. */
   TimeStepType m_TimeStep;
 
-  NormalVectorFunctionBase(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(NormalVectorFunctionBase);
 };
 } // end namespace itk
 
