@@ -33,7 +33,7 @@ namespace itk
  *
  * \par OVERVIEW
  * This object defines the framework for a class of segmentation filters which
- * use level set methods.  These filters work by constructing a ``feature image''
+ * use level set methods.  These filters work by constructing a "feature image"
  * onto which the evolving level set locks as it moves.  In the feature image,
  * values that are close to zero are associated with object boundaries.  An
  * original (or preprocessed) image is given to the filter as the feature image
@@ -143,7 +143,7 @@ namespace itk
 template< typename TInputImage,
           typename TFeatureImage,
           typename TOutputPixelType = float >
-class SegmentationLevelSetImageFilter:
+class ITK_TEMPLATE_EXPORT SegmentationLevelSetImageFilter:
   public SparseFieldLevelSetImageFilter< TInputImage, Image< TOutputPixelType,
                                                              TInputImage::ImageDimension > >
 {
@@ -501,8 +501,7 @@ protected:
   bool m_AutoGenerateSpeedAdvection;
 
 private:
-  SegmentationLevelSetImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(SegmentationLevelSetImageFilter);
 
   SegmentationFunctionType *m_SegmentationFunction;
 };
