@@ -72,7 +72,7 @@ namespace itk
 template< typename TInputImage,
           typename TFeatureImage,
           typename TOutputPixelType = float >
-class ShapePriorSegmentationLevelSetImageFilter:
+class ITK_TEMPLATE_EXPORT ShapePriorSegmentationLevelSetImageFilter:
   public SegmentationLevelSetImageFilter< TInputImage, TFeatureImage,
                                           TOutputPixelType >
 {
@@ -185,8 +185,7 @@ protected:
   void ExtractActiveRegion(NodeContainerType *ptr);
 
 private:
-  ShapePriorSegmentationLevelSetImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ShapePriorSegmentationLevelSetImageFilter);
 
   ShapeFunctionPointer m_ShapeFunction;
   CostFunctionPointer  m_CostFunction;
