@@ -35,7 +35,7 @@ namespace itk
  * \ingroup ITKLevelSets
  */
 template< typename TImageType >
-class NormalBandNode
+class ITK_TEMPLATE_EXPORT NormalBandNode
 {
 public:
   /** The scalar image type. */
@@ -153,7 +153,7 @@ public:
  * \ingroup ITKLevelSets
  */
 template< typename TInputImage, typename TOutputImage >
-class SparseFieldFourthOrderLevelSetImageFilter:
+class ITK_TEMPLATE_EXPORT SparseFieldFourthOrderLevelSetImageFilter:
   public SparseFieldLevelSetImageFilter< TInputImage, TOutputImage >
 {
 public:
@@ -361,8 +361,7 @@ private:
   static const SizeValueType  m_NumVertex;
   static const ValueType      m_DimConst;
 
-  SparseFieldFourthOrderLevelSetImageFilter(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(SparseFieldFourthOrderLevelSetImageFilter);
 };
 } // end namespace itk
 
