@@ -53,7 +53,7 @@ namespace itk
  * \ingroup ITKLevelSets
  */
 template< typename TImageType, typename TFeatureImageType = TImageType >
-class ThresholdSegmentationLevelSetFunction:
+class ITK_TEMPLATE_EXPORT ThresholdSegmentationLevelSetFunction:
   public SegmentationLevelSetFunction< TImageType, TFeatureImageType >
 {
 public:
@@ -169,8 +169,7 @@ protected:
 
   virtual ~ThresholdSegmentationLevelSetFunction(){}
 
-  ThresholdSegmentationLevelSetFunction(const Self &) ITK_DELETE_FUNCTION;
-  void operator=(const Self &) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(ThresholdSegmentationLevelSetFunction);
 
   void PrintSelf(std::ostream & os, Indent indent) const ITK_OVERRIDE
   {
