@@ -117,7 +117,7 @@ public:
   itkNewMacro(Self);
 
   /** Standard Command virtual methods */
-  void Execute(Object *caller, const EventObject &)
+  virtual void Execute(Object *caller, const EventObject &) ITK_OVERRIDE
   {
     std::cout <<
       (dynamic_cast<SparseFieldLevelSetImageFilter< ::LSIFTN::SeedImageType, ::LSIFTN::ImageType> *>(caller))->GetRMSChange()
@@ -127,7 +127,7 @@ public:
               << std::endl;
 
   }
-  void Execute(const Object *, const EventObject &)
+  virtual void Execute(const Object *, const EventObject &) ITK_OVERRIDE
   {
     std::cout << "ack" << std::endl;
 
