@@ -95,7 +95,7 @@ void evaluate_function(::itk::Image<float, 3> *im,
 
 /**
  * \class MorphFunction
- * Subclasses LevelSetFunction, supplying the ``PropagationSpeed'' term.
+ * Subclasses LevelSetFunction, supplying the "PropagationSpeed" term.
  *
  * See LevelSetFunction for more information.
  */
@@ -197,9 +197,9 @@ protected:
     this->SetDifferenceFunction(p);
     m_Iterations = 0;
   }
-  MorphFilter(const Self &) ITK_DELETE_FUNCTION;
 
 private:
+  ITK_DISALLOW_COPY_AND_ASSIGN(MorphFilter);
   unsigned int m_Iterations;
 
   virtual bool Halt() ITK_OVERRIDE
