@@ -47,14 +47,14 @@ namespace itk
  *  \ingroup ITKLevelSetsv4
  */
 template< typename TInputImage, typename TLevelSet >
-class BinaryImageToLevelSetImageAdaptor
+class ITK_TEMPLATE_EXPORT BinaryImageToLevelSetImageAdaptor
 {};
 
 
 /** \brief Partial template specialization for LevelSetDenseImage
  */
 template< typename TInputImage, typename TLevelSetImage >
-class BinaryImageToLevelSetImageAdaptor<
+class ITK_TEMPLATE_EXPORT BinaryImageToLevelSetImageAdaptor<
     TInputImage,
     LevelSetDenseImage< TLevelSetImage > > :
 public BinaryImageToLevelSetImageAdaptorBase<
@@ -111,8 +111,7 @@ protected:
   virtual ~BinaryImageToLevelSetImageAdaptor();
 
 private:
-  BinaryImageToLevelSetImageAdaptor( const Self& ) ITK_DELETE_FUNCTION;
-  void operator = ( const Self& ) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BinaryImageToLevelSetImageAdaptor);
 
   SignedDistanceTransformFilterPointer   m_SignedDistanceTransformFilter;
 };
@@ -125,7 +124,7 @@ private:
  *  \ingroup ITKLevelSetsv4
  */
 template< typename TInput, typename TOutput >
-class BinaryImageToSparseLevelSetImageAdaptorBase :
+class ITK_TEMPLATE_EXPORT BinaryImageToSparseLevelSetImageAdaptorBase :
     public BinaryImageToLevelSetImageAdaptorBase< TInput, TOutput >
 {
 public:
@@ -195,7 +194,7 @@ private:
 /** \brief Partial template specialization for WhitakerSparseLevelSetImage
  */
 template< typename TInput, typename TOutput >
-class BinaryImageToLevelSetImageAdaptor<
+class ITK_TEMPLATE_EXPORT BinaryImageToLevelSetImageAdaptor<
     TInput,
     WhitakerSparseLevelSetImage< TOutput, TInput::ImageDimension > > :
   public BinaryImageToSparseLevelSetImageAdaptorBase<
@@ -269,8 +268,7 @@ protected:
 
 private:
 
-  BinaryImageToLevelSetImageAdaptor( const Self& ) ITK_DELETE_FUNCTION;
-  void operator = ( const Self& ) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BinaryImageToLevelSetImageAdaptor);
 
   /** Fill layer adjacent (OutputLayer) to the layer (LayerToBeScanned) */
   void PropagateToOuterLayers( LayerIdType LayerToBeScanned, LayerIdType OutputLayer, LayerIdType TestValue );
@@ -287,7 +285,7 @@ private:
 /** \brief Partial template specialization for ShiSparseLevelSetImage
  */
 template< typename TInput >
-class BinaryImageToLevelSetImageAdaptor<
+class ITK_TEMPLATE_EXPORT BinaryImageToLevelSetImageAdaptor<
     TInput,
     ShiSparseLevelSetImage< TInput::ImageDimension > > :
 public BinaryImageToSparseLevelSetImageAdaptorBase<
@@ -364,8 +362,7 @@ protected:
 
 private:
 
-  BinaryImageToLevelSetImageAdaptor( const Self& ) ITK_DELETE_FUNCTION;
-  void operator = ( const Self& ) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BinaryImageToLevelSetImageAdaptor);
 };
 
 
@@ -373,7 +370,7 @@ private:
 /** \brief Partial template specialization for MalcolmSparseLevelSetImage
  */
 template< typename TInput >
-class BinaryImageToLevelSetImageAdaptor<
+class ITK_TEMPLATE_EXPORT BinaryImageToLevelSetImageAdaptor<
     TInput,
     MalcolmSparseLevelSetImage< TInput::ImageDimension > > :
   public BinaryImageToSparseLevelSetImageAdaptorBase< TInput, MalcolmSparseLevelSetImage< TInput::ImageDimension > >
@@ -451,8 +448,7 @@ protected:
 
 private:
 
-  BinaryImageToLevelSetImageAdaptor( const Self& ) ITK_DELETE_FUNCTION;
-  void operator = ( const Self& ) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(BinaryImageToLevelSetImageAdaptor);
 };
 
 }
