@@ -33,7 +33,7 @@ namespace itk
  *  \ingroup ITKLevelSetsv4
  */
 template< typename TOutput, unsigned int VDimension >
-class DiscreteLevelSetImage :
+class ITK_TEMPLATE_EXPORT DiscreteLevelSetImage :
   public LevelSetImage< Index< VDimension >, VDimension, TOutput >
 {
 public:
@@ -118,8 +118,7 @@ protected:
 
 private:
 
-  DiscreteLevelSetImage( const Self& ) ITK_DELETE_FUNCTION;
-  void operator = ( const Self& ) ITK_DELETE_FUNCTION;
+  ITK_DISALLOW_COPY_AND_ASSIGN(DiscreteLevelSetImage);
   };
 }
 
